
/*
 * $Id$
 * 
 * Copyright (C) PI 2007-2012. All rights reserved.
 * 
 * Version: 2.0.5
 * 
 */

/**
 * \mainpage
 * Documentation of the PI EDD-Library
 * 
 * \section Introduction Introduction
 * This EDD-Library can be used to write an EDD for PROFIBUS devices which used the PA-Profile Version 3.02.
 * The EDD-Library is a set of ASCII files that can be used by any IEC 61804-3 profile PROFIBUS compatible EDD 
 * interpreter.
 * \section use_of_library How the library can be used
 * The library is designed to be used in conjunction with the IMPORT statement of the EDD language. The files are 
 * organised in a hierachical manner sorted by their block type (PHYSICAL, TRANSDUCER and FUNCTION BLOCK) and 
 * their instance number of the block type. For each type 15 instances are predefined. The only exception is the 
 * physical block. This block exists only once in every device for each type and thus needs only 1 instance inside the library.
 * For each block (type and instance) the library contains a fixed import file and therefore a specific 
 * import reference mechanism. 
 *
 * Additional the library can be used for Identification and Maintenance Functions (I&M). 
 * For 15 instances (different slots) all necessary functions are predefined in the library. For each the library contains a fixed 
 * import file and therefore a specific import reference mechanism. 
 * 
 * The import takes place with IMPORT directive and the corresponding values for the following attributes: 
 * - MANUFACTURER    : is set to __STANDARD to indicate a reference to the PI EDD-Library
 * - DEVICE_TYPE     : reference to the specific block type and instance or I&M data instance  
 * - DEVICE_REVISION : specify the profile version (use 0x0302 for this version of PI EDD-Library)
 * - DD_REVISION     : specify the version of the EDD-Library (0x0001 is the first version of the library)
 * .
 * Example for an import of Physical Block:
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __PHYSICAL_TRANSMITTER, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   ...;
 * }
 * \endcode 
 * 
 * \section device_type Available DEVICE_TYPE
 * A different DEVICE_TYPE for each type and instance of blocks or I&M data for different slots must be used. The DEVICE_TYPE consists of two parts.
 * The first part (byte) of DEVICE_TYPE defines the specific type of block or defines the use of I&M function. 
 * Different types of blocks are, for example PB-Analyser, TB-Temperature, FB-Analog Input and so on.
 * The second part (byte) defines the instance number for this type of block, 1 is the reference to the first instance.
 *
 * For I&M the second part (byte) defines also the instance number, but for each I&M slot a instance must be used.
 *
 * The file 'pa_import_0302.h' contains a list of all available DEVICE_TYPEs.
 * 
 * \subsection phys_device_types Physical Block
 * The following DEVICE_TYPEs for Physical Blocks are defined:
 * - __PHYSICAL_TRANSMITTER
 * - __PHYSICAL_ACTUATOR
 * - __PHYSICAL_DISCRETE_IO
 * - __PHYSICAL_CONTROLLER
 * - __PHYSICAL_ANALYZER
 * - __PHYSICAL_LAB_DEVICE
 * .
 * \subsection trans_device_types Transducer Block
 * The following DEVICE_TYPEs for Transducer Blocks are defined:
 * - __TRANS1_TEMP
 * - __TRANS2_TEMP
 * - __TRANS3_TEMP
 * - __TRANS4_TEMP
 * - __TRANS5_TEMP
 * - __TRANS6_TEMP
 * - __TRANS7_TEMP
 * - __TRANS8_TEMP
 * - __TRANS9_TEMP
 * - __TRANS10_TEMP
 * - __TRANS11_TEMP
 * - __TRANS12_TEMP
 * - __TRANS13_TEMP
 * - __TRANS14_TEMP
 * - __TRANS15_TEMP
 * - __TRANS1_PRESS
 * - __TRANS2_PRESS
 * - __TRANS3_PRESS
 * - __TRANS4_PRESS
 * - __TRANS5_PRESS
 * - __TRANS6_PRESS
 * - __TRANS7_PRESS
 * - __TRANS8_PRESS
 * - __TRANS9_PRESS
 * - __TRANS10_PRESS
 * - __TRANS11_PRESS
 * - __TRANS12_PRESS
 * - __TRANS13_PRESS
 * - __TRANS14_PRESS
 * - __TRANS15_PRESS
 * - __TRANS1_FLOWCM
 * - __TRANS2_FLOWCM
 * - __TRANS3_FLOWCM
 * - __TRANS4_FLOWCM
 * - __TRANS5_FLOWCM
 * - __TRANS6_FLOWCM
 * - __TRANS7_FLOWCM
 * - __TRANS8_FLOWCM
 * - __TRANS9_FLOWCM
 * - __TRANS10_FLOWCM
 * - __TRANS11_FLOWCM
 * - __TRANS12_FLOWCM
 * - __TRANS13_FLOWCM
 * - __TRANS14_FLOWCM
 * - __TRANS15_FLOWCM
 * - __TRANS1_FLOWE
 * - __TRANS2_FLOWE
 * - __TRANS3_FLOWE
 * - __TRANS4_FLOWE
 * - __TRANS5_FLOWE
 * - __TRANS6_FLOWE
 * - __TRANS7_FLOWE
 * - __TRANS8_FLOWE
 * - __TRANS9_FLOWE
 * - __TRANS10_FLOWE
 * - __TRANS11_FLOWE
 * - __TRANS12_FLOWE
 * - __TRANS13_FLOWE
 * - __TRANS14_FLOWE
 * - __TRANS15_FLOWE
 * - __TRANS1_FLOWTM
 * - __TRANS2_FLOWTM
 * - __TRANS3_FLOWTM
 * - __TRANS4_FLOWTM
 * - __TRANS5_FLOWTM
 * - __TRANS6_FLOWTM
 * - __TRANS7_FLOWTM
 * - __TRANS8_FLOWTM
 * - __TRANS9_FLOWTM
 * - __TRANS10_FLOWTM
 * - __TRANS11_FLOWTM
 * - __TRANS12_FLOWTM
 * - __TRANS13_FLOWTM
 * - __TRANS14_FLOWTM
 * - __TRANS15_FLOWTM
 * - __TRANS1_FLOWU
 * - __TRANS2_FLOWU
 * - __TRANS3_FLOWU
 * - __TRANS4_FLOWU
 * - __TRANS5_FLOWU
 * - __TRANS6_FLOWU
 * - __TRANS7_FLOWU
 * - __TRANS8_FLOWU
 * - __TRANS9_FLOWU
 * - __TRANS10_FLOWU
 * - __TRANS11_FLOWU
 * - __TRANS12_FLOWU
 * - __TRANS13_FLOWU
 * - __TRANS14_FLOWU
 * - __TRANS15_FLOWU
 * - __TRANS1_FLOWVA
 * - __TRANS2_FLOWVA
 * - __TRANS3_FLOWVA
 * - __TRANS4_FLOWVA
 * - __TRANS5_FLOWVA
 * - __TRANS6_FLOWVA
 * - __TRANS7_FLOWVA
 * - __TRANS8_FLOWVA
 * - __TRANS9_FLOWVA
 * - __TRANS10_FLOWVA
 * - __TRANS11_FLOWVA
 * - __TRANS12_FLOWVA
 * - __TRANS13_FLOWVA
 * - __TRANS14_FLOWVA
 * - __TRANS15_FLOWVA
 * - __TRANS1_FLOWV
 * - __TRANS2_FLOWV
 * - __TRANS3_FLOWV
 * - __TRANS4_FLOWV
 * - __TRANS5_FLOWV
 * - __TRANS6_FLOWV
 * - __TRANS7_FLOWV
 * - __TRANS8_FLOWV
 * - __TRANS9_FLOWV
 * - __TRANS10_FLOWV
 * - __TRANS11_FLOWV
 * - __TRANS12_FLOWV
 * - __TRANS13_FLOWV
 * - __TRANS14_FLOWV
 * - __TRANS15_FLOWV
 * - __TRANS1_LEVEL
 * - __TRANS2_LEVEL
 * - __TRANS3_LEVEL
 * - __TRANS4_LEVEL
 * - __TRANS5_LEVEL
 * - __TRANS6_LEVEL
 * - __TRANS7_LEVEL
 * - __TRANS8_LEVEL
 * - __TRANS9_LEVEL
 * - __TRANS10_LEVEL
 * - __TRANS11_LEVEL
 * - __TRANS12_LEVEL
 * - __TRANS13_LEVEL
 * - __TRANS14_LEVEL
 * - __TRANS15_LEVEL
 * - __TRANS1_ACTUATOR
 * - __TRANS2_ACTUATOR
 * - __TRANS3_ACTUATOR
 * - __TRANS4_ACTUATOR
 * - __TRANS5_ACTUATOR
 * - __TRANS6_ACTUATOR
 * - __TRANS7_ACTUATOR
 * - __TRANS8_ACTUATOR
 * - __TRANS9_ACTUATOR
 * - __TRANS10_ACTUATOR
 * - __TRANS11_ACTUATOR
 * - __TRANS12_ACTUATOR
 * - __TRANS13_ACTUATOR
 * - __TRANS14_ACTUATOR
 * - __TRANS15_ACTUATOR
 * - __TRANS1_PNEUMATICACTUATOR
 * - __TRANS2_PNEUMATICACTUATOR
 * - __TRANS3_PNEUMATICACTUATOR
 * - __TRANS4_PNEUMATICACTUATOR
 * - __TRANS5_PNEUMATICACTUATOR
 * - __TRANS6_PNEUMATICACTUATOR
 * - __TRANS7_PNEUMATICACTUATOR
 * - __TRANS8_PNEUMATICACTUATOR
 * - __TRANS9_PNEUMATICACTUATOR
 * - __TRANS10_PNEUMATICACTUATOR
 * - __TRANS11_PNEUMATICACTUATOR
 * - __TRANS12_PNEUMATICACTUATOR
 * - __TRANS13_PNEUMATICACTUATOR
 * - __TRANS14_PNEUMATICACTUATOR
 * - __TRANS15_PNEUMATICACTUATOR
 * - __TRANS1_DI
 * - __TRANS2_DI
 * - __TRANS3_DI
 * - __TRANS4_DI
 * - __TRANS5_DI
 * - __TRANS6_DI
 * - __TRANS7_DI
 * - __TRANS8_DI
 * - __TRANS9_DI
 * - __TRANS10_DI
 * - __TRANS11_DI
 * - __TRANS12_DI
 * - __TRANS13_DI
 * - __TRANS14_DI
 * - __TRANS15_DI
 * - __TRANS1_DO
 * - __TRANS2_DO
 * - __TRANS3_DO
 * - __TRANS4_DO
 * - __TRANS5_DO
 * - __TRANS6_DO
 * - __TRANS7_DO
 * - __TRANS8_DO
 * - __TRANS9_DO
 * - __TRANS10_DO
 * - __TRANS11_DO
 * - __TRANS12_DO
 * - __TRANS13_DO
 * - __TRANS14_DO
 * - __TRANS15_DO
 * - __TRANS1_ANALYSIS
 * - __TRANS2_ANALYSIS
 * - __TRANS3_ANALYSIS
 * - __TRANS4_ANALYSIS
 * - __TRANS5_ANALYSIS
 * - __TRANS6_ANALYSIS
 * - __TRANS7_ANALYSIS
 * - __TRANS8_ANALYSIS
 * - __TRANS9_ANALYSIS
 * - __TRANS10_ANALYSIS
 * - __TRANS11_ANALYSIS
 * - __TRANS12_ANALYSIS
 * - __TRANS13_ANALYSIS
 * - __TRANS14_ANALYSIS
 * - __TRANS15_ANALYSIS
 * - __TRANS1_TRANSFER
 * - __TRANS2_TRANSFER
 * - __TRANS3_TRANSFER
 * - __TRANS4_TRANSFER
 * - __TRANS5_TRANSFER
 * - __TRANS6_TRANSFER
 * - __TRANS7_TRANSFER
 * - __TRANS8_TRANSFER
 * - __TRANS9_TRANSFER
 * - __TRANS10_TRANSFER
 * - __TRANS11_TRANSFER
 * - __TRANS12_TRANSFER
 * - __TRANS13_TRANSFER
 * - __TRANS14_TRANSFER
 * - __TRANS15_TRANSFER
 * - __TRANS1_CONTROL_PH
 * - __TRANS2_CONTROL_PH
 * - __TRANS3_CONTROL_PH
 * - __TRANS4_CONTROL_PH
 * - __TRANS5_CONTROL_PH
 * - __TRANS6_CONTROL_PH
 * - __TRANS7_CONTROL_PH
 * - __TRANS8_CONTROL_PH
 * - __TRANS9_CONTROL_PH
 * - __TRANS10_CONTROL_PH
 * - __TRANS11_CONTROL_PH
 * - __TRANS12_CONTROL_PH
 * - __TRANS13_CONTROL_PH
 * - __TRANS14_CONTROL_PH
 * - __TRANS15_CONTROL_PH
 * - __TRANS1_CONTROL_COND
 * - __TRANS2_CONTROL_COND
 * - __TRANS3_CONTROL_COND
 * - __TRANS4_CONTROL_COND
 * - __TRANS5_CONTROL_COND
 * - __TRANS6_CONTROL_COND
 * - __TRANS7_CONTROL_COND
 * - __TRANS8_CONTROL_COND
 * - __TRANS9_CONTROL_COND
 * - __TRANS10_CONTROL_COND
 * - __TRANS11_CONTROL_COND
 * - __TRANS12_CONTROL_COND
 * - __TRANS13_CONTROL_COND
 * - __TRANS14_CONTROL_COND
 * - __TRANS15_CONTROL_COND
 * - __TRANS1_CONTROL_OXYG
 * - __TRANS2_CONTROL_OXYG
 * - __TRANS3_CONTROL_OXYG
 * - __TRANS4_CONTROL_OXYG
 * - __TRANS5_CONTROL_OXYG
 * - __TRANS6_CONTROL_OXYG
 * - __TRANS7_CONTROL_OXYG
 * - __TRANS8_CONTROL_OXYG
 * - __TRANS9_CONTROL_OXYG
 * - __TRANS10_CONTROL_OXYG
 * - __TRANS11_CONTROL_OXYG
 * - __TRANS12_CONTROL_OXYG
 * - __TRANS13_CONTROL_OXYG
 * - __TRANS14_CONTROL_OXYG
 * - __TRANS15_CONTROL_OXYG
 * - __TRANS1_LIMIT
 * - __TRANS2_LIMIT
 * - __TRANS3_LIMIT
 * - __TRANS4_LIMIT
 * - __TRANS5_LIMIT
 * - __TRANS6_LIMIT
 * - __TRANS7_LIMIT
 * - __TRANS8_LIMIT
 * - __TRANS9_LIMIT
 * - __TRANS10_LIMIT
 * - __TRANS11_LIMIT
 * - __TRANS12_LIMIT
 * - __TRANS13_LIMIT
 * - __TRANS14_LIMIT
 * - __TRANS15_LIMIT
 * - __TRANS1_ALARM
 * - __TRANS2_ALARM
 * - __TRANS3_ALARM
 * - __TRANS4_ALARM
 * - __TRANS5_ALARM
 * - __TRANS6_ALARM
 * - __TRANS7_ALARM
 * - __TRANS8_ALARM
 * - __TRANS9_ALARM
 * - __TRANS10_ALARM
 * - __TRANS11_ALARM
 * - __TRANS12_ALARM
 * - __TRANS13_ALARM
 * - __TRANS14_ALARM
 * - __TRANS15_ALARM
 * .
 * \subsection func_device_types Function Block
 * The following DEVICE_TYPEs for Function Blocks are defined:
 * - __FUNC1_AI
 * - __FUNC2_AI
 * - __FUNC3_AI
 * - __FUNC4_AI
 * - __FUNC5_AI
 * - __FUNC6_AI
 * - __FUNC7_AI
 * - __FUNC8_AI
 * - __FUNC9_AI
 * - __FUNC10_AI
 * - __FUNC11_AI
 * - __FUNC12_AI
 * - __FUNC13_AI
 * - __FUNC14_AI
 * - __FUNC15_AI
 * - __FUNC1_TOT
 * - __FUNC2_TOT
 * - __FUNC3_TOT
 * - __FUNC4_TOT
 * - __FUNC5_TOT
 * - __FUNC6_TOT
 * - __FUNC7_TOT
 * - __FUNC8_TOT
 * - __FUNC9_TOT
 * - __FUNC10_TOT
 * - __FUNC11_TOT
 * - __FUNC12_TOT
 * - __FUNC13_TOT
 * - __FUNC14_TOT
 * - __FUNC15_TOT
 * - __FUNC1_AO
 * - __FUNC2_AO
 * - __FUNC3_AO
 * - __FUNC4_AO
 * - __FUNC5_AO
 * - __FUNC6_AO
 * - __FUNC7_AO
 * - __FUNC8_AO
 * - __FUNC9_AO
 * - __FUNC10_AO
 * - __FUNC11_AO
 * - __FUNC12_AO
 * - __FUNC13_AO
 * - __FUNC14_AO
 * - __FUNC15_AO
 * - __FUNC1_DI
 * - __FUNC2_DI
 * - __FUNC3_DI
 * - __FUNC4_DI
 * - __FUNC5_DI
 * - __FUNC6_DI
 * - __FUNC7_DI
 * - __FUNC8_DI
 * - __FUNC9_DI
 * - __FUNC10_DI
 * - __FUNC11_DI
 * - __FUNC12_DI
 * - __FUNC13_DI
 * - __FUNC14_DI
 * - __FUNC15_DI
 * - __FUNC1_DO
 * - __FUNC2_DO
 * - __FUNC3_DO
 * - __FUNC4_DO
 * - __FUNC5_DO
 * - __FUNC6_DO
 * - __FUNC7_DO
 * - __FUNC8_DO
 * - __FUNC9_DO
 * - __FUNC10_DO
 * - __FUNC11_DO
 * - __FUNC12_DO
 * - __FUNC13_DO
 * - __FUNC14_DO
 * - __FUNC15_DO
 * - __FUNC1_LOGBOOK
 * - __FUNC2_LOGBOOK
 * - __FUNC3_LOGBOOK
 * - __FUNC4_LOGBOOK
 * - __FUNC5_LOGBOOK
 * - __FUNC6_LOGBOOK
 * - __FUNC7_LOGBOOK
 * - __FUNC8_LOGBOOK
 * - __FUNC9_LOGBOOK
 * - __FUNC10_LOGBOOK
 * - __FUNC11_LOGBOOK
 * - __FUNC12_LOGBOOK
 * - __FUNC13_LOGBOOK
 * - __FUNC14_LOGBOOK
 * - __FUNC15_LOGBOOK
 * .
* \subsection im_device_types IM Data
 * The following DEVICE_TYPEs for IM Data are defined:
 * - __IAM1_IMDATA
 * - __IAM2_IMDATA
 * - __IAM3_IMDATA
 * - __IAM4_IMDATA
 * - __IAM5_IMDATA
 * - __IAM6_IMDATA
 * - __IAM7_IMDATA
 * - __IAM8_IMDATA
 * - __IAM9_IMDATA
 * - __IAM10_IMDATA
 * - __IAM11_IMDATA
 * - __IAM12_IMDATA
 * - __IAM13_IMDATA
 * - __IAM14_IMDATA
 * - __IAM15_IMDATA
 * .
 * 
 * \subsection adapt_block_number As the block numbers to be adapted (for blocks)
 * The block number of the imported block is predefined to this specific instance number.
 * This number must be redefined for an import to the device specific EDD (order of the blocks).
 * This depends on the device, how many blocks are used inside the device and how the 
 * EDD-Developer wants to use the EDD-Library.
 *
 * \subsection adapt_slot_number As the slot to be adapted (for I&M data)
 * For I&M functions the slot number is predefined over a specific VARIABLE. The DEFAULT_VALUE of 
 * this VARIABLE must be redefined for the specific slot of I&M data.
 * 
 * \section import_m_o_para_cmd Import of mandatory and optional parameter and commands
 * For many blocks it is possible to use predefined macros for import of mandatory and/or optional parameter and commands.
 * The following example is an import of a Physical Block Transmitter with all mandatory parameters and commands defined in the profile definition.
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __PHYSICAL_TRANSMITTER, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   USE_PHYS_MANDATORY_B;
 * }
 * \endcode 
 * For a use of I&M functions use the statement 'EVERYTHING' to import all parameters, commands and so on.
 *
 * Further macro definitions can be found in file 'pa_import_0302.h'.
 *
 * \note Please check and edit the predefined ranges, default values, edit formats, display formats and units of imported variables!
 *
 * \section upload_download Upload and Download
 * The upload and download menu of the device must be compiled from parts of all used blocks.
 * Each import file for a block type and instance contains a documentation of the necessary parameter and 
 * the order of this for upload and download. 
 * \subsection upload_download_change_mode Change the Mode for upload
 * For same parameters it is necessary to switch the mode of the block to MAN. The following example contains this for two
 * analog input function blocks before writing parameter to the device and restore the old mode of this blocks behind the upload.
 * \code
 * MENU upload_variables
 * {
 *   LABEL  [menu_load_to_device];
 *   ITEMS
 *   {
 *     ......
 *   }
 *   PRE_WRITE_ACTIONS
 *   {
 *     prewrite2device
 *   }
 *   POST_WRITE_ACTIONS
 *   {
 *     postwrite2device
 *   }
 * }
 *
 * VARIABLE var_local_func1_AI_MODE_BLK_Actual
 * {
 *   LABEL "";
 *   CLASS LOCAL;
 *   TYPE UNSIGNED_INTEGER (1);
 * }
 * var_local_func2_AI_MODE_BLK_Actual LIKE var_local_func1_AI_MODE_BLK_Actual
 * { REDEFINE LABEL "";}
 *
 * VARIABLE switch_to_MAN_mode
 * {
 *   LABEL  "switch_to_MAN_mode";
 *   CLASS  CONTAINED;
 *   TYPE   ENUMERATED
 *   {
 *     {0,"inactive"},
 *     {1,"active"}
 *   }
 * }
 *
 * METHOD prewrite2device
 * {
 *   LABEL  "";
 *   DEFINITION
 *   {
 *     int choice;
 *
 *     switch_to_MAN_mode=0;
 *     ReadCommand(func1_AI_MODE_BLK_read);
 *     ReadCommand(func2_AI_MODE_BLK_read);
 *     if(func1_AI_MODE_BLK_Actual != 0x10 || func1_AI_MODE_BLK_Actual != 0x10)
 *     {
 *       choice = SELECT_FROM_LIST ("Switch Function Blocks to MAN-Mode?","Cancel;Continue");
 *       if(choice == 1)
 *       {
 *         var_local_func1_AI_MODE_BLK_Actual = func1_AI_MODE_BLK_Actual;
 *         var_local_func2_AI_MODE_BLK_Actual = func2_AI_MODE_BLK_Actual;
 *         func1_AI_TARGET_MODE = 0x10;
 *         func2_AI_TARGET_MODE = 0x10;
 *         WriteCommand(func1_AI_TARGET_MODE_write);
 *         WriteCommand(func2_AI_TARGET_MODE_write);
 *         switch_to_MAN_mode=1;
 *       }
 *     }
 *   }
 * }
 *
 *
 * METHOD postwrite2device
 * {
 *   LABEL  "";
 *   DEFINITION
 *   {
 *     if (switch_to_MAN_mode==1)
 *     {
 *       DELAY(1,"Restoring FB-mode"); 
 *       func1_AI_TARGET_MODE=var_local_func1_AI_MODE_BLK_Actual;
 *       func2_AI_TARGET_MODE=var_local_func2_AI_MODE_BLK_Actual;
 *       WriteCommand(func1_AI_TARGET_MODE_write);
 *       WriteCommand(func2_AI_TARGET_MODE_write);
 *       switch_to_MAN_mode=0;
 *     }
 *   }
 * }
 * \endcode
 *
 * \section Example Simple Example
 * The following simple example shows the use of:
 * - 1 Physical Block, 
 * - 1 Temperature Transducer Block of type thermocouple, 
 * - 1 Pressure Transducer Block, 
 * - 1 Analog Input Function Block, 
 * - 1 Analog Output Function Block, 
 * - 1 TotalizerFunction Block and 
 * - I&M data on slot 0 and 1
 * 
 * from the Library.
 * \subsection Include Necessary Include
 * To use the library it is necessary to include the following file. 
 * \code
 * #include "pa_import_0302.h"
 * \endcode
 *
 * \subsection Device_Information Device Information
 * The following definitions are necessary for all EDDs.
 * \code
 * MANUFACTURER     your manufacturer code, 
 * DEVICE_TYPE      your device type, 
 * DEVICE_REVISION  your device revision,
 * DD_REVISION      your DD revision
 * \endcode
 *
 * \subsection Example_Import_PB Import a specific type of Physical Block
 * First import a type of physical block. The following types are possible.
 * - __PHYSICAL_TRANSMITTER
 * - __PHYSICAL_ACTUATOR
 * - __PHYSICAL_DISCRETE_IO
 * - __PHYSICAL_CONTROLLER
 * - __PHYSICAL_ANALYZER
 * - __PHYSICAL_LAB_DEVICE
 * .
 * 
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __PHYSICAL_TRANSMITTER, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   USE_PHYS_MANDATORY_B;
 *   USE_PHYS_OPTIONAL_B;
 * }
 * \endcode
 * Over the defined macros (pa_import_0302.h) you can add the VARIABLE definitions, the COMMAND definitions and predefinied MENU definitions.
 * 
 * \note Please check and edit the predefined ranges, default values, edit formats and display formats of imported variables!
 *
 * \subsection Example_Import_TB Import of Transducer Block
 * 
 * \subsubsection Example_Import_TB_Temp Temperature Transducer Block
 * The following example imports the Temperature Transducer Block with all mandatory and optional parameter 
 * for type thermocouple. This block must be the first transducer block in the device directory, 
 * otherwise the BLOCK number must be redefined (see the following block)
 * \code
 * STANDARD, DEVICE_TYPE __TRANS1_TEMP, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   USE_TRANS1_TEMP_MANDATORY_B;
 *   USE_TRANS1_TEMP_OPTIONAL_B;
 *   USE_TRANS1_TEMP_THERMOCOUPLE_MANDATORY_B;
 *   USE_TRANS1_TEMP_THERMOCOUPLE_OPTIONAL_B;
 * }
 * \endcode
 * 
 * \subsubsection Example_Import_TB_Press Pressure Transducer Block
 * The following example imports the Pressure Transducer Block with all elements and redefine the BLOCK 
 * number for the second transducer block in the device directory.
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __TRANS1_PRESS, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   EVERYTHING;
 *   REDEFINITIONS
 *   {
 *     BLOCK trans1_Press_block
 *     {
 *       REDEFINE NUMBER 2;
 *     }
 *   }
 * }
 * \endcode
 *
 * \subsection Example_Import_FB Import of Function Blocks
 * 
 * \subsubsection Example_Import_FB_AI_1 Analog Input Function Block 1
 * The following example shows the import of a first Analog Input Function Block with all mandatory and optional elements.
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __FUNC1_AI, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   USE_FUNC1_AI_MANDATORY_B;
 *   USE_FUNC1_AI_OPTIONAL_B;
 * }
 * \endcode
 * 
 * \subsubsection Example_Import_FB_AO_1 Analog Output Function Block 1
 * The following example shows the import of a second Analog Output Function Block with all mandatory and optional elements.
 * For the second Function Block and all additional blocks in the device it is necessary to check the the BLOCK number and if it is necessary to redefine the number.
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __FUNC1_AO, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   USE_FUNC1_AO_MANDATORY_B;
 *   USE_FUNC1_AO_OPTIONAL_B;
 *   REDEFINITIONS
 *   {
 *     BLOCK func1_AO_block
 *     {
 *       REDEFINE NUMBER 2;
 *     }
 *   }
 * }
 * \endcode
 * 
 * \subsubsection Example_Import_FB_TOT_1 Totalizer Function Block 1
 * The following example shows the import of a Totalizer Function Block with all mandatory and optional elements.
 * For this third block in the device directory it is necessary to redefine the BLOCK number.
 * \code
 * IMPORT MANUFACTURER __STANDARD, DEVICE_TYPE __FUNC1_TOT, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   USE_FUNC1_TOT_MANDATORY_B;
 *   USE_FUNC1_TOT_OPTIONAL_B;
 *   REDEFINITIONS
 *   {
 *     BLOCK func1_TOT_block
 *     {
 *       REDEFINE NUMBER 3;
 *     }
 *   }
 * }
 * \endcode
 *
 * \subsection Example_Import_IaM Import of Identification and Maintenance
 * 
 * \subsubsection Example_Import_IaM_Slot0 I&M for Slot 0
 * The following example imports the I&M functions for Slot 0. The slot number is predefined to 0.
 * \code
 * STANDARD, DEVICE_TYPE __IAM1_IMDATA, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   EVERYTHING;
 * }
 * \endcode
 *
 * \subsubsection Example_Import_IaM_Slot1 I&M for Slot 1
 * The following example imports the I&M functions for slot 1. For the use of I&M function 
 * from another slot as 0 the DEFAULT_VALUE of the VARIABLE 'iam2_IMData_SLOT' for setting the 
 * communication slot must be redefined (2 is the instance number).
 * \code
 * STANDARD, DEVICE_TYPE __IAM2_IMDATA, DEVICE_REVISION PROFILE_302, DD_REVISION 0x0001
 * {
 *   EVERYTHING;
 *   REDEFINITIONS
 *   {
 *     VARIABLE iam2_IMData_SLOT
 *     {
 *       REDEFINE TYPE UNSIGNED_INTEGER(1)
 *       {
 *         DEFAULT_VALUE 1;
 *       }
 *     }
 *   }
 * }
 * \endcode
 */

//#define _PDM_ 810

#ifndef __PA_IMPORT_0302_H
#define __PA_IMPORT_0302_H

#ifdef _PDM_
#define CPP_CANT_CONCAT
#endif /* _PDM_ */

/* definitions */
#define FLT_MAX 3.40282346E+38

#define PROFILE_302                             0x0302

#define __STANDARD                              0x0000

#define __PHYSICAL_TRANSMITTER                  0x0101
#define __PHYSICAL_ACTUATOR                     0x0201
#define __PHYSICAL_DISCRETE_IO                  0x0301
#define __PHYSICAL_CONTROLLER                   0x0401
#define __PHYSICAL_ANALYZER                     0x0501
#define __PHYSICAL_LAB_DEVICE                   0x0601

#define __TRANS1_TEMP                           0x1001
#define __TRANS2_TEMP                           0x1002
#define __TRANS3_TEMP                           0x1003
#define __TRANS4_TEMP                           0x1004
#define __TRANS5_TEMP                           0x1005
#define __TRANS6_TEMP                           0x1006
#define __TRANS7_TEMP                           0x1007
#define __TRANS8_TEMP                           0x1008
#define __TRANS9_TEMP                           0x1009
#define __TRANS10_TEMP                          0x100a
#define __TRANS11_TEMP                          0x100b
#define __TRANS12_TEMP                          0x100c
#define __TRANS13_TEMP                          0x100d
#define __TRANS14_TEMP                          0x100e
#define __TRANS15_TEMP                          0x100f

#define __TRANS1_PRESS                          0x1101
#define __TRANS2_PRESS                          0x1102
#define __TRANS3_PRESS                          0x1103
#define __TRANS4_PRESS                          0x1104
#define __TRANS5_PRESS                          0x1105
#define __TRANS6_PRESS                          0x1106
#define __TRANS7_PRESS                          0x1107
#define __TRANS8_PRESS                          0x1108
#define __TRANS9_PRESS                          0x1109
#define __TRANS10_PRESS                         0x110a
#define __TRANS11_PRESS                         0x110b
#define __TRANS12_PRESS                         0x110c
#define __TRANS13_PRESS                         0x110d
#define __TRANS14_PRESS                         0x110e
#define __TRANS15_PRESS                         0x110f

#define __FUNC1_AI                              0x4001
#define __FUNC2_AI                              0x4002
#define __FUNC3_AI                              0x4003
#define __FUNC4_AI                              0x4004
#define __FUNC5_AI                              0x4005
#define __FUNC6_AI                              0x4006
#define __FUNC7_AI                              0x4007
#define __FUNC8_AI                              0x4008
#define __FUNC9_AI                              0x4009
#define __FUNC10_AI                             0x400a
#define __FUNC11_AI                             0x400b
#define __FUNC12_AI                             0x400c
#define __FUNC13_AI                             0x400d
#define __FUNC14_AI                             0x400e
#define __FUNC15_AI                             0x400f

#define __FUNC1_TOT                             0x4101
#define __FUNC2_TOT                             0x4102
#define __FUNC3_TOT                             0x4103
#define __FUNC4_TOT                             0x4104
#define __FUNC5_TOT                             0x4105
#define __FUNC6_TOT                             0x4106
#define __FUNC7_TOT                             0x4107
#define __FUNC8_TOT                             0x4108
#define __FUNC9_TOT                             0x4109
#define __FUNC10_TOT                            0x410a
#define __FUNC11_TOT                            0x410b
#define __FUNC12_TOT                            0x410c
#define __FUNC13_TOT                            0x410d
#define __FUNC14_TOT                            0x410e
#define __FUNC15_TOT                            0x410f

#define __TRANS1_FLOWCM                         0x1201
#define __TRANS2_FLOWCM                         0x1202
#define __TRANS3_FLOWCM                         0x1203
#define __TRANS4_FLOWCM                         0x1204
#define __TRANS5_FLOWCM                         0x1205
#define __TRANS6_FLOWCM                         0x1206
#define __TRANS7_FLOWCM                         0x1207
#define __TRANS8_FLOWCM                         0x1208
#define __TRANS9_FLOWCM                         0x1209
#define __TRANS10_FLOWCM                        0x120a
#define __TRANS11_FLOWCM                        0x120b
#define __TRANS12_FLOWCM                        0x120c
#define __TRANS13_FLOWCM                        0x120d
#define __TRANS14_FLOWCM                        0x120e
#define __TRANS15_FLOWCM                        0x120f

#define __TRANS1_FLOWE                          0x1301
#define __TRANS2_FLOWE                          0x1302
#define __TRANS3_FLOWE                          0x1303
#define __TRANS4_FLOWE                          0x1304
#define __TRANS5_FLOWE                          0x1305
#define __TRANS6_FLOWE                          0x1306
#define __TRANS7_FLOWE                          0x1307
#define __TRANS8_FLOWE                          0x1308
#define __TRANS9_FLOWE                          0x1309
#define __TRANS10_FLOWE                         0x130a
#define __TRANS11_FLOWE                         0x130b
#define __TRANS12_FLOWE                         0x130c
#define __TRANS13_FLOWE                         0x130d
#define __TRANS14_FLOWE                         0x130e
#define __TRANS15_FLOWE                         0x130f

#define __TRANS1_FLOWTM                         0x1401
#define __TRANS2_FLOWTM                         0x1402
#define __TRANS3_FLOWTM                         0x1403
#define __TRANS4_FLOWTM                         0x1404
#define __TRANS5_FLOWTM                         0x1405
#define __TRANS6_FLOWTM                         0x1406
#define __TRANS7_FLOWTM                         0x1407
#define __TRANS8_FLOWTM                         0x1408
#define __TRANS9_FLOWTM                         0x1409
#define __TRANS10_FLOWTM                        0x140a
#define __TRANS11_FLOWTM                        0x140b
#define __TRANS12_FLOWTM                        0x140c
#define __TRANS13_FLOWTM                        0x140d
#define __TRANS14_FLOWTM                        0x140e
#define __TRANS15_FLOWTM                        0x140f

#define __TRANS1_FLOWU                          0x1501
#define __TRANS2_FLOWU                          0x1502
#define __TRANS3_FLOWU                          0x1503
#define __TRANS4_FLOWU                          0x1504
#define __TRANS5_FLOWU                          0x1505
#define __TRANS6_FLOWU                          0x1506
#define __TRANS7_FLOWU                          0x1507
#define __TRANS8_FLOWU                          0x1508
#define __TRANS9_FLOWU                          0x1509
#define __TRANS10_FLOWU                         0x150a
#define __TRANS11_FLOWU                         0x150b
#define __TRANS12_FLOWU                         0x150c
#define __TRANS13_FLOWU                         0x150d
#define __TRANS14_FLOWU                         0x150e
#define __TRANS15_FLOWU                         0x150f

#define __TRANS1_FLOWVA                         0x1601
#define __TRANS2_FLOWVA                         0x1602
#define __TRANS3_FLOWVA                         0x1603
#define __TRANS4_FLOWVA                         0x1604
#define __TRANS5_FLOWVA                         0x1605
#define __TRANS6_FLOWVA                         0x1606
#define __TRANS7_FLOWVA                         0x1607
#define __TRANS8_FLOWVA                         0x1608
#define __TRANS9_FLOWVA                         0x1609
#define __TRANS10_FLOWVA                        0x160a
#define __TRANS11_FLOWVA                        0x160b
#define __TRANS12_FLOWVA                        0x160c
#define __TRANS13_FLOWVA                        0x160d
#define __TRANS14_FLOWVA                        0x160e
#define __TRANS15_FLOWVA                        0x160f

#define __TRANS1_FLOWV                          0x1701
#define __TRANS2_FLOWV                          0x1702
#define __TRANS3_FLOWV                          0x1703
#define __TRANS4_FLOWV                          0x1704
#define __TRANS5_FLOWV                          0x1705
#define __TRANS6_FLOWV                          0x1706
#define __TRANS7_FLOWV                          0x1707
#define __TRANS8_FLOWV                          0x1708
#define __TRANS9_FLOWV                          0x1709
#define __TRANS10_FLOWV                         0x170a
#define __TRANS11_FLOWV                         0x170b
#define __TRANS12_FLOWV                         0x170c
#define __TRANS13_FLOWV                         0x170d
#define __TRANS14_FLOWV                         0x170e
#define __TRANS15_FLOWV                         0x170f

#define __TRANS1_LEVEL                          0x1801
#define __TRANS2_LEVEL                          0x1802
#define __TRANS3_LEVEL                          0x1803
#define __TRANS4_LEVEL                          0x1804
#define __TRANS5_LEVEL                          0x1805
#define __TRANS6_LEVEL                          0x1806
#define __TRANS7_LEVEL                          0x1807
#define __TRANS8_LEVEL                          0x1808
#define __TRANS9_LEVEL                          0x1809
#define __TRANS10_LEVEL                         0x180a
#define __TRANS11_LEVEL                         0x180b
#define __TRANS12_LEVEL                         0x180c
#define __TRANS13_LEVEL                         0x180d
#define __TRANS14_LEVEL                         0x180e
#define __TRANS15_LEVEL                         0x180f

#define __TRANS1_ACTUATOR                       0x1901
#define __TRANS2_ACTUATOR                       0x1902
#define __TRANS3_ACTUATOR                       0x1903
#define __TRANS4_ACTUATOR                       0x1904
#define __TRANS5_ACTUATOR                       0x1905
#define __TRANS6_ACTUATOR                       0x1906
#define __TRANS7_ACTUATOR                       0x1907
#define __TRANS8_ACTUATOR                       0x1908
#define __TRANS9_ACTUATOR                       0x1909
#define __TRANS10_ACTUATOR                      0x190a
#define __TRANS11_ACTUATOR                      0x190b
#define __TRANS12_ACTUATOR                      0x190c
#define __TRANS13_ACTUATOR                      0x190d
#define __TRANS14_ACTUATOR                      0x190e
#define __TRANS15_ACTUATOR                      0x190f

#define __TRANS1_PNEUMATICACTUATOR              0x1a01
#define __TRANS2_PNEUMATICACTUATOR              0x1a02
#define __TRANS3_PNEUMATICACTUATOR              0x1a03
#define __TRANS4_PNEUMATICACTUATOR              0x1a04
#define __TRANS5_PNEUMATICACTUATOR              0x1a05
#define __TRANS6_PNEUMATICACTUATOR              0x1a06
#define __TRANS7_PNEUMATICACTUATOR              0x1a07
#define __TRANS8_PNEUMATICACTUATOR              0x1a08
#define __TRANS9_PNEUMATICACTUATOR              0x1a09
#define __TRANS10_PNEUMATICACTUATOR             0x1a0a
#define __TRANS11_PNEUMATICACTUATOR             0x1a0b
#define __TRANS12_PNEUMATICACTUATOR             0x1a0c
#define __TRANS13_PNEUMATICACTUATOR             0x1a0d
#define __TRANS14_PNEUMATICACTUATOR             0x1a0e
#define __TRANS15_PNEUMATICACTUATOR             0x1a0f

#define __FUNC1_AO                              0x4201
#define __FUNC2_AO                              0x4202
#define __FUNC3_AO                              0x4203
#define __FUNC4_AO                              0x4204
#define __FUNC5_AO                              0x4205
#define __FUNC6_AO                              0x4206
#define __FUNC7_AO                              0x4207
#define __FUNC8_AO                              0x4208
#define __FUNC9_AO                              0x4209
#define __FUNC10_AO                             0x420a
#define __FUNC11_AO                             0x420b
#define __FUNC12_AO                             0x420c
#define __FUNC13_AO                             0x420d
#define __FUNC14_AO                             0x420e
#define __FUNC15_AO                             0x420f

#define __TRANS1_DI                             0x1b01
#define __TRANS2_DI                             0x1b02
#define __TRANS3_DI                             0x1b03
#define __TRANS4_DI                             0x1b04
#define __TRANS5_DI                             0x1b05
#define __TRANS6_DI                             0x1b06
#define __TRANS7_DI                             0x1b07
#define __TRANS8_DI                             0x1b08
#define __TRANS9_DI                             0x1b09
#define __TRANS10_DI                            0x1b0a
#define __TRANS11_DI                            0x1b0b
#define __TRANS12_DI                            0x1b0c
#define __TRANS13_DI                            0x1b0d
#define __TRANS14_DI                            0x1b0e
#define __TRANS15_DI                            0x1b0f

#define __TRANS1_DO                             0x1c01
#define __TRANS2_DO                             0x1c02
#define __TRANS3_DO                             0x1c03
#define __TRANS4_DO                             0x1c04
#define __TRANS5_DO                             0x1c05
#define __TRANS6_DO                             0x1c06
#define __TRANS7_DO                             0x1c07
#define __TRANS8_DO                             0x1c08
#define __TRANS9_DO                             0x1c09
#define __TRANS10_DO                            0x1c0a
#define __TRANS11_DO                            0x1c0b
#define __TRANS12_DO                            0x1c0c
#define __TRANS13_DO                            0x1c0d
#define __TRANS14_DO                            0x1c0e
#define __TRANS15_DO                            0x1c0f

#define __TRANS1_ANALYSIS                       0x1d01
#define __TRANS2_ANALYSIS                       0x1d02
#define __TRANS3_ANALYSIS                       0x1d03
#define __TRANS4_ANALYSIS                       0x1d04
#define __TRANS5_ANALYSIS                       0x1d05
#define __TRANS6_ANALYSIS                       0x1d06
#define __TRANS7_ANALYSIS                       0x1d07
#define __TRANS8_ANALYSIS                       0x1d08
#define __TRANS9_ANALYSIS                       0x1d09
#define __TRANS10_ANALYSIS                      0x1d0a
#define __TRANS11_ANALYSIS                      0x1d0b
#define __TRANS12_ANALYSIS                      0x1d0c
#define __TRANS13_ANALYSIS                      0x1d0d
#define __TRANS14_ANALYSIS                      0x1d0e
#define __TRANS15_ANALYSIS                      0x1d0f

#define __TRANS1_TRANSFER                       0x1e01
#define __TRANS2_TRANSFER                       0x1e02
#define __TRANS3_TRANSFER                       0x1e03
#define __TRANS4_TRANSFER                       0x1e04
#define __TRANS5_TRANSFER                       0x1e05
#define __TRANS6_TRANSFER                       0x1e06
#define __TRANS7_TRANSFER                       0x1e07
#define __TRANS8_TRANSFER                       0x1e08
#define __TRANS9_TRANSFER                       0x1e09
#define __TRANS10_TRANSFER                      0x1e0a
#define __TRANS11_TRANSFER                      0x1e0b
#define __TRANS12_TRANSFER                      0x1e0c
#define __TRANS13_TRANSFER                      0x1e0d
#define __TRANS14_TRANSFER                      0x1e0e
#define __TRANS15_TRANSFER                      0x1e0f

#define __TRANS1_CONTROL_PH                     0x1f01
#define __TRANS2_CONTROL_PH                     0x1f02
#define __TRANS3_CONTROL_PH                     0x1f03
#define __TRANS4_CONTROL_PH                     0x1f04
#define __TRANS5_CONTROL_PH                     0x1f05
#define __TRANS6_CONTROL_PH                     0x1f06
#define __TRANS7_CONTROL_PH                     0x1f07
#define __TRANS8_CONTROL_PH                     0x1f08
#define __TRANS9_CONTROL_PH                     0x1f09
#define __TRANS10_CONTROL_PH                    0x1f0a
#define __TRANS11_CONTROL_PH                    0x1f0b
#define __TRANS12_CONTROL_PH                    0x1f0c
#define __TRANS13_CONTROL_PH                    0x1f0d
#define __TRANS14_CONTROL_PH                    0x1f0e
#define __TRANS15_CONTROL_PH                    0x1f0f

#define __TRANS1_CONTROL_COND                   0x2001
#define __TRANS2_CONTROL_COND                   0x2002
#define __TRANS3_CONTROL_COND                   0x2003
#define __TRANS4_CONTROL_COND                   0x2004
#define __TRANS5_CONTROL_COND                   0x2005
#define __TRANS6_CONTROL_COND                   0x2006
#define __TRANS7_CONTROL_COND                   0x2007
#define __TRANS8_CONTROL_COND                   0x2008
#define __TRANS9_CONTROL_COND                   0x2009
#define __TRANS10_CONTROL_COND                  0x200a
#define __TRANS11_CONTROL_COND                  0x200b
#define __TRANS12_CONTROL_COND                  0x200c
#define __TRANS13_CONTROL_COND                  0x200d
#define __TRANS14_CONTROL_COND                  0x200e
#define __TRANS15_CONTROL_COND                  0x200f

#define __TRANS1_CONTROL_OXYG                   0x2101
#define __TRANS2_CONTROL_OXYG                   0x2102
#define __TRANS3_CONTROL_OXYG                   0x2103
#define __TRANS4_CONTROL_OXYG                   0x2104
#define __TRANS5_CONTROL_OXYG                   0x2105
#define __TRANS6_CONTROL_OXYG                   0x2106
#define __TRANS7_CONTROL_OXYG                   0x2107
#define __TRANS8_CONTROL_OXYG                   0x2108
#define __TRANS9_CONTROL_OXYG                   0x2109
#define __TRANS10_CONTROL_OXYG                  0x210a
#define __TRANS11_CONTROL_OXYG                  0x210b
#define __TRANS12_CONTROL_OXYG                  0x210c
#define __TRANS13_CONTROL_OXYG                  0x210d
#define __TRANS14_CONTROL_OXYG                  0x210e
#define __TRANS15_CONTROL_OXYG                  0x210f

#define __TRANS1_LIMIT                          0x2201
#define __TRANS2_LIMIT                          0x2202
#define __TRANS3_LIMIT                          0x2203
#define __TRANS4_LIMIT                          0x2204
#define __TRANS5_LIMIT                          0x2205
#define __TRANS6_LIMIT                          0x2206
#define __TRANS7_LIMIT                          0x2207
#define __TRANS8_LIMIT                          0x2208
#define __TRANS9_LIMIT                          0x2209
#define __TRANS10_LIMIT                         0x220a
#define __TRANS11_LIMIT                         0x220b
#define __TRANS12_LIMIT                         0x220c
#define __TRANS13_LIMIT                         0x220d
#define __TRANS14_LIMIT                         0x220e
#define __TRANS15_LIMIT                         0x220f

#define __TRANS1_ALARM                          0x2301
#define __TRANS2_ALARM                          0x2302
#define __TRANS3_ALARM                          0x2303
#define __TRANS4_ALARM                          0x2304
#define __TRANS5_ALARM                          0x2305
#define __TRANS6_ALARM                          0x2306
#define __TRANS7_ALARM                          0x2307
#define __TRANS8_ALARM                          0x2308
#define __TRANS9_ALARM                          0x2309
#define __TRANS10_ALARM                         0x230a
#define __TRANS11_ALARM                         0x230b
#define __TRANS12_ALARM                         0x230c
#define __TRANS13_ALARM                         0x230d
#define __TRANS14_ALARM                         0x230e
#define __TRANS15_ALARM                         0x230f

#define __FUNC1_DI                              0x4301
#define __FUNC2_DI                              0x4302
#define __FUNC3_DI                              0x4303
#define __FUNC4_DI                              0x4304
#define __FUNC5_DI                              0x4305
#define __FUNC6_DI                              0x4306
#define __FUNC7_DI                              0x4307
#define __FUNC8_DI                              0x4308
#define __FUNC9_DI                              0x4309
#define __FUNC10_DI                             0x430a
#define __FUNC11_DI                             0x430b
#define __FUNC12_DI                             0x430c
#define __FUNC13_DI                             0x430d
#define __FUNC14_DI                             0x430e
#define __FUNC15_DI                             0x430f

#define __FUNC1_DO                              0x4401
#define __FUNC2_DO                              0x4402
#define __FUNC3_DO                              0x4403
#define __FUNC4_DO                              0x4404
#define __FUNC5_DO                              0x4405
#define __FUNC6_DO                              0x4406
#define __FUNC7_DO                              0x4407
#define __FUNC8_DO                              0x4408
#define __FUNC9_DO                              0x4409
#define __FUNC10_DO                             0x440a
#define __FUNC11_DO                             0x440b
#define __FUNC12_DO                             0x440c
#define __FUNC13_DO                             0x440d
#define __FUNC14_DO                             0x440e
#define __FUNC15_DO                             0x440f

#define __FUNC1_LOGBOOK                         0x4501
#define __FUNC2_LOGBOOK                         0x4502
#define __FUNC3_LOGBOOK                         0x4503
#define __FUNC4_LOGBOOK                         0x4504
#define __FUNC5_LOGBOOK                         0x4505
#define __FUNC6_LOGBOOK                         0x4506
#define __FUNC7_LOGBOOK                         0x4507
#define __FUNC8_LOGBOOK                         0x4508
#define __FUNC9_LOGBOOK                         0x4509
#define __FUNC10_LOGBOOK                        0x450a
#define __FUNC11_LOGBOOK                        0x450b
#define __FUNC12_LOGBOOK                        0x450c
#define __FUNC13_LOGBOOK                        0x450d
#define __FUNC14_LOGBOOK                        0x450e
#define __FUNC15_LOGBOOK                        0x450f

#define __IAM1_IMDATA                           0x7001
#define __IAM2_IMDATA                           0x7002
#define __IAM3_IMDATA                           0x7003
#define __IAM4_IMDATA                           0x7004
#define __IAM5_IMDATA                           0x7005
#define __IAM6_IMDATA                           0x7006
#define __IAM7_IMDATA                           0x7007
#define __IAM8_IMDATA                           0x7008
#define __IAM9_IMDATA                           0x7009
#define __IAM10_IMDATA                          0x700a
#define __IAM11_IMDATA                          0x700b
#define __IAM12_IMDATA                          0x700c
#define __IAM13_IMDATA                          0x700d
#define __IAM14_IMDATA                          0x700e
#define __IAM15_IMDATA                          0x700f

#define USE_PHYS_MANDATORY_BOTH \
	BLOCK phys_block; \
	COLLECTION phys_BLOCK_OBJECT; \
	VARIABLE phys_BLOCK_OBJECT_Reserved; \
	VARIABLE phys_BLOCK_OBJECT_Block_Object; \
	VARIABLE phys_BLOCK_OBJECT_Parent_Class; \
	VARIABLE phys_BLOCK_OBJECT_Class; \
	VARIABLE phys_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE phys_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE phys_BLOCK_OBJECT_DD_Revision; \
	VARIABLE phys_BLOCK_OBJECT_Profile; \
	VARIABLE phys_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE phys_BLOCK_OBJECT_Execution_Time; \
	VARIABLE phys_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE phys_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE phys_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE phys_BLOCK_OBJECT_Number_of_Views; \
	MENU phys_BLOCK_OBJECT_page; \
	COMMAND phys_BLOCK_OBJECT_read; \
	VARIABLE phys_ST_REV; \
	MENU phys_ST_REV_page; \
	COMMAND phys_ST_REV_read; \
	VARIABLE phys_TAG_DESC; \
	MENU phys_TAG_DESC_page; \
	COMMAND phys_TAG_DESC_read; \
	COMMAND phys_TAG_DESC_write; \
	VARIABLE phys_STRATEGY; \
	MENU phys_STRATEGY_page; \
	COMMAND phys_STRATEGY_read; \
	COMMAND phys_STRATEGY_write; \
	VARIABLE phys_ALERT_KEY; \
	MENU phys_ALERT_KEY_page; \
	COMMAND phys_ALERT_KEY_read; \
	COMMAND phys_ALERT_KEY_write; \
	VARIABLE phys_TARGET_MODE; \
	MENU phys_TARGET_MODE_page; \
	COMMAND phys_TARGET_MODE_read; \
	COMMAND phys_TARGET_MODE_write; \
	COLLECTION phys_MODE_BLK; \
	VARIABLE phys_MODE_BLK_Actual; \
	VARIABLE phys_MODE_BLK_Permitted; \
	VARIABLE phys_MODE_BLK_Normal; \
	MENU phys_MODE_BLK_page; \
	COMMAND phys_MODE_BLK_read; \
	COLLECTION phys_ALARM_SUM; \
	VARIABLE phys_ALARM_SUM_Current; \
	VARIABLE phys_ALARM_SUM_Unacknowledged; \
	VARIABLE phys_ALARM_SUM_Unreported; \
	VARIABLE phys_ALARM_SUM_Disabled; \
	MENU phys_ALARM_SUM_page; \
	COMMAND phys_ALARM_SUM_read; \
	VARIABLE phys_SOFTWARE_REVISION; \
	MENU phys_SOFTWARE_REVISION_page; \
	COMMAND phys_SOFTWARE_REVISION_read; \
	VARIABLE phys_HARDWARE_REVISION; \
	MENU phys_HARDWARE_REVISION_page; \
	COMMAND phys_HARDWARE_REVISION_read; \
	VARIABLE phys_DEVICE_MAN_ID; \
	MENU phys_DEVICE_MAN_ID_page; \
	COMMAND phys_DEVICE_MAN_ID_read; \
	VARIABLE phys_DEVICE_ID; \
	MENU phys_DEVICE_ID_page; \
	COMMAND phys_DEVICE_ID_read; \
	VARIABLE phys_DEVICE_SER_NUM; \
	MENU phys_DEVICE_SER_NUM_page; \
	COMMAND phys_DEVICE_SER_NUM_read; \
	VARIABLE phys_DIAGNOSIS; \
	MENU phys_DIAGNOSIS_page; \
	COMMAND phys_DIAGNOSIS_read; \
	VARIABLE phys_DIAGNOSIS_MASK; \
	MENU phys_DIAGNOSIS_MASK_page; \
	COMMAND phys_DIAGNOSIS_MASK_read; \
	COLLECTION phys_FEATURE; \
	VARIABLE phys_FEATURE_Supported; \
	VARIABLE phys_FEATURE_Enabled; \
	MENU phys_FEATURE_page; \
	COMMAND phys_FEATURE_read; \
	VARIABLE phys_COND_STATUS_DIAG; \
	MENU phys_COND_STATUS_DIAG_page; \
	COMMAND phys_COND_STATUS_DIAG_read; \
	COMMAND phys_COND_STATUS_DIAG_write; \
	MENU phys_Diagnosis_page

#define USE_PHYS_MANDATORY_A \
	USE_PHYS_MANDATORY_BOTH; \
	MENU phys_Simple_Dialog_Mandatory_A

#define USE_PHYS_MANDATORY_B \
	USE_PHYS_MANDATORY_BOTH; \
	VARIABLE phys_IDENT_NUMBER_SELECTOR; \
	MENU phys_IDENT_NUMBER_SELECTOR_page; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_read; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_write; \
	COLLECTION phys_VIEW_1; \
	MENU phys_VIEW_1_page; \
	MENU phys_Simple_Dialog_Mandatory_B

#define USE_PHYS_OPTIONAL_BOTH \
	VARIABLE phys_DIAGNOSIS_EXTENSION; \
	MENU phys_DIAGNOSIS_EXTENSION_page; \
	COMMAND phys_DIAGNOSIS_EXTENSION_read; \
	VARIABLE phys_DIAGNOSIS_MASK_EXTENSION; \
	MENU phys_DIAGNOSIS_MASK_EXTENSION_page; \
	COMMAND phys_DIAGNOSIS_MASK_EXTENSION_read; \
	VARIABLE phys_DEVICE_CERTIFICATION; \
	MENU phys_DEVICE_CERTIFICATION_page; \
	COMMAND phys_DEVICE_CERTIFICATION_read; \
	VARIABLE phys_WRITE_LOCKING; \
	MENU phys_WRITE_LOCKING_page; \
	COMMAND phys_WRITE_LOCKING_read; \
	COMMAND phys_WRITE_LOCKING_write; \
	VARIABLE phys_FACTORY_RESET; \
	MENU phys_FACTORY_RESET_page; \
	COMMAND phys_FACTORY_RESET_read; \
	COMMAND phys_FACTORY_RESET_write; \
	VARIABLE phys_DESCRIPTOR; \
	MENU phys_DESCRIPTOR_page; \
	COMMAND phys_DESCRIPTOR_read; \
	COMMAND phys_DESCRIPTOR_write; \
	VARIABLE phys_DEVICE_MESSAGE; \
	MENU phys_DEVICE_MESSAGE_page; \
	COMMAND phys_DEVICE_MESSAGE_read; \
	COMMAND phys_DEVICE_MESSAGE_write; \
	VARIABLE phys_DEVICE_INSTAL_DATE; \
	MENU phys_DEVICE_INSTAL_DATE_page; \
	COMMAND phys_DEVICE_INSTAL_DATE_read; \
	COMMAND phys_DEVICE_INSTAL_DATE_write; \
	VARIABLE phys_LOCAL_OP_ENA; \
	MENU phys_LOCAL_OP_ENA_page; \
	COMMAND phys_LOCAL_OP_ENA_read; \
	COMMAND phys_LOCAL_OP_ENA_write; \
	VARIABLE phys_HW_WRITE_PROTECTION; \
	MENU phys_HW_WRITE_PROTECTION_page; \
	COMMAND phys_HW_WRITE_PROTECTION_read; \
	COLLECTION phys_DIAG_EVENT_SWITCH; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_1_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_1_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_2_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_2_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_3_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_3_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_4_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_4_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_5_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_5_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_6_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_6_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_7_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_7_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_8_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_8_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_9_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_9_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_10_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_10_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_11_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_11_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_12_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_12_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_13_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_13_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_14_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_14_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_15_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_15_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_16_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_16_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_17_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_17_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_18_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_18_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_19_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_19_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_20_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_20_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_21_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_21_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_22_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_22_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_23_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_23_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_24_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_24_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_25_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_25_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_26_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_26_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_27_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_27_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_28_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_28_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_29_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_29_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_30_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_30_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_31_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_31_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_32_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_32_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_33_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_33_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_34_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_34_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_35_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_35_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_36_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_36_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_37_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_37_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_38_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_38_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_39_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_39_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_40_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_40_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_41_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_41_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_42_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_42_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_43_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_43_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_44_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_44_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_45_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_45_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_46_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_46_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_47_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_47_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_48_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_48_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Slot; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Index; \
	MENU phys_DIAG_EVENT_SWITCH_page; \
	COMMAND phys_DIAG_EVENT_SWITCH_read; \
	COMMAND phys_DIAG_EVENT_SWITCH_write; \
	VARIABLE phys_PTA_OP_CODE; \
	MENU phys_PTA_OP_CODE_page; \
	COMMAND phys_PTA_OP_CODE_read; \
	COMMAND phys_PTA_OP_CODE_write; \
	VARIABLE phys_PTA_STATUS; \
	MENU phys_PTA_STATUS_page; \
	COMMAND phys_PTA_STATUS_read; \
	COLLECTION phys_VIEW_2; \
	MENU phys_VIEW_2_page; \
	COLLECTION phys_VIEW_3; \
	MENU phys_VIEW_3_page; \
	COLLECTION phys_VIEW_4; \
	MENU phys_VIEW_4_page; \
	MENU phys_Reset; \
	MENU phys_Reset_page; \
	METHOD phys_method_factory_reset_params; \
	METHOD phys_method_factory_reset_warm; \
	METHOD phys_method_factory_reset_address; \
	METHOD phys_method_factory_reset_device_specific; \
	MENU phys_Dialog_Write_Locking; \
	MENU phys_Dialog_Ident_Number_Selector

#define USE_PHYS_OPTIONAL_A \
	USE_PHYS_OPTIONAL_BOTH; \
	VARIABLE phys_IDENT_NUMBER_SELECTOR; \
	MENU phys_IDENT_NUMBER_SELECTOR_page; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_read; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_write; \
	COLLECTION phys_VIEW_1; \
	MENU phys_VIEW_1_page; \
	MENU phys_Simple_Dialog_Optional_A

#define USE_PHYS_OPTIONAL_B \
	USE_PHYS_OPTIONAL_BOTH; \
	MENU phys_Simple_Dialog_Optional_B

#define USE_PHYS_ANALYZER_MANDATORY_BOTH \
	BLOCK phys_block; \
	COLLECTION phys_BLOCK_OBJECT; \
	VARIABLE phys_BLOCK_OBJECT_Reserved; \
	VARIABLE phys_BLOCK_OBJECT_Block_Object; \
	VARIABLE phys_BLOCK_OBJECT_Parent_Class; \
	VARIABLE phys_BLOCK_OBJECT_Class; \
	VARIABLE phys_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE phys_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE phys_BLOCK_OBJECT_DD_Revision; \
	VARIABLE phys_BLOCK_OBJECT_Profile; \
	VARIABLE phys_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE phys_BLOCK_OBJECT_Execution_Time; \
	VARIABLE phys_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE phys_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE phys_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE phys_BLOCK_OBJECT_Number_of_Views; \
	MENU phys_BLOCK_OBJECT_page; \
	COMMAND phys_BLOCK_OBJECT_read; \
	VARIABLE phys_ST_REV; \
	MENU phys_ST_REV_page; \
	COMMAND phys_ST_REV_read; \
	VARIABLE phys_TAG_DESC; \
	MENU phys_TAG_DESC_page; \
	COMMAND phys_TAG_DESC_read; \
	COMMAND phys_TAG_DESC_write; \
	VARIABLE phys_STRATEGY; \
	MENU phys_STRATEGY_page; \
	COMMAND phys_STRATEGY_read; \
	COMMAND phys_STRATEGY_write; \
	VARIABLE phys_ALERT_KEY; \
	MENU phys_ALERT_KEY_page; \
	COMMAND phys_ALERT_KEY_read; \
	COMMAND phys_ALERT_KEY_write; \
	VARIABLE phys_TARGET_MODE; \
	MENU phys_TARGET_MODE_page; \
	COMMAND phys_TARGET_MODE_read; \
	COMMAND phys_TARGET_MODE_write; \
	COLLECTION phys_MODE_BLK; \
	VARIABLE phys_MODE_BLK_Actual; \
	VARIABLE phys_MODE_BLK_Permitted; \
	VARIABLE phys_MODE_BLK_Normal; \
	MENU phys_MODE_BLK_page; \
	COMMAND phys_MODE_BLK_read; \
	COLLECTION phys_ALARM_SUM; \
	VARIABLE phys_ALARM_SUM_Current; \
	VARIABLE phys_ALARM_SUM_Unacknowledged; \
	VARIABLE phys_ALARM_SUM_Unreported; \
	VARIABLE phys_ALARM_SUM_Disabled; \
	MENU phys_ALARM_SUM_page; \
	COMMAND phys_ALARM_SUM_read; \
	VARIABLE phys_SOFTWARE_REVISION; \
	MENU phys_SOFTWARE_REVISION_page; \
	COMMAND phys_SOFTWARE_REVISION_read; \
	VARIABLE phys_HARDWARE_REVISION; \
	MENU phys_HARDWARE_REVISION_page; \
	COMMAND phys_HARDWARE_REVISION_read; \
	VARIABLE phys_DEVICE_MAN_ID; \
	MENU phys_DEVICE_MAN_ID_page; \
	COMMAND phys_DEVICE_MAN_ID_read; \
	VARIABLE phys_DEVICE_ID; \
	MENU phys_DEVICE_ID_page; \
	COMMAND phys_DEVICE_ID_read; \
	VARIABLE phys_DEVICE_SER_NUM; \
	MENU phys_DEVICE_SER_NUM_page; \
	COMMAND phys_DEVICE_SER_NUM_read; \
	VARIABLE phys_DIAGNOSIS; \
	MENU phys_DIAGNOSIS_page; \
	COMMAND phys_DIAGNOSIS_read; \
	VARIABLE phys_DIAGNOSIS_MASK; \
	MENU phys_DIAGNOSIS_MASK_page; \
	COMMAND phys_DIAGNOSIS_MASK_read; \
	COLLECTION phys_FEATURE; \
	VARIABLE phys_FEATURE_Supported; \
	VARIABLE phys_FEATURE_Enabled; \
	MENU phys_FEATURE_page; \
	COMMAND phys_FEATURE_read; \
	VARIABLE phys_COND_STATUS_DIAG; \
	MENU phys_COND_STATUS_DIAG_page; \
	COMMAND phys_COND_STATUS_DIAG_read; \
	COMMAND phys_COND_STATUS_DIAG_write; \
	VARIABLE phys_DEVICE_CONFIGURATION; \
	MENU phys_DEVICE_CONFIGURATION_page; \
	COMMAND phys_DEVICE_CONFIGURATION_read; \
	VARIABLE phys_INIT_STATE; \
	MENU phys_INIT_STATE_page; \
	COMMAND phys_INIT_STATE_read; \
	COMMAND phys_INIT_STATE_write; \
	VARIABLE phys_DEVICE_STATE; \
	MENU phys_DEVICE_STATE_page; \
	COMMAND phys_DEVICE_STATE_read; \
	COMMAND phys_DEVICE_STATE_write; \
	VARIABLE phys_GLOBAL_STATUS; \
	MENU phys_GLOBAL_STATUS_page; \
	COMMAND phys_GLOBAL_STATUS_read; \
	MENU phys_Diagnosis_page

#define USE_PHYS_ANALYZER_MANDATORY_A \
	USE_PHYS_ANALYZER_MANDATORY_BOTH; \
	MENU phys_Simple_Dialog_Mandatory_A

#define USE_PHYS_ANALYZER_MANDATORY_B \
	USE_PHYS_ANALYZER_MANDATORY_BOTH; \
	VARIABLE phys_IDENT_NUMBER_SELECTOR; \
	MENU phys_IDENT_NUMBER_SELECTOR_page; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_read; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_write; \
	COLLECTION phys_VIEW_1_ANALYZER; \
	VARIABLE phys_ST_REV; \
	COLLECTION phys_MODE_BLK; \
	VARIABLE phys_MODE_BLK_Actual; \
	VARIABLE phys_MODE_BLK_Permitted; \
	VARIABLE phys_MODE_BLK_Normal; \
	COLLECTION phys_ALARM_SUM; \
	VARIABLE phys_ALARM_SUM_Current; \
	VARIABLE phys_ALARM_SUM_Unacknowledged; \
	VARIABLE phys_ALARM_SUM_Unreported; \
	VARIABLE phys_ALARM_SUM_Disabled; \
	VARIABLE phys_DIAGNOSIS; \
	VARIABLE phys_DEVICE_STATE; \
	VARIABLE phys_GLOBAL_STATUS; \
	MENU phys_VIEW_1_ANALYZER_page; \
	COMMAND phys_VIEW_1_ANALYZER_read; \
	MENU phys_Simple_Dialog_Mandatory_B

#define USE_PHYS_ANALYZER_OPTIONAL_BOTH \
	VARIABLE phys_DIAGNOSIS_EXTENSION; \
	MENU phys_DIAGNOSIS_EXTENSION_page; \
	COMMAND phys_DIAGNOSIS_EXTENSION_read; \
	VARIABLE phys_DIAGNOSIS_MASK_EXTENSION; \
	MENU phys_DIAGNOSIS_MASK_EXTENSION_page; \
	COMMAND phys_DIAGNOSIS_MASK_EXTENSION_read; \
	VARIABLE phys_DEVICE_CERTIFICATION; \
	MENU phys_DEVICE_CERTIFICATION_page; \
	COMMAND phys_DEVICE_CERTIFICATION_read; \
	VARIABLE phys_WRITE_LOCKING; \
	MENU phys_WRITE_LOCKING_page; \
	COMMAND phys_WRITE_LOCKING_read; \
	COMMAND phys_WRITE_LOCKING_write; \
	VARIABLE phys_FACTORY_RESET; \
	MENU phys_FACTORY_RESET_page; \
	COMMAND phys_FACTORY_RESET_read; \
	COMMAND phys_FACTORY_RESET_write; \
	VARIABLE phys_DESCRIPTOR; \
	MENU phys_DESCRIPTOR_page; \
	COMMAND phys_DESCRIPTOR_read; \
	COMMAND phys_DESCRIPTOR_write; \
	VARIABLE phys_DEVICE_MESSAGE; \
	MENU phys_DEVICE_MESSAGE_page; \
	COMMAND phys_DEVICE_MESSAGE_read; \
	COMMAND phys_DEVICE_MESSAGE_write; \
	VARIABLE phys_DEVICE_INSTAL_DATE; \
	MENU phys_DEVICE_INSTAL_DATE_page; \
	COMMAND phys_DEVICE_INSTAL_DATE_read; \
	COMMAND phys_DEVICE_INSTAL_DATE_write; \
	VARIABLE phys_LOCAL_OP_ENA; \
	MENU phys_LOCAL_OP_ENA_page; \
	COMMAND phys_LOCAL_OP_ENA_read; \
	COMMAND phys_LOCAL_OP_ENA_write; \
	VARIABLE phys_HW_WRITE_PROTECTION; \
	MENU phys_HW_WRITE_PROTECTION_page; \
	COMMAND phys_HW_WRITE_PROTECTION_read; \
	COLLECTION phys_DIAG_EVENT_SWITCH; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_1_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_1_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_2_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_2_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_3_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_3_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_4_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_4_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_5_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_5_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_6_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_6_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_7_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_7_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_8_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_8_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_9_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_9_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_10_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_10_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_11_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_11_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_12_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_12_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_13_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_13_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_14_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_14_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_15_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_15_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_16_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_16_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_17_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_17_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_18_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_18_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_19_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_19_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_20_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_20_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_21_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_21_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_22_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_22_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_23_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_23_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_24_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_24_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_25_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_25_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_26_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_26_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_27_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_27_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_28_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_28_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_29_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_29_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_30_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_30_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_31_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_31_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_32_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_32_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_33_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_33_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_34_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_34_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_35_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_35_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_36_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_36_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_37_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_37_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_38_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_38_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_39_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_39_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_40_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_40_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_41_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_41_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_42_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_42_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_43_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_43_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_44_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_44_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_45_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_45_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_46_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_46_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_47_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_47_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_48_Diag; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Status_Link_48_Status; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Slot; \
	VARIABLE phys_DIAG_EVENT_SWITCH_Index; \
	MENU phys_DIAG_EVENT_SWITCH_page; \
	COMMAND phys_DIAG_EVENT_SWITCH_read; \
	COMMAND phys_DIAG_EVENT_SWITCH_write; \
	VARIABLE phys_PTA_OP_CODE; \
	MENU phys_PTA_OP_CODE_page; \
	COMMAND phys_PTA_OP_CODE_read; \
	COMMAND phys_PTA_OP_CODE_write; \
	VARIABLE phys_PTA_STATUS; \
	MENU phys_PTA_STATUS_page; \
	COMMAND phys_PTA_STATUS_read; \
	COLLECTION phys_VIEW_2_ANALYZER; \
	VARIABLE phys_ST_REV; \
	COLLECTION phys_MODE_BLK; \
	VARIABLE phys_MODE_BLK_Actual; \
	VARIABLE phys_MODE_BLK_Permitted; \
	VARIABLE phys_MODE_BLK_Normal; \
	COLLECTION phys_ALARM_SUM; \
	VARIABLE phys_ALARM_SUM_Current; \
	VARIABLE phys_ALARM_SUM_Unacknowledged; \
	VARIABLE phys_ALARM_SUM_Unreported; \
	VARIABLE phys_ALARM_SUM_Disabled; \
	VARIABLE phys_DIAGNOSIS; \
	VARIABLE phys_DIAGNOSIS_EXTENSION; \
	VARIABLE phys_WRITE_LOCKING; \
	VARIABLE phys_HW_WRITE_PROTECTION; \
	COLLECTION phys_FEATURE; \
	VARIABLE phys_FEATURE_Supported; \
	VARIABLE phys_FEATURE_Enabled; \
	VARIABLE phys_COND_STATUS_DIAG; \
	VARIABLE phys_DEVICE_STATE; \
	VARIABLE phys_GLOBAL_STATUS; \
	MENU phys_VIEW_2_ANALYZER_page; \
	COMMAND phys_VIEW_2_ANALYZER_read; \
	COLLECTION phys_VIEW_3_ANALYZER; \
	VARIABLE phys_TAG_DESC; \
	VARIABLE phys_STRATEGY; \
	VARIABLE phys_ALERT_KEY; \
	VARIABLE phys_TARGET_MODE; \
	VARIABLE phys_DESCRIPTOR; \
	VARIABLE phys_DEVICE_MESSAGE; \
	VARIABLE phys_DEVICE_INSTAL_DATE; \
	VARIABLE phys_LOCAL_OP_ENA; \
	VARIABLE phys_IDENT_NUMBER_SELECTOR; \
	MENU phys_VIEW_3_ANALYZER_page; \
	COMMAND phys_VIEW_3_ANALYZER_read; \
	COMMAND phys_VIEW_3_ANALYZER_write; \
	MENU phys_Reset; \
	MENU phys_Reset_page; \
	METHOD phys_method_factory_reset_params; \
	METHOD phys_method_factory_reset_warm; \
	METHOD phys_method_factory_reset_address; \
	METHOD phys_method_factory_reset_device_specific; \
	MENU phys_Dialog_Write_Locking; \
	MENU phys_Dialog_Ident_Number_Selector

#define USE_PHYS_ANALYZER_OPTIONAL_A \
	USE_PHYS_ANALYZER_OPTIONAL_BOTH; \
	VARIABLE phys_IDENT_NUMBER_SELECTOR; \
	MENU phys_IDENT_NUMBER_SELECTOR_page; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_read; \
	COMMAND phys_IDENT_NUMBER_SELECTOR_write; \
	COLLECTION phys_VIEW_1_ANALYZER; \
	VARIABLE phys_ST_REV; \
	COLLECTION phys_MODE_BLK; \
	VARIABLE phys_MODE_BLK_Actual; \
	VARIABLE phys_MODE_BLK_Permitted; \
	VARIABLE phys_MODE_BLK_Normal; \
	COLLECTION phys_ALARM_SUM; \
	VARIABLE phys_ALARM_SUM_Current; \
	VARIABLE phys_ALARM_SUM_Unacknowledged; \
	VARIABLE phys_ALARM_SUM_Unreported; \
	VARIABLE phys_ALARM_SUM_Disabled; \
	VARIABLE phys_DIAGNOSIS; \
	VARIABLE phys_DEVICE_STATE; \
	VARIABLE phys_GLOBAL_STATUS; \
	MENU phys_VIEW_1_ANALYZER_page; \
	COMMAND phys_VIEW_1_ANALYZER_read; \
	MENU phys_Simple_Dialog_Optional_A

#define USE_PHYS_ANALYZER_OPTIONAL_B \
	USE_PHYS_ANALYZER_OPTIONAL_BOTH; \
	MENU phys_Simple_Dialog_Optional_B

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_TEMP_MANDATORY_BOTH \
	BLOCK trans1_Temp_block; \
	COLLECTION trans1_Temp_BLOCK_OBJECT; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Temp_BLOCK_OBJECT_page; \
	COMMAND trans1_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans1_Temp_ST_REV; \
	MENU trans1_Temp_ST_REV_page; \
	COMMAND trans1_Temp_ST_REV_read; \
	VARIABLE trans1_Temp_TAG_DESC; \
	MENU trans1_Temp_TAG_DESC_page; \
	COMMAND trans1_Temp_TAG_DESC_read; \
	COMMAND trans1_Temp_TAG_DESC_write; \
	VARIABLE trans1_Temp_STRATEGY; \
	MENU trans1_Temp_STRATEGY_page; \
	COMMAND trans1_Temp_STRATEGY_read; \
	COMMAND trans1_Temp_STRATEGY_write; \
	VARIABLE trans1_Temp_ALERT_KEY; \
	MENU trans1_Temp_ALERT_KEY_page; \
	COMMAND trans1_Temp_ALERT_KEY_read; \
	COMMAND trans1_Temp_ALERT_KEY_write; \
	VARIABLE trans1_Temp_TARGET_MODE; \
	MENU trans1_Temp_TARGET_MODE_page; \
	COMMAND trans1_Temp_TARGET_MODE_read; \
	COMMAND trans1_Temp_TARGET_MODE_write; \
	COLLECTION trans1_Temp_MODE_BLK; \
	VARIABLE trans1_Temp_MODE_BLK_Actual; \
	VARIABLE trans1_Temp_MODE_BLK_Permitted; \
	VARIABLE trans1_Temp_MODE_BLK_Normal; \
	MENU trans1_Temp_MODE_BLK_page; \
	COMMAND trans1_Temp_MODE_BLK_read; \
	COLLECTION trans1_Temp_ALARM_SUM; \
	VARIABLE trans1_Temp_ALARM_SUM_Current; \
	VARIABLE trans1_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans1_Temp_ALARM_SUM_Disabled; \
	MENU trans1_Temp_ALARM_SUM_page; \
	COMMAND trans1_Temp_ALARM_SUM_read; \
	COLLECTION trans1_Temp_PRIMARY_VALUE; \
	VARIABLE trans1_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans1_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans1_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans1_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans1_Temp_PRIMARY_VALUE_page; \
	COMMAND trans1_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans1_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans1_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans1_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans1_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans1_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans1_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans1_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans1_Temp_SENSOR_MEAS_TYPE; \
	MENU trans1_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans1_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans1_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans1_Temp_INPUT_RANGE; \
	MENU trans1_Temp_INPUT_RANGE_page; \
	COMMAND trans1_Temp_INPUT_RANGE_read; \
	COMMAND trans1_Temp_INPUT_RANGE_write; \
	VARIABLE trans1_Temp_LIN_TYPE; \
	MENU trans1_Temp_LIN_TYPE_page; \
	COMMAND trans1_Temp_LIN_TYPE_read; \
	COMMAND trans1_Temp_LIN_TYPE_write; \
	VARIABLE trans1_Temp_BIAS_1; \
	MENU trans1_Temp_BIAS_1_page; \
	COMMAND trans1_Temp_BIAS_1_read; \
	COMMAND trans1_Temp_BIAS_1_write; \
	VARIABLE trans1_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans1_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans1_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans1_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans1_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans1_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans1_Temp_INPUT_FAULT_GEN; \
	MENU trans1_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans1_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans1_Temp_INPUT_FAULT_1; \
	MENU trans1_Temp_INPUT_FAULT_1_page; \
	COMMAND trans1_Temp_INPUT_FAULT_1_read; \
	UNIT trans1_Temp_Unit_1; \
	VARIABLE trans1_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans1_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans1_Temp_Display; \
	CHART trans1_Temp_Display_BarVal_pv; \
	SOURCE trans1_Temp_Display_BarVal_pv_source; \
	MENU trans1_Temp_Display_primary; \
	MENU trans1_Temp_Display_secondary; \
	MENU trans1_Temp_Tab_s; \
	MENU trans1_Temp_Tab_s_measrange; \
	MENU trans1_Temp_Tab_m

#define USE_TRANS1_TEMP_MANDATORY_A \
	USE_TRANS1_TEMP_MANDATORY_BOTH; \
	MENU trans1_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS1_TEMP_MANDATORY_B \
	USE_TRANS1_TEMP_MANDATORY_BOTH; \
	COLLECTION trans1_Temp_VIEW_1; \
	MENU trans1_Temp_VIEW_1_page; \
	MENU trans1_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS1_TEMP_OPTIONAL_BOTH \
	COLLECTION trans1_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans1_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans1_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans1_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans1_Temp_BIAS_2; \
	MENU trans1_Temp_BIAS_2_page; \
	COMMAND trans1_Temp_BIAS_2_read; \
	COMMAND trans1_Temp_BIAS_2_write; \
	VARIABLE trans1_Temp_INPUT_FAULT_2; \
	MENU trans1_Temp_INPUT_FAULT_2_page; \
	COMMAND trans1_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans1_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans1_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans1_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans1_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans1_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans1_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans1_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans1_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans1_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans1_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans1_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans1_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans1_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans1_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans1_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans1_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans1_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans1_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans1_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans1_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans1_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans1_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans1_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans1_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans1_Temp_TAB_ENTRY; \
	MENU trans1_Temp_TAB_ENTRY_page; \
	COMMAND trans1_Temp_TAB_ENTRY_read; \
	COMMAND trans1_Temp_TAB_ENTRY_write; \
	COLLECTION trans1_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans1_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans1_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans1_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans1_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans1_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans1_Temp_TAB_MIN_NUMBER; \
	MENU trans1_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans1_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans1_Temp_TAB_MAX_NUMBER; \
	MENU trans1_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans1_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans1_Temp_TAB_OP_CODE; \
	MENU trans1_Temp_TAB_OP_CODE_page; \
	COMMAND trans1_Temp_TAB_OP_CODE_read; \
	COMMAND trans1_Temp_TAB_OP_CODE_write; \
	VARIABLE trans1_Temp_TAB_STATUS; \
	MENU trans1_Temp_TAB_STATUS_page; \
	COMMAND trans1_Temp_TAB_STATUS_read; \
	VARIABLE trans1_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans1_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans1_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans1_Temp_VIEW_2; \
	MENU trans1_Temp_VIEW_2_page; \
	COLLECTION trans1_Temp_VIEW_3; \
	MENU trans1_Temp_VIEW_3_page; \
	UNIT trans1_Temp_Unit_2

#define USE_TRANS1_TEMP_OPTIONAL_A \
	USE_TRANS1_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans1_Temp_VIEW_1; \
	MENU trans1_Temp_VIEW_1_page; \
	MENU trans1_Temp_Simple_Dialog_Optional_A

#define USE_TRANS1_TEMP_OPTIONAL_B \
	USE_TRANS1_TEMP_OPTIONAL_BOTH; \
	MENU trans1_Temp_Simple_Dialog_Optional_B

#define USE_TRANS1_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans1_Temp_RJ_TYPE; \
	MENU trans1_Temp_RJ_TYPE_page; \
	COMMAND trans1_Temp_RJ_TYPE_read; \
	COMMAND trans1_Temp_RJ_TYPE_write; \
	MENU trans1_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS1_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans1_Temp_SENSOR_CONNECTION; \
	MENU trans1_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans1_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans1_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans1_Temp_COMP_WIRE1; \
	MENU trans1_Temp_COMP_WIRE1_page; \
	COMMAND trans1_Temp_COMP_WIRE1_read; \
	COMMAND trans1_Temp_COMP_WIRE1_write; \
	MENU trans1_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS1_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans1_Temp_EMISSIVITY; \
	MENU trans1_Temp_EMISSIVITY_page; \
	COMMAND trans1_Temp_EMISSIVITY_read; \
	COMMAND trans1_Temp_EMISSIVITY_write; \
	VARIABLE trans1_Temp_PEAK_TRACK; \
	MENU trans1_Temp_PEAK_TRACK_page; \
	COMMAND trans1_Temp_PEAK_TRACK_read; \
	COMMAND trans1_Temp_PEAK_TRACK_write; \
	VARIABLE trans1_Temp_DECAY_RATE; \
	MENU trans1_Temp_DECAY_RATE_page; \
	COMMAND trans1_Temp_DECAY_RATE_read; \
	COMMAND trans1_Temp_DECAY_RATE_write; \
	VARIABLE trans1_Temp_PEAK_TIME; \
	MENU trans1_Temp_PEAK_TIME_page; \
	COMMAND trans1_Temp_PEAK_TIME_read; \
	COMMAND trans1_Temp_PEAK_TIME_write; \
	VARIABLE trans1_Temp_TRACK_HOLD; \
	MENU trans1_Temp_TRACK_HOLD_page; \
	COMMAND trans1_Temp_TRACK_HOLD_read; \
	COMMAND trans1_Temp_TRACK_HOLD_write; \
	VARIABLE trans1_Temp_SPECT_FILT_SET; \
	MENU trans1_Temp_SPECT_FILT_SET_page; \
	COMMAND trans1_Temp_SPECT_FILT_SET_read; \
	COMMAND trans1_Temp_SPECT_FILT_SET_write; \
	MENU trans1_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS1_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans1_Temp_RJ_TYPE; \
	MENU trans1_Temp_RJ_TYPE_page; \
	COMMAND trans1_Temp_RJ_TYPE_read; \
	COMMAND trans1_Temp_RJ_TYPE_write; \
	MENU trans1_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS1_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans1_Temp_SENSOR_CONNECTION; \
	MENU trans1_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans1_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans1_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans1_Temp_COMP_WIRE1; \
	MENU trans1_Temp_COMP_WIRE1_page; \
	COMMAND trans1_Temp_COMP_WIRE1_read; \
	COMMAND trans1_Temp_COMP_WIRE1_write; \
	MENU trans1_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS1_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans1_Temp_EMISSIVITY; \
	MENU trans1_Temp_EMISSIVITY_page; \
	COMMAND trans1_Temp_EMISSIVITY_read; \
	COMMAND trans1_Temp_EMISSIVITY_write; \
	VARIABLE trans1_Temp_PEAK_TRACK; \
	MENU trans1_Temp_PEAK_TRACK_page; \
	COMMAND trans1_Temp_PEAK_TRACK_read; \
	COMMAND trans1_Temp_PEAK_TRACK_write; \
	VARIABLE trans1_Temp_DECAY_RATE; \
	MENU trans1_Temp_DECAY_RATE_page; \
	COMMAND trans1_Temp_DECAY_RATE_read; \
	COMMAND trans1_Temp_DECAY_RATE_write; \
	VARIABLE trans1_Temp_PEAK_TIME; \
	MENU trans1_Temp_PEAK_TIME_page; \
	COMMAND trans1_Temp_PEAK_TIME_read; \
	COMMAND trans1_Temp_PEAK_TIME_write; \
	VARIABLE trans1_Temp_TRACK_HOLD; \
	MENU trans1_Temp_TRACK_HOLD_page; \
	COMMAND trans1_Temp_TRACK_HOLD_read; \
	COMMAND trans1_Temp_TRACK_HOLD_write; \
	VARIABLE trans1_Temp_SPECT_FILT_SET; \
	MENU trans1_Temp_SPECT_FILT_SET_page; \
	COMMAND trans1_Temp_SPECT_FILT_SET_read; \
	COMMAND trans1_Temp_SPECT_FILT_SET_write; \
	MENU trans1_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS1_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans1_Temp_RJ_TEMP; \
	MENU trans1_Temp_RJ_TEMP_page; \
	COMMAND trans1_Temp_RJ_TEMP_read; \
	VARIABLE trans1_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans1_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans1_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans1_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans1_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans1_Temp_Unit_3

#define USE_TRANS1_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans1_Temp_COMP_WIRE2; \
	MENU trans1_Temp_COMP_WIRE2_page; \
	COMMAND trans1_Temp_COMP_WIRE2_read; \
	COMMAND trans1_Temp_COMP_WIRE2_write; \
	MENU trans1_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS1_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans1_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS1_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans1_Temp_RJ_TEMP; \
	MENU trans1_Temp_RJ_TEMP_page; \
	COMMAND trans1_Temp_RJ_TEMP_read; \
	VARIABLE trans1_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans1_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans1_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans1_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans1_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans1_Temp_Unit_3

#define USE_TRANS1_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans1_Temp_COMP_WIRE2; \
	MENU trans1_Temp_COMP_WIRE2_page; \
	COMMAND trans1_Temp_COMP_WIRE2_read; \
	COMMAND trans1_Temp_COMP_WIRE2_write; \
	MENU trans1_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS1_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans1_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_TEMP_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## PRIMARY_VALUE; \
	VARIABLE prefix ## PRIMARY_VALUE_Value; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Condensed; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Quality; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Limit; \
	MENU prefix ## PRIMARY_VALUE_page; \
	COMMAND prefix ## PRIMARY_VALUE_read; \
	VARIABLE prefix ## PRIMARY_VALUE_UNIT; \
	MENU prefix ## PRIMARY_VALUE_UNIT_page; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_read; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_write; \
	COLLECTION prefix ## SECONDARY_VALUE_1; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Value; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Limit; \
	MENU prefix ## SECONDARY_VALUE_1_page; \
	COMMAND prefix ## SECONDARY_VALUE_1_read; \
	VARIABLE prefix ## SENSOR_MEAS_TYPE; \
	MENU prefix ## SENSOR_MEAS_TYPE_page; \
	COMMAND prefix ## SENSOR_MEAS_TYPE_read; \
	COMMAND prefix ## SENSOR_MEAS_TYPE_write; \
	VARIABLE prefix ## INPUT_RANGE; \
	MENU prefix ## INPUT_RANGE_page; \
	COMMAND prefix ## INPUT_RANGE_read; \
	COMMAND prefix ## INPUT_RANGE_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## BIAS_1; \
	MENU prefix ## BIAS_1_page; \
	COMMAND prefix ## BIAS_1_read; \
	COMMAND prefix ## BIAS_1_write; \
	VARIABLE prefix ## UPPER_SENSOR_LIMIT; \
	MENU prefix ## UPPER_SENSOR_LIMIT_page; \
	COMMAND prefix ## UPPER_SENSOR_LIMIT_read; \
	VARIABLE prefix ## LOWER_SENSOR_LIMIT; \
	MENU prefix ## LOWER_SENSOR_LIMIT_page; \
	COMMAND prefix ## LOWER_SENSOR_LIMIT_read; \
	VARIABLE prefix ## INPUT_FAULT_GEN; \
	MENU prefix ## INPUT_FAULT_GEN_page; \
	COMMAND prefix ## INPUT_FAULT_GEN_read; \
	VARIABLE prefix ## INPUT_FAULT_1; \
	MENU prefix ## INPUT_FAULT_1_page; \
	COMMAND prefix ## INPUT_FAULT_1_read; \
	UNIT prefix ## Unit_1; \
	VARIABLE prefix ## PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD prefix ## PRIMARY_VALUE_UNIT_post; \
	MENU prefix ## Display; \
	CHART prefix ## Display_BarVal_pv; \
	SOURCE prefix ## Display_BarVal_pv_source; \
	MENU prefix ## Display_primary; \
	MENU prefix ## Display_secondary; \
	MENU prefix ## Tab_s; \
	MENU prefix ## Tab_s_measrange; \
	MENU prefix ## Tab_m

#define USE_TRANS_TEMP_MANDATORY_A(prefix) \
	USE_TRANS_TEMP_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_TEMP_MANDATORY_B(prefix) \
	USE_TRANS_TEMP_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_TEMP_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## SECONDARY_VALUE_2; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Value; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Limit; \
	MENU prefix ## SECONDARY_VALUE_2_page; \
	COMMAND prefix ## SECONDARY_VALUE_2_read; \
	VARIABLE prefix ## BIAS_2; \
	MENU prefix ## BIAS_2_page; \
	COMMAND prefix ## BIAS_2_read; \
	COMMAND prefix ## BIAS_2_write; \
	VARIABLE prefix ## INPUT_FAULT_2; \
	MENU prefix ## INPUT_FAULT_2_page; \
	COMMAND prefix ## INPUT_FAULT_2_read; \
	VARIABLE prefix ## SENSOR_WIRE_CHECK_1; \
	MENU prefix ## SENSOR_WIRE_CHECK_1_page; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_1_read; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_1_write; \
	VARIABLE prefix ## SENSOR_WIRE_CHECK_2; \
	MENU prefix ## SENSOR_WIRE_CHECK_2_page; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_2_read; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_2_write; \
	VARIABLE prefix ## MAX_SENSOR_VALUE_1; \
	MENU prefix ## MAX_SENSOR_VALUE_1_page; \
	COMMAND prefix ## MAX_SENSOR_VALUE_1_read; \
	COMMAND prefix ## MAX_SENSOR_VALUE_1_write; \
	VARIABLE prefix ## MIN_SENSOR_VALUE_1; \
	MENU prefix ## MIN_SENSOR_VALUE_1_page; \
	COMMAND prefix ## MIN_SENSOR_VALUE_1_read; \
	COMMAND prefix ## MIN_SENSOR_VALUE_1_write; \
	VARIABLE prefix ## MAX_SENSOR_VALUE_2; \
	MENU prefix ## MAX_SENSOR_VALUE_2_page; \
	COMMAND prefix ## MAX_SENSOR_VALUE_2_read; \
	COMMAND prefix ## MAX_SENSOR_VALUE_2_write; \
	VARIABLE prefix ## MIN_SENSOR_VALUE_2; \
	MENU prefix ## MIN_SENSOR_VALUE_2_page; \
	COMMAND prefix ## MIN_SENSOR_VALUE_2_read; \
	COMMAND prefix ## MIN_SENSOR_VALUE_2_write; \
	VARIABLE prefix ## TAB_ENTRY; \
	MENU prefix ## TAB_ENTRY_page; \
	COMMAND prefix ## TAB_ENTRY_read; \
	COMMAND prefix ## TAB_ENTRY_write; \
	COLLECTION prefix ## TAB_X_Y_VALUE; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Lower_Value; \
	MENU prefix ## TAB_X_Y_VALUE_page; \
	COMMAND prefix ## TAB_X_Y_VALUE_read; \
	COMMAND prefix ## TAB_X_Y_VALUE_write; \
	VARIABLE prefix ## TAB_MIN_NUMBER; \
	MENU prefix ## TAB_MIN_NUMBER_page; \
	COMMAND prefix ## TAB_MIN_NUMBER_read; \
	VARIABLE prefix ## TAB_MAX_NUMBER; \
	MENU prefix ## TAB_MAX_NUMBER_page; \
	COMMAND prefix ## TAB_MAX_NUMBER_read; \
	VARIABLE prefix ## TAB_OP_CODE; \
	MENU prefix ## TAB_OP_CODE_page; \
	COMMAND prefix ## TAB_OP_CODE_read; \
	COMMAND prefix ## TAB_OP_CODE_write; \
	VARIABLE prefix ## TAB_STATUS; \
	MENU prefix ## TAB_STATUS_page; \
	COMMAND prefix ## TAB_STATUS_read; \
	VARIABLE prefix ## TAB_ACTUAL_NUMBER; \
	MENU prefix ## TAB_ACTUAL_NUMBER_page; \
	COMMAND prefix ## TAB_ACTUAL_NUMBER_read; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## Unit_2

#define USE_TRANS_TEMP_OPTIONAL_A(prefix) \
	USE_TRANS_TEMP_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_TEMP_OPTIONAL_B(prefix) \
	USE_TRANS_TEMP_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(prefix) \
	VARIABLE prefix ## RJ_TYPE; \
	MENU prefix ## RJ_TYPE_page; \
	COMMAND prefix ## RJ_TYPE_read; \
	COMMAND prefix ## RJ_TYPE_write; \
	MENU prefix ## Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(prefix) \
	VARIABLE prefix ## SENSOR_CONNECTION; \
	MENU prefix ## SENSOR_CONNECTION_page; \
	COMMAND prefix ## SENSOR_CONNECTION_read; \
	COMMAND prefix ## SENSOR_CONNECTION_write; \
	VARIABLE prefix ## COMP_WIRE1; \
	MENU prefix ## COMP_WIRE1_page; \
	COMMAND prefix ## COMP_WIRE1_read; \
	COMMAND prefix ## COMP_WIRE1_write; \
	MENU prefix ## Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS_TEMP_PYROMETER_MANDATORY_A(prefix) \
	VARIABLE prefix ## EMISSIVITY; \
	MENU prefix ## EMISSIVITY_page; \
	COMMAND prefix ## EMISSIVITY_read; \
	COMMAND prefix ## EMISSIVITY_write; \
	VARIABLE prefix ## PEAK_TRACK; \
	MENU prefix ## PEAK_TRACK_page; \
	COMMAND prefix ## PEAK_TRACK_read; \
	COMMAND prefix ## PEAK_TRACK_write; \
	VARIABLE prefix ## DECAY_RATE; \
	MENU prefix ## DECAY_RATE_page; \
	COMMAND prefix ## DECAY_RATE_read; \
	COMMAND prefix ## DECAY_RATE_write; \
	VARIABLE prefix ## PEAK_TIME; \
	MENU prefix ## PEAK_TIME_page; \
	COMMAND prefix ## PEAK_TIME_read; \
	COMMAND prefix ## PEAK_TIME_write; \
	VARIABLE prefix ## TRACK_HOLD; \
	MENU prefix ## TRACK_HOLD_page; \
	COMMAND prefix ## TRACK_HOLD_read; \
	COMMAND prefix ## TRACK_HOLD_write; \
	VARIABLE prefix ## SPECT_FILT_SET; \
	MENU prefix ## SPECT_FILT_SET_page; \
	COMMAND prefix ## SPECT_FILT_SET_read; \
	COMMAND prefix ## SPECT_FILT_SET_write; \
	MENU prefix ## Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(prefix) \
	VARIABLE prefix ## RJ_TYPE; \
	MENU prefix ## RJ_TYPE_page; \
	COMMAND prefix ## RJ_TYPE_read; \
	COMMAND prefix ## RJ_TYPE_write; \
	MENU prefix ## Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(prefix) \
	VARIABLE prefix ## SENSOR_CONNECTION; \
	MENU prefix ## SENSOR_CONNECTION_page; \
	COMMAND prefix ## SENSOR_CONNECTION_read; \
	COMMAND prefix ## SENSOR_CONNECTION_write; \
	VARIABLE prefix ## COMP_WIRE1; \
	MENU prefix ## COMP_WIRE1_page; \
	COMMAND prefix ## COMP_WIRE1_read; \
	COMMAND prefix ## COMP_WIRE1_write; \
	MENU prefix ## Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS_TEMP_PYROMETER_MANDATORY_B(prefix) \
	VARIABLE prefix ## EMISSIVITY; \
	MENU prefix ## EMISSIVITY_page; \
	COMMAND prefix ## EMISSIVITY_read; \
	COMMAND prefix ## EMISSIVITY_write; \
	VARIABLE prefix ## PEAK_TRACK; \
	MENU prefix ## PEAK_TRACK_page; \
	COMMAND prefix ## PEAK_TRACK_read; \
	COMMAND prefix ## PEAK_TRACK_write; \
	VARIABLE prefix ## DECAY_RATE; \
	MENU prefix ## DECAY_RATE_page; \
	COMMAND prefix ## DECAY_RATE_read; \
	COMMAND prefix ## DECAY_RATE_write; \
	VARIABLE prefix ## PEAK_TIME; \
	MENU prefix ## PEAK_TIME_page; \
	COMMAND prefix ## PEAK_TIME_read; \
	COMMAND prefix ## PEAK_TIME_write; \
	VARIABLE prefix ## TRACK_HOLD; \
	MENU prefix ## TRACK_HOLD_page; \
	COMMAND prefix ## TRACK_HOLD_read; \
	COMMAND prefix ## TRACK_HOLD_write; \
	VARIABLE prefix ## SPECT_FILT_SET; \
	MENU prefix ## SPECT_FILT_SET_page; \
	COMMAND prefix ## SPECT_FILT_SET_read; \
	COMMAND prefix ## SPECT_FILT_SET_write; \
	MENU prefix ## Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(prefix) \
	VARIABLE prefix ## RJ_TEMP; \
	MENU prefix ## RJ_TEMP_page; \
	COMMAND prefix ## RJ_TEMP_read; \
	VARIABLE prefix ## EXTERNAL_RJ_VALUE; \
	MENU prefix ## EXTERNAL_RJ_VALUE_page; \
	COMMAND prefix ## EXTERNAL_RJ_VALUE_read; \
	COMMAND prefix ## EXTERNAL_RJ_VALUE_write; \
	MENU prefix ## Thermocouple_Simple_Dialog_Optional_A; \
	UNIT prefix ## Unit_3

#define USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(prefix) \
	VARIABLE prefix ## COMP_WIRE2; \
	MENU prefix ## COMP_WIRE2_page; \
	COMMAND prefix ## COMP_WIRE2_read; \
	COMMAND prefix ## COMP_WIRE2_write; \
	MENU prefix ## Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(prefix) \
	MENU prefix ## Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(prefix) \
	VARIABLE prefix ## RJ_TEMP; \
	MENU prefix ## RJ_TEMP_page; \
	COMMAND prefix ## RJ_TEMP_read; \
	VARIABLE prefix ## EXTERNAL_RJ_VALUE; \
	MENU prefix ## EXTERNAL_RJ_VALUE_page; \
	COMMAND prefix ## EXTERNAL_RJ_VALUE_read; \
	COMMAND prefix ## EXTERNAL_RJ_VALUE_write; \
	MENU prefix ## Thermocouple_Simple_Dialog_Optional_B; \
	UNIT prefix ## Unit_3

#define USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(prefix) \
	VARIABLE prefix ## COMP_WIRE2; \
	MENU prefix ## COMP_WIRE2_page; \
	COMMAND prefix ## COMP_WIRE2_read; \
	COMMAND prefix ## COMP_WIRE2_write; \
	MENU prefix ## Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(prefix) \
	MENU prefix ## Pyrometer_Simple_Dialog_Optional_B

#define USE_TRANS1_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans1_Temp_)
#define USE_TRANS1_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans1_Temp_)
#define USE_TRANS1_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans1_Temp_)
#define USE_TRANS1_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans1_Temp_)
#define USE_TRANS1_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans1_Temp_)
#define USE_TRANS1_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans1_Temp_)
#define USE_TRANS1_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans1_Temp_)
#define USE_TRANS1_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans1_Temp_)
#define USE_TRANS1_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans1_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_TEMP_MANDATORY_BOTH \
	BLOCK trans2_Temp_block; \
	COLLECTION trans2_Temp_BLOCK_OBJECT; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Temp_BLOCK_OBJECT_page; \
	COMMAND trans2_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans2_Temp_ST_REV; \
	MENU trans2_Temp_ST_REV_page; \
	COMMAND trans2_Temp_ST_REV_read; \
	VARIABLE trans2_Temp_TAG_DESC; \
	MENU trans2_Temp_TAG_DESC_page; \
	COMMAND trans2_Temp_TAG_DESC_read; \
	COMMAND trans2_Temp_TAG_DESC_write; \
	VARIABLE trans2_Temp_STRATEGY; \
	MENU trans2_Temp_STRATEGY_page; \
	COMMAND trans2_Temp_STRATEGY_read; \
	COMMAND trans2_Temp_STRATEGY_write; \
	VARIABLE trans2_Temp_ALERT_KEY; \
	MENU trans2_Temp_ALERT_KEY_page; \
	COMMAND trans2_Temp_ALERT_KEY_read; \
	COMMAND trans2_Temp_ALERT_KEY_write; \
	VARIABLE trans2_Temp_TARGET_MODE; \
	MENU trans2_Temp_TARGET_MODE_page; \
	COMMAND trans2_Temp_TARGET_MODE_read; \
	COMMAND trans2_Temp_TARGET_MODE_write; \
	COLLECTION trans2_Temp_MODE_BLK; \
	VARIABLE trans2_Temp_MODE_BLK_Actual; \
	VARIABLE trans2_Temp_MODE_BLK_Permitted; \
	VARIABLE trans2_Temp_MODE_BLK_Normal; \
	MENU trans2_Temp_MODE_BLK_page; \
	COMMAND trans2_Temp_MODE_BLK_read; \
	COLLECTION trans2_Temp_ALARM_SUM; \
	VARIABLE trans2_Temp_ALARM_SUM_Current; \
	VARIABLE trans2_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans2_Temp_ALARM_SUM_Disabled; \
	MENU trans2_Temp_ALARM_SUM_page; \
	COMMAND trans2_Temp_ALARM_SUM_read; \
	COLLECTION trans2_Temp_PRIMARY_VALUE; \
	VARIABLE trans2_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans2_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans2_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans2_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans2_Temp_PRIMARY_VALUE_page; \
	COMMAND trans2_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans2_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans2_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans2_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans2_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans2_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans2_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans2_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans2_Temp_SENSOR_MEAS_TYPE; \
	MENU trans2_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans2_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans2_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans2_Temp_INPUT_RANGE; \
	MENU trans2_Temp_INPUT_RANGE_page; \
	COMMAND trans2_Temp_INPUT_RANGE_read; \
	COMMAND trans2_Temp_INPUT_RANGE_write; \
	VARIABLE trans2_Temp_LIN_TYPE; \
	MENU trans2_Temp_LIN_TYPE_page; \
	COMMAND trans2_Temp_LIN_TYPE_read; \
	COMMAND trans2_Temp_LIN_TYPE_write; \
	VARIABLE trans2_Temp_BIAS_1; \
	MENU trans2_Temp_BIAS_1_page; \
	COMMAND trans2_Temp_BIAS_1_read; \
	COMMAND trans2_Temp_BIAS_1_write; \
	VARIABLE trans2_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans2_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans2_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans2_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans2_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans2_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans2_Temp_INPUT_FAULT_GEN; \
	MENU trans2_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans2_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans2_Temp_INPUT_FAULT_1; \
	MENU trans2_Temp_INPUT_FAULT_1_page; \
	COMMAND trans2_Temp_INPUT_FAULT_1_read; \
	UNIT trans2_Temp_Unit_1; \
	VARIABLE trans2_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans2_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans2_Temp_Display; \
	CHART trans2_Temp_Display_BarVal_pv; \
	SOURCE trans2_Temp_Display_BarVal_pv_source; \
	MENU trans2_Temp_Display_primary; \
	MENU trans2_Temp_Display_secondary; \
	MENU trans2_Temp_Tab_s; \
	MENU trans2_Temp_Tab_s_measrange; \
	MENU trans2_Temp_Tab_m

#define USE_TRANS2_TEMP_MANDATORY_A \
	USE_TRANS2_TEMP_MANDATORY_BOTH; \
	MENU trans2_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS2_TEMP_MANDATORY_B \
	USE_TRANS2_TEMP_MANDATORY_BOTH; \
	COLLECTION trans2_Temp_VIEW_1; \
	MENU trans2_Temp_VIEW_1_page; \
	MENU trans2_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS2_TEMP_OPTIONAL_BOTH \
	COLLECTION trans2_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans2_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans2_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans2_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans2_Temp_BIAS_2; \
	MENU trans2_Temp_BIAS_2_page; \
	COMMAND trans2_Temp_BIAS_2_read; \
	COMMAND trans2_Temp_BIAS_2_write; \
	VARIABLE trans2_Temp_INPUT_FAULT_2; \
	MENU trans2_Temp_INPUT_FAULT_2_page; \
	COMMAND trans2_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans2_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans2_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans2_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans2_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans2_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans2_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans2_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans2_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans2_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans2_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans2_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans2_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans2_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans2_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans2_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans2_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans2_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans2_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans2_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans2_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans2_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans2_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans2_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans2_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans2_Temp_TAB_ENTRY; \
	MENU trans2_Temp_TAB_ENTRY_page; \
	COMMAND trans2_Temp_TAB_ENTRY_read; \
	COMMAND trans2_Temp_TAB_ENTRY_write; \
	COLLECTION trans2_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans2_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans2_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans2_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans2_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans2_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans2_Temp_TAB_MIN_NUMBER; \
	MENU trans2_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans2_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans2_Temp_TAB_MAX_NUMBER; \
	MENU trans2_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans2_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans2_Temp_TAB_OP_CODE; \
	MENU trans2_Temp_TAB_OP_CODE_page; \
	COMMAND trans2_Temp_TAB_OP_CODE_read; \
	COMMAND trans2_Temp_TAB_OP_CODE_write; \
	VARIABLE trans2_Temp_TAB_STATUS; \
	MENU trans2_Temp_TAB_STATUS_page; \
	COMMAND trans2_Temp_TAB_STATUS_read; \
	VARIABLE trans2_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans2_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans2_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans2_Temp_VIEW_2; \
	MENU trans2_Temp_VIEW_2_page; \
	COLLECTION trans2_Temp_VIEW_3; \
	MENU trans2_Temp_VIEW_3_page; \
	UNIT trans2_Temp_Unit_2

#define USE_TRANS2_TEMP_OPTIONAL_A \
	USE_TRANS2_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans2_Temp_VIEW_1; \
	MENU trans2_Temp_VIEW_1_page; \
	MENU trans2_Temp_Simple_Dialog_Optional_A

#define USE_TRANS2_TEMP_OPTIONAL_B \
	USE_TRANS2_TEMP_OPTIONAL_BOTH; \
	MENU trans2_Temp_Simple_Dialog_Optional_B

#define USE_TRANS2_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans2_Temp_RJ_TYPE; \
	MENU trans2_Temp_RJ_TYPE_page; \
	COMMAND trans2_Temp_RJ_TYPE_read; \
	COMMAND trans2_Temp_RJ_TYPE_write; \
	MENU trans2_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS2_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans2_Temp_SENSOR_CONNECTION; \
	MENU trans2_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans2_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans2_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans2_Temp_COMP_WIRE1; \
	MENU trans2_Temp_COMP_WIRE1_page; \
	COMMAND trans2_Temp_COMP_WIRE1_read; \
	COMMAND trans2_Temp_COMP_WIRE1_write; \
	MENU trans2_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS2_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans2_Temp_EMISSIVITY; \
	MENU trans2_Temp_EMISSIVITY_page; \
	COMMAND trans2_Temp_EMISSIVITY_read; \
	COMMAND trans2_Temp_EMISSIVITY_write; \
	VARIABLE trans2_Temp_PEAK_TRACK; \
	MENU trans2_Temp_PEAK_TRACK_page; \
	COMMAND trans2_Temp_PEAK_TRACK_read; \
	COMMAND trans2_Temp_PEAK_TRACK_write; \
	VARIABLE trans2_Temp_DECAY_RATE; \
	MENU trans2_Temp_DECAY_RATE_page; \
	COMMAND trans2_Temp_DECAY_RATE_read; \
	COMMAND trans2_Temp_DECAY_RATE_write; \
	VARIABLE trans2_Temp_PEAK_TIME; \
	MENU trans2_Temp_PEAK_TIME_page; \
	COMMAND trans2_Temp_PEAK_TIME_read; \
	COMMAND trans2_Temp_PEAK_TIME_write; \
	VARIABLE trans2_Temp_TRACK_HOLD; \
	MENU trans2_Temp_TRACK_HOLD_page; \
	COMMAND trans2_Temp_TRACK_HOLD_read; \
	COMMAND trans2_Temp_TRACK_HOLD_write; \
	VARIABLE trans2_Temp_SPECT_FILT_SET; \
	MENU trans2_Temp_SPECT_FILT_SET_page; \
	COMMAND trans2_Temp_SPECT_FILT_SET_read; \
	COMMAND trans2_Temp_SPECT_FILT_SET_write; \
	MENU trans2_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS2_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans2_Temp_RJ_TYPE; \
	MENU trans2_Temp_RJ_TYPE_page; \
	COMMAND trans2_Temp_RJ_TYPE_read; \
	COMMAND trans2_Temp_RJ_TYPE_write; \
	MENU trans2_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS2_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans2_Temp_SENSOR_CONNECTION; \
	MENU trans2_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans2_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans2_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans2_Temp_COMP_WIRE1; \
	MENU trans2_Temp_COMP_WIRE1_page; \
	COMMAND trans2_Temp_COMP_WIRE1_read; \
	COMMAND trans2_Temp_COMP_WIRE1_write; \
	MENU trans2_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS2_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans2_Temp_EMISSIVITY; \
	MENU trans2_Temp_EMISSIVITY_page; \
	COMMAND trans2_Temp_EMISSIVITY_read; \
	COMMAND trans2_Temp_EMISSIVITY_write; \
	VARIABLE trans2_Temp_PEAK_TRACK; \
	MENU trans2_Temp_PEAK_TRACK_page; \
	COMMAND trans2_Temp_PEAK_TRACK_read; \
	COMMAND trans2_Temp_PEAK_TRACK_write; \
	VARIABLE trans2_Temp_DECAY_RATE; \
	MENU trans2_Temp_DECAY_RATE_page; \
	COMMAND trans2_Temp_DECAY_RATE_read; \
	COMMAND trans2_Temp_DECAY_RATE_write; \
	VARIABLE trans2_Temp_PEAK_TIME; \
	MENU trans2_Temp_PEAK_TIME_page; \
	COMMAND trans2_Temp_PEAK_TIME_read; \
	COMMAND trans2_Temp_PEAK_TIME_write; \
	VARIABLE trans2_Temp_TRACK_HOLD; \
	MENU trans2_Temp_TRACK_HOLD_page; \
	COMMAND trans2_Temp_TRACK_HOLD_read; \
	COMMAND trans2_Temp_TRACK_HOLD_write; \
	VARIABLE trans2_Temp_SPECT_FILT_SET; \
	MENU trans2_Temp_SPECT_FILT_SET_page; \
	COMMAND trans2_Temp_SPECT_FILT_SET_read; \
	COMMAND trans2_Temp_SPECT_FILT_SET_write; \
	MENU trans2_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS2_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans2_Temp_RJ_TEMP; \
	MENU trans2_Temp_RJ_TEMP_page; \
	COMMAND trans2_Temp_RJ_TEMP_read; \
	VARIABLE trans2_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans2_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans2_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans2_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans2_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans2_Temp_Unit_3

#define USE_TRANS2_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans2_Temp_COMP_WIRE2; \
	MENU trans2_Temp_COMP_WIRE2_page; \
	COMMAND trans2_Temp_COMP_WIRE2_read; \
	COMMAND trans2_Temp_COMP_WIRE2_write; \
	MENU trans2_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS2_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans2_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS2_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans2_Temp_RJ_TEMP; \
	MENU trans2_Temp_RJ_TEMP_page; \
	COMMAND trans2_Temp_RJ_TEMP_read; \
	VARIABLE trans2_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans2_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans2_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans2_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans2_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans2_Temp_Unit_3

#define USE_TRANS2_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans2_Temp_COMP_WIRE2; \
	MENU trans2_Temp_COMP_WIRE2_page; \
	COMMAND trans2_Temp_COMP_WIRE2_read; \
	COMMAND trans2_Temp_COMP_WIRE2_write; \
	MENU trans2_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS2_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans2_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans2_Temp_)
#define USE_TRANS2_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans2_Temp_)
#define USE_TRANS2_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans2_Temp_)
#define USE_TRANS2_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans2_Temp_)
#define USE_TRANS2_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans2_Temp_)
#define USE_TRANS2_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans2_Temp_)
#define USE_TRANS2_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans2_Temp_)
#define USE_TRANS2_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans2_Temp_)
#define USE_TRANS2_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans2_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_TEMP_MANDATORY_BOTH \
	BLOCK trans3_Temp_block; \
	COLLECTION trans3_Temp_BLOCK_OBJECT; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Temp_BLOCK_OBJECT_page; \
	COMMAND trans3_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans3_Temp_ST_REV; \
	MENU trans3_Temp_ST_REV_page; \
	COMMAND trans3_Temp_ST_REV_read; \
	VARIABLE trans3_Temp_TAG_DESC; \
	MENU trans3_Temp_TAG_DESC_page; \
	COMMAND trans3_Temp_TAG_DESC_read; \
	COMMAND trans3_Temp_TAG_DESC_write; \
	VARIABLE trans3_Temp_STRATEGY; \
	MENU trans3_Temp_STRATEGY_page; \
	COMMAND trans3_Temp_STRATEGY_read; \
	COMMAND trans3_Temp_STRATEGY_write; \
	VARIABLE trans3_Temp_ALERT_KEY; \
	MENU trans3_Temp_ALERT_KEY_page; \
	COMMAND trans3_Temp_ALERT_KEY_read; \
	COMMAND trans3_Temp_ALERT_KEY_write; \
	VARIABLE trans3_Temp_TARGET_MODE; \
	MENU trans3_Temp_TARGET_MODE_page; \
	COMMAND trans3_Temp_TARGET_MODE_read; \
	COMMAND trans3_Temp_TARGET_MODE_write; \
	COLLECTION trans3_Temp_MODE_BLK; \
	VARIABLE trans3_Temp_MODE_BLK_Actual; \
	VARIABLE trans3_Temp_MODE_BLK_Permitted; \
	VARIABLE trans3_Temp_MODE_BLK_Normal; \
	MENU trans3_Temp_MODE_BLK_page; \
	COMMAND trans3_Temp_MODE_BLK_read; \
	COLLECTION trans3_Temp_ALARM_SUM; \
	VARIABLE trans3_Temp_ALARM_SUM_Current; \
	VARIABLE trans3_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans3_Temp_ALARM_SUM_Disabled; \
	MENU trans3_Temp_ALARM_SUM_page; \
	COMMAND trans3_Temp_ALARM_SUM_read; \
	COLLECTION trans3_Temp_PRIMARY_VALUE; \
	VARIABLE trans3_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans3_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans3_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans3_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans3_Temp_PRIMARY_VALUE_page; \
	COMMAND trans3_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans3_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans3_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans3_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans3_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans3_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans3_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans3_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans3_Temp_SENSOR_MEAS_TYPE; \
	MENU trans3_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans3_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans3_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans3_Temp_INPUT_RANGE; \
	MENU trans3_Temp_INPUT_RANGE_page; \
	COMMAND trans3_Temp_INPUT_RANGE_read; \
	COMMAND trans3_Temp_INPUT_RANGE_write; \
	VARIABLE trans3_Temp_LIN_TYPE; \
	MENU trans3_Temp_LIN_TYPE_page; \
	COMMAND trans3_Temp_LIN_TYPE_read; \
	COMMAND trans3_Temp_LIN_TYPE_write; \
	VARIABLE trans3_Temp_BIAS_1; \
	MENU trans3_Temp_BIAS_1_page; \
	COMMAND trans3_Temp_BIAS_1_read; \
	COMMAND trans3_Temp_BIAS_1_write; \
	VARIABLE trans3_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans3_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans3_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans3_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans3_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans3_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans3_Temp_INPUT_FAULT_GEN; \
	MENU trans3_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans3_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans3_Temp_INPUT_FAULT_1; \
	MENU trans3_Temp_INPUT_FAULT_1_page; \
	COMMAND trans3_Temp_INPUT_FAULT_1_read; \
	UNIT trans3_Temp_Unit_1; \
	VARIABLE trans3_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans3_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans3_Temp_Display; \
	CHART trans3_Temp_Display_BarVal_pv; \
	SOURCE trans3_Temp_Display_BarVal_pv_source; \
	MENU trans3_Temp_Display_primary; \
	MENU trans3_Temp_Display_secondary; \
	MENU trans3_Temp_Tab_s; \
	MENU trans3_Temp_Tab_s_measrange; \
	MENU trans3_Temp_Tab_m

#define USE_TRANS3_TEMP_MANDATORY_A \
	USE_TRANS3_TEMP_MANDATORY_BOTH; \
	MENU trans3_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS3_TEMP_MANDATORY_B \
	USE_TRANS3_TEMP_MANDATORY_BOTH; \
	COLLECTION trans3_Temp_VIEW_1; \
	MENU trans3_Temp_VIEW_1_page; \
	MENU trans3_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS3_TEMP_OPTIONAL_BOTH \
	COLLECTION trans3_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans3_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans3_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans3_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans3_Temp_BIAS_2; \
	MENU trans3_Temp_BIAS_2_page; \
	COMMAND trans3_Temp_BIAS_2_read; \
	COMMAND trans3_Temp_BIAS_2_write; \
	VARIABLE trans3_Temp_INPUT_FAULT_2; \
	MENU trans3_Temp_INPUT_FAULT_2_page; \
	COMMAND trans3_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans3_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans3_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans3_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans3_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans3_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans3_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans3_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans3_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans3_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans3_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans3_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans3_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans3_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans3_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans3_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans3_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans3_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans3_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans3_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans3_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans3_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans3_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans3_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans3_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans3_Temp_TAB_ENTRY; \
	MENU trans3_Temp_TAB_ENTRY_page; \
	COMMAND trans3_Temp_TAB_ENTRY_read; \
	COMMAND trans3_Temp_TAB_ENTRY_write; \
	COLLECTION trans3_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans3_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans3_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans3_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans3_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans3_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans3_Temp_TAB_MIN_NUMBER; \
	MENU trans3_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans3_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans3_Temp_TAB_MAX_NUMBER; \
	MENU trans3_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans3_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans3_Temp_TAB_OP_CODE; \
	MENU trans3_Temp_TAB_OP_CODE_page; \
	COMMAND trans3_Temp_TAB_OP_CODE_read; \
	COMMAND trans3_Temp_TAB_OP_CODE_write; \
	VARIABLE trans3_Temp_TAB_STATUS; \
	MENU trans3_Temp_TAB_STATUS_page; \
	COMMAND trans3_Temp_TAB_STATUS_read; \
	VARIABLE trans3_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans3_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans3_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans3_Temp_VIEW_2; \
	MENU trans3_Temp_VIEW_2_page; \
	COLLECTION trans3_Temp_VIEW_3; \
	MENU trans3_Temp_VIEW_3_page; \
	UNIT trans3_Temp_Unit_2

#define USE_TRANS3_TEMP_OPTIONAL_A \
	USE_TRANS3_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans3_Temp_VIEW_1; \
	MENU trans3_Temp_VIEW_1_page; \
	MENU trans3_Temp_Simple_Dialog_Optional_A

#define USE_TRANS3_TEMP_OPTIONAL_B \
	USE_TRANS3_TEMP_OPTIONAL_BOTH; \
	MENU trans3_Temp_Simple_Dialog_Optional_B

#define USE_TRANS3_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans3_Temp_RJ_TYPE; \
	MENU trans3_Temp_RJ_TYPE_page; \
	COMMAND trans3_Temp_RJ_TYPE_read; \
	COMMAND trans3_Temp_RJ_TYPE_write; \
	MENU trans3_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS3_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans3_Temp_SENSOR_CONNECTION; \
	MENU trans3_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans3_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans3_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans3_Temp_COMP_WIRE1; \
	MENU trans3_Temp_COMP_WIRE1_page; \
	COMMAND trans3_Temp_COMP_WIRE1_read; \
	COMMAND trans3_Temp_COMP_WIRE1_write; \
	MENU trans3_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS3_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans3_Temp_EMISSIVITY; \
	MENU trans3_Temp_EMISSIVITY_page; \
	COMMAND trans3_Temp_EMISSIVITY_read; \
	COMMAND trans3_Temp_EMISSIVITY_write; \
	VARIABLE trans3_Temp_PEAK_TRACK; \
	MENU trans3_Temp_PEAK_TRACK_page; \
	COMMAND trans3_Temp_PEAK_TRACK_read; \
	COMMAND trans3_Temp_PEAK_TRACK_write; \
	VARIABLE trans3_Temp_DECAY_RATE; \
	MENU trans3_Temp_DECAY_RATE_page; \
	COMMAND trans3_Temp_DECAY_RATE_read; \
	COMMAND trans3_Temp_DECAY_RATE_write; \
	VARIABLE trans3_Temp_PEAK_TIME; \
	MENU trans3_Temp_PEAK_TIME_page; \
	COMMAND trans3_Temp_PEAK_TIME_read; \
	COMMAND trans3_Temp_PEAK_TIME_write; \
	VARIABLE trans3_Temp_TRACK_HOLD; \
	MENU trans3_Temp_TRACK_HOLD_page; \
	COMMAND trans3_Temp_TRACK_HOLD_read; \
	COMMAND trans3_Temp_TRACK_HOLD_write; \
	VARIABLE trans3_Temp_SPECT_FILT_SET; \
	MENU trans3_Temp_SPECT_FILT_SET_page; \
	COMMAND trans3_Temp_SPECT_FILT_SET_read; \
	COMMAND trans3_Temp_SPECT_FILT_SET_write; \
	MENU trans3_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS3_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans3_Temp_RJ_TYPE; \
	MENU trans3_Temp_RJ_TYPE_page; \
	COMMAND trans3_Temp_RJ_TYPE_read; \
	COMMAND trans3_Temp_RJ_TYPE_write; \
	MENU trans3_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS3_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans3_Temp_SENSOR_CONNECTION; \
	MENU trans3_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans3_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans3_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans3_Temp_COMP_WIRE1; \
	MENU trans3_Temp_COMP_WIRE1_page; \
	COMMAND trans3_Temp_COMP_WIRE1_read; \
	COMMAND trans3_Temp_COMP_WIRE1_write; \
	MENU trans3_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS3_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans3_Temp_EMISSIVITY; \
	MENU trans3_Temp_EMISSIVITY_page; \
	COMMAND trans3_Temp_EMISSIVITY_read; \
	COMMAND trans3_Temp_EMISSIVITY_write; \
	VARIABLE trans3_Temp_PEAK_TRACK; \
	MENU trans3_Temp_PEAK_TRACK_page; \
	COMMAND trans3_Temp_PEAK_TRACK_read; \
	COMMAND trans3_Temp_PEAK_TRACK_write; \
	VARIABLE trans3_Temp_DECAY_RATE; \
	MENU trans3_Temp_DECAY_RATE_page; \
	COMMAND trans3_Temp_DECAY_RATE_read; \
	COMMAND trans3_Temp_DECAY_RATE_write; \
	VARIABLE trans3_Temp_PEAK_TIME; \
	MENU trans3_Temp_PEAK_TIME_page; \
	COMMAND trans3_Temp_PEAK_TIME_read; \
	COMMAND trans3_Temp_PEAK_TIME_write; \
	VARIABLE trans3_Temp_TRACK_HOLD; \
	MENU trans3_Temp_TRACK_HOLD_page; \
	COMMAND trans3_Temp_TRACK_HOLD_read; \
	COMMAND trans3_Temp_TRACK_HOLD_write; \
	VARIABLE trans3_Temp_SPECT_FILT_SET; \
	MENU trans3_Temp_SPECT_FILT_SET_page; \
	COMMAND trans3_Temp_SPECT_FILT_SET_read; \
	COMMAND trans3_Temp_SPECT_FILT_SET_write; \
	MENU trans3_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS3_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans3_Temp_RJ_TEMP; \
	MENU trans3_Temp_RJ_TEMP_page; \
	COMMAND trans3_Temp_RJ_TEMP_read; \
	VARIABLE trans3_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans3_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans3_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans3_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans3_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans3_Temp_Unit_3

#define USE_TRANS3_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans3_Temp_COMP_WIRE2; \
	MENU trans3_Temp_COMP_WIRE2_page; \
	COMMAND trans3_Temp_COMP_WIRE2_read; \
	COMMAND trans3_Temp_COMP_WIRE2_write; \
	MENU trans3_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS3_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans3_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS3_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans3_Temp_RJ_TEMP; \
	MENU trans3_Temp_RJ_TEMP_page; \
	COMMAND trans3_Temp_RJ_TEMP_read; \
	VARIABLE trans3_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans3_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans3_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans3_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans3_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans3_Temp_Unit_3

#define USE_TRANS3_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans3_Temp_COMP_WIRE2; \
	MENU trans3_Temp_COMP_WIRE2_page; \
	COMMAND trans3_Temp_COMP_WIRE2_read; \
	COMMAND trans3_Temp_COMP_WIRE2_write; \
	MENU trans3_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS3_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans3_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans3_Temp_)
#define USE_TRANS3_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans3_Temp_)
#define USE_TRANS3_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans3_Temp_)
#define USE_TRANS3_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans3_Temp_)
#define USE_TRANS3_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans3_Temp_)
#define USE_TRANS3_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans3_Temp_)
#define USE_TRANS3_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans3_Temp_)
#define USE_TRANS3_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans3_Temp_)
#define USE_TRANS3_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans3_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_TEMP_MANDATORY_BOTH \
	BLOCK trans4_Temp_block; \
	COLLECTION trans4_Temp_BLOCK_OBJECT; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Temp_BLOCK_OBJECT_page; \
	COMMAND trans4_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans4_Temp_ST_REV; \
	MENU trans4_Temp_ST_REV_page; \
	COMMAND trans4_Temp_ST_REV_read; \
	VARIABLE trans4_Temp_TAG_DESC; \
	MENU trans4_Temp_TAG_DESC_page; \
	COMMAND trans4_Temp_TAG_DESC_read; \
	COMMAND trans4_Temp_TAG_DESC_write; \
	VARIABLE trans4_Temp_STRATEGY; \
	MENU trans4_Temp_STRATEGY_page; \
	COMMAND trans4_Temp_STRATEGY_read; \
	COMMAND trans4_Temp_STRATEGY_write; \
	VARIABLE trans4_Temp_ALERT_KEY; \
	MENU trans4_Temp_ALERT_KEY_page; \
	COMMAND trans4_Temp_ALERT_KEY_read; \
	COMMAND trans4_Temp_ALERT_KEY_write; \
	VARIABLE trans4_Temp_TARGET_MODE; \
	MENU trans4_Temp_TARGET_MODE_page; \
	COMMAND trans4_Temp_TARGET_MODE_read; \
	COMMAND trans4_Temp_TARGET_MODE_write; \
	COLLECTION trans4_Temp_MODE_BLK; \
	VARIABLE trans4_Temp_MODE_BLK_Actual; \
	VARIABLE trans4_Temp_MODE_BLK_Permitted; \
	VARIABLE trans4_Temp_MODE_BLK_Normal; \
	MENU trans4_Temp_MODE_BLK_page; \
	COMMAND trans4_Temp_MODE_BLK_read; \
	COLLECTION trans4_Temp_ALARM_SUM; \
	VARIABLE trans4_Temp_ALARM_SUM_Current; \
	VARIABLE trans4_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans4_Temp_ALARM_SUM_Disabled; \
	MENU trans4_Temp_ALARM_SUM_page; \
	COMMAND trans4_Temp_ALARM_SUM_read; \
	COLLECTION trans4_Temp_PRIMARY_VALUE; \
	VARIABLE trans4_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans4_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans4_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans4_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans4_Temp_PRIMARY_VALUE_page; \
	COMMAND trans4_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans4_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans4_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans4_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans4_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans4_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans4_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans4_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans4_Temp_SENSOR_MEAS_TYPE; \
	MENU trans4_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans4_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans4_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans4_Temp_INPUT_RANGE; \
	MENU trans4_Temp_INPUT_RANGE_page; \
	COMMAND trans4_Temp_INPUT_RANGE_read; \
	COMMAND trans4_Temp_INPUT_RANGE_write; \
	VARIABLE trans4_Temp_LIN_TYPE; \
	MENU trans4_Temp_LIN_TYPE_page; \
	COMMAND trans4_Temp_LIN_TYPE_read; \
	COMMAND trans4_Temp_LIN_TYPE_write; \
	VARIABLE trans4_Temp_BIAS_1; \
	MENU trans4_Temp_BIAS_1_page; \
	COMMAND trans4_Temp_BIAS_1_read; \
	COMMAND trans4_Temp_BIAS_1_write; \
	VARIABLE trans4_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans4_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans4_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans4_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans4_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans4_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans4_Temp_INPUT_FAULT_GEN; \
	MENU trans4_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans4_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans4_Temp_INPUT_FAULT_1; \
	MENU trans4_Temp_INPUT_FAULT_1_page; \
	COMMAND trans4_Temp_INPUT_FAULT_1_read; \
	UNIT trans4_Temp_Unit_1; \
	VARIABLE trans4_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans4_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans4_Temp_Display; \
	CHART trans4_Temp_Display_BarVal_pv; \
	SOURCE trans4_Temp_Display_BarVal_pv_source; \
	MENU trans4_Temp_Display_primary; \
	MENU trans4_Temp_Display_secondary; \
	MENU trans4_Temp_Tab_s; \
	MENU trans4_Temp_Tab_s_measrange; \
	MENU trans4_Temp_Tab_m

#define USE_TRANS4_TEMP_MANDATORY_A \
	USE_TRANS4_TEMP_MANDATORY_BOTH; \
	MENU trans4_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS4_TEMP_MANDATORY_B \
	USE_TRANS4_TEMP_MANDATORY_BOTH; \
	COLLECTION trans4_Temp_VIEW_1; \
	MENU trans4_Temp_VIEW_1_page; \
	MENU trans4_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS4_TEMP_OPTIONAL_BOTH \
	COLLECTION trans4_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans4_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans4_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans4_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans4_Temp_BIAS_2; \
	MENU trans4_Temp_BIAS_2_page; \
	COMMAND trans4_Temp_BIAS_2_read; \
	COMMAND trans4_Temp_BIAS_2_write; \
	VARIABLE trans4_Temp_INPUT_FAULT_2; \
	MENU trans4_Temp_INPUT_FAULT_2_page; \
	COMMAND trans4_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans4_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans4_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans4_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans4_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans4_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans4_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans4_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans4_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans4_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans4_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans4_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans4_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans4_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans4_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans4_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans4_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans4_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans4_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans4_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans4_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans4_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans4_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans4_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans4_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans4_Temp_TAB_ENTRY; \
	MENU trans4_Temp_TAB_ENTRY_page; \
	COMMAND trans4_Temp_TAB_ENTRY_read; \
	COMMAND trans4_Temp_TAB_ENTRY_write; \
	COLLECTION trans4_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans4_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans4_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans4_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans4_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans4_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans4_Temp_TAB_MIN_NUMBER; \
	MENU trans4_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans4_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans4_Temp_TAB_MAX_NUMBER; \
	MENU trans4_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans4_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans4_Temp_TAB_OP_CODE; \
	MENU trans4_Temp_TAB_OP_CODE_page; \
	COMMAND trans4_Temp_TAB_OP_CODE_read; \
	COMMAND trans4_Temp_TAB_OP_CODE_write; \
	VARIABLE trans4_Temp_TAB_STATUS; \
	MENU trans4_Temp_TAB_STATUS_page; \
	COMMAND trans4_Temp_TAB_STATUS_read; \
	VARIABLE trans4_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans4_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans4_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans4_Temp_VIEW_2; \
	MENU trans4_Temp_VIEW_2_page; \
	COLLECTION trans4_Temp_VIEW_3; \
	MENU trans4_Temp_VIEW_3_page; \
	UNIT trans4_Temp_Unit_2

#define USE_TRANS4_TEMP_OPTIONAL_A \
	USE_TRANS4_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans4_Temp_VIEW_1; \
	MENU trans4_Temp_VIEW_1_page; \
	MENU trans4_Temp_Simple_Dialog_Optional_A

#define USE_TRANS4_TEMP_OPTIONAL_B \
	USE_TRANS4_TEMP_OPTIONAL_BOTH; \
	MENU trans4_Temp_Simple_Dialog_Optional_B

#define USE_TRANS4_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans4_Temp_RJ_TYPE; \
	MENU trans4_Temp_RJ_TYPE_page; \
	COMMAND trans4_Temp_RJ_TYPE_read; \
	COMMAND trans4_Temp_RJ_TYPE_write; \
	MENU trans4_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS4_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans4_Temp_SENSOR_CONNECTION; \
	MENU trans4_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans4_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans4_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans4_Temp_COMP_WIRE1; \
	MENU trans4_Temp_COMP_WIRE1_page; \
	COMMAND trans4_Temp_COMP_WIRE1_read; \
	COMMAND trans4_Temp_COMP_WIRE1_write; \
	MENU trans4_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS4_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans4_Temp_EMISSIVITY; \
	MENU trans4_Temp_EMISSIVITY_page; \
	COMMAND trans4_Temp_EMISSIVITY_read; \
	COMMAND trans4_Temp_EMISSIVITY_write; \
	VARIABLE trans4_Temp_PEAK_TRACK; \
	MENU trans4_Temp_PEAK_TRACK_page; \
	COMMAND trans4_Temp_PEAK_TRACK_read; \
	COMMAND trans4_Temp_PEAK_TRACK_write; \
	VARIABLE trans4_Temp_DECAY_RATE; \
	MENU trans4_Temp_DECAY_RATE_page; \
	COMMAND trans4_Temp_DECAY_RATE_read; \
	COMMAND trans4_Temp_DECAY_RATE_write; \
	VARIABLE trans4_Temp_PEAK_TIME; \
	MENU trans4_Temp_PEAK_TIME_page; \
	COMMAND trans4_Temp_PEAK_TIME_read; \
	COMMAND trans4_Temp_PEAK_TIME_write; \
	VARIABLE trans4_Temp_TRACK_HOLD; \
	MENU trans4_Temp_TRACK_HOLD_page; \
	COMMAND trans4_Temp_TRACK_HOLD_read; \
	COMMAND trans4_Temp_TRACK_HOLD_write; \
	VARIABLE trans4_Temp_SPECT_FILT_SET; \
	MENU trans4_Temp_SPECT_FILT_SET_page; \
	COMMAND trans4_Temp_SPECT_FILT_SET_read; \
	COMMAND trans4_Temp_SPECT_FILT_SET_write; \
	MENU trans4_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS4_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans4_Temp_RJ_TYPE; \
	MENU trans4_Temp_RJ_TYPE_page; \
	COMMAND trans4_Temp_RJ_TYPE_read; \
	COMMAND trans4_Temp_RJ_TYPE_write; \
	MENU trans4_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS4_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans4_Temp_SENSOR_CONNECTION; \
	MENU trans4_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans4_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans4_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans4_Temp_COMP_WIRE1; \
	MENU trans4_Temp_COMP_WIRE1_page; \
	COMMAND trans4_Temp_COMP_WIRE1_read; \
	COMMAND trans4_Temp_COMP_WIRE1_write; \
	MENU trans4_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS4_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans4_Temp_EMISSIVITY; \
	MENU trans4_Temp_EMISSIVITY_page; \
	COMMAND trans4_Temp_EMISSIVITY_read; \
	COMMAND trans4_Temp_EMISSIVITY_write; \
	VARIABLE trans4_Temp_PEAK_TRACK; \
	MENU trans4_Temp_PEAK_TRACK_page; \
	COMMAND trans4_Temp_PEAK_TRACK_read; \
	COMMAND trans4_Temp_PEAK_TRACK_write; \
	VARIABLE trans4_Temp_DECAY_RATE; \
	MENU trans4_Temp_DECAY_RATE_page; \
	COMMAND trans4_Temp_DECAY_RATE_read; \
	COMMAND trans4_Temp_DECAY_RATE_write; \
	VARIABLE trans4_Temp_PEAK_TIME; \
	MENU trans4_Temp_PEAK_TIME_page; \
	COMMAND trans4_Temp_PEAK_TIME_read; \
	COMMAND trans4_Temp_PEAK_TIME_write; \
	VARIABLE trans4_Temp_TRACK_HOLD; \
	MENU trans4_Temp_TRACK_HOLD_page; \
	COMMAND trans4_Temp_TRACK_HOLD_read; \
	COMMAND trans4_Temp_TRACK_HOLD_write; \
	VARIABLE trans4_Temp_SPECT_FILT_SET; \
	MENU trans4_Temp_SPECT_FILT_SET_page; \
	COMMAND trans4_Temp_SPECT_FILT_SET_read; \
	COMMAND trans4_Temp_SPECT_FILT_SET_write; \
	MENU trans4_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS4_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans4_Temp_RJ_TEMP; \
	MENU trans4_Temp_RJ_TEMP_page; \
	COMMAND trans4_Temp_RJ_TEMP_read; \
	VARIABLE trans4_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans4_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans4_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans4_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans4_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans4_Temp_Unit_3

#define USE_TRANS4_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans4_Temp_COMP_WIRE2; \
	MENU trans4_Temp_COMP_WIRE2_page; \
	COMMAND trans4_Temp_COMP_WIRE2_read; \
	COMMAND trans4_Temp_COMP_WIRE2_write; \
	MENU trans4_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS4_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans4_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS4_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans4_Temp_RJ_TEMP; \
	MENU trans4_Temp_RJ_TEMP_page; \
	COMMAND trans4_Temp_RJ_TEMP_read; \
	VARIABLE trans4_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans4_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans4_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans4_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans4_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans4_Temp_Unit_3

#define USE_TRANS4_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans4_Temp_COMP_WIRE2; \
	MENU trans4_Temp_COMP_WIRE2_page; \
	COMMAND trans4_Temp_COMP_WIRE2_read; \
	COMMAND trans4_Temp_COMP_WIRE2_write; \
	MENU trans4_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS4_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans4_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans4_Temp_)
#define USE_TRANS4_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans4_Temp_)
#define USE_TRANS4_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans4_Temp_)
#define USE_TRANS4_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans4_Temp_)
#define USE_TRANS4_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans4_Temp_)
#define USE_TRANS4_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans4_Temp_)
#define USE_TRANS4_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans4_Temp_)
#define USE_TRANS4_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans4_Temp_)
#define USE_TRANS4_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans4_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_TEMP_MANDATORY_BOTH \
	BLOCK trans5_Temp_block; \
	COLLECTION trans5_Temp_BLOCK_OBJECT; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Temp_BLOCK_OBJECT_page; \
	COMMAND trans5_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans5_Temp_ST_REV; \
	MENU trans5_Temp_ST_REV_page; \
	COMMAND trans5_Temp_ST_REV_read; \
	VARIABLE trans5_Temp_TAG_DESC; \
	MENU trans5_Temp_TAG_DESC_page; \
	COMMAND trans5_Temp_TAG_DESC_read; \
	COMMAND trans5_Temp_TAG_DESC_write; \
	VARIABLE trans5_Temp_STRATEGY; \
	MENU trans5_Temp_STRATEGY_page; \
	COMMAND trans5_Temp_STRATEGY_read; \
	COMMAND trans5_Temp_STRATEGY_write; \
	VARIABLE trans5_Temp_ALERT_KEY; \
	MENU trans5_Temp_ALERT_KEY_page; \
	COMMAND trans5_Temp_ALERT_KEY_read; \
	COMMAND trans5_Temp_ALERT_KEY_write; \
	VARIABLE trans5_Temp_TARGET_MODE; \
	MENU trans5_Temp_TARGET_MODE_page; \
	COMMAND trans5_Temp_TARGET_MODE_read; \
	COMMAND trans5_Temp_TARGET_MODE_write; \
	COLLECTION trans5_Temp_MODE_BLK; \
	VARIABLE trans5_Temp_MODE_BLK_Actual; \
	VARIABLE trans5_Temp_MODE_BLK_Permitted; \
	VARIABLE trans5_Temp_MODE_BLK_Normal; \
	MENU trans5_Temp_MODE_BLK_page; \
	COMMAND trans5_Temp_MODE_BLK_read; \
	COLLECTION trans5_Temp_ALARM_SUM; \
	VARIABLE trans5_Temp_ALARM_SUM_Current; \
	VARIABLE trans5_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans5_Temp_ALARM_SUM_Disabled; \
	MENU trans5_Temp_ALARM_SUM_page; \
	COMMAND trans5_Temp_ALARM_SUM_read; \
	COLLECTION trans5_Temp_PRIMARY_VALUE; \
	VARIABLE trans5_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans5_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans5_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans5_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans5_Temp_PRIMARY_VALUE_page; \
	COMMAND trans5_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans5_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans5_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans5_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans5_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans5_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans5_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans5_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans5_Temp_SENSOR_MEAS_TYPE; \
	MENU trans5_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans5_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans5_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans5_Temp_INPUT_RANGE; \
	MENU trans5_Temp_INPUT_RANGE_page; \
	COMMAND trans5_Temp_INPUT_RANGE_read; \
	COMMAND trans5_Temp_INPUT_RANGE_write; \
	VARIABLE trans5_Temp_LIN_TYPE; \
	MENU trans5_Temp_LIN_TYPE_page; \
	COMMAND trans5_Temp_LIN_TYPE_read; \
	COMMAND trans5_Temp_LIN_TYPE_write; \
	VARIABLE trans5_Temp_BIAS_1; \
	MENU trans5_Temp_BIAS_1_page; \
	COMMAND trans5_Temp_BIAS_1_read; \
	COMMAND trans5_Temp_BIAS_1_write; \
	VARIABLE trans5_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans5_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans5_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans5_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans5_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans5_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans5_Temp_INPUT_FAULT_GEN; \
	MENU trans5_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans5_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans5_Temp_INPUT_FAULT_1; \
	MENU trans5_Temp_INPUT_FAULT_1_page; \
	COMMAND trans5_Temp_INPUT_FAULT_1_read; \
	UNIT trans5_Temp_Unit_1; \
	VARIABLE trans5_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans5_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans5_Temp_Display; \
	CHART trans5_Temp_Display_BarVal_pv; \
	SOURCE trans5_Temp_Display_BarVal_pv_source; \
	MENU trans5_Temp_Display_primary; \
	MENU trans5_Temp_Display_secondary; \
	MENU trans5_Temp_Tab_s; \
	MENU trans5_Temp_Tab_s_measrange; \
	MENU trans5_Temp_Tab_m

#define USE_TRANS5_TEMP_MANDATORY_A \
	USE_TRANS5_TEMP_MANDATORY_BOTH; \
	MENU trans5_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS5_TEMP_MANDATORY_B \
	USE_TRANS5_TEMP_MANDATORY_BOTH; \
	COLLECTION trans5_Temp_VIEW_1; \
	MENU trans5_Temp_VIEW_1_page; \
	MENU trans5_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS5_TEMP_OPTIONAL_BOTH \
	COLLECTION trans5_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans5_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans5_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans5_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans5_Temp_BIAS_2; \
	MENU trans5_Temp_BIAS_2_page; \
	COMMAND trans5_Temp_BIAS_2_read; \
	COMMAND trans5_Temp_BIAS_2_write; \
	VARIABLE trans5_Temp_INPUT_FAULT_2; \
	MENU trans5_Temp_INPUT_FAULT_2_page; \
	COMMAND trans5_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans5_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans5_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans5_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans5_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans5_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans5_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans5_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans5_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans5_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans5_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans5_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans5_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans5_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans5_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans5_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans5_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans5_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans5_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans5_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans5_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans5_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans5_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans5_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans5_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans5_Temp_TAB_ENTRY; \
	MENU trans5_Temp_TAB_ENTRY_page; \
	COMMAND trans5_Temp_TAB_ENTRY_read; \
	COMMAND trans5_Temp_TAB_ENTRY_write; \
	COLLECTION trans5_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans5_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans5_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans5_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans5_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans5_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans5_Temp_TAB_MIN_NUMBER; \
	MENU trans5_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans5_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans5_Temp_TAB_MAX_NUMBER; \
	MENU trans5_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans5_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans5_Temp_TAB_OP_CODE; \
	MENU trans5_Temp_TAB_OP_CODE_page; \
	COMMAND trans5_Temp_TAB_OP_CODE_read; \
	COMMAND trans5_Temp_TAB_OP_CODE_write; \
	VARIABLE trans5_Temp_TAB_STATUS; \
	MENU trans5_Temp_TAB_STATUS_page; \
	COMMAND trans5_Temp_TAB_STATUS_read; \
	VARIABLE trans5_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans5_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans5_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans5_Temp_VIEW_2; \
	MENU trans5_Temp_VIEW_2_page; \
	COLLECTION trans5_Temp_VIEW_3; \
	MENU trans5_Temp_VIEW_3_page; \
	UNIT trans5_Temp_Unit_2

#define USE_TRANS5_TEMP_OPTIONAL_A \
	USE_TRANS5_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans5_Temp_VIEW_1; \
	MENU trans5_Temp_VIEW_1_page; \
	MENU trans5_Temp_Simple_Dialog_Optional_A

#define USE_TRANS5_TEMP_OPTIONAL_B \
	USE_TRANS5_TEMP_OPTIONAL_BOTH; \
	MENU trans5_Temp_Simple_Dialog_Optional_B

#define USE_TRANS5_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans5_Temp_RJ_TYPE; \
	MENU trans5_Temp_RJ_TYPE_page; \
	COMMAND trans5_Temp_RJ_TYPE_read; \
	COMMAND trans5_Temp_RJ_TYPE_write; \
	MENU trans5_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS5_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans5_Temp_SENSOR_CONNECTION; \
	MENU trans5_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans5_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans5_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans5_Temp_COMP_WIRE1; \
	MENU trans5_Temp_COMP_WIRE1_page; \
	COMMAND trans5_Temp_COMP_WIRE1_read; \
	COMMAND trans5_Temp_COMP_WIRE1_write; \
	MENU trans5_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS5_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans5_Temp_EMISSIVITY; \
	MENU trans5_Temp_EMISSIVITY_page; \
	COMMAND trans5_Temp_EMISSIVITY_read; \
	COMMAND trans5_Temp_EMISSIVITY_write; \
	VARIABLE trans5_Temp_PEAK_TRACK; \
	MENU trans5_Temp_PEAK_TRACK_page; \
	COMMAND trans5_Temp_PEAK_TRACK_read; \
	COMMAND trans5_Temp_PEAK_TRACK_write; \
	VARIABLE trans5_Temp_DECAY_RATE; \
	MENU trans5_Temp_DECAY_RATE_page; \
	COMMAND trans5_Temp_DECAY_RATE_read; \
	COMMAND trans5_Temp_DECAY_RATE_write; \
	VARIABLE trans5_Temp_PEAK_TIME; \
	MENU trans5_Temp_PEAK_TIME_page; \
	COMMAND trans5_Temp_PEAK_TIME_read; \
	COMMAND trans5_Temp_PEAK_TIME_write; \
	VARIABLE trans5_Temp_TRACK_HOLD; \
	MENU trans5_Temp_TRACK_HOLD_page; \
	COMMAND trans5_Temp_TRACK_HOLD_read; \
	COMMAND trans5_Temp_TRACK_HOLD_write; \
	VARIABLE trans5_Temp_SPECT_FILT_SET; \
	MENU trans5_Temp_SPECT_FILT_SET_page; \
	COMMAND trans5_Temp_SPECT_FILT_SET_read; \
	COMMAND trans5_Temp_SPECT_FILT_SET_write; \
	MENU trans5_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS5_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans5_Temp_RJ_TYPE; \
	MENU trans5_Temp_RJ_TYPE_page; \
	COMMAND trans5_Temp_RJ_TYPE_read; \
	COMMAND trans5_Temp_RJ_TYPE_write; \
	MENU trans5_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS5_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans5_Temp_SENSOR_CONNECTION; \
	MENU trans5_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans5_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans5_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans5_Temp_COMP_WIRE1; \
	MENU trans5_Temp_COMP_WIRE1_page; \
	COMMAND trans5_Temp_COMP_WIRE1_read; \
	COMMAND trans5_Temp_COMP_WIRE1_write; \
	MENU trans5_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS5_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans5_Temp_EMISSIVITY; \
	MENU trans5_Temp_EMISSIVITY_page; \
	COMMAND trans5_Temp_EMISSIVITY_read; \
	COMMAND trans5_Temp_EMISSIVITY_write; \
	VARIABLE trans5_Temp_PEAK_TRACK; \
	MENU trans5_Temp_PEAK_TRACK_page; \
	COMMAND trans5_Temp_PEAK_TRACK_read; \
	COMMAND trans5_Temp_PEAK_TRACK_write; \
	VARIABLE trans5_Temp_DECAY_RATE; \
	MENU trans5_Temp_DECAY_RATE_page; \
	COMMAND trans5_Temp_DECAY_RATE_read; \
	COMMAND trans5_Temp_DECAY_RATE_write; \
	VARIABLE trans5_Temp_PEAK_TIME; \
	MENU trans5_Temp_PEAK_TIME_page; \
	COMMAND trans5_Temp_PEAK_TIME_read; \
	COMMAND trans5_Temp_PEAK_TIME_write; \
	VARIABLE trans5_Temp_TRACK_HOLD; \
	MENU trans5_Temp_TRACK_HOLD_page; \
	COMMAND trans5_Temp_TRACK_HOLD_read; \
	COMMAND trans5_Temp_TRACK_HOLD_write; \
	VARIABLE trans5_Temp_SPECT_FILT_SET; \
	MENU trans5_Temp_SPECT_FILT_SET_page; \
	COMMAND trans5_Temp_SPECT_FILT_SET_read; \
	COMMAND trans5_Temp_SPECT_FILT_SET_write; \
	MENU trans5_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS5_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans5_Temp_RJ_TEMP; \
	MENU trans5_Temp_RJ_TEMP_page; \
	COMMAND trans5_Temp_RJ_TEMP_read; \
	VARIABLE trans5_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans5_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans5_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans5_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans5_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans5_Temp_Unit_3

#define USE_TRANS5_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans5_Temp_COMP_WIRE2; \
	MENU trans5_Temp_COMP_WIRE2_page; \
	COMMAND trans5_Temp_COMP_WIRE2_read; \
	COMMAND trans5_Temp_COMP_WIRE2_write; \
	MENU trans5_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS5_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans5_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS5_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans5_Temp_RJ_TEMP; \
	MENU trans5_Temp_RJ_TEMP_page; \
	COMMAND trans5_Temp_RJ_TEMP_read; \
	VARIABLE trans5_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans5_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans5_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans5_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans5_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans5_Temp_Unit_3

#define USE_TRANS5_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans5_Temp_COMP_WIRE2; \
	MENU trans5_Temp_COMP_WIRE2_page; \
	COMMAND trans5_Temp_COMP_WIRE2_read; \
	COMMAND trans5_Temp_COMP_WIRE2_write; \
	MENU trans5_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS5_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans5_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans5_Temp_)
#define USE_TRANS5_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans5_Temp_)
#define USE_TRANS5_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans5_Temp_)
#define USE_TRANS5_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans5_Temp_)
#define USE_TRANS5_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans5_Temp_)
#define USE_TRANS5_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans5_Temp_)
#define USE_TRANS5_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans5_Temp_)
#define USE_TRANS5_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans5_Temp_)
#define USE_TRANS5_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans5_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_TEMP_MANDATORY_BOTH \
	BLOCK trans6_Temp_block; \
	COLLECTION trans6_Temp_BLOCK_OBJECT; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Temp_BLOCK_OBJECT_page; \
	COMMAND trans6_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans6_Temp_ST_REV; \
	MENU trans6_Temp_ST_REV_page; \
	COMMAND trans6_Temp_ST_REV_read; \
	VARIABLE trans6_Temp_TAG_DESC; \
	MENU trans6_Temp_TAG_DESC_page; \
	COMMAND trans6_Temp_TAG_DESC_read; \
	COMMAND trans6_Temp_TAG_DESC_write; \
	VARIABLE trans6_Temp_STRATEGY; \
	MENU trans6_Temp_STRATEGY_page; \
	COMMAND trans6_Temp_STRATEGY_read; \
	COMMAND trans6_Temp_STRATEGY_write; \
	VARIABLE trans6_Temp_ALERT_KEY; \
	MENU trans6_Temp_ALERT_KEY_page; \
	COMMAND trans6_Temp_ALERT_KEY_read; \
	COMMAND trans6_Temp_ALERT_KEY_write; \
	VARIABLE trans6_Temp_TARGET_MODE; \
	MENU trans6_Temp_TARGET_MODE_page; \
	COMMAND trans6_Temp_TARGET_MODE_read; \
	COMMAND trans6_Temp_TARGET_MODE_write; \
	COLLECTION trans6_Temp_MODE_BLK; \
	VARIABLE trans6_Temp_MODE_BLK_Actual; \
	VARIABLE trans6_Temp_MODE_BLK_Permitted; \
	VARIABLE trans6_Temp_MODE_BLK_Normal; \
	MENU trans6_Temp_MODE_BLK_page; \
	COMMAND trans6_Temp_MODE_BLK_read; \
	COLLECTION trans6_Temp_ALARM_SUM; \
	VARIABLE trans6_Temp_ALARM_SUM_Current; \
	VARIABLE trans6_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans6_Temp_ALARM_SUM_Disabled; \
	MENU trans6_Temp_ALARM_SUM_page; \
	COMMAND trans6_Temp_ALARM_SUM_read; \
	COLLECTION trans6_Temp_PRIMARY_VALUE; \
	VARIABLE trans6_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans6_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans6_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans6_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans6_Temp_PRIMARY_VALUE_page; \
	COMMAND trans6_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans6_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans6_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans6_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans6_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans6_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans6_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans6_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans6_Temp_SENSOR_MEAS_TYPE; \
	MENU trans6_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans6_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans6_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans6_Temp_INPUT_RANGE; \
	MENU trans6_Temp_INPUT_RANGE_page; \
	COMMAND trans6_Temp_INPUT_RANGE_read; \
	COMMAND trans6_Temp_INPUT_RANGE_write; \
	VARIABLE trans6_Temp_LIN_TYPE; \
	MENU trans6_Temp_LIN_TYPE_page; \
	COMMAND trans6_Temp_LIN_TYPE_read; \
	COMMAND trans6_Temp_LIN_TYPE_write; \
	VARIABLE trans6_Temp_BIAS_1; \
	MENU trans6_Temp_BIAS_1_page; \
	COMMAND trans6_Temp_BIAS_1_read; \
	COMMAND trans6_Temp_BIAS_1_write; \
	VARIABLE trans6_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans6_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans6_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans6_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans6_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans6_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans6_Temp_INPUT_FAULT_GEN; \
	MENU trans6_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans6_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans6_Temp_INPUT_FAULT_1; \
	MENU trans6_Temp_INPUT_FAULT_1_page; \
	COMMAND trans6_Temp_INPUT_FAULT_1_read; \
	UNIT trans6_Temp_Unit_1; \
	VARIABLE trans6_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans6_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans6_Temp_Display; \
	CHART trans6_Temp_Display_BarVal_pv; \
	SOURCE trans6_Temp_Display_BarVal_pv_source; \
	MENU trans6_Temp_Display_primary; \
	MENU trans6_Temp_Display_secondary; \
	MENU trans6_Temp_Tab_s; \
	MENU trans6_Temp_Tab_s_measrange; \
	MENU trans6_Temp_Tab_m

#define USE_TRANS6_TEMP_MANDATORY_A \
	USE_TRANS6_TEMP_MANDATORY_BOTH; \
	MENU trans6_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS6_TEMP_MANDATORY_B \
	USE_TRANS6_TEMP_MANDATORY_BOTH; \
	COLLECTION trans6_Temp_VIEW_1; \
	MENU trans6_Temp_VIEW_1_page; \
	MENU trans6_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS6_TEMP_OPTIONAL_BOTH \
	COLLECTION trans6_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans6_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans6_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans6_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans6_Temp_BIAS_2; \
	MENU trans6_Temp_BIAS_2_page; \
	COMMAND trans6_Temp_BIAS_2_read; \
	COMMAND trans6_Temp_BIAS_2_write; \
	VARIABLE trans6_Temp_INPUT_FAULT_2; \
	MENU trans6_Temp_INPUT_FAULT_2_page; \
	COMMAND trans6_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans6_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans6_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans6_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans6_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans6_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans6_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans6_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans6_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans6_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans6_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans6_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans6_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans6_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans6_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans6_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans6_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans6_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans6_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans6_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans6_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans6_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans6_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans6_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans6_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans6_Temp_TAB_ENTRY; \
	MENU trans6_Temp_TAB_ENTRY_page; \
	COMMAND trans6_Temp_TAB_ENTRY_read; \
	COMMAND trans6_Temp_TAB_ENTRY_write; \
	COLLECTION trans6_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans6_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans6_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans6_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans6_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans6_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans6_Temp_TAB_MIN_NUMBER; \
	MENU trans6_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans6_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans6_Temp_TAB_MAX_NUMBER; \
	MENU trans6_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans6_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans6_Temp_TAB_OP_CODE; \
	MENU trans6_Temp_TAB_OP_CODE_page; \
	COMMAND trans6_Temp_TAB_OP_CODE_read; \
	COMMAND trans6_Temp_TAB_OP_CODE_write; \
	VARIABLE trans6_Temp_TAB_STATUS; \
	MENU trans6_Temp_TAB_STATUS_page; \
	COMMAND trans6_Temp_TAB_STATUS_read; \
	VARIABLE trans6_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans6_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans6_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans6_Temp_VIEW_2; \
	MENU trans6_Temp_VIEW_2_page; \
	COLLECTION trans6_Temp_VIEW_3; \
	MENU trans6_Temp_VIEW_3_page; \
	UNIT trans6_Temp_Unit_2

#define USE_TRANS6_TEMP_OPTIONAL_A \
	USE_TRANS6_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans6_Temp_VIEW_1; \
	MENU trans6_Temp_VIEW_1_page; \
	MENU trans6_Temp_Simple_Dialog_Optional_A

#define USE_TRANS6_TEMP_OPTIONAL_B \
	USE_TRANS6_TEMP_OPTIONAL_BOTH; \
	MENU trans6_Temp_Simple_Dialog_Optional_B

#define USE_TRANS6_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans6_Temp_RJ_TYPE; \
	MENU trans6_Temp_RJ_TYPE_page; \
	COMMAND trans6_Temp_RJ_TYPE_read; \
	COMMAND trans6_Temp_RJ_TYPE_write; \
	MENU trans6_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS6_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans6_Temp_SENSOR_CONNECTION; \
	MENU trans6_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans6_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans6_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans6_Temp_COMP_WIRE1; \
	MENU trans6_Temp_COMP_WIRE1_page; \
	COMMAND trans6_Temp_COMP_WIRE1_read; \
	COMMAND trans6_Temp_COMP_WIRE1_write; \
	MENU trans6_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS6_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans6_Temp_EMISSIVITY; \
	MENU trans6_Temp_EMISSIVITY_page; \
	COMMAND trans6_Temp_EMISSIVITY_read; \
	COMMAND trans6_Temp_EMISSIVITY_write; \
	VARIABLE trans6_Temp_PEAK_TRACK; \
	MENU trans6_Temp_PEAK_TRACK_page; \
	COMMAND trans6_Temp_PEAK_TRACK_read; \
	COMMAND trans6_Temp_PEAK_TRACK_write; \
	VARIABLE trans6_Temp_DECAY_RATE; \
	MENU trans6_Temp_DECAY_RATE_page; \
	COMMAND trans6_Temp_DECAY_RATE_read; \
	COMMAND trans6_Temp_DECAY_RATE_write; \
	VARIABLE trans6_Temp_PEAK_TIME; \
	MENU trans6_Temp_PEAK_TIME_page; \
	COMMAND trans6_Temp_PEAK_TIME_read; \
	COMMAND trans6_Temp_PEAK_TIME_write; \
	VARIABLE trans6_Temp_TRACK_HOLD; \
	MENU trans6_Temp_TRACK_HOLD_page; \
	COMMAND trans6_Temp_TRACK_HOLD_read; \
	COMMAND trans6_Temp_TRACK_HOLD_write; \
	VARIABLE trans6_Temp_SPECT_FILT_SET; \
	MENU trans6_Temp_SPECT_FILT_SET_page; \
	COMMAND trans6_Temp_SPECT_FILT_SET_read; \
	COMMAND trans6_Temp_SPECT_FILT_SET_write; \
	MENU trans6_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS6_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans6_Temp_RJ_TYPE; \
	MENU trans6_Temp_RJ_TYPE_page; \
	COMMAND trans6_Temp_RJ_TYPE_read; \
	COMMAND trans6_Temp_RJ_TYPE_write; \
	MENU trans6_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS6_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans6_Temp_SENSOR_CONNECTION; \
	MENU trans6_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans6_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans6_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans6_Temp_COMP_WIRE1; \
	MENU trans6_Temp_COMP_WIRE1_page; \
	COMMAND trans6_Temp_COMP_WIRE1_read; \
	COMMAND trans6_Temp_COMP_WIRE1_write; \
	MENU trans6_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS6_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans6_Temp_EMISSIVITY; \
	MENU trans6_Temp_EMISSIVITY_page; \
	COMMAND trans6_Temp_EMISSIVITY_read; \
	COMMAND trans6_Temp_EMISSIVITY_write; \
	VARIABLE trans6_Temp_PEAK_TRACK; \
	MENU trans6_Temp_PEAK_TRACK_page; \
	COMMAND trans6_Temp_PEAK_TRACK_read; \
	COMMAND trans6_Temp_PEAK_TRACK_write; \
	VARIABLE trans6_Temp_DECAY_RATE; \
	MENU trans6_Temp_DECAY_RATE_page; \
	COMMAND trans6_Temp_DECAY_RATE_read; \
	COMMAND trans6_Temp_DECAY_RATE_write; \
	VARIABLE trans6_Temp_PEAK_TIME; \
	MENU trans6_Temp_PEAK_TIME_page; \
	COMMAND trans6_Temp_PEAK_TIME_read; \
	COMMAND trans6_Temp_PEAK_TIME_write; \
	VARIABLE trans6_Temp_TRACK_HOLD; \
	MENU trans6_Temp_TRACK_HOLD_page; \
	COMMAND trans6_Temp_TRACK_HOLD_read; \
	COMMAND trans6_Temp_TRACK_HOLD_write; \
	VARIABLE trans6_Temp_SPECT_FILT_SET; \
	MENU trans6_Temp_SPECT_FILT_SET_page; \
	COMMAND trans6_Temp_SPECT_FILT_SET_read; \
	COMMAND trans6_Temp_SPECT_FILT_SET_write; \
	MENU trans6_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS6_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans6_Temp_RJ_TEMP; \
	MENU trans6_Temp_RJ_TEMP_page; \
	COMMAND trans6_Temp_RJ_TEMP_read; \
	VARIABLE trans6_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans6_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans6_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans6_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans6_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans6_Temp_Unit_3

#define USE_TRANS6_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans6_Temp_COMP_WIRE2; \
	MENU trans6_Temp_COMP_WIRE2_page; \
	COMMAND trans6_Temp_COMP_WIRE2_read; \
	COMMAND trans6_Temp_COMP_WIRE2_write; \
	MENU trans6_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS6_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans6_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS6_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans6_Temp_RJ_TEMP; \
	MENU trans6_Temp_RJ_TEMP_page; \
	COMMAND trans6_Temp_RJ_TEMP_read; \
	VARIABLE trans6_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans6_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans6_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans6_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans6_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans6_Temp_Unit_3

#define USE_TRANS6_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans6_Temp_COMP_WIRE2; \
	MENU trans6_Temp_COMP_WIRE2_page; \
	COMMAND trans6_Temp_COMP_WIRE2_read; \
	COMMAND trans6_Temp_COMP_WIRE2_write; \
	MENU trans6_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS6_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans6_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans6_Temp_)
#define USE_TRANS6_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans6_Temp_)
#define USE_TRANS6_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans6_Temp_)
#define USE_TRANS6_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans6_Temp_)
#define USE_TRANS6_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans6_Temp_)
#define USE_TRANS6_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans6_Temp_)
#define USE_TRANS6_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans6_Temp_)
#define USE_TRANS6_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans6_Temp_)
#define USE_TRANS6_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans6_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_TEMP_MANDATORY_BOTH \
	BLOCK trans7_Temp_block; \
	COLLECTION trans7_Temp_BLOCK_OBJECT; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Temp_BLOCK_OBJECT_page; \
	COMMAND trans7_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans7_Temp_ST_REV; \
	MENU trans7_Temp_ST_REV_page; \
	COMMAND trans7_Temp_ST_REV_read; \
	VARIABLE trans7_Temp_TAG_DESC; \
	MENU trans7_Temp_TAG_DESC_page; \
	COMMAND trans7_Temp_TAG_DESC_read; \
	COMMAND trans7_Temp_TAG_DESC_write; \
	VARIABLE trans7_Temp_STRATEGY; \
	MENU trans7_Temp_STRATEGY_page; \
	COMMAND trans7_Temp_STRATEGY_read; \
	COMMAND trans7_Temp_STRATEGY_write; \
	VARIABLE trans7_Temp_ALERT_KEY; \
	MENU trans7_Temp_ALERT_KEY_page; \
	COMMAND trans7_Temp_ALERT_KEY_read; \
	COMMAND trans7_Temp_ALERT_KEY_write; \
	VARIABLE trans7_Temp_TARGET_MODE; \
	MENU trans7_Temp_TARGET_MODE_page; \
	COMMAND trans7_Temp_TARGET_MODE_read; \
	COMMAND trans7_Temp_TARGET_MODE_write; \
	COLLECTION trans7_Temp_MODE_BLK; \
	VARIABLE trans7_Temp_MODE_BLK_Actual; \
	VARIABLE trans7_Temp_MODE_BLK_Permitted; \
	VARIABLE trans7_Temp_MODE_BLK_Normal; \
	MENU trans7_Temp_MODE_BLK_page; \
	COMMAND trans7_Temp_MODE_BLK_read; \
	COLLECTION trans7_Temp_ALARM_SUM; \
	VARIABLE trans7_Temp_ALARM_SUM_Current; \
	VARIABLE trans7_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans7_Temp_ALARM_SUM_Disabled; \
	MENU trans7_Temp_ALARM_SUM_page; \
	COMMAND trans7_Temp_ALARM_SUM_read; \
	COLLECTION trans7_Temp_PRIMARY_VALUE; \
	VARIABLE trans7_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans7_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans7_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans7_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans7_Temp_PRIMARY_VALUE_page; \
	COMMAND trans7_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans7_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans7_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans7_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans7_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans7_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans7_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans7_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans7_Temp_SENSOR_MEAS_TYPE; \
	MENU trans7_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans7_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans7_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans7_Temp_INPUT_RANGE; \
	MENU trans7_Temp_INPUT_RANGE_page; \
	COMMAND trans7_Temp_INPUT_RANGE_read; \
	COMMAND trans7_Temp_INPUT_RANGE_write; \
	VARIABLE trans7_Temp_LIN_TYPE; \
	MENU trans7_Temp_LIN_TYPE_page; \
	COMMAND trans7_Temp_LIN_TYPE_read; \
	COMMAND trans7_Temp_LIN_TYPE_write; \
	VARIABLE trans7_Temp_BIAS_1; \
	MENU trans7_Temp_BIAS_1_page; \
	COMMAND trans7_Temp_BIAS_1_read; \
	COMMAND trans7_Temp_BIAS_1_write; \
	VARIABLE trans7_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans7_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans7_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans7_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans7_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans7_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans7_Temp_INPUT_FAULT_GEN; \
	MENU trans7_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans7_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans7_Temp_INPUT_FAULT_1; \
	MENU trans7_Temp_INPUT_FAULT_1_page; \
	COMMAND trans7_Temp_INPUT_FAULT_1_read; \
	UNIT trans7_Temp_Unit_1; \
	VARIABLE trans7_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans7_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans7_Temp_Display; \
	CHART trans7_Temp_Display_BarVal_pv; \
	SOURCE trans7_Temp_Display_BarVal_pv_source; \
	MENU trans7_Temp_Display_primary; \
	MENU trans7_Temp_Display_secondary; \
	MENU trans7_Temp_Tab_s; \
	MENU trans7_Temp_Tab_s_measrange; \
	MENU trans7_Temp_Tab_m

#define USE_TRANS7_TEMP_MANDATORY_A \
	USE_TRANS7_TEMP_MANDATORY_BOTH; \
	MENU trans7_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS7_TEMP_MANDATORY_B \
	USE_TRANS7_TEMP_MANDATORY_BOTH; \
	COLLECTION trans7_Temp_VIEW_1; \
	MENU trans7_Temp_VIEW_1_page; \
	MENU trans7_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS7_TEMP_OPTIONAL_BOTH \
	COLLECTION trans7_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans7_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans7_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans7_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans7_Temp_BIAS_2; \
	MENU trans7_Temp_BIAS_2_page; \
	COMMAND trans7_Temp_BIAS_2_read; \
	COMMAND trans7_Temp_BIAS_2_write; \
	VARIABLE trans7_Temp_INPUT_FAULT_2; \
	MENU trans7_Temp_INPUT_FAULT_2_page; \
	COMMAND trans7_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans7_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans7_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans7_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans7_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans7_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans7_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans7_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans7_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans7_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans7_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans7_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans7_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans7_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans7_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans7_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans7_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans7_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans7_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans7_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans7_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans7_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans7_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans7_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans7_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans7_Temp_TAB_ENTRY; \
	MENU trans7_Temp_TAB_ENTRY_page; \
	COMMAND trans7_Temp_TAB_ENTRY_read; \
	COMMAND trans7_Temp_TAB_ENTRY_write; \
	COLLECTION trans7_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans7_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans7_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans7_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans7_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans7_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans7_Temp_TAB_MIN_NUMBER; \
	MENU trans7_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans7_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans7_Temp_TAB_MAX_NUMBER; \
	MENU trans7_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans7_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans7_Temp_TAB_OP_CODE; \
	MENU trans7_Temp_TAB_OP_CODE_page; \
	COMMAND trans7_Temp_TAB_OP_CODE_read; \
	COMMAND trans7_Temp_TAB_OP_CODE_write; \
	VARIABLE trans7_Temp_TAB_STATUS; \
	MENU trans7_Temp_TAB_STATUS_page; \
	COMMAND trans7_Temp_TAB_STATUS_read; \
	VARIABLE trans7_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans7_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans7_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans7_Temp_VIEW_2; \
	MENU trans7_Temp_VIEW_2_page; \
	COLLECTION trans7_Temp_VIEW_3; \
	MENU trans7_Temp_VIEW_3_page; \
	UNIT trans7_Temp_Unit_2

#define USE_TRANS7_TEMP_OPTIONAL_A \
	USE_TRANS7_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans7_Temp_VIEW_1; \
	MENU trans7_Temp_VIEW_1_page; \
	MENU trans7_Temp_Simple_Dialog_Optional_A

#define USE_TRANS7_TEMP_OPTIONAL_B \
	USE_TRANS7_TEMP_OPTIONAL_BOTH; \
	MENU trans7_Temp_Simple_Dialog_Optional_B

#define USE_TRANS7_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans7_Temp_RJ_TYPE; \
	MENU trans7_Temp_RJ_TYPE_page; \
	COMMAND trans7_Temp_RJ_TYPE_read; \
	COMMAND trans7_Temp_RJ_TYPE_write; \
	MENU trans7_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS7_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans7_Temp_SENSOR_CONNECTION; \
	MENU trans7_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans7_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans7_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans7_Temp_COMP_WIRE1; \
	MENU trans7_Temp_COMP_WIRE1_page; \
	COMMAND trans7_Temp_COMP_WIRE1_read; \
	COMMAND trans7_Temp_COMP_WIRE1_write; \
	MENU trans7_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS7_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans7_Temp_EMISSIVITY; \
	MENU trans7_Temp_EMISSIVITY_page; \
	COMMAND trans7_Temp_EMISSIVITY_read; \
	COMMAND trans7_Temp_EMISSIVITY_write; \
	VARIABLE trans7_Temp_PEAK_TRACK; \
	MENU trans7_Temp_PEAK_TRACK_page; \
	COMMAND trans7_Temp_PEAK_TRACK_read; \
	COMMAND trans7_Temp_PEAK_TRACK_write; \
	VARIABLE trans7_Temp_DECAY_RATE; \
	MENU trans7_Temp_DECAY_RATE_page; \
	COMMAND trans7_Temp_DECAY_RATE_read; \
	COMMAND trans7_Temp_DECAY_RATE_write; \
	VARIABLE trans7_Temp_PEAK_TIME; \
	MENU trans7_Temp_PEAK_TIME_page; \
	COMMAND trans7_Temp_PEAK_TIME_read; \
	COMMAND trans7_Temp_PEAK_TIME_write; \
	VARIABLE trans7_Temp_TRACK_HOLD; \
	MENU trans7_Temp_TRACK_HOLD_page; \
	COMMAND trans7_Temp_TRACK_HOLD_read; \
	COMMAND trans7_Temp_TRACK_HOLD_write; \
	VARIABLE trans7_Temp_SPECT_FILT_SET; \
	MENU trans7_Temp_SPECT_FILT_SET_page; \
	COMMAND trans7_Temp_SPECT_FILT_SET_read; \
	COMMAND trans7_Temp_SPECT_FILT_SET_write; \
	MENU trans7_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS7_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans7_Temp_RJ_TYPE; \
	MENU trans7_Temp_RJ_TYPE_page; \
	COMMAND trans7_Temp_RJ_TYPE_read; \
	COMMAND trans7_Temp_RJ_TYPE_write; \
	MENU trans7_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS7_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans7_Temp_SENSOR_CONNECTION; \
	MENU trans7_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans7_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans7_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans7_Temp_COMP_WIRE1; \
	MENU trans7_Temp_COMP_WIRE1_page; \
	COMMAND trans7_Temp_COMP_WIRE1_read; \
	COMMAND trans7_Temp_COMP_WIRE1_write; \
	MENU trans7_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS7_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans7_Temp_EMISSIVITY; \
	MENU trans7_Temp_EMISSIVITY_page; \
	COMMAND trans7_Temp_EMISSIVITY_read; \
	COMMAND trans7_Temp_EMISSIVITY_write; \
	VARIABLE trans7_Temp_PEAK_TRACK; \
	MENU trans7_Temp_PEAK_TRACK_page; \
	COMMAND trans7_Temp_PEAK_TRACK_read; \
	COMMAND trans7_Temp_PEAK_TRACK_write; \
	VARIABLE trans7_Temp_DECAY_RATE; \
	MENU trans7_Temp_DECAY_RATE_page; \
	COMMAND trans7_Temp_DECAY_RATE_read; \
	COMMAND trans7_Temp_DECAY_RATE_write; \
	VARIABLE trans7_Temp_PEAK_TIME; \
	MENU trans7_Temp_PEAK_TIME_page; \
	COMMAND trans7_Temp_PEAK_TIME_read; \
	COMMAND trans7_Temp_PEAK_TIME_write; \
	VARIABLE trans7_Temp_TRACK_HOLD; \
	MENU trans7_Temp_TRACK_HOLD_page; \
	COMMAND trans7_Temp_TRACK_HOLD_read; \
	COMMAND trans7_Temp_TRACK_HOLD_write; \
	VARIABLE trans7_Temp_SPECT_FILT_SET; \
	MENU trans7_Temp_SPECT_FILT_SET_page; \
	COMMAND trans7_Temp_SPECT_FILT_SET_read; \
	COMMAND trans7_Temp_SPECT_FILT_SET_write; \
	MENU trans7_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS7_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans7_Temp_RJ_TEMP; \
	MENU trans7_Temp_RJ_TEMP_page; \
	COMMAND trans7_Temp_RJ_TEMP_read; \
	VARIABLE trans7_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans7_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans7_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans7_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans7_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans7_Temp_Unit_3

#define USE_TRANS7_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans7_Temp_COMP_WIRE2; \
	MENU trans7_Temp_COMP_WIRE2_page; \
	COMMAND trans7_Temp_COMP_WIRE2_read; \
	COMMAND trans7_Temp_COMP_WIRE2_write; \
	MENU trans7_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS7_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans7_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS7_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans7_Temp_RJ_TEMP; \
	MENU trans7_Temp_RJ_TEMP_page; \
	COMMAND trans7_Temp_RJ_TEMP_read; \
	VARIABLE trans7_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans7_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans7_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans7_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans7_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans7_Temp_Unit_3

#define USE_TRANS7_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans7_Temp_COMP_WIRE2; \
	MENU trans7_Temp_COMP_WIRE2_page; \
	COMMAND trans7_Temp_COMP_WIRE2_read; \
	COMMAND trans7_Temp_COMP_WIRE2_write; \
	MENU trans7_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS7_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans7_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans7_Temp_)
#define USE_TRANS7_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans7_Temp_)
#define USE_TRANS7_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans7_Temp_)
#define USE_TRANS7_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans7_Temp_)
#define USE_TRANS7_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans7_Temp_)
#define USE_TRANS7_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans7_Temp_)
#define USE_TRANS7_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans7_Temp_)
#define USE_TRANS7_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans7_Temp_)
#define USE_TRANS7_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans7_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_TEMP_MANDATORY_BOTH \
	BLOCK trans8_Temp_block; \
	COLLECTION trans8_Temp_BLOCK_OBJECT; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Temp_BLOCK_OBJECT_page; \
	COMMAND trans8_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans8_Temp_ST_REV; \
	MENU trans8_Temp_ST_REV_page; \
	COMMAND trans8_Temp_ST_REV_read; \
	VARIABLE trans8_Temp_TAG_DESC; \
	MENU trans8_Temp_TAG_DESC_page; \
	COMMAND trans8_Temp_TAG_DESC_read; \
	COMMAND trans8_Temp_TAG_DESC_write; \
	VARIABLE trans8_Temp_STRATEGY; \
	MENU trans8_Temp_STRATEGY_page; \
	COMMAND trans8_Temp_STRATEGY_read; \
	COMMAND trans8_Temp_STRATEGY_write; \
	VARIABLE trans8_Temp_ALERT_KEY; \
	MENU trans8_Temp_ALERT_KEY_page; \
	COMMAND trans8_Temp_ALERT_KEY_read; \
	COMMAND trans8_Temp_ALERT_KEY_write; \
	VARIABLE trans8_Temp_TARGET_MODE; \
	MENU trans8_Temp_TARGET_MODE_page; \
	COMMAND trans8_Temp_TARGET_MODE_read; \
	COMMAND trans8_Temp_TARGET_MODE_write; \
	COLLECTION trans8_Temp_MODE_BLK; \
	VARIABLE trans8_Temp_MODE_BLK_Actual; \
	VARIABLE trans8_Temp_MODE_BLK_Permitted; \
	VARIABLE trans8_Temp_MODE_BLK_Normal; \
	MENU trans8_Temp_MODE_BLK_page; \
	COMMAND trans8_Temp_MODE_BLK_read; \
	COLLECTION trans8_Temp_ALARM_SUM; \
	VARIABLE trans8_Temp_ALARM_SUM_Current; \
	VARIABLE trans8_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans8_Temp_ALARM_SUM_Disabled; \
	MENU trans8_Temp_ALARM_SUM_page; \
	COMMAND trans8_Temp_ALARM_SUM_read; \
	COLLECTION trans8_Temp_PRIMARY_VALUE; \
	VARIABLE trans8_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans8_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans8_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans8_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans8_Temp_PRIMARY_VALUE_page; \
	COMMAND trans8_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans8_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans8_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans8_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans8_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans8_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans8_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans8_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans8_Temp_SENSOR_MEAS_TYPE; \
	MENU trans8_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans8_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans8_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans8_Temp_INPUT_RANGE; \
	MENU trans8_Temp_INPUT_RANGE_page; \
	COMMAND trans8_Temp_INPUT_RANGE_read; \
	COMMAND trans8_Temp_INPUT_RANGE_write; \
	VARIABLE trans8_Temp_LIN_TYPE; \
	MENU trans8_Temp_LIN_TYPE_page; \
	COMMAND trans8_Temp_LIN_TYPE_read; \
	COMMAND trans8_Temp_LIN_TYPE_write; \
	VARIABLE trans8_Temp_BIAS_1; \
	MENU trans8_Temp_BIAS_1_page; \
	COMMAND trans8_Temp_BIAS_1_read; \
	COMMAND trans8_Temp_BIAS_1_write; \
	VARIABLE trans8_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans8_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans8_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans8_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans8_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans8_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans8_Temp_INPUT_FAULT_GEN; \
	MENU trans8_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans8_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans8_Temp_INPUT_FAULT_1; \
	MENU trans8_Temp_INPUT_FAULT_1_page; \
	COMMAND trans8_Temp_INPUT_FAULT_1_read; \
	UNIT trans8_Temp_Unit_1; \
	VARIABLE trans8_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans8_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans8_Temp_Display; \
	CHART trans8_Temp_Display_BarVal_pv; \
	SOURCE trans8_Temp_Display_BarVal_pv_source; \
	MENU trans8_Temp_Display_primary; \
	MENU trans8_Temp_Display_secondary; \
	MENU trans8_Temp_Tab_s; \
	MENU trans8_Temp_Tab_s_measrange; \
	MENU trans8_Temp_Tab_m

#define USE_TRANS8_TEMP_MANDATORY_A \
	USE_TRANS8_TEMP_MANDATORY_BOTH; \
	MENU trans8_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS8_TEMP_MANDATORY_B \
	USE_TRANS8_TEMP_MANDATORY_BOTH; \
	COLLECTION trans8_Temp_VIEW_1; \
	MENU trans8_Temp_VIEW_1_page; \
	MENU trans8_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS8_TEMP_OPTIONAL_BOTH \
	COLLECTION trans8_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans8_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans8_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans8_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans8_Temp_BIAS_2; \
	MENU trans8_Temp_BIAS_2_page; \
	COMMAND trans8_Temp_BIAS_2_read; \
	COMMAND trans8_Temp_BIAS_2_write; \
	VARIABLE trans8_Temp_INPUT_FAULT_2; \
	MENU trans8_Temp_INPUT_FAULT_2_page; \
	COMMAND trans8_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans8_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans8_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans8_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans8_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans8_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans8_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans8_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans8_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans8_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans8_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans8_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans8_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans8_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans8_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans8_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans8_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans8_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans8_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans8_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans8_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans8_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans8_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans8_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans8_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans8_Temp_TAB_ENTRY; \
	MENU trans8_Temp_TAB_ENTRY_page; \
	COMMAND trans8_Temp_TAB_ENTRY_read; \
	COMMAND trans8_Temp_TAB_ENTRY_write; \
	COLLECTION trans8_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans8_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans8_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans8_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans8_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans8_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans8_Temp_TAB_MIN_NUMBER; \
	MENU trans8_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans8_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans8_Temp_TAB_MAX_NUMBER; \
	MENU trans8_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans8_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans8_Temp_TAB_OP_CODE; \
	MENU trans8_Temp_TAB_OP_CODE_page; \
	COMMAND trans8_Temp_TAB_OP_CODE_read; \
	COMMAND trans8_Temp_TAB_OP_CODE_write; \
	VARIABLE trans8_Temp_TAB_STATUS; \
	MENU trans8_Temp_TAB_STATUS_page; \
	COMMAND trans8_Temp_TAB_STATUS_read; \
	VARIABLE trans8_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans8_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans8_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans8_Temp_VIEW_2; \
	MENU trans8_Temp_VIEW_2_page; \
	COLLECTION trans8_Temp_VIEW_3; \
	MENU trans8_Temp_VIEW_3_page; \
	UNIT trans8_Temp_Unit_2

#define USE_TRANS8_TEMP_OPTIONAL_A \
	USE_TRANS8_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans8_Temp_VIEW_1; \
	MENU trans8_Temp_VIEW_1_page; \
	MENU trans8_Temp_Simple_Dialog_Optional_A

#define USE_TRANS8_TEMP_OPTIONAL_B \
	USE_TRANS8_TEMP_OPTIONAL_BOTH; \
	MENU trans8_Temp_Simple_Dialog_Optional_B

#define USE_TRANS8_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans8_Temp_RJ_TYPE; \
	MENU trans8_Temp_RJ_TYPE_page; \
	COMMAND trans8_Temp_RJ_TYPE_read; \
	COMMAND trans8_Temp_RJ_TYPE_write; \
	MENU trans8_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS8_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans8_Temp_SENSOR_CONNECTION; \
	MENU trans8_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans8_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans8_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans8_Temp_COMP_WIRE1; \
	MENU trans8_Temp_COMP_WIRE1_page; \
	COMMAND trans8_Temp_COMP_WIRE1_read; \
	COMMAND trans8_Temp_COMP_WIRE1_write; \
	MENU trans8_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS8_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans8_Temp_EMISSIVITY; \
	MENU trans8_Temp_EMISSIVITY_page; \
	COMMAND trans8_Temp_EMISSIVITY_read; \
	COMMAND trans8_Temp_EMISSIVITY_write; \
	VARIABLE trans8_Temp_PEAK_TRACK; \
	MENU trans8_Temp_PEAK_TRACK_page; \
	COMMAND trans8_Temp_PEAK_TRACK_read; \
	COMMAND trans8_Temp_PEAK_TRACK_write; \
	VARIABLE trans8_Temp_DECAY_RATE; \
	MENU trans8_Temp_DECAY_RATE_page; \
	COMMAND trans8_Temp_DECAY_RATE_read; \
	COMMAND trans8_Temp_DECAY_RATE_write; \
	VARIABLE trans8_Temp_PEAK_TIME; \
	MENU trans8_Temp_PEAK_TIME_page; \
	COMMAND trans8_Temp_PEAK_TIME_read; \
	COMMAND trans8_Temp_PEAK_TIME_write; \
	VARIABLE trans8_Temp_TRACK_HOLD; \
	MENU trans8_Temp_TRACK_HOLD_page; \
	COMMAND trans8_Temp_TRACK_HOLD_read; \
	COMMAND trans8_Temp_TRACK_HOLD_write; \
	VARIABLE trans8_Temp_SPECT_FILT_SET; \
	MENU trans8_Temp_SPECT_FILT_SET_page; \
	COMMAND trans8_Temp_SPECT_FILT_SET_read; \
	COMMAND trans8_Temp_SPECT_FILT_SET_write; \
	MENU trans8_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS8_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans8_Temp_RJ_TYPE; \
	MENU trans8_Temp_RJ_TYPE_page; \
	COMMAND trans8_Temp_RJ_TYPE_read; \
	COMMAND trans8_Temp_RJ_TYPE_write; \
	MENU trans8_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS8_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans8_Temp_SENSOR_CONNECTION; \
	MENU trans8_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans8_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans8_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans8_Temp_COMP_WIRE1; \
	MENU trans8_Temp_COMP_WIRE1_page; \
	COMMAND trans8_Temp_COMP_WIRE1_read; \
	COMMAND trans8_Temp_COMP_WIRE1_write; \
	MENU trans8_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS8_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans8_Temp_EMISSIVITY; \
	MENU trans8_Temp_EMISSIVITY_page; \
	COMMAND trans8_Temp_EMISSIVITY_read; \
	COMMAND trans8_Temp_EMISSIVITY_write; \
	VARIABLE trans8_Temp_PEAK_TRACK; \
	MENU trans8_Temp_PEAK_TRACK_page; \
	COMMAND trans8_Temp_PEAK_TRACK_read; \
	COMMAND trans8_Temp_PEAK_TRACK_write; \
	VARIABLE trans8_Temp_DECAY_RATE; \
	MENU trans8_Temp_DECAY_RATE_page; \
	COMMAND trans8_Temp_DECAY_RATE_read; \
	COMMAND trans8_Temp_DECAY_RATE_write; \
	VARIABLE trans8_Temp_PEAK_TIME; \
	MENU trans8_Temp_PEAK_TIME_page; \
	COMMAND trans8_Temp_PEAK_TIME_read; \
	COMMAND trans8_Temp_PEAK_TIME_write; \
	VARIABLE trans8_Temp_TRACK_HOLD; \
	MENU trans8_Temp_TRACK_HOLD_page; \
	COMMAND trans8_Temp_TRACK_HOLD_read; \
	COMMAND trans8_Temp_TRACK_HOLD_write; \
	VARIABLE trans8_Temp_SPECT_FILT_SET; \
	MENU trans8_Temp_SPECT_FILT_SET_page; \
	COMMAND trans8_Temp_SPECT_FILT_SET_read; \
	COMMAND trans8_Temp_SPECT_FILT_SET_write; \
	MENU trans8_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS8_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans8_Temp_RJ_TEMP; \
	MENU trans8_Temp_RJ_TEMP_page; \
	COMMAND trans8_Temp_RJ_TEMP_read; \
	VARIABLE trans8_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans8_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans8_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans8_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans8_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans8_Temp_Unit_3

#define USE_TRANS8_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans8_Temp_COMP_WIRE2; \
	MENU trans8_Temp_COMP_WIRE2_page; \
	COMMAND trans8_Temp_COMP_WIRE2_read; \
	COMMAND trans8_Temp_COMP_WIRE2_write; \
	MENU trans8_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS8_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans8_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS8_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans8_Temp_RJ_TEMP; \
	MENU trans8_Temp_RJ_TEMP_page; \
	COMMAND trans8_Temp_RJ_TEMP_read; \
	VARIABLE trans8_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans8_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans8_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans8_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans8_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans8_Temp_Unit_3

#define USE_TRANS8_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans8_Temp_COMP_WIRE2; \
	MENU trans8_Temp_COMP_WIRE2_page; \
	COMMAND trans8_Temp_COMP_WIRE2_read; \
	COMMAND trans8_Temp_COMP_WIRE2_write; \
	MENU trans8_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS8_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans8_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans8_Temp_)
#define USE_TRANS8_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans8_Temp_)
#define USE_TRANS8_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans8_Temp_)
#define USE_TRANS8_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans8_Temp_)
#define USE_TRANS8_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans8_Temp_)
#define USE_TRANS8_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans8_Temp_)
#define USE_TRANS8_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans8_Temp_)
#define USE_TRANS8_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans8_Temp_)
#define USE_TRANS8_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans8_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_TEMP_MANDATORY_BOTH \
	BLOCK trans9_Temp_block; \
	COLLECTION trans9_Temp_BLOCK_OBJECT; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Temp_BLOCK_OBJECT_page; \
	COMMAND trans9_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans9_Temp_ST_REV; \
	MENU trans9_Temp_ST_REV_page; \
	COMMAND trans9_Temp_ST_REV_read; \
	VARIABLE trans9_Temp_TAG_DESC; \
	MENU trans9_Temp_TAG_DESC_page; \
	COMMAND trans9_Temp_TAG_DESC_read; \
	COMMAND trans9_Temp_TAG_DESC_write; \
	VARIABLE trans9_Temp_STRATEGY; \
	MENU trans9_Temp_STRATEGY_page; \
	COMMAND trans9_Temp_STRATEGY_read; \
	COMMAND trans9_Temp_STRATEGY_write; \
	VARIABLE trans9_Temp_ALERT_KEY; \
	MENU trans9_Temp_ALERT_KEY_page; \
	COMMAND trans9_Temp_ALERT_KEY_read; \
	COMMAND trans9_Temp_ALERT_KEY_write; \
	VARIABLE trans9_Temp_TARGET_MODE; \
	MENU trans9_Temp_TARGET_MODE_page; \
	COMMAND trans9_Temp_TARGET_MODE_read; \
	COMMAND trans9_Temp_TARGET_MODE_write; \
	COLLECTION trans9_Temp_MODE_BLK; \
	VARIABLE trans9_Temp_MODE_BLK_Actual; \
	VARIABLE trans9_Temp_MODE_BLK_Permitted; \
	VARIABLE trans9_Temp_MODE_BLK_Normal; \
	MENU trans9_Temp_MODE_BLK_page; \
	COMMAND trans9_Temp_MODE_BLK_read; \
	COLLECTION trans9_Temp_ALARM_SUM; \
	VARIABLE trans9_Temp_ALARM_SUM_Current; \
	VARIABLE trans9_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans9_Temp_ALARM_SUM_Disabled; \
	MENU trans9_Temp_ALARM_SUM_page; \
	COMMAND trans9_Temp_ALARM_SUM_read; \
	COLLECTION trans9_Temp_PRIMARY_VALUE; \
	VARIABLE trans9_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans9_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans9_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans9_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans9_Temp_PRIMARY_VALUE_page; \
	COMMAND trans9_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans9_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans9_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans9_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans9_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans9_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans9_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans9_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans9_Temp_SENSOR_MEAS_TYPE; \
	MENU trans9_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans9_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans9_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans9_Temp_INPUT_RANGE; \
	MENU trans9_Temp_INPUT_RANGE_page; \
	COMMAND trans9_Temp_INPUT_RANGE_read; \
	COMMAND trans9_Temp_INPUT_RANGE_write; \
	VARIABLE trans9_Temp_LIN_TYPE; \
	MENU trans9_Temp_LIN_TYPE_page; \
	COMMAND trans9_Temp_LIN_TYPE_read; \
	COMMAND trans9_Temp_LIN_TYPE_write; \
	VARIABLE trans9_Temp_BIAS_1; \
	MENU trans9_Temp_BIAS_1_page; \
	COMMAND trans9_Temp_BIAS_1_read; \
	COMMAND trans9_Temp_BIAS_1_write; \
	VARIABLE trans9_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans9_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans9_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans9_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans9_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans9_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans9_Temp_INPUT_FAULT_GEN; \
	MENU trans9_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans9_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans9_Temp_INPUT_FAULT_1; \
	MENU trans9_Temp_INPUT_FAULT_1_page; \
	COMMAND trans9_Temp_INPUT_FAULT_1_read; \
	UNIT trans9_Temp_Unit_1; \
	VARIABLE trans9_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans9_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans9_Temp_Display; \
	CHART trans9_Temp_Display_BarVal_pv; \
	SOURCE trans9_Temp_Display_BarVal_pv_source; \
	MENU trans9_Temp_Display_primary; \
	MENU trans9_Temp_Display_secondary; \
	MENU trans9_Temp_Tab_s; \
	MENU trans9_Temp_Tab_s_measrange; \
	MENU trans9_Temp_Tab_m

#define USE_TRANS9_TEMP_MANDATORY_A \
	USE_TRANS9_TEMP_MANDATORY_BOTH; \
	MENU trans9_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS9_TEMP_MANDATORY_B \
	USE_TRANS9_TEMP_MANDATORY_BOTH; \
	COLLECTION trans9_Temp_VIEW_1; \
	MENU trans9_Temp_VIEW_1_page; \
	MENU trans9_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS9_TEMP_OPTIONAL_BOTH \
	COLLECTION trans9_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans9_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans9_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans9_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans9_Temp_BIAS_2; \
	MENU trans9_Temp_BIAS_2_page; \
	COMMAND trans9_Temp_BIAS_2_read; \
	COMMAND trans9_Temp_BIAS_2_write; \
	VARIABLE trans9_Temp_INPUT_FAULT_2; \
	MENU trans9_Temp_INPUT_FAULT_2_page; \
	COMMAND trans9_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans9_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans9_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans9_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans9_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans9_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans9_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans9_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans9_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans9_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans9_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans9_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans9_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans9_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans9_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans9_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans9_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans9_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans9_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans9_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans9_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans9_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans9_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans9_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans9_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans9_Temp_TAB_ENTRY; \
	MENU trans9_Temp_TAB_ENTRY_page; \
	COMMAND trans9_Temp_TAB_ENTRY_read; \
	COMMAND trans9_Temp_TAB_ENTRY_write; \
	COLLECTION trans9_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans9_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans9_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans9_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans9_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans9_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans9_Temp_TAB_MIN_NUMBER; \
	MENU trans9_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans9_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans9_Temp_TAB_MAX_NUMBER; \
	MENU trans9_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans9_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans9_Temp_TAB_OP_CODE; \
	MENU trans9_Temp_TAB_OP_CODE_page; \
	COMMAND trans9_Temp_TAB_OP_CODE_read; \
	COMMAND trans9_Temp_TAB_OP_CODE_write; \
	VARIABLE trans9_Temp_TAB_STATUS; \
	MENU trans9_Temp_TAB_STATUS_page; \
	COMMAND trans9_Temp_TAB_STATUS_read; \
	VARIABLE trans9_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans9_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans9_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans9_Temp_VIEW_2; \
	MENU trans9_Temp_VIEW_2_page; \
	COLLECTION trans9_Temp_VIEW_3; \
	MENU trans9_Temp_VIEW_3_page; \
	UNIT trans9_Temp_Unit_2

#define USE_TRANS9_TEMP_OPTIONAL_A \
	USE_TRANS9_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans9_Temp_VIEW_1; \
	MENU trans9_Temp_VIEW_1_page; \
	MENU trans9_Temp_Simple_Dialog_Optional_A

#define USE_TRANS9_TEMP_OPTIONAL_B \
	USE_TRANS9_TEMP_OPTIONAL_BOTH; \
	MENU trans9_Temp_Simple_Dialog_Optional_B

#define USE_TRANS9_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans9_Temp_RJ_TYPE; \
	MENU trans9_Temp_RJ_TYPE_page; \
	COMMAND trans9_Temp_RJ_TYPE_read; \
	COMMAND trans9_Temp_RJ_TYPE_write; \
	MENU trans9_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS9_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans9_Temp_SENSOR_CONNECTION; \
	MENU trans9_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans9_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans9_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans9_Temp_COMP_WIRE1; \
	MENU trans9_Temp_COMP_WIRE1_page; \
	COMMAND trans9_Temp_COMP_WIRE1_read; \
	COMMAND trans9_Temp_COMP_WIRE1_write; \
	MENU trans9_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS9_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans9_Temp_EMISSIVITY; \
	MENU trans9_Temp_EMISSIVITY_page; \
	COMMAND trans9_Temp_EMISSIVITY_read; \
	COMMAND trans9_Temp_EMISSIVITY_write; \
	VARIABLE trans9_Temp_PEAK_TRACK; \
	MENU trans9_Temp_PEAK_TRACK_page; \
	COMMAND trans9_Temp_PEAK_TRACK_read; \
	COMMAND trans9_Temp_PEAK_TRACK_write; \
	VARIABLE trans9_Temp_DECAY_RATE; \
	MENU trans9_Temp_DECAY_RATE_page; \
	COMMAND trans9_Temp_DECAY_RATE_read; \
	COMMAND trans9_Temp_DECAY_RATE_write; \
	VARIABLE trans9_Temp_PEAK_TIME; \
	MENU trans9_Temp_PEAK_TIME_page; \
	COMMAND trans9_Temp_PEAK_TIME_read; \
	COMMAND trans9_Temp_PEAK_TIME_write; \
	VARIABLE trans9_Temp_TRACK_HOLD; \
	MENU trans9_Temp_TRACK_HOLD_page; \
	COMMAND trans9_Temp_TRACK_HOLD_read; \
	COMMAND trans9_Temp_TRACK_HOLD_write; \
	VARIABLE trans9_Temp_SPECT_FILT_SET; \
	MENU trans9_Temp_SPECT_FILT_SET_page; \
	COMMAND trans9_Temp_SPECT_FILT_SET_read; \
	COMMAND trans9_Temp_SPECT_FILT_SET_write; \
	MENU trans9_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS9_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans9_Temp_RJ_TYPE; \
	MENU trans9_Temp_RJ_TYPE_page; \
	COMMAND trans9_Temp_RJ_TYPE_read; \
	COMMAND trans9_Temp_RJ_TYPE_write; \
	MENU trans9_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS9_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans9_Temp_SENSOR_CONNECTION; \
	MENU trans9_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans9_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans9_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans9_Temp_COMP_WIRE1; \
	MENU trans9_Temp_COMP_WIRE1_page; \
	COMMAND trans9_Temp_COMP_WIRE1_read; \
	COMMAND trans9_Temp_COMP_WIRE1_write; \
	MENU trans9_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS9_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans9_Temp_EMISSIVITY; \
	MENU trans9_Temp_EMISSIVITY_page; \
	COMMAND trans9_Temp_EMISSIVITY_read; \
	COMMAND trans9_Temp_EMISSIVITY_write; \
	VARIABLE trans9_Temp_PEAK_TRACK; \
	MENU trans9_Temp_PEAK_TRACK_page; \
	COMMAND trans9_Temp_PEAK_TRACK_read; \
	COMMAND trans9_Temp_PEAK_TRACK_write; \
	VARIABLE trans9_Temp_DECAY_RATE; \
	MENU trans9_Temp_DECAY_RATE_page; \
	COMMAND trans9_Temp_DECAY_RATE_read; \
	COMMAND trans9_Temp_DECAY_RATE_write; \
	VARIABLE trans9_Temp_PEAK_TIME; \
	MENU trans9_Temp_PEAK_TIME_page; \
	COMMAND trans9_Temp_PEAK_TIME_read; \
	COMMAND trans9_Temp_PEAK_TIME_write; \
	VARIABLE trans9_Temp_TRACK_HOLD; \
	MENU trans9_Temp_TRACK_HOLD_page; \
	COMMAND trans9_Temp_TRACK_HOLD_read; \
	COMMAND trans9_Temp_TRACK_HOLD_write; \
	VARIABLE trans9_Temp_SPECT_FILT_SET; \
	MENU trans9_Temp_SPECT_FILT_SET_page; \
	COMMAND trans9_Temp_SPECT_FILT_SET_read; \
	COMMAND trans9_Temp_SPECT_FILT_SET_write; \
	MENU trans9_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS9_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans9_Temp_RJ_TEMP; \
	MENU trans9_Temp_RJ_TEMP_page; \
	COMMAND trans9_Temp_RJ_TEMP_read; \
	VARIABLE trans9_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans9_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans9_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans9_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans9_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans9_Temp_Unit_3

#define USE_TRANS9_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans9_Temp_COMP_WIRE2; \
	MENU trans9_Temp_COMP_WIRE2_page; \
	COMMAND trans9_Temp_COMP_WIRE2_read; \
	COMMAND trans9_Temp_COMP_WIRE2_write; \
	MENU trans9_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS9_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans9_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS9_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans9_Temp_RJ_TEMP; \
	MENU trans9_Temp_RJ_TEMP_page; \
	COMMAND trans9_Temp_RJ_TEMP_read; \
	VARIABLE trans9_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans9_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans9_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans9_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans9_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans9_Temp_Unit_3

#define USE_TRANS9_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans9_Temp_COMP_WIRE2; \
	MENU trans9_Temp_COMP_WIRE2_page; \
	COMMAND trans9_Temp_COMP_WIRE2_read; \
	COMMAND trans9_Temp_COMP_WIRE2_write; \
	MENU trans9_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS9_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans9_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans9_Temp_)
#define USE_TRANS9_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans9_Temp_)
#define USE_TRANS9_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans9_Temp_)
#define USE_TRANS9_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans9_Temp_)
#define USE_TRANS9_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans9_Temp_)
#define USE_TRANS9_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans9_Temp_)
#define USE_TRANS9_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans9_Temp_)
#define USE_TRANS9_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans9_Temp_)
#define USE_TRANS9_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans9_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_TEMP_MANDATORY_BOTH \
	BLOCK trans10_Temp_block; \
	COLLECTION trans10_Temp_BLOCK_OBJECT; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Temp_BLOCK_OBJECT_page; \
	COMMAND trans10_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans10_Temp_ST_REV; \
	MENU trans10_Temp_ST_REV_page; \
	COMMAND trans10_Temp_ST_REV_read; \
	VARIABLE trans10_Temp_TAG_DESC; \
	MENU trans10_Temp_TAG_DESC_page; \
	COMMAND trans10_Temp_TAG_DESC_read; \
	COMMAND trans10_Temp_TAG_DESC_write; \
	VARIABLE trans10_Temp_STRATEGY; \
	MENU trans10_Temp_STRATEGY_page; \
	COMMAND trans10_Temp_STRATEGY_read; \
	COMMAND trans10_Temp_STRATEGY_write; \
	VARIABLE trans10_Temp_ALERT_KEY; \
	MENU trans10_Temp_ALERT_KEY_page; \
	COMMAND trans10_Temp_ALERT_KEY_read; \
	COMMAND trans10_Temp_ALERT_KEY_write; \
	VARIABLE trans10_Temp_TARGET_MODE; \
	MENU trans10_Temp_TARGET_MODE_page; \
	COMMAND trans10_Temp_TARGET_MODE_read; \
	COMMAND trans10_Temp_TARGET_MODE_write; \
	COLLECTION trans10_Temp_MODE_BLK; \
	VARIABLE trans10_Temp_MODE_BLK_Actual; \
	VARIABLE trans10_Temp_MODE_BLK_Permitted; \
	VARIABLE trans10_Temp_MODE_BLK_Normal; \
	MENU trans10_Temp_MODE_BLK_page; \
	COMMAND trans10_Temp_MODE_BLK_read; \
	COLLECTION trans10_Temp_ALARM_SUM; \
	VARIABLE trans10_Temp_ALARM_SUM_Current; \
	VARIABLE trans10_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans10_Temp_ALARM_SUM_Disabled; \
	MENU trans10_Temp_ALARM_SUM_page; \
	COMMAND trans10_Temp_ALARM_SUM_read; \
	COLLECTION trans10_Temp_PRIMARY_VALUE; \
	VARIABLE trans10_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans10_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans10_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans10_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans10_Temp_PRIMARY_VALUE_page; \
	COMMAND trans10_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans10_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans10_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans10_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans10_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans10_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans10_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans10_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans10_Temp_SENSOR_MEAS_TYPE; \
	MENU trans10_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans10_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans10_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans10_Temp_INPUT_RANGE; \
	MENU trans10_Temp_INPUT_RANGE_page; \
	COMMAND trans10_Temp_INPUT_RANGE_read; \
	COMMAND trans10_Temp_INPUT_RANGE_write; \
	VARIABLE trans10_Temp_LIN_TYPE; \
	MENU trans10_Temp_LIN_TYPE_page; \
	COMMAND trans10_Temp_LIN_TYPE_read; \
	COMMAND trans10_Temp_LIN_TYPE_write; \
	VARIABLE trans10_Temp_BIAS_1; \
	MENU trans10_Temp_BIAS_1_page; \
	COMMAND trans10_Temp_BIAS_1_read; \
	COMMAND trans10_Temp_BIAS_1_write; \
	VARIABLE trans10_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans10_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans10_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans10_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans10_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans10_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans10_Temp_INPUT_FAULT_GEN; \
	MENU trans10_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans10_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans10_Temp_INPUT_FAULT_1; \
	MENU trans10_Temp_INPUT_FAULT_1_page; \
	COMMAND trans10_Temp_INPUT_FAULT_1_read; \
	UNIT trans10_Temp_Unit_1; \
	VARIABLE trans10_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans10_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans10_Temp_Display; \
	CHART trans10_Temp_Display_BarVal_pv; \
	SOURCE trans10_Temp_Display_BarVal_pv_source; \
	MENU trans10_Temp_Display_primary; \
	MENU trans10_Temp_Display_secondary; \
	MENU trans10_Temp_Tab_s; \
	MENU trans10_Temp_Tab_s_measrange; \
	MENU trans10_Temp_Tab_m

#define USE_TRANS10_TEMP_MANDATORY_A \
	USE_TRANS10_TEMP_MANDATORY_BOTH; \
	MENU trans10_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS10_TEMP_MANDATORY_B \
	USE_TRANS10_TEMP_MANDATORY_BOTH; \
	COLLECTION trans10_Temp_VIEW_1; \
	MENU trans10_Temp_VIEW_1_page; \
	MENU trans10_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS10_TEMP_OPTIONAL_BOTH \
	COLLECTION trans10_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans10_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans10_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans10_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans10_Temp_BIAS_2; \
	MENU trans10_Temp_BIAS_2_page; \
	COMMAND trans10_Temp_BIAS_2_read; \
	COMMAND trans10_Temp_BIAS_2_write; \
	VARIABLE trans10_Temp_INPUT_FAULT_2; \
	MENU trans10_Temp_INPUT_FAULT_2_page; \
	COMMAND trans10_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans10_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans10_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans10_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans10_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans10_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans10_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans10_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans10_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans10_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans10_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans10_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans10_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans10_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans10_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans10_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans10_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans10_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans10_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans10_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans10_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans10_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans10_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans10_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans10_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans10_Temp_TAB_ENTRY; \
	MENU trans10_Temp_TAB_ENTRY_page; \
	COMMAND trans10_Temp_TAB_ENTRY_read; \
	COMMAND trans10_Temp_TAB_ENTRY_write; \
	COLLECTION trans10_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans10_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans10_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans10_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans10_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans10_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans10_Temp_TAB_MIN_NUMBER; \
	MENU trans10_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans10_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans10_Temp_TAB_MAX_NUMBER; \
	MENU trans10_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans10_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans10_Temp_TAB_OP_CODE; \
	MENU trans10_Temp_TAB_OP_CODE_page; \
	COMMAND trans10_Temp_TAB_OP_CODE_read; \
	COMMAND trans10_Temp_TAB_OP_CODE_write; \
	VARIABLE trans10_Temp_TAB_STATUS; \
	MENU trans10_Temp_TAB_STATUS_page; \
	COMMAND trans10_Temp_TAB_STATUS_read; \
	VARIABLE trans10_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans10_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans10_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans10_Temp_VIEW_2; \
	MENU trans10_Temp_VIEW_2_page; \
	COLLECTION trans10_Temp_VIEW_3; \
	MENU trans10_Temp_VIEW_3_page; \
	UNIT trans10_Temp_Unit_2

#define USE_TRANS10_TEMP_OPTIONAL_A \
	USE_TRANS10_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans10_Temp_VIEW_1; \
	MENU trans10_Temp_VIEW_1_page; \
	MENU trans10_Temp_Simple_Dialog_Optional_A

#define USE_TRANS10_TEMP_OPTIONAL_B \
	USE_TRANS10_TEMP_OPTIONAL_BOTH; \
	MENU trans10_Temp_Simple_Dialog_Optional_B

#define USE_TRANS10_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans10_Temp_RJ_TYPE; \
	MENU trans10_Temp_RJ_TYPE_page; \
	COMMAND trans10_Temp_RJ_TYPE_read; \
	COMMAND trans10_Temp_RJ_TYPE_write; \
	MENU trans10_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS10_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans10_Temp_SENSOR_CONNECTION; \
	MENU trans10_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans10_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans10_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans10_Temp_COMP_WIRE1; \
	MENU trans10_Temp_COMP_WIRE1_page; \
	COMMAND trans10_Temp_COMP_WIRE1_read; \
	COMMAND trans10_Temp_COMP_WIRE1_write; \
	MENU trans10_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS10_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans10_Temp_EMISSIVITY; \
	MENU trans10_Temp_EMISSIVITY_page; \
	COMMAND trans10_Temp_EMISSIVITY_read; \
	COMMAND trans10_Temp_EMISSIVITY_write; \
	VARIABLE trans10_Temp_PEAK_TRACK; \
	MENU trans10_Temp_PEAK_TRACK_page; \
	COMMAND trans10_Temp_PEAK_TRACK_read; \
	COMMAND trans10_Temp_PEAK_TRACK_write; \
	VARIABLE trans10_Temp_DECAY_RATE; \
	MENU trans10_Temp_DECAY_RATE_page; \
	COMMAND trans10_Temp_DECAY_RATE_read; \
	COMMAND trans10_Temp_DECAY_RATE_write; \
	VARIABLE trans10_Temp_PEAK_TIME; \
	MENU trans10_Temp_PEAK_TIME_page; \
	COMMAND trans10_Temp_PEAK_TIME_read; \
	COMMAND trans10_Temp_PEAK_TIME_write; \
	VARIABLE trans10_Temp_TRACK_HOLD; \
	MENU trans10_Temp_TRACK_HOLD_page; \
	COMMAND trans10_Temp_TRACK_HOLD_read; \
	COMMAND trans10_Temp_TRACK_HOLD_write; \
	VARIABLE trans10_Temp_SPECT_FILT_SET; \
	MENU trans10_Temp_SPECT_FILT_SET_page; \
	COMMAND trans10_Temp_SPECT_FILT_SET_read; \
	COMMAND trans10_Temp_SPECT_FILT_SET_write; \
	MENU trans10_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS10_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans10_Temp_RJ_TYPE; \
	MENU trans10_Temp_RJ_TYPE_page; \
	COMMAND trans10_Temp_RJ_TYPE_read; \
	COMMAND trans10_Temp_RJ_TYPE_write; \
	MENU trans10_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS10_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans10_Temp_SENSOR_CONNECTION; \
	MENU trans10_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans10_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans10_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans10_Temp_COMP_WIRE1; \
	MENU trans10_Temp_COMP_WIRE1_page; \
	COMMAND trans10_Temp_COMP_WIRE1_read; \
	COMMAND trans10_Temp_COMP_WIRE1_write; \
	MENU trans10_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS10_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans10_Temp_EMISSIVITY; \
	MENU trans10_Temp_EMISSIVITY_page; \
	COMMAND trans10_Temp_EMISSIVITY_read; \
	COMMAND trans10_Temp_EMISSIVITY_write; \
	VARIABLE trans10_Temp_PEAK_TRACK; \
	MENU trans10_Temp_PEAK_TRACK_page; \
	COMMAND trans10_Temp_PEAK_TRACK_read; \
	COMMAND trans10_Temp_PEAK_TRACK_write; \
	VARIABLE trans10_Temp_DECAY_RATE; \
	MENU trans10_Temp_DECAY_RATE_page; \
	COMMAND trans10_Temp_DECAY_RATE_read; \
	COMMAND trans10_Temp_DECAY_RATE_write; \
	VARIABLE trans10_Temp_PEAK_TIME; \
	MENU trans10_Temp_PEAK_TIME_page; \
	COMMAND trans10_Temp_PEAK_TIME_read; \
	COMMAND trans10_Temp_PEAK_TIME_write; \
	VARIABLE trans10_Temp_TRACK_HOLD; \
	MENU trans10_Temp_TRACK_HOLD_page; \
	COMMAND trans10_Temp_TRACK_HOLD_read; \
	COMMAND trans10_Temp_TRACK_HOLD_write; \
	VARIABLE trans10_Temp_SPECT_FILT_SET; \
	MENU trans10_Temp_SPECT_FILT_SET_page; \
	COMMAND trans10_Temp_SPECT_FILT_SET_read; \
	COMMAND trans10_Temp_SPECT_FILT_SET_write; \
	MENU trans10_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS10_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans10_Temp_RJ_TEMP; \
	MENU trans10_Temp_RJ_TEMP_page; \
	COMMAND trans10_Temp_RJ_TEMP_read; \
	VARIABLE trans10_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans10_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans10_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans10_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans10_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans10_Temp_Unit_3

#define USE_TRANS10_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans10_Temp_COMP_WIRE2; \
	MENU trans10_Temp_COMP_WIRE2_page; \
	COMMAND trans10_Temp_COMP_WIRE2_read; \
	COMMAND trans10_Temp_COMP_WIRE2_write; \
	MENU trans10_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS10_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans10_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS10_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans10_Temp_RJ_TEMP; \
	MENU trans10_Temp_RJ_TEMP_page; \
	COMMAND trans10_Temp_RJ_TEMP_read; \
	VARIABLE trans10_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans10_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans10_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans10_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans10_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans10_Temp_Unit_3

#define USE_TRANS10_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans10_Temp_COMP_WIRE2; \
	MENU trans10_Temp_COMP_WIRE2_page; \
	COMMAND trans10_Temp_COMP_WIRE2_read; \
	COMMAND trans10_Temp_COMP_WIRE2_write; \
	MENU trans10_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS10_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans10_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans10_Temp_)
#define USE_TRANS10_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans10_Temp_)
#define USE_TRANS10_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans10_Temp_)
#define USE_TRANS10_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans10_Temp_)
#define USE_TRANS10_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans10_Temp_)
#define USE_TRANS10_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans10_Temp_)
#define USE_TRANS10_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans10_Temp_)
#define USE_TRANS10_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans10_Temp_)
#define USE_TRANS10_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans10_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_TEMP_MANDATORY_BOTH \
	BLOCK trans11_Temp_block; \
	COLLECTION trans11_Temp_BLOCK_OBJECT; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Temp_BLOCK_OBJECT_page; \
	COMMAND trans11_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans11_Temp_ST_REV; \
	MENU trans11_Temp_ST_REV_page; \
	COMMAND trans11_Temp_ST_REV_read; \
	VARIABLE trans11_Temp_TAG_DESC; \
	MENU trans11_Temp_TAG_DESC_page; \
	COMMAND trans11_Temp_TAG_DESC_read; \
	COMMAND trans11_Temp_TAG_DESC_write; \
	VARIABLE trans11_Temp_STRATEGY; \
	MENU trans11_Temp_STRATEGY_page; \
	COMMAND trans11_Temp_STRATEGY_read; \
	COMMAND trans11_Temp_STRATEGY_write; \
	VARIABLE trans11_Temp_ALERT_KEY; \
	MENU trans11_Temp_ALERT_KEY_page; \
	COMMAND trans11_Temp_ALERT_KEY_read; \
	COMMAND trans11_Temp_ALERT_KEY_write; \
	VARIABLE trans11_Temp_TARGET_MODE; \
	MENU trans11_Temp_TARGET_MODE_page; \
	COMMAND trans11_Temp_TARGET_MODE_read; \
	COMMAND trans11_Temp_TARGET_MODE_write; \
	COLLECTION trans11_Temp_MODE_BLK; \
	VARIABLE trans11_Temp_MODE_BLK_Actual; \
	VARIABLE trans11_Temp_MODE_BLK_Permitted; \
	VARIABLE trans11_Temp_MODE_BLK_Normal; \
	MENU trans11_Temp_MODE_BLK_page; \
	COMMAND trans11_Temp_MODE_BLK_read; \
	COLLECTION trans11_Temp_ALARM_SUM; \
	VARIABLE trans11_Temp_ALARM_SUM_Current; \
	VARIABLE trans11_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans11_Temp_ALARM_SUM_Disabled; \
	MENU trans11_Temp_ALARM_SUM_page; \
	COMMAND trans11_Temp_ALARM_SUM_read; \
	COLLECTION trans11_Temp_PRIMARY_VALUE; \
	VARIABLE trans11_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans11_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans11_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans11_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans11_Temp_PRIMARY_VALUE_page; \
	COMMAND trans11_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans11_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans11_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans11_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans11_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans11_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans11_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans11_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans11_Temp_SENSOR_MEAS_TYPE; \
	MENU trans11_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans11_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans11_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans11_Temp_INPUT_RANGE; \
	MENU trans11_Temp_INPUT_RANGE_page; \
	COMMAND trans11_Temp_INPUT_RANGE_read; \
	COMMAND trans11_Temp_INPUT_RANGE_write; \
	VARIABLE trans11_Temp_LIN_TYPE; \
	MENU trans11_Temp_LIN_TYPE_page; \
	COMMAND trans11_Temp_LIN_TYPE_read; \
	COMMAND trans11_Temp_LIN_TYPE_write; \
	VARIABLE trans11_Temp_BIAS_1; \
	MENU trans11_Temp_BIAS_1_page; \
	COMMAND trans11_Temp_BIAS_1_read; \
	COMMAND trans11_Temp_BIAS_1_write; \
	VARIABLE trans11_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans11_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans11_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans11_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans11_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans11_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans11_Temp_INPUT_FAULT_GEN; \
	MENU trans11_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans11_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans11_Temp_INPUT_FAULT_1; \
	MENU trans11_Temp_INPUT_FAULT_1_page; \
	COMMAND trans11_Temp_INPUT_FAULT_1_read; \
	UNIT trans11_Temp_Unit_1; \
	VARIABLE trans11_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans11_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans11_Temp_Display; \
	CHART trans11_Temp_Display_BarVal_pv; \
	SOURCE trans11_Temp_Display_BarVal_pv_source; \
	MENU trans11_Temp_Display_primary; \
	MENU trans11_Temp_Display_secondary; \
	MENU trans11_Temp_Tab_s; \
	MENU trans11_Temp_Tab_s_measrange; \
	MENU trans11_Temp_Tab_m

#define USE_TRANS11_TEMP_MANDATORY_A \
	USE_TRANS11_TEMP_MANDATORY_BOTH; \
	MENU trans11_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS11_TEMP_MANDATORY_B \
	USE_TRANS11_TEMP_MANDATORY_BOTH; \
	COLLECTION trans11_Temp_VIEW_1; \
	MENU trans11_Temp_VIEW_1_page; \
	MENU trans11_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS11_TEMP_OPTIONAL_BOTH \
	COLLECTION trans11_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans11_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans11_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans11_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans11_Temp_BIAS_2; \
	MENU trans11_Temp_BIAS_2_page; \
	COMMAND trans11_Temp_BIAS_2_read; \
	COMMAND trans11_Temp_BIAS_2_write; \
	VARIABLE trans11_Temp_INPUT_FAULT_2; \
	MENU trans11_Temp_INPUT_FAULT_2_page; \
	COMMAND trans11_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans11_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans11_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans11_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans11_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans11_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans11_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans11_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans11_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans11_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans11_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans11_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans11_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans11_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans11_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans11_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans11_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans11_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans11_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans11_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans11_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans11_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans11_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans11_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans11_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans11_Temp_TAB_ENTRY; \
	MENU trans11_Temp_TAB_ENTRY_page; \
	COMMAND trans11_Temp_TAB_ENTRY_read; \
	COMMAND trans11_Temp_TAB_ENTRY_write; \
	COLLECTION trans11_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans11_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans11_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans11_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans11_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans11_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans11_Temp_TAB_MIN_NUMBER; \
	MENU trans11_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans11_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans11_Temp_TAB_MAX_NUMBER; \
	MENU trans11_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans11_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans11_Temp_TAB_OP_CODE; \
	MENU trans11_Temp_TAB_OP_CODE_page; \
	COMMAND trans11_Temp_TAB_OP_CODE_read; \
	COMMAND trans11_Temp_TAB_OP_CODE_write; \
	VARIABLE trans11_Temp_TAB_STATUS; \
	MENU trans11_Temp_TAB_STATUS_page; \
	COMMAND trans11_Temp_TAB_STATUS_read; \
	VARIABLE trans11_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans11_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans11_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans11_Temp_VIEW_2; \
	MENU trans11_Temp_VIEW_2_page; \
	COLLECTION trans11_Temp_VIEW_3; \
	MENU trans11_Temp_VIEW_3_page; \
	UNIT trans11_Temp_Unit_2

#define USE_TRANS11_TEMP_OPTIONAL_A \
	USE_TRANS11_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans11_Temp_VIEW_1; \
	MENU trans11_Temp_VIEW_1_page; \
	MENU trans11_Temp_Simple_Dialog_Optional_A

#define USE_TRANS11_TEMP_OPTIONAL_B \
	USE_TRANS11_TEMP_OPTIONAL_BOTH; \
	MENU trans11_Temp_Simple_Dialog_Optional_B

#define USE_TRANS11_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans11_Temp_RJ_TYPE; \
	MENU trans11_Temp_RJ_TYPE_page; \
	COMMAND trans11_Temp_RJ_TYPE_read; \
	COMMAND trans11_Temp_RJ_TYPE_write; \
	MENU trans11_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS11_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans11_Temp_SENSOR_CONNECTION; \
	MENU trans11_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans11_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans11_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans11_Temp_COMP_WIRE1; \
	MENU trans11_Temp_COMP_WIRE1_page; \
	COMMAND trans11_Temp_COMP_WIRE1_read; \
	COMMAND trans11_Temp_COMP_WIRE1_write; \
	MENU trans11_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS11_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans11_Temp_EMISSIVITY; \
	MENU trans11_Temp_EMISSIVITY_page; \
	COMMAND trans11_Temp_EMISSIVITY_read; \
	COMMAND trans11_Temp_EMISSIVITY_write; \
	VARIABLE trans11_Temp_PEAK_TRACK; \
	MENU trans11_Temp_PEAK_TRACK_page; \
	COMMAND trans11_Temp_PEAK_TRACK_read; \
	COMMAND trans11_Temp_PEAK_TRACK_write; \
	VARIABLE trans11_Temp_DECAY_RATE; \
	MENU trans11_Temp_DECAY_RATE_page; \
	COMMAND trans11_Temp_DECAY_RATE_read; \
	COMMAND trans11_Temp_DECAY_RATE_write; \
	VARIABLE trans11_Temp_PEAK_TIME; \
	MENU trans11_Temp_PEAK_TIME_page; \
	COMMAND trans11_Temp_PEAK_TIME_read; \
	COMMAND trans11_Temp_PEAK_TIME_write; \
	VARIABLE trans11_Temp_TRACK_HOLD; \
	MENU trans11_Temp_TRACK_HOLD_page; \
	COMMAND trans11_Temp_TRACK_HOLD_read; \
	COMMAND trans11_Temp_TRACK_HOLD_write; \
	VARIABLE trans11_Temp_SPECT_FILT_SET; \
	MENU trans11_Temp_SPECT_FILT_SET_page; \
	COMMAND trans11_Temp_SPECT_FILT_SET_read; \
	COMMAND trans11_Temp_SPECT_FILT_SET_write; \
	MENU trans11_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS11_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans11_Temp_RJ_TYPE; \
	MENU trans11_Temp_RJ_TYPE_page; \
	COMMAND trans11_Temp_RJ_TYPE_read; \
	COMMAND trans11_Temp_RJ_TYPE_write; \
	MENU trans11_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS11_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans11_Temp_SENSOR_CONNECTION; \
	MENU trans11_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans11_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans11_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans11_Temp_COMP_WIRE1; \
	MENU trans11_Temp_COMP_WIRE1_page; \
	COMMAND trans11_Temp_COMP_WIRE1_read; \
	COMMAND trans11_Temp_COMP_WIRE1_write; \
	MENU trans11_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS11_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans11_Temp_EMISSIVITY; \
	MENU trans11_Temp_EMISSIVITY_page; \
	COMMAND trans11_Temp_EMISSIVITY_read; \
	COMMAND trans11_Temp_EMISSIVITY_write; \
	VARIABLE trans11_Temp_PEAK_TRACK; \
	MENU trans11_Temp_PEAK_TRACK_page; \
	COMMAND trans11_Temp_PEAK_TRACK_read; \
	COMMAND trans11_Temp_PEAK_TRACK_write; \
	VARIABLE trans11_Temp_DECAY_RATE; \
	MENU trans11_Temp_DECAY_RATE_page; \
	COMMAND trans11_Temp_DECAY_RATE_read; \
	COMMAND trans11_Temp_DECAY_RATE_write; \
	VARIABLE trans11_Temp_PEAK_TIME; \
	MENU trans11_Temp_PEAK_TIME_page; \
	COMMAND trans11_Temp_PEAK_TIME_read; \
	COMMAND trans11_Temp_PEAK_TIME_write; \
	VARIABLE trans11_Temp_TRACK_HOLD; \
	MENU trans11_Temp_TRACK_HOLD_page; \
	COMMAND trans11_Temp_TRACK_HOLD_read; \
	COMMAND trans11_Temp_TRACK_HOLD_write; \
	VARIABLE trans11_Temp_SPECT_FILT_SET; \
	MENU trans11_Temp_SPECT_FILT_SET_page; \
	COMMAND trans11_Temp_SPECT_FILT_SET_read; \
	COMMAND trans11_Temp_SPECT_FILT_SET_write; \
	MENU trans11_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS11_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans11_Temp_RJ_TEMP; \
	MENU trans11_Temp_RJ_TEMP_page; \
	COMMAND trans11_Temp_RJ_TEMP_read; \
	VARIABLE trans11_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans11_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans11_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans11_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans11_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans11_Temp_Unit_3

#define USE_TRANS11_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans11_Temp_COMP_WIRE2; \
	MENU trans11_Temp_COMP_WIRE2_page; \
	COMMAND trans11_Temp_COMP_WIRE2_read; \
	COMMAND trans11_Temp_COMP_WIRE2_write; \
	MENU trans11_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS11_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans11_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS11_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans11_Temp_RJ_TEMP; \
	MENU trans11_Temp_RJ_TEMP_page; \
	COMMAND trans11_Temp_RJ_TEMP_read; \
	VARIABLE trans11_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans11_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans11_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans11_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans11_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans11_Temp_Unit_3

#define USE_TRANS11_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans11_Temp_COMP_WIRE2; \
	MENU trans11_Temp_COMP_WIRE2_page; \
	COMMAND trans11_Temp_COMP_WIRE2_read; \
	COMMAND trans11_Temp_COMP_WIRE2_write; \
	MENU trans11_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS11_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans11_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans11_Temp_)
#define USE_TRANS11_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans11_Temp_)
#define USE_TRANS11_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans11_Temp_)
#define USE_TRANS11_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans11_Temp_)
#define USE_TRANS11_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans11_Temp_)
#define USE_TRANS11_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans11_Temp_)
#define USE_TRANS11_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans11_Temp_)
#define USE_TRANS11_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans11_Temp_)
#define USE_TRANS11_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans11_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_TEMP_MANDATORY_BOTH \
	BLOCK trans12_Temp_block; \
	COLLECTION trans12_Temp_BLOCK_OBJECT; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Temp_BLOCK_OBJECT_page; \
	COMMAND trans12_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans12_Temp_ST_REV; \
	MENU trans12_Temp_ST_REV_page; \
	COMMAND trans12_Temp_ST_REV_read; \
	VARIABLE trans12_Temp_TAG_DESC; \
	MENU trans12_Temp_TAG_DESC_page; \
	COMMAND trans12_Temp_TAG_DESC_read; \
	COMMAND trans12_Temp_TAG_DESC_write; \
	VARIABLE trans12_Temp_STRATEGY; \
	MENU trans12_Temp_STRATEGY_page; \
	COMMAND trans12_Temp_STRATEGY_read; \
	COMMAND trans12_Temp_STRATEGY_write; \
	VARIABLE trans12_Temp_ALERT_KEY; \
	MENU trans12_Temp_ALERT_KEY_page; \
	COMMAND trans12_Temp_ALERT_KEY_read; \
	COMMAND trans12_Temp_ALERT_KEY_write; \
	VARIABLE trans12_Temp_TARGET_MODE; \
	MENU trans12_Temp_TARGET_MODE_page; \
	COMMAND trans12_Temp_TARGET_MODE_read; \
	COMMAND trans12_Temp_TARGET_MODE_write; \
	COLLECTION trans12_Temp_MODE_BLK; \
	VARIABLE trans12_Temp_MODE_BLK_Actual; \
	VARIABLE trans12_Temp_MODE_BLK_Permitted; \
	VARIABLE trans12_Temp_MODE_BLK_Normal; \
	MENU trans12_Temp_MODE_BLK_page; \
	COMMAND trans12_Temp_MODE_BLK_read; \
	COLLECTION trans12_Temp_ALARM_SUM; \
	VARIABLE trans12_Temp_ALARM_SUM_Current; \
	VARIABLE trans12_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans12_Temp_ALARM_SUM_Disabled; \
	MENU trans12_Temp_ALARM_SUM_page; \
	COMMAND trans12_Temp_ALARM_SUM_read; \
	COLLECTION trans12_Temp_PRIMARY_VALUE; \
	VARIABLE trans12_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans12_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans12_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans12_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans12_Temp_PRIMARY_VALUE_page; \
	COMMAND trans12_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans12_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans12_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans12_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans12_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans12_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans12_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans12_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans12_Temp_SENSOR_MEAS_TYPE; \
	MENU trans12_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans12_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans12_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans12_Temp_INPUT_RANGE; \
	MENU trans12_Temp_INPUT_RANGE_page; \
	COMMAND trans12_Temp_INPUT_RANGE_read; \
	COMMAND trans12_Temp_INPUT_RANGE_write; \
	VARIABLE trans12_Temp_LIN_TYPE; \
	MENU trans12_Temp_LIN_TYPE_page; \
	COMMAND trans12_Temp_LIN_TYPE_read; \
	COMMAND trans12_Temp_LIN_TYPE_write; \
	VARIABLE trans12_Temp_BIAS_1; \
	MENU trans12_Temp_BIAS_1_page; \
	COMMAND trans12_Temp_BIAS_1_read; \
	COMMAND trans12_Temp_BIAS_1_write; \
	VARIABLE trans12_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans12_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans12_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans12_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans12_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans12_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans12_Temp_INPUT_FAULT_GEN; \
	MENU trans12_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans12_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans12_Temp_INPUT_FAULT_1; \
	MENU trans12_Temp_INPUT_FAULT_1_page; \
	COMMAND trans12_Temp_INPUT_FAULT_1_read; \
	UNIT trans12_Temp_Unit_1; \
	VARIABLE trans12_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans12_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans12_Temp_Display; \
	CHART trans12_Temp_Display_BarVal_pv; \
	SOURCE trans12_Temp_Display_BarVal_pv_source; \
	MENU trans12_Temp_Display_primary; \
	MENU trans12_Temp_Display_secondary; \
	MENU trans12_Temp_Tab_s; \
	MENU trans12_Temp_Tab_s_measrange; \
	MENU trans12_Temp_Tab_m

#define USE_TRANS12_TEMP_MANDATORY_A \
	USE_TRANS12_TEMP_MANDATORY_BOTH; \
	MENU trans12_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS12_TEMP_MANDATORY_B \
	USE_TRANS12_TEMP_MANDATORY_BOTH; \
	COLLECTION trans12_Temp_VIEW_1; \
	MENU trans12_Temp_VIEW_1_page; \
	MENU trans12_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS12_TEMP_OPTIONAL_BOTH \
	COLLECTION trans12_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans12_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans12_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans12_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans12_Temp_BIAS_2; \
	MENU trans12_Temp_BIAS_2_page; \
	COMMAND trans12_Temp_BIAS_2_read; \
	COMMAND trans12_Temp_BIAS_2_write; \
	VARIABLE trans12_Temp_INPUT_FAULT_2; \
	MENU trans12_Temp_INPUT_FAULT_2_page; \
	COMMAND trans12_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans12_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans12_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans12_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans12_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans12_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans12_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans12_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans12_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans12_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans12_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans12_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans12_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans12_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans12_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans12_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans12_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans12_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans12_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans12_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans12_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans12_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans12_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans12_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans12_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans12_Temp_TAB_ENTRY; \
	MENU trans12_Temp_TAB_ENTRY_page; \
	COMMAND trans12_Temp_TAB_ENTRY_read; \
	COMMAND trans12_Temp_TAB_ENTRY_write; \
	COLLECTION trans12_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans12_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans12_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans12_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans12_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans12_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans12_Temp_TAB_MIN_NUMBER; \
	MENU trans12_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans12_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans12_Temp_TAB_MAX_NUMBER; \
	MENU trans12_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans12_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans12_Temp_TAB_OP_CODE; \
	MENU trans12_Temp_TAB_OP_CODE_page; \
	COMMAND trans12_Temp_TAB_OP_CODE_read; \
	COMMAND trans12_Temp_TAB_OP_CODE_write; \
	VARIABLE trans12_Temp_TAB_STATUS; \
	MENU trans12_Temp_TAB_STATUS_page; \
	COMMAND trans12_Temp_TAB_STATUS_read; \
	VARIABLE trans12_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans12_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans12_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans12_Temp_VIEW_2; \
	MENU trans12_Temp_VIEW_2_page; \
	COLLECTION trans12_Temp_VIEW_3; \
	MENU trans12_Temp_VIEW_3_page; \
	UNIT trans12_Temp_Unit_2

#define USE_TRANS12_TEMP_OPTIONAL_A \
	USE_TRANS12_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans12_Temp_VIEW_1; \
	MENU trans12_Temp_VIEW_1_page; \
	MENU trans12_Temp_Simple_Dialog_Optional_A

#define USE_TRANS12_TEMP_OPTIONAL_B \
	USE_TRANS12_TEMP_OPTIONAL_BOTH; \
	MENU trans12_Temp_Simple_Dialog_Optional_B

#define USE_TRANS12_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans12_Temp_RJ_TYPE; \
	MENU trans12_Temp_RJ_TYPE_page; \
	COMMAND trans12_Temp_RJ_TYPE_read; \
	COMMAND trans12_Temp_RJ_TYPE_write; \
	MENU trans12_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS12_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans12_Temp_SENSOR_CONNECTION; \
	MENU trans12_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans12_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans12_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans12_Temp_COMP_WIRE1; \
	MENU trans12_Temp_COMP_WIRE1_page; \
	COMMAND trans12_Temp_COMP_WIRE1_read; \
	COMMAND trans12_Temp_COMP_WIRE1_write; \
	MENU trans12_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS12_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans12_Temp_EMISSIVITY; \
	MENU trans12_Temp_EMISSIVITY_page; \
	COMMAND trans12_Temp_EMISSIVITY_read; \
	COMMAND trans12_Temp_EMISSIVITY_write; \
	VARIABLE trans12_Temp_PEAK_TRACK; \
	MENU trans12_Temp_PEAK_TRACK_page; \
	COMMAND trans12_Temp_PEAK_TRACK_read; \
	COMMAND trans12_Temp_PEAK_TRACK_write; \
	VARIABLE trans12_Temp_DECAY_RATE; \
	MENU trans12_Temp_DECAY_RATE_page; \
	COMMAND trans12_Temp_DECAY_RATE_read; \
	COMMAND trans12_Temp_DECAY_RATE_write; \
	VARIABLE trans12_Temp_PEAK_TIME; \
	MENU trans12_Temp_PEAK_TIME_page; \
	COMMAND trans12_Temp_PEAK_TIME_read; \
	COMMAND trans12_Temp_PEAK_TIME_write; \
	VARIABLE trans12_Temp_TRACK_HOLD; \
	MENU trans12_Temp_TRACK_HOLD_page; \
	COMMAND trans12_Temp_TRACK_HOLD_read; \
	COMMAND trans12_Temp_TRACK_HOLD_write; \
	VARIABLE trans12_Temp_SPECT_FILT_SET; \
	MENU trans12_Temp_SPECT_FILT_SET_page; \
	COMMAND trans12_Temp_SPECT_FILT_SET_read; \
	COMMAND trans12_Temp_SPECT_FILT_SET_write; \
	MENU trans12_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS12_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans12_Temp_RJ_TYPE; \
	MENU trans12_Temp_RJ_TYPE_page; \
	COMMAND trans12_Temp_RJ_TYPE_read; \
	COMMAND trans12_Temp_RJ_TYPE_write; \
	MENU trans12_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS12_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans12_Temp_SENSOR_CONNECTION; \
	MENU trans12_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans12_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans12_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans12_Temp_COMP_WIRE1; \
	MENU trans12_Temp_COMP_WIRE1_page; \
	COMMAND trans12_Temp_COMP_WIRE1_read; \
	COMMAND trans12_Temp_COMP_WIRE1_write; \
	MENU trans12_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS12_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans12_Temp_EMISSIVITY; \
	MENU trans12_Temp_EMISSIVITY_page; \
	COMMAND trans12_Temp_EMISSIVITY_read; \
	COMMAND trans12_Temp_EMISSIVITY_write; \
	VARIABLE trans12_Temp_PEAK_TRACK; \
	MENU trans12_Temp_PEAK_TRACK_page; \
	COMMAND trans12_Temp_PEAK_TRACK_read; \
	COMMAND trans12_Temp_PEAK_TRACK_write; \
	VARIABLE trans12_Temp_DECAY_RATE; \
	MENU trans12_Temp_DECAY_RATE_page; \
	COMMAND trans12_Temp_DECAY_RATE_read; \
	COMMAND trans12_Temp_DECAY_RATE_write; \
	VARIABLE trans12_Temp_PEAK_TIME; \
	MENU trans12_Temp_PEAK_TIME_page; \
	COMMAND trans12_Temp_PEAK_TIME_read; \
	COMMAND trans12_Temp_PEAK_TIME_write; \
	VARIABLE trans12_Temp_TRACK_HOLD; \
	MENU trans12_Temp_TRACK_HOLD_page; \
	COMMAND trans12_Temp_TRACK_HOLD_read; \
	COMMAND trans12_Temp_TRACK_HOLD_write; \
	VARIABLE trans12_Temp_SPECT_FILT_SET; \
	MENU trans12_Temp_SPECT_FILT_SET_page; \
	COMMAND trans12_Temp_SPECT_FILT_SET_read; \
	COMMAND trans12_Temp_SPECT_FILT_SET_write; \
	MENU trans12_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS12_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans12_Temp_RJ_TEMP; \
	MENU trans12_Temp_RJ_TEMP_page; \
	COMMAND trans12_Temp_RJ_TEMP_read; \
	VARIABLE trans12_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans12_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans12_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans12_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans12_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans12_Temp_Unit_3

#define USE_TRANS12_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans12_Temp_COMP_WIRE2; \
	MENU trans12_Temp_COMP_WIRE2_page; \
	COMMAND trans12_Temp_COMP_WIRE2_read; \
	COMMAND trans12_Temp_COMP_WIRE2_write; \
	MENU trans12_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS12_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans12_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS12_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans12_Temp_RJ_TEMP; \
	MENU trans12_Temp_RJ_TEMP_page; \
	COMMAND trans12_Temp_RJ_TEMP_read; \
	VARIABLE trans12_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans12_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans12_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans12_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans12_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans12_Temp_Unit_3

#define USE_TRANS12_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans12_Temp_COMP_WIRE2; \
	MENU trans12_Temp_COMP_WIRE2_page; \
	COMMAND trans12_Temp_COMP_WIRE2_read; \
	COMMAND trans12_Temp_COMP_WIRE2_write; \
	MENU trans12_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS12_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans12_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans12_Temp_)
#define USE_TRANS12_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans12_Temp_)
#define USE_TRANS12_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans12_Temp_)
#define USE_TRANS12_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans12_Temp_)
#define USE_TRANS12_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans12_Temp_)
#define USE_TRANS12_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans12_Temp_)
#define USE_TRANS12_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans12_Temp_)
#define USE_TRANS12_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans12_Temp_)
#define USE_TRANS12_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans12_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_TEMP_MANDATORY_BOTH \
	BLOCK trans13_Temp_block; \
	COLLECTION trans13_Temp_BLOCK_OBJECT; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Temp_BLOCK_OBJECT_page; \
	COMMAND trans13_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans13_Temp_ST_REV; \
	MENU trans13_Temp_ST_REV_page; \
	COMMAND trans13_Temp_ST_REV_read; \
	VARIABLE trans13_Temp_TAG_DESC; \
	MENU trans13_Temp_TAG_DESC_page; \
	COMMAND trans13_Temp_TAG_DESC_read; \
	COMMAND trans13_Temp_TAG_DESC_write; \
	VARIABLE trans13_Temp_STRATEGY; \
	MENU trans13_Temp_STRATEGY_page; \
	COMMAND trans13_Temp_STRATEGY_read; \
	COMMAND trans13_Temp_STRATEGY_write; \
	VARIABLE trans13_Temp_ALERT_KEY; \
	MENU trans13_Temp_ALERT_KEY_page; \
	COMMAND trans13_Temp_ALERT_KEY_read; \
	COMMAND trans13_Temp_ALERT_KEY_write; \
	VARIABLE trans13_Temp_TARGET_MODE; \
	MENU trans13_Temp_TARGET_MODE_page; \
	COMMAND trans13_Temp_TARGET_MODE_read; \
	COMMAND trans13_Temp_TARGET_MODE_write; \
	COLLECTION trans13_Temp_MODE_BLK; \
	VARIABLE trans13_Temp_MODE_BLK_Actual; \
	VARIABLE trans13_Temp_MODE_BLK_Permitted; \
	VARIABLE trans13_Temp_MODE_BLK_Normal; \
	MENU trans13_Temp_MODE_BLK_page; \
	COMMAND trans13_Temp_MODE_BLK_read; \
	COLLECTION trans13_Temp_ALARM_SUM; \
	VARIABLE trans13_Temp_ALARM_SUM_Current; \
	VARIABLE trans13_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans13_Temp_ALARM_SUM_Disabled; \
	MENU trans13_Temp_ALARM_SUM_page; \
	COMMAND trans13_Temp_ALARM_SUM_read; \
	COLLECTION trans13_Temp_PRIMARY_VALUE; \
	VARIABLE trans13_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans13_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans13_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans13_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans13_Temp_PRIMARY_VALUE_page; \
	COMMAND trans13_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans13_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans13_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans13_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans13_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans13_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans13_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans13_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans13_Temp_SENSOR_MEAS_TYPE; \
	MENU trans13_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans13_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans13_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans13_Temp_INPUT_RANGE; \
	MENU trans13_Temp_INPUT_RANGE_page; \
	COMMAND trans13_Temp_INPUT_RANGE_read; \
	COMMAND trans13_Temp_INPUT_RANGE_write; \
	VARIABLE trans13_Temp_LIN_TYPE; \
	MENU trans13_Temp_LIN_TYPE_page; \
	COMMAND trans13_Temp_LIN_TYPE_read; \
	COMMAND trans13_Temp_LIN_TYPE_write; \
	VARIABLE trans13_Temp_BIAS_1; \
	MENU trans13_Temp_BIAS_1_page; \
	COMMAND trans13_Temp_BIAS_1_read; \
	COMMAND trans13_Temp_BIAS_1_write; \
	VARIABLE trans13_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans13_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans13_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans13_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans13_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans13_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans13_Temp_INPUT_FAULT_GEN; \
	MENU trans13_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans13_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans13_Temp_INPUT_FAULT_1; \
	MENU trans13_Temp_INPUT_FAULT_1_page; \
	COMMAND trans13_Temp_INPUT_FAULT_1_read; \
	UNIT trans13_Temp_Unit_1; \
	VARIABLE trans13_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans13_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans13_Temp_Display; \
	CHART trans13_Temp_Display_BarVal_pv; \
	SOURCE trans13_Temp_Display_BarVal_pv_source; \
	MENU trans13_Temp_Display_primary; \
	MENU trans13_Temp_Display_secondary; \
	MENU trans13_Temp_Tab_s; \
	MENU trans13_Temp_Tab_s_measrange; \
	MENU trans13_Temp_Tab_m

#define USE_TRANS13_TEMP_MANDATORY_A \
	USE_TRANS13_TEMP_MANDATORY_BOTH; \
	MENU trans13_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS13_TEMP_MANDATORY_B \
	USE_TRANS13_TEMP_MANDATORY_BOTH; \
	COLLECTION trans13_Temp_VIEW_1; \
	MENU trans13_Temp_VIEW_1_page; \
	MENU trans13_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS13_TEMP_OPTIONAL_BOTH \
	COLLECTION trans13_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans13_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans13_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans13_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans13_Temp_BIAS_2; \
	MENU trans13_Temp_BIAS_2_page; \
	COMMAND trans13_Temp_BIAS_2_read; \
	COMMAND trans13_Temp_BIAS_2_write; \
	VARIABLE trans13_Temp_INPUT_FAULT_2; \
	MENU trans13_Temp_INPUT_FAULT_2_page; \
	COMMAND trans13_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans13_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans13_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans13_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans13_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans13_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans13_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans13_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans13_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans13_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans13_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans13_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans13_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans13_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans13_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans13_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans13_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans13_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans13_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans13_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans13_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans13_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans13_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans13_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans13_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans13_Temp_TAB_ENTRY; \
	MENU trans13_Temp_TAB_ENTRY_page; \
	COMMAND trans13_Temp_TAB_ENTRY_read; \
	COMMAND trans13_Temp_TAB_ENTRY_write; \
	COLLECTION trans13_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans13_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans13_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans13_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans13_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans13_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans13_Temp_TAB_MIN_NUMBER; \
	MENU trans13_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans13_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans13_Temp_TAB_MAX_NUMBER; \
	MENU trans13_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans13_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans13_Temp_TAB_OP_CODE; \
	MENU trans13_Temp_TAB_OP_CODE_page; \
	COMMAND trans13_Temp_TAB_OP_CODE_read; \
	COMMAND trans13_Temp_TAB_OP_CODE_write; \
	VARIABLE trans13_Temp_TAB_STATUS; \
	MENU trans13_Temp_TAB_STATUS_page; \
	COMMAND trans13_Temp_TAB_STATUS_read; \
	VARIABLE trans13_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans13_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans13_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans13_Temp_VIEW_2; \
	MENU trans13_Temp_VIEW_2_page; \
	COLLECTION trans13_Temp_VIEW_3; \
	MENU trans13_Temp_VIEW_3_page; \
	UNIT trans13_Temp_Unit_2

#define USE_TRANS13_TEMP_OPTIONAL_A \
	USE_TRANS13_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans13_Temp_VIEW_1; \
	MENU trans13_Temp_VIEW_1_page; \
	MENU trans13_Temp_Simple_Dialog_Optional_A

#define USE_TRANS13_TEMP_OPTIONAL_B \
	USE_TRANS13_TEMP_OPTIONAL_BOTH; \
	MENU trans13_Temp_Simple_Dialog_Optional_B

#define USE_TRANS13_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans13_Temp_RJ_TYPE; \
	MENU trans13_Temp_RJ_TYPE_page; \
	COMMAND trans13_Temp_RJ_TYPE_read; \
	COMMAND trans13_Temp_RJ_TYPE_write; \
	MENU trans13_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS13_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans13_Temp_SENSOR_CONNECTION; \
	MENU trans13_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans13_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans13_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans13_Temp_COMP_WIRE1; \
	MENU trans13_Temp_COMP_WIRE1_page; \
	COMMAND trans13_Temp_COMP_WIRE1_read; \
	COMMAND trans13_Temp_COMP_WIRE1_write; \
	MENU trans13_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS13_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans13_Temp_EMISSIVITY; \
	MENU trans13_Temp_EMISSIVITY_page; \
	COMMAND trans13_Temp_EMISSIVITY_read; \
	COMMAND trans13_Temp_EMISSIVITY_write; \
	VARIABLE trans13_Temp_PEAK_TRACK; \
	MENU trans13_Temp_PEAK_TRACK_page; \
	COMMAND trans13_Temp_PEAK_TRACK_read; \
	COMMAND trans13_Temp_PEAK_TRACK_write; \
	VARIABLE trans13_Temp_DECAY_RATE; \
	MENU trans13_Temp_DECAY_RATE_page; \
	COMMAND trans13_Temp_DECAY_RATE_read; \
	COMMAND trans13_Temp_DECAY_RATE_write; \
	VARIABLE trans13_Temp_PEAK_TIME; \
	MENU trans13_Temp_PEAK_TIME_page; \
	COMMAND trans13_Temp_PEAK_TIME_read; \
	COMMAND trans13_Temp_PEAK_TIME_write; \
	VARIABLE trans13_Temp_TRACK_HOLD; \
	MENU trans13_Temp_TRACK_HOLD_page; \
	COMMAND trans13_Temp_TRACK_HOLD_read; \
	COMMAND trans13_Temp_TRACK_HOLD_write; \
	VARIABLE trans13_Temp_SPECT_FILT_SET; \
	MENU trans13_Temp_SPECT_FILT_SET_page; \
	COMMAND trans13_Temp_SPECT_FILT_SET_read; \
	COMMAND trans13_Temp_SPECT_FILT_SET_write; \
	MENU trans13_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS13_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans13_Temp_RJ_TYPE; \
	MENU trans13_Temp_RJ_TYPE_page; \
	COMMAND trans13_Temp_RJ_TYPE_read; \
	COMMAND trans13_Temp_RJ_TYPE_write; \
	MENU trans13_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS13_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans13_Temp_SENSOR_CONNECTION; \
	MENU trans13_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans13_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans13_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans13_Temp_COMP_WIRE1; \
	MENU trans13_Temp_COMP_WIRE1_page; \
	COMMAND trans13_Temp_COMP_WIRE1_read; \
	COMMAND trans13_Temp_COMP_WIRE1_write; \
	MENU trans13_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS13_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans13_Temp_EMISSIVITY; \
	MENU trans13_Temp_EMISSIVITY_page; \
	COMMAND trans13_Temp_EMISSIVITY_read; \
	COMMAND trans13_Temp_EMISSIVITY_write; \
	VARIABLE trans13_Temp_PEAK_TRACK; \
	MENU trans13_Temp_PEAK_TRACK_page; \
	COMMAND trans13_Temp_PEAK_TRACK_read; \
	COMMAND trans13_Temp_PEAK_TRACK_write; \
	VARIABLE trans13_Temp_DECAY_RATE; \
	MENU trans13_Temp_DECAY_RATE_page; \
	COMMAND trans13_Temp_DECAY_RATE_read; \
	COMMAND trans13_Temp_DECAY_RATE_write; \
	VARIABLE trans13_Temp_PEAK_TIME; \
	MENU trans13_Temp_PEAK_TIME_page; \
	COMMAND trans13_Temp_PEAK_TIME_read; \
	COMMAND trans13_Temp_PEAK_TIME_write; \
	VARIABLE trans13_Temp_TRACK_HOLD; \
	MENU trans13_Temp_TRACK_HOLD_page; \
	COMMAND trans13_Temp_TRACK_HOLD_read; \
	COMMAND trans13_Temp_TRACK_HOLD_write; \
	VARIABLE trans13_Temp_SPECT_FILT_SET; \
	MENU trans13_Temp_SPECT_FILT_SET_page; \
	COMMAND trans13_Temp_SPECT_FILT_SET_read; \
	COMMAND trans13_Temp_SPECT_FILT_SET_write; \
	MENU trans13_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS13_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans13_Temp_RJ_TEMP; \
	MENU trans13_Temp_RJ_TEMP_page; \
	COMMAND trans13_Temp_RJ_TEMP_read; \
	VARIABLE trans13_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans13_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans13_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans13_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans13_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans13_Temp_Unit_3

#define USE_TRANS13_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans13_Temp_COMP_WIRE2; \
	MENU trans13_Temp_COMP_WIRE2_page; \
	COMMAND trans13_Temp_COMP_WIRE2_read; \
	COMMAND trans13_Temp_COMP_WIRE2_write; \
	MENU trans13_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS13_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans13_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS13_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans13_Temp_RJ_TEMP; \
	MENU trans13_Temp_RJ_TEMP_page; \
	COMMAND trans13_Temp_RJ_TEMP_read; \
	VARIABLE trans13_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans13_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans13_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans13_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans13_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans13_Temp_Unit_3

#define USE_TRANS13_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans13_Temp_COMP_WIRE2; \
	MENU trans13_Temp_COMP_WIRE2_page; \
	COMMAND trans13_Temp_COMP_WIRE2_read; \
	COMMAND trans13_Temp_COMP_WIRE2_write; \
	MENU trans13_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS13_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans13_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans13_Temp_)
#define USE_TRANS13_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans13_Temp_)
#define USE_TRANS13_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans13_Temp_)
#define USE_TRANS13_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans13_Temp_)
#define USE_TRANS13_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans13_Temp_)
#define USE_TRANS13_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans13_Temp_)
#define USE_TRANS13_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans13_Temp_)
#define USE_TRANS13_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans13_Temp_)
#define USE_TRANS13_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans13_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_TEMP_MANDATORY_BOTH \
	BLOCK trans14_Temp_block; \
	COLLECTION trans14_Temp_BLOCK_OBJECT; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Temp_BLOCK_OBJECT_page; \
	COMMAND trans14_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans14_Temp_ST_REV; \
	MENU trans14_Temp_ST_REV_page; \
	COMMAND trans14_Temp_ST_REV_read; \
	VARIABLE trans14_Temp_TAG_DESC; \
	MENU trans14_Temp_TAG_DESC_page; \
	COMMAND trans14_Temp_TAG_DESC_read; \
	COMMAND trans14_Temp_TAG_DESC_write; \
	VARIABLE trans14_Temp_STRATEGY; \
	MENU trans14_Temp_STRATEGY_page; \
	COMMAND trans14_Temp_STRATEGY_read; \
	COMMAND trans14_Temp_STRATEGY_write; \
	VARIABLE trans14_Temp_ALERT_KEY; \
	MENU trans14_Temp_ALERT_KEY_page; \
	COMMAND trans14_Temp_ALERT_KEY_read; \
	COMMAND trans14_Temp_ALERT_KEY_write; \
	VARIABLE trans14_Temp_TARGET_MODE; \
	MENU trans14_Temp_TARGET_MODE_page; \
	COMMAND trans14_Temp_TARGET_MODE_read; \
	COMMAND trans14_Temp_TARGET_MODE_write; \
	COLLECTION trans14_Temp_MODE_BLK; \
	VARIABLE trans14_Temp_MODE_BLK_Actual; \
	VARIABLE trans14_Temp_MODE_BLK_Permitted; \
	VARIABLE trans14_Temp_MODE_BLK_Normal; \
	MENU trans14_Temp_MODE_BLK_page; \
	COMMAND trans14_Temp_MODE_BLK_read; \
	COLLECTION trans14_Temp_ALARM_SUM; \
	VARIABLE trans14_Temp_ALARM_SUM_Current; \
	VARIABLE trans14_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans14_Temp_ALARM_SUM_Disabled; \
	MENU trans14_Temp_ALARM_SUM_page; \
	COMMAND trans14_Temp_ALARM_SUM_read; \
	COLLECTION trans14_Temp_PRIMARY_VALUE; \
	VARIABLE trans14_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans14_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans14_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans14_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans14_Temp_PRIMARY_VALUE_page; \
	COMMAND trans14_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans14_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans14_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans14_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans14_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans14_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans14_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans14_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans14_Temp_SENSOR_MEAS_TYPE; \
	MENU trans14_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans14_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans14_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans14_Temp_INPUT_RANGE; \
	MENU trans14_Temp_INPUT_RANGE_page; \
	COMMAND trans14_Temp_INPUT_RANGE_read; \
	COMMAND trans14_Temp_INPUT_RANGE_write; \
	VARIABLE trans14_Temp_LIN_TYPE; \
	MENU trans14_Temp_LIN_TYPE_page; \
	COMMAND trans14_Temp_LIN_TYPE_read; \
	COMMAND trans14_Temp_LIN_TYPE_write; \
	VARIABLE trans14_Temp_BIAS_1; \
	MENU trans14_Temp_BIAS_1_page; \
	COMMAND trans14_Temp_BIAS_1_read; \
	COMMAND trans14_Temp_BIAS_1_write; \
	VARIABLE trans14_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans14_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans14_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans14_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans14_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans14_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans14_Temp_INPUT_FAULT_GEN; \
	MENU trans14_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans14_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans14_Temp_INPUT_FAULT_1; \
	MENU trans14_Temp_INPUT_FAULT_1_page; \
	COMMAND trans14_Temp_INPUT_FAULT_1_read; \
	UNIT trans14_Temp_Unit_1; \
	VARIABLE trans14_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans14_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans14_Temp_Display; \
	CHART trans14_Temp_Display_BarVal_pv; \
	SOURCE trans14_Temp_Display_BarVal_pv_source; \
	MENU trans14_Temp_Display_primary; \
	MENU trans14_Temp_Display_secondary; \
	MENU trans14_Temp_Tab_s; \
	MENU trans14_Temp_Tab_s_measrange; \
	MENU trans14_Temp_Tab_m

#define USE_TRANS14_TEMP_MANDATORY_A \
	USE_TRANS14_TEMP_MANDATORY_BOTH; \
	MENU trans14_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS14_TEMP_MANDATORY_B \
	USE_TRANS14_TEMP_MANDATORY_BOTH; \
	COLLECTION trans14_Temp_VIEW_1; \
	MENU trans14_Temp_VIEW_1_page; \
	MENU trans14_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS14_TEMP_OPTIONAL_BOTH \
	COLLECTION trans14_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans14_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans14_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans14_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans14_Temp_BIAS_2; \
	MENU trans14_Temp_BIAS_2_page; \
	COMMAND trans14_Temp_BIAS_2_read; \
	COMMAND trans14_Temp_BIAS_2_write; \
	VARIABLE trans14_Temp_INPUT_FAULT_2; \
	MENU trans14_Temp_INPUT_FAULT_2_page; \
	COMMAND trans14_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans14_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans14_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans14_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans14_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans14_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans14_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans14_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans14_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans14_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans14_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans14_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans14_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans14_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans14_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans14_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans14_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans14_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans14_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans14_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans14_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans14_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans14_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans14_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans14_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans14_Temp_TAB_ENTRY; \
	MENU trans14_Temp_TAB_ENTRY_page; \
	COMMAND trans14_Temp_TAB_ENTRY_read; \
	COMMAND trans14_Temp_TAB_ENTRY_write; \
	COLLECTION trans14_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans14_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans14_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans14_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans14_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans14_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans14_Temp_TAB_MIN_NUMBER; \
	MENU trans14_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans14_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans14_Temp_TAB_MAX_NUMBER; \
	MENU trans14_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans14_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans14_Temp_TAB_OP_CODE; \
	MENU trans14_Temp_TAB_OP_CODE_page; \
	COMMAND trans14_Temp_TAB_OP_CODE_read; \
	COMMAND trans14_Temp_TAB_OP_CODE_write; \
	VARIABLE trans14_Temp_TAB_STATUS; \
	MENU trans14_Temp_TAB_STATUS_page; \
	COMMAND trans14_Temp_TAB_STATUS_read; \
	VARIABLE trans14_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans14_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans14_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans14_Temp_VIEW_2; \
	MENU trans14_Temp_VIEW_2_page; \
	COLLECTION trans14_Temp_VIEW_3; \
	MENU trans14_Temp_VIEW_3_page; \
	UNIT trans14_Temp_Unit_2

#define USE_TRANS14_TEMP_OPTIONAL_A \
	USE_TRANS14_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans14_Temp_VIEW_1; \
	MENU trans14_Temp_VIEW_1_page; \
	MENU trans14_Temp_Simple_Dialog_Optional_A

#define USE_TRANS14_TEMP_OPTIONAL_B \
	USE_TRANS14_TEMP_OPTIONAL_BOTH; \
	MENU trans14_Temp_Simple_Dialog_Optional_B

#define USE_TRANS14_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans14_Temp_RJ_TYPE; \
	MENU trans14_Temp_RJ_TYPE_page; \
	COMMAND trans14_Temp_RJ_TYPE_read; \
	COMMAND trans14_Temp_RJ_TYPE_write; \
	MENU trans14_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS14_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans14_Temp_SENSOR_CONNECTION; \
	MENU trans14_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans14_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans14_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans14_Temp_COMP_WIRE1; \
	MENU trans14_Temp_COMP_WIRE1_page; \
	COMMAND trans14_Temp_COMP_WIRE1_read; \
	COMMAND trans14_Temp_COMP_WIRE1_write; \
	MENU trans14_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS14_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans14_Temp_EMISSIVITY; \
	MENU trans14_Temp_EMISSIVITY_page; \
	COMMAND trans14_Temp_EMISSIVITY_read; \
	COMMAND trans14_Temp_EMISSIVITY_write; \
	VARIABLE trans14_Temp_PEAK_TRACK; \
	MENU trans14_Temp_PEAK_TRACK_page; \
	COMMAND trans14_Temp_PEAK_TRACK_read; \
	COMMAND trans14_Temp_PEAK_TRACK_write; \
	VARIABLE trans14_Temp_DECAY_RATE; \
	MENU trans14_Temp_DECAY_RATE_page; \
	COMMAND trans14_Temp_DECAY_RATE_read; \
	COMMAND trans14_Temp_DECAY_RATE_write; \
	VARIABLE trans14_Temp_PEAK_TIME; \
	MENU trans14_Temp_PEAK_TIME_page; \
	COMMAND trans14_Temp_PEAK_TIME_read; \
	COMMAND trans14_Temp_PEAK_TIME_write; \
	VARIABLE trans14_Temp_TRACK_HOLD; \
	MENU trans14_Temp_TRACK_HOLD_page; \
	COMMAND trans14_Temp_TRACK_HOLD_read; \
	COMMAND trans14_Temp_TRACK_HOLD_write; \
	VARIABLE trans14_Temp_SPECT_FILT_SET; \
	MENU trans14_Temp_SPECT_FILT_SET_page; \
	COMMAND trans14_Temp_SPECT_FILT_SET_read; \
	COMMAND trans14_Temp_SPECT_FILT_SET_write; \
	MENU trans14_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS14_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans14_Temp_RJ_TYPE; \
	MENU trans14_Temp_RJ_TYPE_page; \
	COMMAND trans14_Temp_RJ_TYPE_read; \
	COMMAND trans14_Temp_RJ_TYPE_write; \
	MENU trans14_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS14_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans14_Temp_SENSOR_CONNECTION; \
	MENU trans14_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans14_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans14_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans14_Temp_COMP_WIRE1; \
	MENU trans14_Temp_COMP_WIRE1_page; \
	COMMAND trans14_Temp_COMP_WIRE1_read; \
	COMMAND trans14_Temp_COMP_WIRE1_write; \
	MENU trans14_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS14_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans14_Temp_EMISSIVITY; \
	MENU trans14_Temp_EMISSIVITY_page; \
	COMMAND trans14_Temp_EMISSIVITY_read; \
	COMMAND trans14_Temp_EMISSIVITY_write; \
	VARIABLE trans14_Temp_PEAK_TRACK; \
	MENU trans14_Temp_PEAK_TRACK_page; \
	COMMAND trans14_Temp_PEAK_TRACK_read; \
	COMMAND trans14_Temp_PEAK_TRACK_write; \
	VARIABLE trans14_Temp_DECAY_RATE; \
	MENU trans14_Temp_DECAY_RATE_page; \
	COMMAND trans14_Temp_DECAY_RATE_read; \
	COMMAND trans14_Temp_DECAY_RATE_write; \
	VARIABLE trans14_Temp_PEAK_TIME; \
	MENU trans14_Temp_PEAK_TIME_page; \
	COMMAND trans14_Temp_PEAK_TIME_read; \
	COMMAND trans14_Temp_PEAK_TIME_write; \
	VARIABLE trans14_Temp_TRACK_HOLD; \
	MENU trans14_Temp_TRACK_HOLD_page; \
	COMMAND trans14_Temp_TRACK_HOLD_read; \
	COMMAND trans14_Temp_TRACK_HOLD_write; \
	VARIABLE trans14_Temp_SPECT_FILT_SET; \
	MENU trans14_Temp_SPECT_FILT_SET_page; \
	COMMAND trans14_Temp_SPECT_FILT_SET_read; \
	COMMAND trans14_Temp_SPECT_FILT_SET_write; \
	MENU trans14_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS14_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans14_Temp_RJ_TEMP; \
	MENU trans14_Temp_RJ_TEMP_page; \
	COMMAND trans14_Temp_RJ_TEMP_read; \
	VARIABLE trans14_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans14_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans14_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans14_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans14_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans14_Temp_Unit_3

#define USE_TRANS14_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans14_Temp_COMP_WIRE2; \
	MENU trans14_Temp_COMP_WIRE2_page; \
	COMMAND trans14_Temp_COMP_WIRE2_read; \
	COMMAND trans14_Temp_COMP_WIRE2_write; \
	MENU trans14_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS14_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans14_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS14_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans14_Temp_RJ_TEMP; \
	MENU trans14_Temp_RJ_TEMP_page; \
	COMMAND trans14_Temp_RJ_TEMP_read; \
	VARIABLE trans14_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans14_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans14_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans14_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans14_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans14_Temp_Unit_3

#define USE_TRANS14_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans14_Temp_COMP_WIRE2; \
	MENU trans14_Temp_COMP_WIRE2_page; \
	COMMAND trans14_Temp_COMP_WIRE2_read; \
	COMMAND trans14_Temp_COMP_WIRE2_write; \
	MENU trans14_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS14_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans14_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans14_Temp_)
#define USE_TRANS14_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans14_Temp_)
#define USE_TRANS14_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans14_Temp_)
#define USE_TRANS14_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans14_Temp_)
#define USE_TRANS14_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans14_Temp_)
#define USE_TRANS14_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans14_Temp_)
#define USE_TRANS14_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans14_Temp_)
#define USE_TRANS14_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans14_Temp_)
#define USE_TRANS14_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans14_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_TEMP_MANDATORY_BOTH \
	BLOCK trans15_Temp_block; \
	COLLECTION trans15_Temp_BLOCK_OBJECT; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Temp_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Temp_BLOCK_OBJECT_page; \
	COMMAND trans15_Temp_BLOCK_OBJECT_read; \
	VARIABLE trans15_Temp_ST_REV; \
	MENU trans15_Temp_ST_REV_page; \
	COMMAND trans15_Temp_ST_REV_read; \
	VARIABLE trans15_Temp_TAG_DESC; \
	MENU trans15_Temp_TAG_DESC_page; \
	COMMAND trans15_Temp_TAG_DESC_read; \
	COMMAND trans15_Temp_TAG_DESC_write; \
	VARIABLE trans15_Temp_STRATEGY; \
	MENU trans15_Temp_STRATEGY_page; \
	COMMAND trans15_Temp_STRATEGY_read; \
	COMMAND trans15_Temp_STRATEGY_write; \
	VARIABLE trans15_Temp_ALERT_KEY; \
	MENU trans15_Temp_ALERT_KEY_page; \
	COMMAND trans15_Temp_ALERT_KEY_read; \
	COMMAND trans15_Temp_ALERT_KEY_write; \
	VARIABLE trans15_Temp_TARGET_MODE; \
	MENU trans15_Temp_TARGET_MODE_page; \
	COMMAND trans15_Temp_TARGET_MODE_read; \
	COMMAND trans15_Temp_TARGET_MODE_write; \
	COLLECTION trans15_Temp_MODE_BLK; \
	VARIABLE trans15_Temp_MODE_BLK_Actual; \
	VARIABLE trans15_Temp_MODE_BLK_Permitted; \
	VARIABLE trans15_Temp_MODE_BLK_Normal; \
	MENU trans15_Temp_MODE_BLK_page; \
	COMMAND trans15_Temp_MODE_BLK_read; \
	COLLECTION trans15_Temp_ALARM_SUM; \
	VARIABLE trans15_Temp_ALARM_SUM_Current; \
	VARIABLE trans15_Temp_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Temp_ALARM_SUM_Unreported; \
	VARIABLE trans15_Temp_ALARM_SUM_Disabled; \
	MENU trans15_Temp_ALARM_SUM_page; \
	COMMAND trans15_Temp_ALARM_SUM_read; \
	COLLECTION trans15_Temp_PRIMARY_VALUE; \
	VARIABLE trans15_Temp_PRIMARY_VALUE_Value; \
	VARIABLE trans15_Temp_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans15_Temp_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans15_Temp_PRIMARY_VALUE_Status_Limit; \
	MENU trans15_Temp_PRIMARY_VALUE_page; \
	COMMAND trans15_Temp_PRIMARY_VALUE_read; \
	VARIABLE trans15_Temp_PRIMARY_VALUE_UNIT; \
	MENU trans15_Temp_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans15_Temp_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans15_Temp_PRIMARY_VALUE_UNIT_write; \
	COLLECTION trans15_Temp_SECONDARY_VALUE_1; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_1_Value; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans15_Temp_SECONDARY_VALUE_1_page; \
	COMMAND trans15_Temp_SECONDARY_VALUE_1_read; \
	VARIABLE trans15_Temp_SENSOR_MEAS_TYPE; \
	MENU trans15_Temp_SENSOR_MEAS_TYPE_page; \
	COMMAND trans15_Temp_SENSOR_MEAS_TYPE_read; \
	COMMAND trans15_Temp_SENSOR_MEAS_TYPE_write; \
	VARIABLE trans15_Temp_INPUT_RANGE; \
	MENU trans15_Temp_INPUT_RANGE_page; \
	COMMAND trans15_Temp_INPUT_RANGE_read; \
	COMMAND trans15_Temp_INPUT_RANGE_write; \
	VARIABLE trans15_Temp_LIN_TYPE; \
	MENU trans15_Temp_LIN_TYPE_page; \
	COMMAND trans15_Temp_LIN_TYPE_read; \
	COMMAND trans15_Temp_LIN_TYPE_write; \
	VARIABLE trans15_Temp_BIAS_1; \
	MENU trans15_Temp_BIAS_1_page; \
	COMMAND trans15_Temp_BIAS_1_read; \
	COMMAND trans15_Temp_BIAS_1_write; \
	VARIABLE trans15_Temp_UPPER_SENSOR_LIMIT; \
	MENU trans15_Temp_UPPER_SENSOR_LIMIT_page; \
	COMMAND trans15_Temp_UPPER_SENSOR_LIMIT_read; \
	VARIABLE trans15_Temp_LOWER_SENSOR_LIMIT; \
	MENU trans15_Temp_LOWER_SENSOR_LIMIT_page; \
	COMMAND trans15_Temp_LOWER_SENSOR_LIMIT_read; \
	VARIABLE trans15_Temp_INPUT_FAULT_GEN; \
	MENU trans15_Temp_INPUT_FAULT_GEN_page; \
	COMMAND trans15_Temp_INPUT_FAULT_GEN_read; \
	VARIABLE trans15_Temp_INPUT_FAULT_1; \
	MENU trans15_Temp_INPUT_FAULT_1_page; \
	COMMAND trans15_Temp_INPUT_FAULT_1_read; \
	UNIT trans15_Temp_Unit_1; \
	VARIABLE trans15_Temp_PRIMARY_VALUE_UNIT_for_RJ_TEMP; \
	METHOD trans15_Temp_PRIMARY_VALUE_UNIT_post; \
	MENU trans15_Temp_Display; \
	CHART trans15_Temp_Display_BarVal_pv; \
	SOURCE trans15_Temp_Display_BarVal_pv_source; \
	MENU trans15_Temp_Display_primary; \
	MENU trans15_Temp_Display_secondary; \
	MENU trans15_Temp_Tab_s; \
	MENU trans15_Temp_Tab_s_measrange; \
	MENU trans15_Temp_Tab_m

#define USE_TRANS15_TEMP_MANDATORY_A \
	USE_TRANS15_TEMP_MANDATORY_BOTH; \
	MENU trans15_Temp_Simple_Dialog_Mandatory_A

#define USE_TRANS15_TEMP_MANDATORY_B \
	USE_TRANS15_TEMP_MANDATORY_BOTH; \
	COLLECTION trans15_Temp_VIEW_1; \
	MENU trans15_Temp_VIEW_1_page; \
	MENU trans15_Temp_Simple_Dialog_Mandatory_B

#define USE_TRANS15_TEMP_OPTIONAL_BOTH \
	COLLECTION trans15_Temp_SECONDARY_VALUE_2; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_2_Value; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans15_Temp_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans15_Temp_SECONDARY_VALUE_2_page; \
	COMMAND trans15_Temp_SECONDARY_VALUE_2_read; \
	VARIABLE trans15_Temp_BIAS_2; \
	MENU trans15_Temp_BIAS_2_page; \
	COMMAND trans15_Temp_BIAS_2_read; \
	COMMAND trans15_Temp_BIAS_2_write; \
	VARIABLE trans15_Temp_INPUT_FAULT_2; \
	MENU trans15_Temp_INPUT_FAULT_2_page; \
	COMMAND trans15_Temp_INPUT_FAULT_2_read; \
	VARIABLE trans15_Temp_SENSOR_WIRE_CHECK_1; \
	MENU trans15_Temp_SENSOR_WIRE_CHECK_1_page; \
	COMMAND trans15_Temp_SENSOR_WIRE_CHECK_1_read; \
	COMMAND trans15_Temp_SENSOR_WIRE_CHECK_1_write; \
	VARIABLE trans15_Temp_SENSOR_WIRE_CHECK_2; \
	MENU trans15_Temp_SENSOR_WIRE_CHECK_2_page; \
	COMMAND trans15_Temp_SENSOR_WIRE_CHECK_2_read; \
	COMMAND trans15_Temp_SENSOR_WIRE_CHECK_2_write; \
	VARIABLE trans15_Temp_MAX_SENSOR_VALUE_1; \
	MENU trans15_Temp_MAX_SENSOR_VALUE_1_page; \
	COMMAND trans15_Temp_MAX_SENSOR_VALUE_1_read; \
	COMMAND trans15_Temp_MAX_SENSOR_VALUE_1_write; \
	VARIABLE trans15_Temp_MIN_SENSOR_VALUE_1; \
	MENU trans15_Temp_MIN_SENSOR_VALUE_1_page; \
	COMMAND trans15_Temp_MIN_SENSOR_VALUE_1_read; \
	COMMAND trans15_Temp_MIN_SENSOR_VALUE_1_write; \
	VARIABLE trans15_Temp_MAX_SENSOR_VALUE_2; \
	MENU trans15_Temp_MAX_SENSOR_VALUE_2_page; \
	COMMAND trans15_Temp_MAX_SENSOR_VALUE_2_read; \
	COMMAND trans15_Temp_MAX_SENSOR_VALUE_2_write; \
	VARIABLE trans15_Temp_MIN_SENSOR_VALUE_2; \
	MENU trans15_Temp_MIN_SENSOR_VALUE_2_page; \
	COMMAND trans15_Temp_MIN_SENSOR_VALUE_2_read; \
	COMMAND trans15_Temp_MIN_SENSOR_VALUE_2_write; \
	VARIABLE trans15_Temp_TAB_ENTRY; \
	MENU trans15_Temp_TAB_ENTRY_page; \
	COMMAND trans15_Temp_TAB_ENTRY_read; \
	COMMAND trans15_Temp_TAB_ENTRY_write; \
	COLLECTION trans15_Temp_TAB_X_Y_VALUE; \
	VARIABLE trans15_Temp_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans15_Temp_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans15_Temp_TAB_X_Y_VALUE_page; \
	COMMAND trans15_Temp_TAB_X_Y_VALUE_read; \
	COMMAND trans15_Temp_TAB_X_Y_VALUE_write; \
	VARIABLE trans15_Temp_TAB_MIN_NUMBER; \
	MENU trans15_Temp_TAB_MIN_NUMBER_page; \
	COMMAND trans15_Temp_TAB_MIN_NUMBER_read; \
	VARIABLE trans15_Temp_TAB_MAX_NUMBER; \
	MENU trans15_Temp_TAB_MAX_NUMBER_page; \
	COMMAND trans15_Temp_TAB_MAX_NUMBER_read; \
	VARIABLE trans15_Temp_TAB_OP_CODE; \
	MENU trans15_Temp_TAB_OP_CODE_page; \
	COMMAND trans15_Temp_TAB_OP_CODE_read; \
	COMMAND trans15_Temp_TAB_OP_CODE_write; \
	VARIABLE trans15_Temp_TAB_STATUS; \
	MENU trans15_Temp_TAB_STATUS_page; \
	COMMAND trans15_Temp_TAB_STATUS_read; \
	VARIABLE trans15_Temp_TAB_ACTUAL_NUMBER; \
	MENU trans15_Temp_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans15_Temp_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans15_Temp_VIEW_2; \
	MENU trans15_Temp_VIEW_2_page; \
	COLLECTION trans15_Temp_VIEW_3; \
	MENU trans15_Temp_VIEW_3_page; \
	UNIT trans15_Temp_Unit_2

#define USE_TRANS15_TEMP_OPTIONAL_A \
	USE_TRANS15_TEMP_OPTIONAL_BOTH; \
	COLLECTION trans15_Temp_VIEW_1; \
	MENU trans15_Temp_VIEW_1_page; \
	MENU trans15_Temp_Simple_Dialog_Optional_A

#define USE_TRANS15_TEMP_OPTIONAL_B \
	USE_TRANS15_TEMP_OPTIONAL_BOTH; \
	MENU trans15_Temp_Simple_Dialog_Optional_B

#define USE_TRANS15_TEMP_THERMOCOUPLE_MANDATORY_A \
	VARIABLE trans15_Temp_RJ_TYPE; \
	MENU trans15_Temp_RJ_TYPE_page; \
	COMMAND trans15_Temp_RJ_TYPE_read; \
	COMMAND trans15_Temp_RJ_TYPE_write; \
	MENU trans15_Temp_Thermocouple_Simple_Dialog_Mandatory_A

#define USE_TRANS15_TEMP_THERMORESISTANCE_MANDATORY_A \
	VARIABLE trans15_Temp_SENSOR_CONNECTION; \
	MENU trans15_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans15_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans15_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans15_Temp_COMP_WIRE1; \
	MENU trans15_Temp_COMP_WIRE1_page; \
	COMMAND trans15_Temp_COMP_WIRE1_read; \
	COMMAND trans15_Temp_COMP_WIRE1_write; \
	MENU trans15_Temp_Thermoresistance_Simple_Dialog_Mandatory_A

#define USE_TRANS15_TEMP_PYROMETER_MANDATORY_A \
	VARIABLE trans15_Temp_EMISSIVITY; \
	MENU trans15_Temp_EMISSIVITY_page; \
	COMMAND trans15_Temp_EMISSIVITY_read; \
	COMMAND trans15_Temp_EMISSIVITY_write; \
	VARIABLE trans15_Temp_PEAK_TRACK; \
	MENU trans15_Temp_PEAK_TRACK_page; \
	COMMAND trans15_Temp_PEAK_TRACK_read; \
	COMMAND trans15_Temp_PEAK_TRACK_write; \
	VARIABLE trans15_Temp_DECAY_RATE; \
	MENU trans15_Temp_DECAY_RATE_page; \
	COMMAND trans15_Temp_DECAY_RATE_read; \
	COMMAND trans15_Temp_DECAY_RATE_write; \
	VARIABLE trans15_Temp_PEAK_TIME; \
	MENU trans15_Temp_PEAK_TIME_page; \
	COMMAND trans15_Temp_PEAK_TIME_read; \
	COMMAND trans15_Temp_PEAK_TIME_write; \
	VARIABLE trans15_Temp_TRACK_HOLD; \
	MENU trans15_Temp_TRACK_HOLD_page; \
	COMMAND trans15_Temp_TRACK_HOLD_read; \
	COMMAND trans15_Temp_TRACK_HOLD_write; \
	VARIABLE trans15_Temp_SPECT_FILT_SET; \
	MENU trans15_Temp_SPECT_FILT_SET_page; \
	COMMAND trans15_Temp_SPECT_FILT_SET_read; \
	COMMAND trans15_Temp_SPECT_FILT_SET_write; \
	MENU trans15_Temp_Pyrometer_Simple_Dialog_Mandatory_A

#define USE_TRANS15_TEMP_THERMOCOUPLE_MANDATORY_B \
	VARIABLE trans15_Temp_RJ_TYPE; \
	MENU trans15_Temp_RJ_TYPE_page; \
	COMMAND trans15_Temp_RJ_TYPE_read; \
	COMMAND trans15_Temp_RJ_TYPE_write; \
	MENU trans15_Temp_Thermocouple_Simple_Dialog_Mandatory_B

#define USE_TRANS15_TEMP_THERMORESISTANCE_MANDATORY_B \
	VARIABLE trans15_Temp_SENSOR_CONNECTION; \
	MENU trans15_Temp_SENSOR_CONNECTION_page; \
	COMMAND trans15_Temp_SENSOR_CONNECTION_read; \
	COMMAND trans15_Temp_SENSOR_CONNECTION_write; \
	VARIABLE trans15_Temp_COMP_WIRE1; \
	MENU trans15_Temp_COMP_WIRE1_page; \
	COMMAND trans15_Temp_COMP_WIRE1_read; \
	COMMAND trans15_Temp_COMP_WIRE1_write; \
	MENU trans15_Temp_Thermoresistance_Simple_Dialog_Mandatory_B

#define USE_TRANS15_TEMP_PYROMETER_MANDATORY_B \
	VARIABLE trans15_Temp_EMISSIVITY; \
	MENU trans15_Temp_EMISSIVITY_page; \
	COMMAND trans15_Temp_EMISSIVITY_read; \
	COMMAND trans15_Temp_EMISSIVITY_write; \
	VARIABLE trans15_Temp_PEAK_TRACK; \
	MENU trans15_Temp_PEAK_TRACK_page; \
	COMMAND trans15_Temp_PEAK_TRACK_read; \
	COMMAND trans15_Temp_PEAK_TRACK_write; \
	VARIABLE trans15_Temp_DECAY_RATE; \
	MENU trans15_Temp_DECAY_RATE_page; \
	COMMAND trans15_Temp_DECAY_RATE_read; \
	COMMAND trans15_Temp_DECAY_RATE_write; \
	VARIABLE trans15_Temp_PEAK_TIME; \
	MENU trans15_Temp_PEAK_TIME_page; \
	COMMAND trans15_Temp_PEAK_TIME_read; \
	COMMAND trans15_Temp_PEAK_TIME_write; \
	VARIABLE trans15_Temp_TRACK_HOLD; \
	MENU trans15_Temp_TRACK_HOLD_page; \
	COMMAND trans15_Temp_TRACK_HOLD_read; \
	COMMAND trans15_Temp_TRACK_HOLD_write; \
	VARIABLE trans15_Temp_SPECT_FILT_SET; \
	MENU trans15_Temp_SPECT_FILT_SET_page; \
	COMMAND trans15_Temp_SPECT_FILT_SET_read; \
	COMMAND trans15_Temp_SPECT_FILT_SET_write; \
	MENU trans15_Temp_Pyrometer_Simple_Dialog_Mandatory_B

#define USE_TRANS15_TEMP_THERMOCOUPLE_OPTIONAL_A \
	VARIABLE trans15_Temp_RJ_TEMP; \
	MENU trans15_Temp_RJ_TEMP_page; \
	COMMAND trans15_Temp_RJ_TEMP_read; \
	VARIABLE trans15_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans15_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans15_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans15_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans15_Temp_Thermocouple_Simple_Dialog_Optional_A; \
	UNIT trans15_Temp_Unit_3

#define USE_TRANS15_TEMP_THERMORESISTANCE_OPTIONAL_A \
	VARIABLE trans15_Temp_COMP_WIRE2; \
	MENU trans15_Temp_COMP_WIRE2_page; \
	COMMAND trans15_Temp_COMP_WIRE2_read; \
	COMMAND trans15_Temp_COMP_WIRE2_write; \
	MENU trans15_Temp_Thermoresistance_Simple_Dialog_Optional_A

#define USE_TRANS15_TEMP_PYROMETER_OPTIONAL_A \
	MENU trans15_Temp_Pyrometer_Simple_Dialog_Optional_A

#define USE_TRANS15_TEMP_THERMOCOUPLE_OPTIONAL_B \
	VARIABLE trans15_Temp_RJ_TEMP; \
	MENU trans15_Temp_RJ_TEMP_page; \
	COMMAND trans15_Temp_RJ_TEMP_read; \
	VARIABLE trans15_Temp_EXTERNAL_RJ_VALUE; \
	MENU trans15_Temp_EXTERNAL_RJ_VALUE_page; \
	COMMAND trans15_Temp_EXTERNAL_RJ_VALUE_read; \
	COMMAND trans15_Temp_EXTERNAL_RJ_VALUE_write; \
	MENU trans15_Temp_Thermocouple_Simple_Dialog_Optional_B; \
	UNIT trans15_Temp_Unit_3

#define USE_TRANS15_TEMP_THERMORESISTANCE_OPTIONAL_B \
	VARIABLE trans15_Temp_COMP_WIRE2; \
	MENU trans15_Temp_COMP_WIRE2_page; \
	COMMAND trans15_Temp_COMP_WIRE2_read; \
	COMMAND trans15_Temp_COMP_WIRE2_write; \
	MENU trans15_Temp_Thermoresistance_Simple_Dialog_Optional_B

#define USE_TRANS15_TEMP_PYROMETER_OPTIONAL_B \
	MENU trans15_Temp_Pyrometer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_TEMP_MANDATORY_A USE_TRANS_TEMP_MANDATORY_A(trans15_Temp_)
#define USE_TRANS15_TEMP_MANDATORY_B USE_TRANS_TEMP_MANDATORY_B(trans15_Temp_)
#define USE_TRANS15_TEMP_OPTIONAL_A  USE_TRANS_TEMP_OPTIONAL_A(trans15_Temp_)
#define USE_TRANS15_TEMP_OPTIONAL_B  USE_TRANS_TEMP_OPTIONAL_B(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMOCOUPLE_MANDATORY_A \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_A(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMORESISTANCE_MANDATORY_A \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_A(trans15_Temp_)
#define USE_TRANS15_TEMP_PYROMETER_MANDATORY_A \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_A(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMOCOUPLE_MANDATORY_B \
		USE_TRANS_TEMP_THERMOCOUPLE_MANDATORY_B(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMORESISTANCE_MANDATORY_B \
		USE_TRANS_TEMP_THERMORESISTANCE_MANDATORY_B(trans15_Temp_)
#define USE_TRANS15_TEMP_PYROMETER_MANDATORY_B \
		USE_TRANS_TEMP_PYROMETER_MANDATORY_B(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMOCOUPLE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_A(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMORESISTANCE_OPTIONAL_A \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_A(trans15_Temp_)
#define USE_TRANS15_TEMP_PYROMETER_OPTIONAL_A \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_A(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMOCOUPLE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMOCOUPLE_OPTIONAL_B(trans15_Temp_)
#define USE_TRANS15_TEMP_THERMORESISTANCE_OPTIONAL_B \
		USE_TRANS_TEMP_THERMORESISTANCE_OPTIONAL_B(trans15_Temp_)
#define USE_TRANS15_TEMP_PYROMETER_OPTIONAL_B \
		USE_TRANS_TEMP_PYROMETER_OPTIONAL_B(trans15_Temp_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_PRESS_MANDATORY_BOTH \
	BLOCK trans1_Press_block; \
	COLLECTION trans1_Press_BLOCK_OBJECT; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Press_BLOCK_OBJECT_page; \
	COMMAND trans1_Press_BLOCK_OBJECT_read; \
	VARIABLE trans1_Press_ST_REV; \
	MENU trans1_Press_ST_REV_page; \
	COMMAND trans1_Press_ST_REV_read; \
	VARIABLE trans1_Press_TAG_DESC; \
	MENU trans1_Press_TAG_DESC_page; \
	COMMAND trans1_Press_TAG_DESC_read; \
	COMMAND trans1_Press_TAG_DESC_write; \
	VARIABLE trans1_Press_STRATEGY; \
	MENU trans1_Press_STRATEGY_page; \
	COMMAND trans1_Press_STRATEGY_read; \
	COMMAND trans1_Press_STRATEGY_write; \
	VARIABLE trans1_Press_ALERT_KEY; \
	MENU trans1_Press_ALERT_KEY_page; \
	COMMAND trans1_Press_ALERT_KEY_read; \
	COMMAND trans1_Press_ALERT_KEY_write; \
	VARIABLE trans1_Press_TARGET_MODE; \
	MENU trans1_Press_TARGET_MODE_page; \
	COMMAND trans1_Press_TARGET_MODE_read; \
	COMMAND trans1_Press_TARGET_MODE_write; \
	COLLECTION trans1_Press_MODE_BLK; \
	VARIABLE trans1_Press_MODE_BLK_Actual; \
	VARIABLE trans1_Press_MODE_BLK_Permitted; \
	VARIABLE trans1_Press_MODE_BLK_Normal; \
	MENU trans1_Press_MODE_BLK_page; \
	COMMAND trans1_Press_MODE_BLK_read; \
	COLLECTION trans1_Press_ALARM_SUM; \
	VARIABLE trans1_Press_ALARM_SUM_Current; \
	VARIABLE trans1_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Press_ALARM_SUM_Unreported; \
	VARIABLE trans1_Press_ALARM_SUM_Disabled; \
	MENU trans1_Press_ALARM_SUM_page; \
	COMMAND trans1_Press_ALARM_SUM_read

#define USE_TRANS1_PRESS_MANDATORY_A \
	USE_TRANS1_PRESS_MANDATORY_BOTH; \
	MENU trans1_Press_Simple_Dialog_Mandatory_A; \
	MENU trans1_Press_Tab_s_mandatory_A; \
	MENU trans1_Press_Tab_m_mandatory_A

#define USE_TRANS1_PRESS_MANDATORY_B \
	USE_TRANS1_PRESS_MANDATORY_BOTH; \
	VARIABLE trans1_Press_SENSOR_VALUE; \
	MENU trans1_Press_SENSOR_VALUE_page; \
	COMMAND trans1_Press_SENSOR_VALUE_read; \
	VARIABLE trans1_Press_SENSOR_HI_LIM; \
	MENU trans1_Press_SENSOR_HI_LIM_page; \
	COMMAND trans1_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans1_Press_SENSOR_LO_LIM; \
	MENU trans1_Press_SENSOR_LO_LIM_page; \
	COMMAND trans1_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans1_Press_CAL_POINT_HI; \
	MENU trans1_Press_CAL_POINT_HI_page; \
	COMMAND trans1_Press_CAL_POINT_HI_read; \
	COMMAND trans1_Press_CAL_POINT_HI_write; \
	VARIABLE trans1_Press_CAL_POINT_LO; \
	MENU trans1_Press_CAL_POINT_LO_page; \
	COMMAND trans1_Press_CAL_POINT_LO_read; \
	COMMAND trans1_Press_CAL_POINT_LO_write; \
	VARIABLE trans1_Press_CAL_MIN_SPAN; \
	MENU trans1_Press_CAL_MIN_SPAN_page; \
	COMMAND trans1_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans1_Press_SENSOR_UNIT; \
	MENU trans1_Press_SENSOR_UNIT_page; \
	COMMAND trans1_Press_SENSOR_UNIT_read; \
	COMMAND trans1_Press_SENSOR_UNIT_write; \
	COLLECTION trans1_Press_TRIMMED_VALUE; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans1_Press_TRIMMED_VALUE_page; \
	COMMAND trans1_Press_TRIMMED_VALUE_read; \
	VARIABLE trans1_Press_SENSOR_TYPE; \
	MENU trans1_Press_SENSOR_TYPE_page; \
	COMMAND trans1_Press_SENSOR_TYPE_read; \
	VARIABLE trans1_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans1_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans1_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans1_Press_PRIMARY_VALUE; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans1_Press_PRIMARY_VALUE_page; \
	COMMAND trans1_Press_PRIMARY_VALUE_read; \
	VARIABLE trans1_Press_PRIMARY_VALUE_UNIT; \
	MENU trans1_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans1_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans1_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans1_Press_PRIMARY_VALUE_TYPE; \
	MENU trans1_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans1_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans1_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans1_Press_LIN_TYPE; \
	MENU trans1_Press_LIN_TYPE_page; \
	COMMAND trans1_Press_LIN_TYPE_read; \
	COMMAND trans1_Press_LIN_TYPE_write; \
	COLLECTION trans1_Press_VIEW_1; \
	MENU trans1_Press_VIEW_1_page; \
	MENU trans1_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans1_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans1_Press_Sensor_unit_1; \
	MENU trans1_Press_Tab_s_mandatory_B; \
	MENU trans1_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans1_Press_Tab_s_input_table_mandatory_B; \
	MENU trans1_Press_Tab_m_mandatory_B; \
	MENU trans1_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans1_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS1_PRESS_OPTIONAL_BOTH \
	VARIABLE trans1_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans1_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans1_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans1_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans1_Press_SENSOR_FILL_FLUID; \
	MENU trans1_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans1_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans1_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans1_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans1_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans1_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans1_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans1_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans1_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans1_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans1_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans1_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans1_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans1_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans1_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans1_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans1_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans1_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans1_Press_TEMPERATURE; \
	VARIABLE trans1_Press_TEMPERATURE_Value; \
	VARIABLE trans1_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans1_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans1_Press_TEMPERATURE_Status_Limit; \
	MENU trans1_Press_TEMPERATURE_page; \
	COMMAND trans1_Press_TEMPERATURE_read; \
	VARIABLE trans1_Press_TEMPERATURE_UNIT; \
	MENU trans1_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans1_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans1_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans1_Press_SECONDARY_VALUE_1; \
	VARIABLE trans1_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans1_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans1_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans1_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans1_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans1_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans1_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans1_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans1_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans1_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans1_Press_SECONDARY_VALUE_2; \
	VARIABLE trans1_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans1_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans1_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans1_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans1_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans1_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans1_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans1_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans1_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans1_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans1_Press_SCALE_IN; \
	VARIABLE trans1_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans1_Press_SCALE_IN_Lower_Value; \
	MENU trans1_Press_SCALE_IN_page; \
	COMMAND trans1_Press_SCALE_IN_read; \
	COMMAND trans1_Press_SCALE_IN_write; \
	COLLECTION trans1_Press_SCALE_OUT; \
	VARIABLE trans1_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans1_Press_SCALE_OUT_Lower_Value; \
	MENU trans1_Press_SCALE_OUT_page; \
	COMMAND trans1_Press_SCALE_OUT_read; \
	COMMAND trans1_Press_SCALE_OUT_write; \
	VARIABLE trans1_Press_LOW_FLOW_CUT_OFF; \
	MENU trans1_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans1_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans1_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans1_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans1_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans1_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans1_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans1_Press_TAB_ACTUAL_NUMBER; \
	MENU trans1_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans1_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans1_Press_TAB_ENTRY; \
	MENU trans1_Press_TAB_ENTRY_page; \
	COMMAND trans1_Press_TAB_ENTRY_read; \
	COMMAND trans1_Press_TAB_ENTRY_write; \
	VARIABLE trans1_Press_TAB_MAX_NUMBER; \
	MENU trans1_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans1_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans1_Press_TAB_MIN_NUMBER; \
	MENU trans1_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans1_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans1_Press_TAB_OP_CODE; \
	MENU trans1_Press_TAB_OP_CODE_page; \
	COMMAND trans1_Press_TAB_OP_CODE_read; \
	COMMAND trans1_Press_TAB_OP_CODE_write; \
	VARIABLE trans1_Press_TAB_STATUS; \
	MENU trans1_Press_TAB_STATUS_page; \
	COMMAND trans1_Press_TAB_STATUS_read; \
	COLLECTION trans1_Press_TAB_X_Y_VALUE; \
	VARIABLE trans1_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans1_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans1_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans1_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans1_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans1_Press_MAX_SENSOR_VALUE; \
	MENU trans1_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans1_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans1_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans1_Press_MIN_SENSOR_VALUE; \
	MENU trans1_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans1_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans1_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans1_Press_MAX_TEMPERATURE; \
	MENU trans1_Press_MAX_TEMPERATURE_page; \
	COMMAND trans1_Press_MAX_TEMPERATURE_read; \
	COMMAND trans1_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans1_Press_MIN_TEMPERATURE; \
	MENU trans1_Press_MIN_TEMPERATURE_page; \
	COMMAND trans1_Press_MIN_TEMPERATURE_read; \
	COMMAND trans1_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans1_Press_VIEW_2; \
	MENU trans1_Press_VIEW_2_page; \
	COLLECTION trans1_Press_VIEW_3; \
	MENU trans1_Press_VIEW_3_page; \
	UNIT trans1_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans1_Press_Sensor_unit_2; \
	UNIT trans1_Press_Temperature_unit; \
	UNIT trans1_Press_Secondary_Value_1_unit; \
	UNIT trans1_Press_Secondary_Value_2_unit

#define USE_TRANS1_PRESS_OPTIONAL_A \
	USE_TRANS1_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans1_Press_SENSOR_VALUE; \
	MENU trans1_Press_SENSOR_VALUE_page; \
	COMMAND trans1_Press_SENSOR_VALUE_read; \
	VARIABLE trans1_Press_SENSOR_HI_LIM; \
	MENU trans1_Press_SENSOR_HI_LIM_page; \
	COMMAND trans1_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans1_Press_SENSOR_LO_LIM; \
	MENU trans1_Press_SENSOR_LO_LIM_page; \
	COMMAND trans1_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans1_Press_CAL_POINT_HI; \
	MENU trans1_Press_CAL_POINT_HI_page; \
	COMMAND trans1_Press_CAL_POINT_HI_read; \
	COMMAND trans1_Press_CAL_POINT_HI_write; \
	VARIABLE trans1_Press_CAL_POINT_LO; \
	MENU trans1_Press_CAL_POINT_LO_page; \
	COMMAND trans1_Press_CAL_POINT_LO_read; \
	COMMAND trans1_Press_CAL_POINT_LO_write; \
	VARIABLE trans1_Press_CAL_MIN_SPAN; \
	MENU trans1_Press_CAL_MIN_SPAN_page; \
	COMMAND trans1_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans1_Press_SENSOR_UNIT; \
	MENU trans1_Press_SENSOR_UNIT_page; \
	COMMAND trans1_Press_SENSOR_UNIT_read; \
	COMMAND trans1_Press_SENSOR_UNIT_write; \
	COLLECTION trans1_Press_TRIMMED_VALUE; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans1_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans1_Press_TRIMMED_VALUE_page; \
	COMMAND trans1_Press_TRIMMED_VALUE_read; \
	VARIABLE trans1_Press_SENSOR_TYPE; \
	MENU trans1_Press_SENSOR_TYPE_page; \
	COMMAND trans1_Press_SENSOR_TYPE_read; \
	VARIABLE trans1_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans1_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans1_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans1_Press_PRIMARY_VALUE; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans1_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans1_Press_PRIMARY_VALUE_page; \
	COMMAND trans1_Press_PRIMARY_VALUE_read; \
	VARIABLE trans1_Press_PRIMARY_VALUE_UNIT; \
	MENU trans1_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans1_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans1_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans1_Press_PRIMARY_VALUE_TYPE; \
	MENU trans1_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans1_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans1_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans1_Press_LIN_TYPE; \
	MENU trans1_Press_LIN_TYPE_page; \
	COMMAND trans1_Press_LIN_TYPE_read; \
	COMMAND trans1_Press_LIN_TYPE_write; \
	COLLECTION trans1_Press_VIEW_1; \
	MENU trans1_Press_VIEW_1_page; \
	MENU trans1_Press_Simple_Dialog_Optional_A; \
	UNIT trans1_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans1_Press_Sensor_unit_1

#define USE_TRANS1_PRESS_OPTIONAL_B \
	USE_TRANS1_PRESS_OPTIONAL_BOTH; \
	MENU trans1_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_PRESS_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read

#define USE_TRANS_PRESS_MANDATORY_A(prefix) \
	USE_TRANS_PRESS_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A; \
	MENU prefix ## Tab_s_mandatory_A; \
	MENU prefix ## Tab_m_mandatory_A

#define USE_TRANS_PRESS_MANDATORY_B(prefix) \
	USE_TRANS_PRESS_MANDATORY_BOTH(prefix); \
	VARIABLE prefix ## SENSOR_VALUE; \
	MENU prefix ## SENSOR_VALUE_page; \
	COMMAND prefix ## SENSOR_VALUE_read; \
	VARIABLE prefix ## SENSOR_HI_LIM; \
	MENU prefix ## SENSOR_HI_LIM_page; \
	COMMAND prefix ## SENSOR_HI_LIM_read; \
	VARIABLE prefix ## SENSOR_LO_LIM; \
	MENU prefix ## SENSOR_LO_LIM_page; \
	COMMAND prefix ## SENSOR_LO_LIM_read; \
	VARIABLE prefix ## CAL_POINT_HI; \
	MENU prefix ## CAL_POINT_HI_page; \
	COMMAND prefix ## CAL_POINT_HI_read; \
	COMMAND prefix ## CAL_POINT_HI_write; \
	VARIABLE prefix ## CAL_POINT_LO; \
	MENU prefix ## CAL_POINT_LO_page; \
	COMMAND prefix ## CAL_POINT_LO_read; \
	COMMAND prefix ## CAL_POINT_LO_write; \
	VARIABLE prefix ## CAL_MIN_SPAN; \
	MENU prefix ## CAL_MIN_SPAN_page; \
	COMMAND prefix ## CAL_MIN_SPAN_read; \
	VARIABLE prefix ## SENSOR_UNIT; \
	MENU prefix ## SENSOR_UNIT_page; \
	COMMAND prefix ## SENSOR_UNIT_read; \
	COMMAND prefix ## SENSOR_UNIT_write; \
	COLLECTION prefix ## TRIMMED_VALUE; \
	VARIABLE prefix ## TRIMMED_VALUE_Value; \
	VARIABLE prefix ## TRIMMED_VALUE_Status_Condensed; \
	VARIABLE prefix ## TRIMMED_VALUE_Status_Quality; \
	VARIABLE prefix ## TRIMMED_VALUE_Status_Limit; \
	MENU prefix ## TRIMMED_VALUE_page; \
	COMMAND prefix ## TRIMMED_VALUE_read; \
	VARIABLE prefix ## SENSOR_TYPE; \
	MENU prefix ## SENSOR_TYPE_page; \
	COMMAND prefix ## SENSOR_TYPE_read; \
	VARIABLE prefix ## SENSOR_SERIAL_NUMBER; \
	MENU prefix ## SENSOR_SERIAL_NUMBER_page; \
	COMMAND prefix ## SENSOR_SERIAL_NUMBER_read; \
	COLLECTION prefix ## PRIMARY_VALUE; \
	VARIABLE prefix ## PRIMARY_VALUE_Value; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Condensed; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Quality; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Limit; \
	MENU prefix ## PRIMARY_VALUE_page; \
	COMMAND prefix ## PRIMARY_VALUE_read; \
	VARIABLE prefix ## PRIMARY_VALUE_UNIT; \
	MENU prefix ## PRIMARY_VALUE_UNIT_page; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_read; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_write; \
	VARIABLE prefix ## PRIMARY_VALUE_TYPE; \
	MENU prefix ## PRIMARY_VALUE_TYPE_page; \
	COMMAND prefix ## PRIMARY_VALUE_TYPE_read; \
	COMMAND prefix ## PRIMARY_VALUE_TYPE_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B; \
	UNIT prefix ## PRIMARY_VALUE_UNIT_unit_1; \
	UNIT prefix ## Sensor_unit_1; \
	MENU prefix ## Tab_s_mandatory_B; \
	MENU prefix ## Tab_s_input_meassurelimit_mandatory_B; \
	MENU prefix ## Tab_s_input_table_mandatory_B; \
	MENU prefix ## Tab_m_mandatory_B; \
	MENU prefix ## Tab_m_input_meassurelimit_mandatory_B; \
	MENU prefix ## Tab_m_input_table_mandatory_B

#define USE_TRANS_PRESS_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## SENSOR_DIAPHRAGM_MATERIAL; \
	MENU prefix ## SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND prefix ## SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND prefix ## SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE prefix ## SENSOR_FILL_FLUID; \
	MENU prefix ## SENSOR_FILL_FLUID_page; \
	COMMAND prefix ## SENSOR_FILL_FLUID_read; \
	COMMAND prefix ## SENSOR_FILL_FLUID_write; \
	VARIABLE prefix ## SENSOR_MAX_STATIC_PRESSURE; \
	MENU prefix ## SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND prefix ## SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE prefix ## SENSOR_O_RING_MATERIAL; \
	MENU prefix ## SENSOR_O_RING_MATERIAL_page; \
	COMMAND prefix ## SENSOR_O_RING_MATERIAL_read; \
	COMMAND prefix ## SENSOR_O_RING_MATERIAL_write; \
	VARIABLE prefix ## PROCESS_CONNECTION_TYPE; \
	MENU prefix ## PROCESS_CONNECTION_TYPE_page; \
	COMMAND prefix ## PROCESS_CONNECTION_TYPE_read; \
	COMMAND prefix ## PROCESS_CONNECTION_TYPE_write; \
	VARIABLE prefix ## PROCESS_CONNECTION_MATERIAL; \
	MENU prefix ## PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND prefix ## PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND prefix ## PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION prefix ## TEMPERATURE; \
	VARIABLE prefix ## TEMPERATURE_Value; \
	VARIABLE prefix ## TEMPERATURE_Status_Condensed; \
	VARIABLE prefix ## TEMPERATURE_Status_Quality; \
	VARIABLE prefix ## TEMPERATURE_Status_Limit; \
	MENU prefix ## TEMPERATURE_page; \
	COMMAND prefix ## TEMPERATURE_read; \
	VARIABLE prefix ## TEMPERATURE_UNIT; \
	MENU prefix ## TEMPERATURE_UNIT_page; \
	COMMAND prefix ## TEMPERATURE_UNIT_read; \
	COMMAND prefix ## TEMPERATURE_UNIT_write; \
	COLLECTION prefix ## SECONDARY_VALUE_1; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Value; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Limit; \
	MENU prefix ## SECONDARY_VALUE_1_page; \
	COMMAND prefix ## SECONDARY_VALUE_1_read; \
	VARIABLE prefix ## SECONDARY_VALUE_1_UNIT; \
	MENU prefix ## SECONDARY_VALUE_1_UNIT_page; \
	COMMAND prefix ## SECONDARY_VALUE_1_UNIT_read; \
	COMMAND prefix ## SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION prefix ## SECONDARY_VALUE_2; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Value; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Limit; \
	MENU prefix ## SECONDARY_VALUE_2_page; \
	COMMAND prefix ## SECONDARY_VALUE_2_read; \
	VARIABLE prefix ## SECONDARY_VALUE_2_UNIT; \
	MENU prefix ## SECONDARY_VALUE_2_UNIT_page; \
	COMMAND prefix ## SECONDARY_VALUE_2_UNIT_read; \
	COMMAND prefix ## SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION prefix ## SCALE_IN; \
	VARIABLE prefix ## SCALE_IN_Upper_Value; \
	VARIABLE prefix ## SCALE_IN_Lower_Value; \
	MENU prefix ## SCALE_IN_page; \
	COMMAND prefix ## SCALE_IN_read; \
	COMMAND prefix ## SCALE_IN_write; \
	COLLECTION prefix ## SCALE_OUT; \
	VARIABLE prefix ## SCALE_OUT_Upper_Value; \
	VARIABLE prefix ## SCALE_OUT_Lower_Value; \
	MENU prefix ## SCALE_OUT_page; \
	COMMAND prefix ## SCALE_OUT_read; \
	COMMAND prefix ## SCALE_OUT_write; \
	VARIABLE prefix ## LOW_FLOW_CUT_OFF; \
	MENU prefix ## LOW_FLOW_CUT_OFF_page; \
	COMMAND prefix ## LOW_FLOW_CUT_OFF_read; \
	COMMAND prefix ## LOW_FLOW_CUT_OFF_write; \
	VARIABLE prefix ## FLOW_LIN_SQRT_POINT; \
	MENU prefix ## FLOW_LIN_SQRT_POINT_page; \
	COMMAND prefix ## FLOW_LIN_SQRT_POINT_read; \
	COMMAND prefix ## FLOW_LIN_SQRT_POINT_write; \
	VARIABLE prefix ## TAB_ACTUAL_NUMBER; \
	MENU prefix ## TAB_ACTUAL_NUMBER_page; \
	COMMAND prefix ## TAB_ACTUAL_NUMBER_read; \
	VARIABLE prefix ## TAB_ENTRY; \
	MENU prefix ## TAB_ENTRY_page; \
	COMMAND prefix ## TAB_ENTRY_read; \
	COMMAND prefix ## TAB_ENTRY_write; \
	VARIABLE prefix ## TAB_MAX_NUMBER; \
	MENU prefix ## TAB_MAX_NUMBER_page; \
	COMMAND prefix ## TAB_MAX_NUMBER_read; \
	VARIABLE prefix ## TAB_MIN_NUMBER; \
	MENU prefix ## TAB_MIN_NUMBER_page; \
	COMMAND prefix ## TAB_MIN_NUMBER_read; \
	VARIABLE prefix ## TAB_OP_CODE; \
	MENU prefix ## TAB_OP_CODE_page; \
	COMMAND prefix ## TAB_OP_CODE_read; \
	COMMAND prefix ## TAB_OP_CODE_write; \
	VARIABLE prefix ## TAB_STATUS; \
	MENU prefix ## TAB_STATUS_page; \
	COMMAND prefix ## TAB_STATUS_read; \
	COLLECTION prefix ## TAB_X_Y_VALUE; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Lower_Value; \
	MENU prefix ## TAB_X_Y_VALUE_page; \
	COMMAND prefix ## TAB_X_Y_VALUE_read; \
	COMMAND prefix ## TAB_X_Y_VALUE_write; \
	VARIABLE prefix ## MAX_SENSOR_VALUE; \
	MENU prefix ## MAX_SENSOR_VALUE_page; \
	COMMAND prefix ## MAX_SENSOR_VALUE_read; \
	COMMAND prefix ## MAX_SENSOR_VALUE_write; \
	VARIABLE prefix ## MIN_SENSOR_VALUE; \
	MENU prefix ## MIN_SENSOR_VALUE_page; \
	COMMAND prefix ## MIN_SENSOR_VALUE_read; \
	COMMAND prefix ## MIN_SENSOR_VALUE_write; \
	VARIABLE prefix ## MAX_TEMPERATURE; \
	MENU prefix ## MAX_TEMPERATURE_page; \
	COMMAND prefix ## MAX_TEMPERATURE_read; \
	COMMAND prefix ## MAX_TEMPERATURE_write; \
	VARIABLE prefix ## MIN_TEMPERATURE; \
	MENU prefix ## MIN_TEMPERATURE_page; \
	COMMAND prefix ## MIN_TEMPERATURE_read; \
	COMMAND prefix ## MIN_TEMPERATURE_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## PRIMARY_VALUE_UNIT_unit_2; \
	UNIT prefix ## Sensor_unit_2; \
	UNIT prefix ## Temperature_unit; \
	UNIT prefix ## Secondary_Value_1_unit; \
	UNIT prefix ## Secondary_Value_2_unit

#define USE_TRANS_PRESS_OPTIONAL_A(prefix) \
	USE_TRANS_PRESS_OPTIONAL_BOTH(prefix); \
	VARIABLE prefix ## SENSOR_VALUE; \
	MENU prefix ## SENSOR_VALUE_page; \
	COMMAND prefix ## SENSOR_VALUE_read; \
	VARIABLE prefix ## SENSOR_HI_LIM; \
	MENU prefix ## SENSOR_HI_LIM_page; \
	COMMAND prefix ## SENSOR_HI_LIM_read; \
	VARIABLE prefix ## SENSOR_LO_LIM; \
	MENU prefix ## SENSOR_LO_LIM_page; \
	COMMAND prefix ## SENSOR_LO_LIM_read; \
	VARIABLE prefix ## CAL_POINT_HI; \
	MENU prefix ## CAL_POINT_HI_page; \
	COMMAND prefix ## CAL_POINT_HI_read; \
	COMMAND prefix ## CAL_POINT_HI_write; \
	VARIABLE prefix ## CAL_POINT_LO; \
	MENU prefix ## CAL_POINT_LO_page; \
	COMMAND prefix ## CAL_POINT_LO_read; \
	COMMAND prefix ## CAL_POINT_LO_write; \
	VARIABLE prefix ## CAL_MIN_SPAN; \
	MENU prefix ## CAL_MIN_SPAN_page; \
	COMMAND prefix ## CAL_MIN_SPAN_read; \
	VARIABLE prefix ## SENSOR_UNIT; \
	MENU prefix ## SENSOR_UNIT_page; \
	COMMAND prefix ## SENSOR_UNIT_read; \
	COMMAND prefix ## SENSOR_UNIT_write; \
	COLLECTION prefix ## TRIMMED_VALUE; \
	VARIABLE prefix ## TRIMMED_VALUE_Value; \
	VARIABLE prefix ## TRIMMED_VALUE_Status_Condensed; \
	VARIABLE prefix ## TRIMMED_VALUE_Status_Quality; \
	VARIABLE prefix ## TRIMMED_VALUE_Status_Limit; \
	MENU prefix ## TRIMMED_VALUE_page; \
	COMMAND prefix ## TRIMMED_VALUE_read; \
	VARIABLE prefix ## SENSOR_TYPE; \
	MENU prefix ## SENSOR_TYPE_page; \
	COMMAND prefix ## SENSOR_TYPE_read; \
	VARIABLE prefix ## SENSOR_SERIAL_NUMBER; \
	MENU prefix ## SENSOR_SERIAL_NUMBER_page; \
	COMMAND prefix ## SENSOR_SERIAL_NUMBER_read; \
	COLLECTION prefix ## PRIMARY_VALUE; \
	VARIABLE prefix ## PRIMARY_VALUE_Value; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Condensed; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Quality; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Limit; \
	MENU prefix ## PRIMARY_VALUE_page; \
	COMMAND prefix ## PRIMARY_VALUE_read; \
	VARIABLE prefix ## PRIMARY_VALUE_UNIT; \
	MENU prefix ## PRIMARY_VALUE_UNIT_page; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_read; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_write; \
	VARIABLE prefix ## PRIMARY_VALUE_TYPE; \
	MENU prefix ## PRIMARY_VALUE_TYPE_page; \
	COMMAND prefix ## PRIMARY_VALUE_TYPE_read; \
	COMMAND prefix ## PRIMARY_VALUE_TYPE_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A; \
	UNIT prefix ## PRIMARY_VALUE_UNIT_unit_1; \
	UNIT prefix ## Sensor_unit_1

#define USE_TRANS_PRESS_OPTIONAL_B(prefix) \
	USE_TRANS_PRESS_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans1_Press_)
#define USE_TRANS1_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans1_Press_)
#define USE_TRANS1_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans1_Press_)
#define USE_TRANS1_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans1_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_PRESS_MANDATORY_BOTH \
	BLOCK trans2_Press_block; \
	COLLECTION trans2_Press_BLOCK_OBJECT; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Press_BLOCK_OBJECT_page; \
	COMMAND trans2_Press_BLOCK_OBJECT_read; \
	VARIABLE trans2_Press_ST_REV; \
	MENU trans2_Press_ST_REV_page; \
	COMMAND trans2_Press_ST_REV_read; \
	VARIABLE trans2_Press_TAG_DESC; \
	MENU trans2_Press_TAG_DESC_page; \
	COMMAND trans2_Press_TAG_DESC_read; \
	COMMAND trans2_Press_TAG_DESC_write; \
	VARIABLE trans2_Press_STRATEGY; \
	MENU trans2_Press_STRATEGY_page; \
	COMMAND trans2_Press_STRATEGY_read; \
	COMMAND trans2_Press_STRATEGY_write; \
	VARIABLE trans2_Press_ALERT_KEY; \
	MENU trans2_Press_ALERT_KEY_page; \
	COMMAND trans2_Press_ALERT_KEY_read; \
	COMMAND trans2_Press_ALERT_KEY_write; \
	VARIABLE trans2_Press_TARGET_MODE; \
	MENU trans2_Press_TARGET_MODE_page; \
	COMMAND trans2_Press_TARGET_MODE_read; \
	COMMAND trans2_Press_TARGET_MODE_write; \
	COLLECTION trans2_Press_MODE_BLK; \
	VARIABLE trans2_Press_MODE_BLK_Actual; \
	VARIABLE trans2_Press_MODE_BLK_Permitted; \
	VARIABLE trans2_Press_MODE_BLK_Normal; \
	MENU trans2_Press_MODE_BLK_page; \
	COMMAND trans2_Press_MODE_BLK_read; \
	COLLECTION trans2_Press_ALARM_SUM; \
	VARIABLE trans2_Press_ALARM_SUM_Current; \
	VARIABLE trans2_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Press_ALARM_SUM_Unreported; \
	VARIABLE trans2_Press_ALARM_SUM_Disabled; \
	MENU trans2_Press_ALARM_SUM_page; \
	COMMAND trans2_Press_ALARM_SUM_read

#define USE_TRANS2_PRESS_MANDATORY_A \
	USE_TRANS2_PRESS_MANDATORY_BOTH; \
	MENU trans2_Press_Simple_Dialog_Mandatory_A; \
	MENU trans2_Press_Tab_s_mandatory_A; \
	MENU trans2_Press_Tab_m_mandatory_A

#define USE_TRANS2_PRESS_MANDATORY_B \
	USE_TRANS2_PRESS_MANDATORY_BOTH; \
	VARIABLE trans2_Press_SENSOR_VALUE; \
	MENU trans2_Press_SENSOR_VALUE_page; \
	COMMAND trans2_Press_SENSOR_VALUE_read; \
	VARIABLE trans2_Press_SENSOR_HI_LIM; \
	MENU trans2_Press_SENSOR_HI_LIM_page; \
	COMMAND trans2_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans2_Press_SENSOR_LO_LIM; \
	MENU trans2_Press_SENSOR_LO_LIM_page; \
	COMMAND trans2_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans2_Press_CAL_POINT_HI; \
	MENU trans2_Press_CAL_POINT_HI_page; \
	COMMAND trans2_Press_CAL_POINT_HI_read; \
	COMMAND trans2_Press_CAL_POINT_HI_write; \
	VARIABLE trans2_Press_CAL_POINT_LO; \
	MENU trans2_Press_CAL_POINT_LO_page; \
	COMMAND trans2_Press_CAL_POINT_LO_read; \
	COMMAND trans2_Press_CAL_POINT_LO_write; \
	VARIABLE trans2_Press_CAL_MIN_SPAN; \
	MENU trans2_Press_CAL_MIN_SPAN_page; \
	COMMAND trans2_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans2_Press_SENSOR_UNIT; \
	MENU trans2_Press_SENSOR_UNIT_page; \
	COMMAND trans2_Press_SENSOR_UNIT_read; \
	COMMAND trans2_Press_SENSOR_UNIT_write; \
	COLLECTION trans2_Press_TRIMMED_VALUE; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans2_Press_TRIMMED_VALUE_page; \
	COMMAND trans2_Press_TRIMMED_VALUE_read; \
	VARIABLE trans2_Press_SENSOR_TYPE; \
	MENU trans2_Press_SENSOR_TYPE_page; \
	COMMAND trans2_Press_SENSOR_TYPE_read; \
	VARIABLE trans2_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans2_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans2_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans2_Press_PRIMARY_VALUE; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans2_Press_PRIMARY_VALUE_page; \
	COMMAND trans2_Press_PRIMARY_VALUE_read; \
	VARIABLE trans2_Press_PRIMARY_VALUE_UNIT; \
	MENU trans2_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans2_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans2_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans2_Press_PRIMARY_VALUE_TYPE; \
	MENU trans2_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans2_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans2_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans2_Press_LIN_TYPE; \
	MENU trans2_Press_LIN_TYPE_page; \
	COMMAND trans2_Press_LIN_TYPE_read; \
	COMMAND trans2_Press_LIN_TYPE_write; \
	COLLECTION trans2_Press_VIEW_1; \
	MENU trans2_Press_VIEW_1_page; \
	MENU trans2_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans2_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans2_Press_Sensor_unit_1; \
	MENU trans2_Press_Tab_s_mandatory_B; \
	MENU trans2_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans2_Press_Tab_s_input_table_mandatory_B; \
	MENU trans2_Press_Tab_m_mandatory_B; \
	MENU trans2_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans2_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS2_PRESS_OPTIONAL_BOTH \
	VARIABLE trans2_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans2_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans2_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans2_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans2_Press_SENSOR_FILL_FLUID; \
	MENU trans2_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans2_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans2_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans2_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans2_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans2_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans2_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans2_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans2_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans2_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans2_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans2_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans2_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans2_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans2_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans2_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans2_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans2_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans2_Press_TEMPERATURE; \
	VARIABLE trans2_Press_TEMPERATURE_Value; \
	VARIABLE trans2_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans2_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans2_Press_TEMPERATURE_Status_Limit; \
	MENU trans2_Press_TEMPERATURE_page; \
	COMMAND trans2_Press_TEMPERATURE_read; \
	VARIABLE trans2_Press_TEMPERATURE_UNIT; \
	MENU trans2_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans2_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans2_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans2_Press_SECONDARY_VALUE_1; \
	VARIABLE trans2_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans2_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans2_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans2_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans2_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans2_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans2_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans2_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans2_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans2_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans2_Press_SECONDARY_VALUE_2; \
	VARIABLE trans2_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans2_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans2_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans2_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans2_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans2_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans2_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans2_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans2_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans2_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans2_Press_SCALE_IN; \
	VARIABLE trans2_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans2_Press_SCALE_IN_Lower_Value; \
	MENU trans2_Press_SCALE_IN_page; \
	COMMAND trans2_Press_SCALE_IN_read; \
	COMMAND trans2_Press_SCALE_IN_write; \
	COLLECTION trans2_Press_SCALE_OUT; \
	VARIABLE trans2_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans2_Press_SCALE_OUT_Lower_Value; \
	MENU trans2_Press_SCALE_OUT_page; \
	COMMAND trans2_Press_SCALE_OUT_read; \
	COMMAND trans2_Press_SCALE_OUT_write; \
	VARIABLE trans2_Press_LOW_FLOW_CUT_OFF; \
	MENU trans2_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans2_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans2_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans2_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans2_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans2_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans2_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans2_Press_TAB_ACTUAL_NUMBER; \
	MENU trans2_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans2_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans2_Press_TAB_ENTRY; \
	MENU trans2_Press_TAB_ENTRY_page; \
	COMMAND trans2_Press_TAB_ENTRY_read; \
	COMMAND trans2_Press_TAB_ENTRY_write; \
	VARIABLE trans2_Press_TAB_MAX_NUMBER; \
	MENU trans2_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans2_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans2_Press_TAB_MIN_NUMBER; \
	MENU trans2_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans2_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans2_Press_TAB_OP_CODE; \
	MENU trans2_Press_TAB_OP_CODE_page; \
	COMMAND trans2_Press_TAB_OP_CODE_read; \
	COMMAND trans2_Press_TAB_OP_CODE_write; \
	VARIABLE trans2_Press_TAB_STATUS; \
	MENU trans2_Press_TAB_STATUS_page; \
	COMMAND trans2_Press_TAB_STATUS_read; \
	COLLECTION trans2_Press_TAB_X_Y_VALUE; \
	VARIABLE trans2_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans2_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans2_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans2_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans2_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans2_Press_MAX_SENSOR_VALUE; \
	MENU trans2_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans2_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans2_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans2_Press_MIN_SENSOR_VALUE; \
	MENU trans2_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans2_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans2_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans2_Press_MAX_TEMPERATURE; \
	MENU trans2_Press_MAX_TEMPERATURE_page; \
	COMMAND trans2_Press_MAX_TEMPERATURE_read; \
	COMMAND trans2_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans2_Press_MIN_TEMPERATURE; \
	MENU trans2_Press_MIN_TEMPERATURE_page; \
	COMMAND trans2_Press_MIN_TEMPERATURE_read; \
	COMMAND trans2_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans2_Press_VIEW_2; \
	MENU trans2_Press_VIEW_2_page; \
	COLLECTION trans2_Press_VIEW_3; \
	MENU trans2_Press_VIEW_3_page; \
	UNIT trans2_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans2_Press_Sensor_unit_2; \
	UNIT trans2_Press_Temperature_unit; \
	UNIT trans2_Press_Secondary_Value_1_unit; \
	UNIT trans2_Press_Secondary_Value_2_unit

#define USE_TRANS2_PRESS_OPTIONAL_A \
	USE_TRANS2_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans2_Press_SENSOR_VALUE; \
	MENU trans2_Press_SENSOR_VALUE_page; \
	COMMAND trans2_Press_SENSOR_VALUE_read; \
	VARIABLE trans2_Press_SENSOR_HI_LIM; \
	MENU trans2_Press_SENSOR_HI_LIM_page; \
	COMMAND trans2_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans2_Press_SENSOR_LO_LIM; \
	MENU trans2_Press_SENSOR_LO_LIM_page; \
	COMMAND trans2_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans2_Press_CAL_POINT_HI; \
	MENU trans2_Press_CAL_POINT_HI_page; \
	COMMAND trans2_Press_CAL_POINT_HI_read; \
	COMMAND trans2_Press_CAL_POINT_HI_write; \
	VARIABLE trans2_Press_CAL_POINT_LO; \
	MENU trans2_Press_CAL_POINT_LO_page; \
	COMMAND trans2_Press_CAL_POINT_LO_read; \
	COMMAND trans2_Press_CAL_POINT_LO_write; \
	VARIABLE trans2_Press_CAL_MIN_SPAN; \
	MENU trans2_Press_CAL_MIN_SPAN_page; \
	COMMAND trans2_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans2_Press_SENSOR_UNIT; \
	MENU trans2_Press_SENSOR_UNIT_page; \
	COMMAND trans2_Press_SENSOR_UNIT_read; \
	COMMAND trans2_Press_SENSOR_UNIT_write; \
	COLLECTION trans2_Press_TRIMMED_VALUE; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans2_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans2_Press_TRIMMED_VALUE_page; \
	COMMAND trans2_Press_TRIMMED_VALUE_read; \
	VARIABLE trans2_Press_SENSOR_TYPE; \
	MENU trans2_Press_SENSOR_TYPE_page; \
	COMMAND trans2_Press_SENSOR_TYPE_read; \
	VARIABLE trans2_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans2_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans2_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans2_Press_PRIMARY_VALUE; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans2_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans2_Press_PRIMARY_VALUE_page; \
	COMMAND trans2_Press_PRIMARY_VALUE_read; \
	VARIABLE trans2_Press_PRIMARY_VALUE_UNIT; \
	MENU trans2_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans2_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans2_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans2_Press_PRIMARY_VALUE_TYPE; \
	MENU trans2_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans2_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans2_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans2_Press_LIN_TYPE; \
	MENU trans2_Press_LIN_TYPE_page; \
	COMMAND trans2_Press_LIN_TYPE_read; \
	COMMAND trans2_Press_LIN_TYPE_write; \
	COLLECTION trans2_Press_VIEW_1; \
	MENU trans2_Press_VIEW_1_page; \
	MENU trans2_Press_Simple_Dialog_Optional_A; \
	UNIT trans2_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans2_Press_Sensor_unit_1

#define USE_TRANS2_PRESS_OPTIONAL_B \
	USE_TRANS2_PRESS_OPTIONAL_BOTH; \
	MENU trans2_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans2_Press_)
#define USE_TRANS2_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans2_Press_)
#define USE_TRANS2_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans2_Press_)
#define USE_TRANS2_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans2_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_PRESS_MANDATORY_BOTH \
	BLOCK trans3_Press_block; \
	COLLECTION trans3_Press_BLOCK_OBJECT; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Press_BLOCK_OBJECT_page; \
	COMMAND trans3_Press_BLOCK_OBJECT_read; \
	VARIABLE trans3_Press_ST_REV; \
	MENU trans3_Press_ST_REV_page; \
	COMMAND trans3_Press_ST_REV_read; \
	VARIABLE trans3_Press_TAG_DESC; \
	MENU trans3_Press_TAG_DESC_page; \
	COMMAND trans3_Press_TAG_DESC_read; \
	COMMAND trans3_Press_TAG_DESC_write; \
	VARIABLE trans3_Press_STRATEGY; \
	MENU trans3_Press_STRATEGY_page; \
	COMMAND trans3_Press_STRATEGY_read; \
	COMMAND trans3_Press_STRATEGY_write; \
	VARIABLE trans3_Press_ALERT_KEY; \
	MENU trans3_Press_ALERT_KEY_page; \
	COMMAND trans3_Press_ALERT_KEY_read; \
	COMMAND trans3_Press_ALERT_KEY_write; \
	VARIABLE trans3_Press_TARGET_MODE; \
	MENU trans3_Press_TARGET_MODE_page; \
	COMMAND trans3_Press_TARGET_MODE_read; \
	COMMAND trans3_Press_TARGET_MODE_write; \
	COLLECTION trans3_Press_MODE_BLK; \
	VARIABLE trans3_Press_MODE_BLK_Actual; \
	VARIABLE trans3_Press_MODE_BLK_Permitted; \
	VARIABLE trans3_Press_MODE_BLK_Normal; \
	MENU trans3_Press_MODE_BLK_page; \
	COMMAND trans3_Press_MODE_BLK_read; \
	COLLECTION trans3_Press_ALARM_SUM; \
	VARIABLE trans3_Press_ALARM_SUM_Current; \
	VARIABLE trans3_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Press_ALARM_SUM_Unreported; \
	VARIABLE trans3_Press_ALARM_SUM_Disabled; \
	MENU trans3_Press_ALARM_SUM_page; \
	COMMAND trans3_Press_ALARM_SUM_read

#define USE_TRANS3_PRESS_MANDATORY_A \
	USE_TRANS3_PRESS_MANDATORY_BOTH; \
	MENU trans3_Press_Simple_Dialog_Mandatory_A; \
	MENU trans3_Press_Tab_s_mandatory_A; \
	MENU trans3_Press_Tab_m_mandatory_A

#define USE_TRANS3_PRESS_MANDATORY_B \
	USE_TRANS3_PRESS_MANDATORY_BOTH; \
	VARIABLE trans3_Press_SENSOR_VALUE; \
	MENU trans3_Press_SENSOR_VALUE_page; \
	COMMAND trans3_Press_SENSOR_VALUE_read; \
	VARIABLE trans3_Press_SENSOR_HI_LIM; \
	MENU trans3_Press_SENSOR_HI_LIM_page; \
	COMMAND trans3_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans3_Press_SENSOR_LO_LIM; \
	MENU trans3_Press_SENSOR_LO_LIM_page; \
	COMMAND trans3_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans3_Press_CAL_POINT_HI; \
	MENU trans3_Press_CAL_POINT_HI_page; \
	COMMAND trans3_Press_CAL_POINT_HI_read; \
	COMMAND trans3_Press_CAL_POINT_HI_write; \
	VARIABLE trans3_Press_CAL_POINT_LO; \
	MENU trans3_Press_CAL_POINT_LO_page; \
	COMMAND trans3_Press_CAL_POINT_LO_read; \
	COMMAND trans3_Press_CAL_POINT_LO_write; \
	VARIABLE trans3_Press_CAL_MIN_SPAN; \
	MENU trans3_Press_CAL_MIN_SPAN_page; \
	COMMAND trans3_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans3_Press_SENSOR_UNIT; \
	MENU trans3_Press_SENSOR_UNIT_page; \
	COMMAND trans3_Press_SENSOR_UNIT_read; \
	COMMAND trans3_Press_SENSOR_UNIT_write; \
	COLLECTION trans3_Press_TRIMMED_VALUE; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans3_Press_TRIMMED_VALUE_page; \
	COMMAND trans3_Press_TRIMMED_VALUE_read; \
	VARIABLE trans3_Press_SENSOR_TYPE; \
	MENU trans3_Press_SENSOR_TYPE_page; \
	COMMAND trans3_Press_SENSOR_TYPE_read; \
	VARIABLE trans3_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans3_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans3_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans3_Press_PRIMARY_VALUE; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans3_Press_PRIMARY_VALUE_page; \
	COMMAND trans3_Press_PRIMARY_VALUE_read; \
	VARIABLE trans3_Press_PRIMARY_VALUE_UNIT; \
	MENU trans3_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans3_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans3_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans3_Press_PRIMARY_VALUE_TYPE; \
	MENU trans3_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans3_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans3_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans3_Press_LIN_TYPE; \
	MENU trans3_Press_LIN_TYPE_page; \
	COMMAND trans3_Press_LIN_TYPE_read; \
	COMMAND trans3_Press_LIN_TYPE_write; \
	COLLECTION trans3_Press_VIEW_1; \
	MENU trans3_Press_VIEW_1_page; \
	MENU trans3_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans3_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans3_Press_Sensor_unit_1; \
	MENU trans3_Press_Tab_s_mandatory_B; \
	MENU trans3_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans3_Press_Tab_s_input_table_mandatory_B; \
	MENU trans3_Press_Tab_m_mandatory_B; \
	MENU trans3_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans3_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS3_PRESS_OPTIONAL_BOTH \
	VARIABLE trans3_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans3_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans3_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans3_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans3_Press_SENSOR_FILL_FLUID; \
	MENU trans3_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans3_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans3_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans3_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans3_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans3_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans3_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans3_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans3_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans3_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans3_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans3_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans3_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans3_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans3_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans3_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans3_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans3_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans3_Press_TEMPERATURE; \
	VARIABLE trans3_Press_TEMPERATURE_Value; \
	VARIABLE trans3_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans3_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans3_Press_TEMPERATURE_Status_Limit; \
	MENU trans3_Press_TEMPERATURE_page; \
	COMMAND trans3_Press_TEMPERATURE_read; \
	VARIABLE trans3_Press_TEMPERATURE_UNIT; \
	MENU trans3_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans3_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans3_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans3_Press_SECONDARY_VALUE_1; \
	VARIABLE trans3_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans3_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans3_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans3_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans3_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans3_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans3_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans3_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans3_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans3_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans3_Press_SECONDARY_VALUE_2; \
	VARIABLE trans3_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans3_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans3_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans3_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans3_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans3_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans3_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans3_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans3_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans3_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans3_Press_SCALE_IN; \
	VARIABLE trans3_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans3_Press_SCALE_IN_Lower_Value; \
	MENU trans3_Press_SCALE_IN_page; \
	COMMAND trans3_Press_SCALE_IN_read; \
	COMMAND trans3_Press_SCALE_IN_write; \
	COLLECTION trans3_Press_SCALE_OUT; \
	VARIABLE trans3_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans3_Press_SCALE_OUT_Lower_Value; \
	MENU trans3_Press_SCALE_OUT_page; \
	COMMAND trans3_Press_SCALE_OUT_read; \
	COMMAND trans3_Press_SCALE_OUT_write; \
	VARIABLE trans3_Press_LOW_FLOW_CUT_OFF; \
	MENU trans3_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans3_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans3_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans3_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans3_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans3_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans3_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans3_Press_TAB_ACTUAL_NUMBER; \
	MENU trans3_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans3_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans3_Press_TAB_ENTRY; \
	MENU trans3_Press_TAB_ENTRY_page; \
	COMMAND trans3_Press_TAB_ENTRY_read; \
	COMMAND trans3_Press_TAB_ENTRY_write; \
	VARIABLE trans3_Press_TAB_MAX_NUMBER; \
	MENU trans3_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans3_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans3_Press_TAB_MIN_NUMBER; \
	MENU trans3_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans3_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans3_Press_TAB_OP_CODE; \
	MENU trans3_Press_TAB_OP_CODE_page; \
	COMMAND trans3_Press_TAB_OP_CODE_read; \
	COMMAND trans3_Press_TAB_OP_CODE_write; \
	VARIABLE trans3_Press_TAB_STATUS; \
	MENU trans3_Press_TAB_STATUS_page; \
	COMMAND trans3_Press_TAB_STATUS_read; \
	COLLECTION trans3_Press_TAB_X_Y_VALUE; \
	VARIABLE trans3_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans3_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans3_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans3_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans3_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans3_Press_MAX_SENSOR_VALUE; \
	MENU trans3_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans3_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans3_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans3_Press_MIN_SENSOR_VALUE; \
	MENU trans3_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans3_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans3_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans3_Press_MAX_TEMPERATURE; \
	MENU trans3_Press_MAX_TEMPERATURE_page; \
	COMMAND trans3_Press_MAX_TEMPERATURE_read; \
	COMMAND trans3_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans3_Press_MIN_TEMPERATURE; \
	MENU trans3_Press_MIN_TEMPERATURE_page; \
	COMMAND trans3_Press_MIN_TEMPERATURE_read; \
	COMMAND trans3_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans3_Press_VIEW_2; \
	MENU trans3_Press_VIEW_2_page; \
	COLLECTION trans3_Press_VIEW_3; \
	MENU trans3_Press_VIEW_3_page; \
	UNIT trans3_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans3_Press_Sensor_unit_2; \
	UNIT trans3_Press_Temperature_unit; \
	UNIT trans3_Press_Secondary_Value_1_unit; \
	UNIT trans3_Press_Secondary_Value_2_unit

#define USE_TRANS3_PRESS_OPTIONAL_A \
	USE_TRANS3_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans3_Press_SENSOR_VALUE; \
	MENU trans3_Press_SENSOR_VALUE_page; \
	COMMAND trans3_Press_SENSOR_VALUE_read; \
	VARIABLE trans3_Press_SENSOR_HI_LIM; \
	MENU trans3_Press_SENSOR_HI_LIM_page; \
	COMMAND trans3_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans3_Press_SENSOR_LO_LIM; \
	MENU trans3_Press_SENSOR_LO_LIM_page; \
	COMMAND trans3_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans3_Press_CAL_POINT_HI; \
	MENU trans3_Press_CAL_POINT_HI_page; \
	COMMAND trans3_Press_CAL_POINT_HI_read; \
	COMMAND trans3_Press_CAL_POINT_HI_write; \
	VARIABLE trans3_Press_CAL_POINT_LO; \
	MENU trans3_Press_CAL_POINT_LO_page; \
	COMMAND trans3_Press_CAL_POINT_LO_read; \
	COMMAND trans3_Press_CAL_POINT_LO_write; \
	VARIABLE trans3_Press_CAL_MIN_SPAN; \
	MENU trans3_Press_CAL_MIN_SPAN_page; \
	COMMAND trans3_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans3_Press_SENSOR_UNIT; \
	MENU trans3_Press_SENSOR_UNIT_page; \
	COMMAND trans3_Press_SENSOR_UNIT_read; \
	COMMAND trans3_Press_SENSOR_UNIT_write; \
	COLLECTION trans3_Press_TRIMMED_VALUE; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans3_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans3_Press_TRIMMED_VALUE_page; \
	COMMAND trans3_Press_TRIMMED_VALUE_read; \
	VARIABLE trans3_Press_SENSOR_TYPE; \
	MENU trans3_Press_SENSOR_TYPE_page; \
	COMMAND trans3_Press_SENSOR_TYPE_read; \
	VARIABLE trans3_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans3_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans3_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans3_Press_PRIMARY_VALUE; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans3_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans3_Press_PRIMARY_VALUE_page; \
	COMMAND trans3_Press_PRIMARY_VALUE_read; \
	VARIABLE trans3_Press_PRIMARY_VALUE_UNIT; \
	MENU trans3_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans3_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans3_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans3_Press_PRIMARY_VALUE_TYPE; \
	MENU trans3_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans3_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans3_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans3_Press_LIN_TYPE; \
	MENU trans3_Press_LIN_TYPE_page; \
	COMMAND trans3_Press_LIN_TYPE_read; \
	COMMAND trans3_Press_LIN_TYPE_write; \
	COLLECTION trans3_Press_VIEW_1; \
	MENU trans3_Press_VIEW_1_page; \
	MENU trans3_Press_Simple_Dialog_Optional_A; \
	UNIT trans3_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans3_Press_Sensor_unit_1

#define USE_TRANS3_PRESS_OPTIONAL_B \
	USE_TRANS3_PRESS_OPTIONAL_BOTH; \
	MENU trans3_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans3_Press_)
#define USE_TRANS3_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans3_Press_)
#define USE_TRANS3_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans3_Press_)
#define USE_TRANS3_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans3_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_PRESS_MANDATORY_BOTH \
	BLOCK trans4_Press_block; \
	COLLECTION trans4_Press_BLOCK_OBJECT; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Press_BLOCK_OBJECT_page; \
	COMMAND trans4_Press_BLOCK_OBJECT_read; \
	VARIABLE trans4_Press_ST_REV; \
	MENU trans4_Press_ST_REV_page; \
	COMMAND trans4_Press_ST_REV_read; \
	VARIABLE trans4_Press_TAG_DESC; \
	MENU trans4_Press_TAG_DESC_page; \
	COMMAND trans4_Press_TAG_DESC_read; \
	COMMAND trans4_Press_TAG_DESC_write; \
	VARIABLE trans4_Press_STRATEGY; \
	MENU trans4_Press_STRATEGY_page; \
	COMMAND trans4_Press_STRATEGY_read; \
	COMMAND trans4_Press_STRATEGY_write; \
	VARIABLE trans4_Press_ALERT_KEY; \
	MENU trans4_Press_ALERT_KEY_page; \
	COMMAND trans4_Press_ALERT_KEY_read; \
	COMMAND trans4_Press_ALERT_KEY_write; \
	VARIABLE trans4_Press_TARGET_MODE; \
	MENU trans4_Press_TARGET_MODE_page; \
	COMMAND trans4_Press_TARGET_MODE_read; \
	COMMAND trans4_Press_TARGET_MODE_write; \
	COLLECTION trans4_Press_MODE_BLK; \
	VARIABLE trans4_Press_MODE_BLK_Actual; \
	VARIABLE trans4_Press_MODE_BLK_Permitted; \
	VARIABLE trans4_Press_MODE_BLK_Normal; \
	MENU trans4_Press_MODE_BLK_page; \
	COMMAND trans4_Press_MODE_BLK_read; \
	COLLECTION trans4_Press_ALARM_SUM; \
	VARIABLE trans4_Press_ALARM_SUM_Current; \
	VARIABLE trans4_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Press_ALARM_SUM_Unreported; \
	VARIABLE trans4_Press_ALARM_SUM_Disabled; \
	MENU trans4_Press_ALARM_SUM_page; \
	COMMAND trans4_Press_ALARM_SUM_read

#define USE_TRANS4_PRESS_MANDATORY_A \
	USE_TRANS4_PRESS_MANDATORY_BOTH; \
	MENU trans4_Press_Simple_Dialog_Mandatory_A; \
	MENU trans4_Press_Tab_s_mandatory_A; \
	MENU trans4_Press_Tab_m_mandatory_A

#define USE_TRANS4_PRESS_MANDATORY_B \
	USE_TRANS4_PRESS_MANDATORY_BOTH; \
	VARIABLE trans4_Press_SENSOR_VALUE; \
	MENU trans4_Press_SENSOR_VALUE_page; \
	COMMAND trans4_Press_SENSOR_VALUE_read; \
	VARIABLE trans4_Press_SENSOR_HI_LIM; \
	MENU trans4_Press_SENSOR_HI_LIM_page; \
	COMMAND trans4_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans4_Press_SENSOR_LO_LIM; \
	MENU trans4_Press_SENSOR_LO_LIM_page; \
	COMMAND trans4_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans4_Press_CAL_POINT_HI; \
	MENU trans4_Press_CAL_POINT_HI_page; \
	COMMAND trans4_Press_CAL_POINT_HI_read; \
	COMMAND trans4_Press_CAL_POINT_HI_write; \
	VARIABLE trans4_Press_CAL_POINT_LO; \
	MENU trans4_Press_CAL_POINT_LO_page; \
	COMMAND trans4_Press_CAL_POINT_LO_read; \
	COMMAND trans4_Press_CAL_POINT_LO_write; \
	VARIABLE trans4_Press_CAL_MIN_SPAN; \
	MENU trans4_Press_CAL_MIN_SPAN_page; \
	COMMAND trans4_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans4_Press_SENSOR_UNIT; \
	MENU trans4_Press_SENSOR_UNIT_page; \
	COMMAND trans4_Press_SENSOR_UNIT_read; \
	COMMAND trans4_Press_SENSOR_UNIT_write; \
	COLLECTION trans4_Press_TRIMMED_VALUE; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans4_Press_TRIMMED_VALUE_page; \
	COMMAND trans4_Press_TRIMMED_VALUE_read; \
	VARIABLE trans4_Press_SENSOR_TYPE; \
	MENU trans4_Press_SENSOR_TYPE_page; \
	COMMAND trans4_Press_SENSOR_TYPE_read; \
	VARIABLE trans4_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans4_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans4_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans4_Press_PRIMARY_VALUE; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans4_Press_PRIMARY_VALUE_page; \
	COMMAND trans4_Press_PRIMARY_VALUE_read; \
	VARIABLE trans4_Press_PRIMARY_VALUE_UNIT; \
	MENU trans4_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans4_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans4_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans4_Press_PRIMARY_VALUE_TYPE; \
	MENU trans4_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans4_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans4_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans4_Press_LIN_TYPE; \
	MENU trans4_Press_LIN_TYPE_page; \
	COMMAND trans4_Press_LIN_TYPE_read; \
	COMMAND trans4_Press_LIN_TYPE_write; \
	COLLECTION trans4_Press_VIEW_1; \
	MENU trans4_Press_VIEW_1_page; \
	MENU trans4_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans4_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans4_Press_Sensor_unit_1; \
	MENU trans4_Press_Tab_s_mandatory_B; \
	MENU trans4_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans4_Press_Tab_s_input_table_mandatory_B; \
	MENU trans4_Press_Tab_m_mandatory_B; \
	MENU trans4_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans4_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS4_PRESS_OPTIONAL_BOTH \
	VARIABLE trans4_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans4_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans4_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans4_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans4_Press_SENSOR_FILL_FLUID; \
	MENU trans4_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans4_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans4_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans4_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans4_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans4_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans4_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans4_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans4_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans4_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans4_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans4_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans4_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans4_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans4_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans4_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans4_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans4_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans4_Press_TEMPERATURE; \
	VARIABLE trans4_Press_TEMPERATURE_Value; \
	VARIABLE trans4_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans4_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans4_Press_TEMPERATURE_Status_Limit; \
	MENU trans4_Press_TEMPERATURE_page; \
	COMMAND trans4_Press_TEMPERATURE_read; \
	VARIABLE trans4_Press_TEMPERATURE_UNIT; \
	MENU trans4_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans4_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans4_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans4_Press_SECONDARY_VALUE_1; \
	VARIABLE trans4_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans4_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans4_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans4_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans4_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans4_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans4_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans4_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans4_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans4_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans4_Press_SECONDARY_VALUE_2; \
	VARIABLE trans4_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans4_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans4_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans4_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans4_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans4_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans4_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans4_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans4_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans4_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans4_Press_SCALE_IN; \
	VARIABLE trans4_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans4_Press_SCALE_IN_Lower_Value; \
	MENU trans4_Press_SCALE_IN_page; \
	COMMAND trans4_Press_SCALE_IN_read; \
	COMMAND trans4_Press_SCALE_IN_write; \
	COLLECTION trans4_Press_SCALE_OUT; \
	VARIABLE trans4_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans4_Press_SCALE_OUT_Lower_Value; \
	MENU trans4_Press_SCALE_OUT_page; \
	COMMAND trans4_Press_SCALE_OUT_read; \
	COMMAND trans4_Press_SCALE_OUT_write; \
	VARIABLE trans4_Press_LOW_FLOW_CUT_OFF; \
	MENU trans4_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans4_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans4_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans4_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans4_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans4_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans4_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans4_Press_TAB_ACTUAL_NUMBER; \
	MENU trans4_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans4_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans4_Press_TAB_ENTRY; \
	MENU trans4_Press_TAB_ENTRY_page; \
	COMMAND trans4_Press_TAB_ENTRY_read; \
	COMMAND trans4_Press_TAB_ENTRY_write; \
	VARIABLE trans4_Press_TAB_MAX_NUMBER; \
	MENU trans4_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans4_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans4_Press_TAB_MIN_NUMBER; \
	MENU trans4_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans4_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans4_Press_TAB_OP_CODE; \
	MENU trans4_Press_TAB_OP_CODE_page; \
	COMMAND trans4_Press_TAB_OP_CODE_read; \
	COMMAND trans4_Press_TAB_OP_CODE_write; \
	VARIABLE trans4_Press_TAB_STATUS; \
	MENU trans4_Press_TAB_STATUS_page; \
	COMMAND trans4_Press_TAB_STATUS_read; \
	COLLECTION trans4_Press_TAB_X_Y_VALUE; \
	VARIABLE trans4_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans4_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans4_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans4_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans4_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans4_Press_MAX_SENSOR_VALUE; \
	MENU trans4_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans4_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans4_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans4_Press_MIN_SENSOR_VALUE; \
	MENU trans4_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans4_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans4_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans4_Press_MAX_TEMPERATURE; \
	MENU trans4_Press_MAX_TEMPERATURE_page; \
	COMMAND trans4_Press_MAX_TEMPERATURE_read; \
	COMMAND trans4_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans4_Press_MIN_TEMPERATURE; \
	MENU trans4_Press_MIN_TEMPERATURE_page; \
	COMMAND trans4_Press_MIN_TEMPERATURE_read; \
	COMMAND trans4_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans4_Press_VIEW_2; \
	MENU trans4_Press_VIEW_2_page; \
	COLLECTION trans4_Press_VIEW_3; \
	MENU trans4_Press_VIEW_3_page; \
	UNIT trans4_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans4_Press_Sensor_unit_2; \
	UNIT trans4_Press_Temperature_unit; \
	UNIT trans4_Press_Secondary_Value_1_unit; \
	UNIT trans4_Press_Secondary_Value_2_unit

#define USE_TRANS4_PRESS_OPTIONAL_A \
	USE_TRANS4_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans4_Press_SENSOR_VALUE; \
	MENU trans4_Press_SENSOR_VALUE_page; \
	COMMAND trans4_Press_SENSOR_VALUE_read; \
	VARIABLE trans4_Press_SENSOR_HI_LIM; \
	MENU trans4_Press_SENSOR_HI_LIM_page; \
	COMMAND trans4_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans4_Press_SENSOR_LO_LIM; \
	MENU trans4_Press_SENSOR_LO_LIM_page; \
	COMMAND trans4_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans4_Press_CAL_POINT_HI; \
	MENU trans4_Press_CAL_POINT_HI_page; \
	COMMAND trans4_Press_CAL_POINT_HI_read; \
	COMMAND trans4_Press_CAL_POINT_HI_write; \
	VARIABLE trans4_Press_CAL_POINT_LO; \
	MENU trans4_Press_CAL_POINT_LO_page; \
	COMMAND trans4_Press_CAL_POINT_LO_read; \
	COMMAND trans4_Press_CAL_POINT_LO_write; \
	VARIABLE trans4_Press_CAL_MIN_SPAN; \
	MENU trans4_Press_CAL_MIN_SPAN_page; \
	COMMAND trans4_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans4_Press_SENSOR_UNIT; \
	MENU trans4_Press_SENSOR_UNIT_page; \
	COMMAND trans4_Press_SENSOR_UNIT_read; \
	COMMAND trans4_Press_SENSOR_UNIT_write; \
	COLLECTION trans4_Press_TRIMMED_VALUE; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans4_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans4_Press_TRIMMED_VALUE_page; \
	COMMAND trans4_Press_TRIMMED_VALUE_read; \
	VARIABLE trans4_Press_SENSOR_TYPE; \
	MENU trans4_Press_SENSOR_TYPE_page; \
	COMMAND trans4_Press_SENSOR_TYPE_read; \
	VARIABLE trans4_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans4_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans4_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans4_Press_PRIMARY_VALUE; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans4_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans4_Press_PRIMARY_VALUE_page; \
	COMMAND trans4_Press_PRIMARY_VALUE_read; \
	VARIABLE trans4_Press_PRIMARY_VALUE_UNIT; \
	MENU trans4_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans4_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans4_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans4_Press_PRIMARY_VALUE_TYPE; \
	MENU trans4_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans4_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans4_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans4_Press_LIN_TYPE; \
	MENU trans4_Press_LIN_TYPE_page; \
	COMMAND trans4_Press_LIN_TYPE_read; \
	COMMAND trans4_Press_LIN_TYPE_write; \
	COLLECTION trans4_Press_VIEW_1; \
	MENU trans4_Press_VIEW_1_page; \
	MENU trans4_Press_Simple_Dialog_Optional_A; \
	UNIT trans4_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans4_Press_Sensor_unit_1

#define USE_TRANS4_PRESS_OPTIONAL_B \
	USE_TRANS4_PRESS_OPTIONAL_BOTH; \
	MENU trans4_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans4_Press_)
#define USE_TRANS4_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans4_Press_)
#define USE_TRANS4_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans4_Press_)
#define USE_TRANS4_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans4_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_PRESS_MANDATORY_BOTH \
	BLOCK trans5_Press_block; \
	COLLECTION trans5_Press_BLOCK_OBJECT; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Press_BLOCK_OBJECT_page; \
	COMMAND trans5_Press_BLOCK_OBJECT_read; \
	VARIABLE trans5_Press_ST_REV; \
	MENU trans5_Press_ST_REV_page; \
	COMMAND trans5_Press_ST_REV_read; \
	VARIABLE trans5_Press_TAG_DESC; \
	MENU trans5_Press_TAG_DESC_page; \
	COMMAND trans5_Press_TAG_DESC_read; \
	COMMAND trans5_Press_TAG_DESC_write; \
	VARIABLE trans5_Press_STRATEGY; \
	MENU trans5_Press_STRATEGY_page; \
	COMMAND trans5_Press_STRATEGY_read; \
	COMMAND trans5_Press_STRATEGY_write; \
	VARIABLE trans5_Press_ALERT_KEY; \
	MENU trans5_Press_ALERT_KEY_page; \
	COMMAND trans5_Press_ALERT_KEY_read; \
	COMMAND trans5_Press_ALERT_KEY_write; \
	VARIABLE trans5_Press_TARGET_MODE; \
	MENU trans5_Press_TARGET_MODE_page; \
	COMMAND trans5_Press_TARGET_MODE_read; \
	COMMAND trans5_Press_TARGET_MODE_write; \
	COLLECTION trans5_Press_MODE_BLK; \
	VARIABLE trans5_Press_MODE_BLK_Actual; \
	VARIABLE trans5_Press_MODE_BLK_Permitted; \
	VARIABLE trans5_Press_MODE_BLK_Normal; \
	MENU trans5_Press_MODE_BLK_page; \
	COMMAND trans5_Press_MODE_BLK_read; \
	COLLECTION trans5_Press_ALARM_SUM; \
	VARIABLE trans5_Press_ALARM_SUM_Current; \
	VARIABLE trans5_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Press_ALARM_SUM_Unreported; \
	VARIABLE trans5_Press_ALARM_SUM_Disabled; \
	MENU trans5_Press_ALARM_SUM_page; \
	COMMAND trans5_Press_ALARM_SUM_read

#define USE_TRANS5_PRESS_MANDATORY_A \
	USE_TRANS5_PRESS_MANDATORY_BOTH; \
	MENU trans5_Press_Simple_Dialog_Mandatory_A; \
	MENU trans5_Press_Tab_s_mandatory_A; \
	MENU trans5_Press_Tab_m_mandatory_A

#define USE_TRANS5_PRESS_MANDATORY_B \
	USE_TRANS5_PRESS_MANDATORY_BOTH; \
	VARIABLE trans5_Press_SENSOR_VALUE; \
	MENU trans5_Press_SENSOR_VALUE_page; \
	COMMAND trans5_Press_SENSOR_VALUE_read; \
	VARIABLE trans5_Press_SENSOR_HI_LIM; \
	MENU trans5_Press_SENSOR_HI_LIM_page; \
	COMMAND trans5_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans5_Press_SENSOR_LO_LIM; \
	MENU trans5_Press_SENSOR_LO_LIM_page; \
	COMMAND trans5_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans5_Press_CAL_POINT_HI; \
	MENU trans5_Press_CAL_POINT_HI_page; \
	COMMAND trans5_Press_CAL_POINT_HI_read; \
	COMMAND trans5_Press_CAL_POINT_HI_write; \
	VARIABLE trans5_Press_CAL_POINT_LO; \
	MENU trans5_Press_CAL_POINT_LO_page; \
	COMMAND trans5_Press_CAL_POINT_LO_read; \
	COMMAND trans5_Press_CAL_POINT_LO_write; \
	VARIABLE trans5_Press_CAL_MIN_SPAN; \
	MENU trans5_Press_CAL_MIN_SPAN_page; \
	COMMAND trans5_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans5_Press_SENSOR_UNIT; \
	MENU trans5_Press_SENSOR_UNIT_page; \
	COMMAND trans5_Press_SENSOR_UNIT_read; \
	COMMAND trans5_Press_SENSOR_UNIT_write; \
	COLLECTION trans5_Press_TRIMMED_VALUE; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans5_Press_TRIMMED_VALUE_page; \
	COMMAND trans5_Press_TRIMMED_VALUE_read; \
	VARIABLE trans5_Press_SENSOR_TYPE; \
	MENU trans5_Press_SENSOR_TYPE_page; \
	COMMAND trans5_Press_SENSOR_TYPE_read; \
	VARIABLE trans5_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans5_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans5_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans5_Press_PRIMARY_VALUE; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans5_Press_PRIMARY_VALUE_page; \
	COMMAND trans5_Press_PRIMARY_VALUE_read; \
	VARIABLE trans5_Press_PRIMARY_VALUE_UNIT; \
	MENU trans5_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans5_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans5_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans5_Press_PRIMARY_VALUE_TYPE; \
	MENU trans5_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans5_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans5_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans5_Press_LIN_TYPE; \
	MENU trans5_Press_LIN_TYPE_page; \
	COMMAND trans5_Press_LIN_TYPE_read; \
	COMMAND trans5_Press_LIN_TYPE_write; \
	COLLECTION trans5_Press_VIEW_1; \
	MENU trans5_Press_VIEW_1_page; \
	MENU trans5_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans5_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans5_Press_Sensor_unit_1; \
	MENU trans5_Press_Tab_s_mandatory_B; \
	MENU trans5_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans5_Press_Tab_s_input_table_mandatory_B; \
	MENU trans5_Press_Tab_m_mandatory_B; \
	MENU trans5_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans5_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS5_PRESS_OPTIONAL_BOTH \
	VARIABLE trans5_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans5_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans5_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans5_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans5_Press_SENSOR_FILL_FLUID; \
	MENU trans5_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans5_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans5_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans5_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans5_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans5_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans5_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans5_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans5_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans5_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans5_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans5_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans5_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans5_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans5_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans5_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans5_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans5_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans5_Press_TEMPERATURE; \
	VARIABLE trans5_Press_TEMPERATURE_Value; \
	VARIABLE trans5_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans5_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans5_Press_TEMPERATURE_Status_Limit; \
	MENU trans5_Press_TEMPERATURE_page; \
	COMMAND trans5_Press_TEMPERATURE_read; \
	VARIABLE trans5_Press_TEMPERATURE_UNIT; \
	MENU trans5_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans5_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans5_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans5_Press_SECONDARY_VALUE_1; \
	VARIABLE trans5_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans5_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans5_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans5_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans5_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans5_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans5_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans5_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans5_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans5_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans5_Press_SECONDARY_VALUE_2; \
	VARIABLE trans5_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans5_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans5_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans5_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans5_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans5_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans5_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans5_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans5_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans5_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans5_Press_SCALE_IN; \
	VARIABLE trans5_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans5_Press_SCALE_IN_Lower_Value; \
	MENU trans5_Press_SCALE_IN_page; \
	COMMAND trans5_Press_SCALE_IN_read; \
	COMMAND trans5_Press_SCALE_IN_write; \
	COLLECTION trans5_Press_SCALE_OUT; \
	VARIABLE trans5_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans5_Press_SCALE_OUT_Lower_Value; \
	MENU trans5_Press_SCALE_OUT_page; \
	COMMAND trans5_Press_SCALE_OUT_read; \
	COMMAND trans5_Press_SCALE_OUT_write; \
	VARIABLE trans5_Press_LOW_FLOW_CUT_OFF; \
	MENU trans5_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans5_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans5_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans5_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans5_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans5_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans5_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans5_Press_TAB_ACTUAL_NUMBER; \
	MENU trans5_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans5_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans5_Press_TAB_ENTRY; \
	MENU trans5_Press_TAB_ENTRY_page; \
	COMMAND trans5_Press_TAB_ENTRY_read; \
	COMMAND trans5_Press_TAB_ENTRY_write; \
	VARIABLE trans5_Press_TAB_MAX_NUMBER; \
	MENU trans5_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans5_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans5_Press_TAB_MIN_NUMBER; \
	MENU trans5_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans5_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans5_Press_TAB_OP_CODE; \
	MENU trans5_Press_TAB_OP_CODE_page; \
	COMMAND trans5_Press_TAB_OP_CODE_read; \
	COMMAND trans5_Press_TAB_OP_CODE_write; \
	VARIABLE trans5_Press_TAB_STATUS; \
	MENU trans5_Press_TAB_STATUS_page; \
	COMMAND trans5_Press_TAB_STATUS_read; \
	COLLECTION trans5_Press_TAB_X_Y_VALUE; \
	VARIABLE trans5_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans5_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans5_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans5_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans5_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans5_Press_MAX_SENSOR_VALUE; \
	MENU trans5_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans5_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans5_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans5_Press_MIN_SENSOR_VALUE; \
	MENU trans5_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans5_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans5_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans5_Press_MAX_TEMPERATURE; \
	MENU trans5_Press_MAX_TEMPERATURE_page; \
	COMMAND trans5_Press_MAX_TEMPERATURE_read; \
	COMMAND trans5_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans5_Press_MIN_TEMPERATURE; \
	MENU trans5_Press_MIN_TEMPERATURE_page; \
	COMMAND trans5_Press_MIN_TEMPERATURE_read; \
	COMMAND trans5_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans5_Press_VIEW_2; \
	MENU trans5_Press_VIEW_2_page; \
	COLLECTION trans5_Press_VIEW_3; \
	MENU trans5_Press_VIEW_3_page; \
	UNIT trans5_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans5_Press_Sensor_unit_2; \
	UNIT trans5_Press_Temperature_unit; \
	UNIT trans5_Press_Secondary_Value_1_unit; \
	UNIT trans5_Press_Secondary_Value_2_unit

#define USE_TRANS5_PRESS_OPTIONAL_A \
	USE_TRANS5_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans5_Press_SENSOR_VALUE; \
	MENU trans5_Press_SENSOR_VALUE_page; \
	COMMAND trans5_Press_SENSOR_VALUE_read; \
	VARIABLE trans5_Press_SENSOR_HI_LIM; \
	MENU trans5_Press_SENSOR_HI_LIM_page; \
	COMMAND trans5_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans5_Press_SENSOR_LO_LIM; \
	MENU trans5_Press_SENSOR_LO_LIM_page; \
	COMMAND trans5_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans5_Press_CAL_POINT_HI; \
	MENU trans5_Press_CAL_POINT_HI_page; \
	COMMAND trans5_Press_CAL_POINT_HI_read; \
	COMMAND trans5_Press_CAL_POINT_HI_write; \
	VARIABLE trans5_Press_CAL_POINT_LO; \
	MENU trans5_Press_CAL_POINT_LO_page; \
	COMMAND trans5_Press_CAL_POINT_LO_read; \
	COMMAND trans5_Press_CAL_POINT_LO_write; \
	VARIABLE trans5_Press_CAL_MIN_SPAN; \
	MENU trans5_Press_CAL_MIN_SPAN_page; \
	COMMAND trans5_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans5_Press_SENSOR_UNIT; \
	MENU trans5_Press_SENSOR_UNIT_page; \
	COMMAND trans5_Press_SENSOR_UNIT_read; \
	COMMAND trans5_Press_SENSOR_UNIT_write; \
	COLLECTION trans5_Press_TRIMMED_VALUE; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans5_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans5_Press_TRIMMED_VALUE_page; \
	COMMAND trans5_Press_TRIMMED_VALUE_read; \
	VARIABLE trans5_Press_SENSOR_TYPE; \
	MENU trans5_Press_SENSOR_TYPE_page; \
	COMMAND trans5_Press_SENSOR_TYPE_read; \
	VARIABLE trans5_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans5_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans5_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans5_Press_PRIMARY_VALUE; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans5_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans5_Press_PRIMARY_VALUE_page; \
	COMMAND trans5_Press_PRIMARY_VALUE_read; \
	VARIABLE trans5_Press_PRIMARY_VALUE_UNIT; \
	MENU trans5_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans5_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans5_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans5_Press_PRIMARY_VALUE_TYPE; \
	MENU trans5_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans5_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans5_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans5_Press_LIN_TYPE; \
	MENU trans5_Press_LIN_TYPE_page; \
	COMMAND trans5_Press_LIN_TYPE_read; \
	COMMAND trans5_Press_LIN_TYPE_write; \
	COLLECTION trans5_Press_VIEW_1; \
	MENU trans5_Press_VIEW_1_page; \
	MENU trans5_Press_Simple_Dialog_Optional_A; \
	UNIT trans5_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans5_Press_Sensor_unit_1

#define USE_TRANS5_PRESS_OPTIONAL_B \
	USE_TRANS5_PRESS_OPTIONAL_BOTH; \
	MENU trans5_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans5_Press_)
#define USE_TRANS5_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans5_Press_)
#define USE_TRANS5_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans5_Press_)
#define USE_TRANS5_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans5_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_PRESS_MANDATORY_BOTH \
	BLOCK trans6_Press_block; \
	COLLECTION trans6_Press_BLOCK_OBJECT; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Press_BLOCK_OBJECT_page; \
	COMMAND trans6_Press_BLOCK_OBJECT_read; \
	VARIABLE trans6_Press_ST_REV; \
	MENU trans6_Press_ST_REV_page; \
	COMMAND trans6_Press_ST_REV_read; \
	VARIABLE trans6_Press_TAG_DESC; \
	MENU trans6_Press_TAG_DESC_page; \
	COMMAND trans6_Press_TAG_DESC_read; \
	COMMAND trans6_Press_TAG_DESC_write; \
	VARIABLE trans6_Press_STRATEGY; \
	MENU trans6_Press_STRATEGY_page; \
	COMMAND trans6_Press_STRATEGY_read; \
	COMMAND trans6_Press_STRATEGY_write; \
	VARIABLE trans6_Press_ALERT_KEY; \
	MENU trans6_Press_ALERT_KEY_page; \
	COMMAND trans6_Press_ALERT_KEY_read; \
	COMMAND trans6_Press_ALERT_KEY_write; \
	VARIABLE trans6_Press_TARGET_MODE; \
	MENU trans6_Press_TARGET_MODE_page; \
	COMMAND trans6_Press_TARGET_MODE_read; \
	COMMAND trans6_Press_TARGET_MODE_write; \
	COLLECTION trans6_Press_MODE_BLK; \
	VARIABLE trans6_Press_MODE_BLK_Actual; \
	VARIABLE trans6_Press_MODE_BLK_Permitted; \
	VARIABLE trans6_Press_MODE_BLK_Normal; \
	MENU trans6_Press_MODE_BLK_page; \
	COMMAND trans6_Press_MODE_BLK_read; \
	COLLECTION trans6_Press_ALARM_SUM; \
	VARIABLE trans6_Press_ALARM_SUM_Current; \
	VARIABLE trans6_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Press_ALARM_SUM_Unreported; \
	VARIABLE trans6_Press_ALARM_SUM_Disabled; \
	MENU trans6_Press_ALARM_SUM_page; \
	COMMAND trans6_Press_ALARM_SUM_read

#define USE_TRANS6_PRESS_MANDATORY_A \
	USE_TRANS6_PRESS_MANDATORY_BOTH; \
	MENU trans6_Press_Simple_Dialog_Mandatory_A; \
	MENU trans6_Press_Tab_s_mandatory_A; \
	MENU trans6_Press_Tab_m_mandatory_A

#define USE_TRANS6_PRESS_MANDATORY_B \
	USE_TRANS6_PRESS_MANDATORY_BOTH; \
	VARIABLE trans6_Press_SENSOR_VALUE; \
	MENU trans6_Press_SENSOR_VALUE_page; \
	COMMAND trans6_Press_SENSOR_VALUE_read; \
	VARIABLE trans6_Press_SENSOR_HI_LIM; \
	MENU trans6_Press_SENSOR_HI_LIM_page; \
	COMMAND trans6_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans6_Press_SENSOR_LO_LIM; \
	MENU trans6_Press_SENSOR_LO_LIM_page; \
	COMMAND trans6_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans6_Press_CAL_POINT_HI; \
	MENU trans6_Press_CAL_POINT_HI_page; \
	COMMAND trans6_Press_CAL_POINT_HI_read; \
	COMMAND trans6_Press_CAL_POINT_HI_write; \
	VARIABLE trans6_Press_CAL_POINT_LO; \
	MENU trans6_Press_CAL_POINT_LO_page; \
	COMMAND trans6_Press_CAL_POINT_LO_read; \
	COMMAND trans6_Press_CAL_POINT_LO_write; \
	VARIABLE trans6_Press_CAL_MIN_SPAN; \
	MENU trans6_Press_CAL_MIN_SPAN_page; \
	COMMAND trans6_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans6_Press_SENSOR_UNIT; \
	MENU trans6_Press_SENSOR_UNIT_page; \
	COMMAND trans6_Press_SENSOR_UNIT_read; \
	COMMAND trans6_Press_SENSOR_UNIT_write; \
	COLLECTION trans6_Press_TRIMMED_VALUE; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans6_Press_TRIMMED_VALUE_page; \
	COMMAND trans6_Press_TRIMMED_VALUE_read; \
	VARIABLE trans6_Press_SENSOR_TYPE; \
	MENU trans6_Press_SENSOR_TYPE_page; \
	COMMAND trans6_Press_SENSOR_TYPE_read; \
	VARIABLE trans6_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans6_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans6_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans6_Press_PRIMARY_VALUE; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans6_Press_PRIMARY_VALUE_page; \
	COMMAND trans6_Press_PRIMARY_VALUE_read; \
	VARIABLE trans6_Press_PRIMARY_VALUE_UNIT; \
	MENU trans6_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans6_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans6_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans6_Press_PRIMARY_VALUE_TYPE; \
	MENU trans6_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans6_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans6_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans6_Press_LIN_TYPE; \
	MENU trans6_Press_LIN_TYPE_page; \
	COMMAND trans6_Press_LIN_TYPE_read; \
	COMMAND trans6_Press_LIN_TYPE_write; \
	COLLECTION trans6_Press_VIEW_1; \
	MENU trans6_Press_VIEW_1_page; \
	MENU trans6_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans6_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans6_Press_Sensor_unit_1; \
	MENU trans6_Press_Tab_s_mandatory_B; \
	MENU trans6_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans6_Press_Tab_s_input_table_mandatory_B; \
	MENU trans6_Press_Tab_m_mandatory_B; \
	MENU trans6_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans6_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS6_PRESS_OPTIONAL_BOTH \
	VARIABLE trans6_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans6_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans6_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans6_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans6_Press_SENSOR_FILL_FLUID; \
	MENU trans6_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans6_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans6_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans6_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans6_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans6_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans6_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans6_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans6_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans6_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans6_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans6_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans6_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans6_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans6_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans6_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans6_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans6_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans6_Press_TEMPERATURE; \
	VARIABLE trans6_Press_TEMPERATURE_Value; \
	VARIABLE trans6_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans6_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans6_Press_TEMPERATURE_Status_Limit; \
	MENU trans6_Press_TEMPERATURE_page; \
	COMMAND trans6_Press_TEMPERATURE_read; \
	VARIABLE trans6_Press_TEMPERATURE_UNIT; \
	MENU trans6_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans6_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans6_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans6_Press_SECONDARY_VALUE_1; \
	VARIABLE trans6_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans6_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans6_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans6_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans6_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans6_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans6_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans6_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans6_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans6_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans6_Press_SECONDARY_VALUE_2; \
	VARIABLE trans6_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans6_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans6_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans6_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans6_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans6_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans6_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans6_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans6_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans6_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans6_Press_SCALE_IN; \
	VARIABLE trans6_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans6_Press_SCALE_IN_Lower_Value; \
	MENU trans6_Press_SCALE_IN_page; \
	COMMAND trans6_Press_SCALE_IN_read; \
	COMMAND trans6_Press_SCALE_IN_write; \
	COLLECTION trans6_Press_SCALE_OUT; \
	VARIABLE trans6_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans6_Press_SCALE_OUT_Lower_Value; \
	MENU trans6_Press_SCALE_OUT_page; \
	COMMAND trans6_Press_SCALE_OUT_read; \
	COMMAND trans6_Press_SCALE_OUT_write; \
	VARIABLE trans6_Press_LOW_FLOW_CUT_OFF; \
	MENU trans6_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans6_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans6_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans6_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans6_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans6_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans6_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans6_Press_TAB_ACTUAL_NUMBER; \
	MENU trans6_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans6_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans6_Press_TAB_ENTRY; \
	MENU trans6_Press_TAB_ENTRY_page; \
	COMMAND trans6_Press_TAB_ENTRY_read; \
	COMMAND trans6_Press_TAB_ENTRY_write; \
	VARIABLE trans6_Press_TAB_MAX_NUMBER; \
	MENU trans6_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans6_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans6_Press_TAB_MIN_NUMBER; \
	MENU trans6_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans6_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans6_Press_TAB_OP_CODE; \
	MENU trans6_Press_TAB_OP_CODE_page; \
	COMMAND trans6_Press_TAB_OP_CODE_read; \
	COMMAND trans6_Press_TAB_OP_CODE_write; \
	VARIABLE trans6_Press_TAB_STATUS; \
	MENU trans6_Press_TAB_STATUS_page; \
	COMMAND trans6_Press_TAB_STATUS_read; \
	COLLECTION trans6_Press_TAB_X_Y_VALUE; \
	VARIABLE trans6_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans6_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans6_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans6_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans6_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans6_Press_MAX_SENSOR_VALUE; \
	MENU trans6_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans6_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans6_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans6_Press_MIN_SENSOR_VALUE; \
	MENU trans6_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans6_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans6_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans6_Press_MAX_TEMPERATURE; \
	MENU trans6_Press_MAX_TEMPERATURE_page; \
	COMMAND trans6_Press_MAX_TEMPERATURE_read; \
	COMMAND trans6_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans6_Press_MIN_TEMPERATURE; \
	MENU trans6_Press_MIN_TEMPERATURE_page; \
	COMMAND trans6_Press_MIN_TEMPERATURE_read; \
	COMMAND trans6_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans6_Press_VIEW_2; \
	MENU trans6_Press_VIEW_2_page; \
	COLLECTION trans6_Press_VIEW_3; \
	MENU trans6_Press_VIEW_3_page; \
	UNIT trans6_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans6_Press_Sensor_unit_2; \
	UNIT trans6_Press_Temperature_unit; \
	UNIT trans6_Press_Secondary_Value_1_unit; \
	UNIT trans6_Press_Secondary_Value_2_unit

#define USE_TRANS6_PRESS_OPTIONAL_A \
	USE_TRANS6_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans6_Press_SENSOR_VALUE; \
	MENU trans6_Press_SENSOR_VALUE_page; \
	COMMAND trans6_Press_SENSOR_VALUE_read; \
	VARIABLE trans6_Press_SENSOR_HI_LIM; \
	MENU trans6_Press_SENSOR_HI_LIM_page; \
	COMMAND trans6_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans6_Press_SENSOR_LO_LIM; \
	MENU trans6_Press_SENSOR_LO_LIM_page; \
	COMMAND trans6_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans6_Press_CAL_POINT_HI; \
	MENU trans6_Press_CAL_POINT_HI_page; \
	COMMAND trans6_Press_CAL_POINT_HI_read; \
	COMMAND trans6_Press_CAL_POINT_HI_write; \
	VARIABLE trans6_Press_CAL_POINT_LO; \
	MENU trans6_Press_CAL_POINT_LO_page; \
	COMMAND trans6_Press_CAL_POINT_LO_read; \
	COMMAND trans6_Press_CAL_POINT_LO_write; \
	VARIABLE trans6_Press_CAL_MIN_SPAN; \
	MENU trans6_Press_CAL_MIN_SPAN_page; \
	COMMAND trans6_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans6_Press_SENSOR_UNIT; \
	MENU trans6_Press_SENSOR_UNIT_page; \
	COMMAND trans6_Press_SENSOR_UNIT_read; \
	COMMAND trans6_Press_SENSOR_UNIT_write; \
	COLLECTION trans6_Press_TRIMMED_VALUE; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans6_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans6_Press_TRIMMED_VALUE_page; \
	COMMAND trans6_Press_TRIMMED_VALUE_read; \
	VARIABLE trans6_Press_SENSOR_TYPE; \
	MENU trans6_Press_SENSOR_TYPE_page; \
	COMMAND trans6_Press_SENSOR_TYPE_read; \
	VARIABLE trans6_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans6_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans6_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans6_Press_PRIMARY_VALUE; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans6_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans6_Press_PRIMARY_VALUE_page; \
	COMMAND trans6_Press_PRIMARY_VALUE_read; \
	VARIABLE trans6_Press_PRIMARY_VALUE_UNIT; \
	MENU trans6_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans6_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans6_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans6_Press_PRIMARY_VALUE_TYPE; \
	MENU trans6_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans6_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans6_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans6_Press_LIN_TYPE; \
	MENU trans6_Press_LIN_TYPE_page; \
	COMMAND trans6_Press_LIN_TYPE_read; \
	COMMAND trans6_Press_LIN_TYPE_write; \
	COLLECTION trans6_Press_VIEW_1; \
	MENU trans6_Press_VIEW_1_page; \
	MENU trans6_Press_Simple_Dialog_Optional_A; \
	UNIT trans6_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans6_Press_Sensor_unit_1

#define USE_TRANS6_PRESS_OPTIONAL_B \
	USE_TRANS6_PRESS_OPTIONAL_BOTH; \
	MENU trans6_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans6_Press_)
#define USE_TRANS6_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans6_Press_)
#define USE_TRANS6_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans6_Press_)
#define USE_TRANS6_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans6_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_PRESS_MANDATORY_BOTH \
	BLOCK trans7_Press_block; \
	COLLECTION trans7_Press_BLOCK_OBJECT; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Press_BLOCK_OBJECT_page; \
	COMMAND trans7_Press_BLOCK_OBJECT_read; \
	VARIABLE trans7_Press_ST_REV; \
	MENU trans7_Press_ST_REV_page; \
	COMMAND trans7_Press_ST_REV_read; \
	VARIABLE trans7_Press_TAG_DESC; \
	MENU trans7_Press_TAG_DESC_page; \
	COMMAND trans7_Press_TAG_DESC_read; \
	COMMAND trans7_Press_TAG_DESC_write; \
	VARIABLE trans7_Press_STRATEGY; \
	MENU trans7_Press_STRATEGY_page; \
	COMMAND trans7_Press_STRATEGY_read; \
	COMMAND trans7_Press_STRATEGY_write; \
	VARIABLE trans7_Press_ALERT_KEY; \
	MENU trans7_Press_ALERT_KEY_page; \
	COMMAND trans7_Press_ALERT_KEY_read; \
	COMMAND trans7_Press_ALERT_KEY_write; \
	VARIABLE trans7_Press_TARGET_MODE; \
	MENU trans7_Press_TARGET_MODE_page; \
	COMMAND trans7_Press_TARGET_MODE_read; \
	COMMAND trans7_Press_TARGET_MODE_write; \
	COLLECTION trans7_Press_MODE_BLK; \
	VARIABLE trans7_Press_MODE_BLK_Actual; \
	VARIABLE trans7_Press_MODE_BLK_Permitted; \
	VARIABLE trans7_Press_MODE_BLK_Normal; \
	MENU trans7_Press_MODE_BLK_page; \
	COMMAND trans7_Press_MODE_BLK_read; \
	COLLECTION trans7_Press_ALARM_SUM; \
	VARIABLE trans7_Press_ALARM_SUM_Current; \
	VARIABLE trans7_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Press_ALARM_SUM_Unreported; \
	VARIABLE trans7_Press_ALARM_SUM_Disabled; \
	MENU trans7_Press_ALARM_SUM_page; \
	COMMAND trans7_Press_ALARM_SUM_read

#define USE_TRANS7_PRESS_MANDATORY_A \
	USE_TRANS7_PRESS_MANDATORY_BOTH; \
	MENU trans7_Press_Simple_Dialog_Mandatory_A; \
	MENU trans7_Press_Tab_s_mandatory_A; \
	MENU trans7_Press_Tab_m_mandatory_A

#define USE_TRANS7_PRESS_MANDATORY_B \
	USE_TRANS7_PRESS_MANDATORY_BOTH; \
	VARIABLE trans7_Press_SENSOR_VALUE; \
	MENU trans7_Press_SENSOR_VALUE_page; \
	COMMAND trans7_Press_SENSOR_VALUE_read; \
	VARIABLE trans7_Press_SENSOR_HI_LIM; \
	MENU trans7_Press_SENSOR_HI_LIM_page; \
	COMMAND trans7_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans7_Press_SENSOR_LO_LIM; \
	MENU trans7_Press_SENSOR_LO_LIM_page; \
	COMMAND trans7_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans7_Press_CAL_POINT_HI; \
	MENU trans7_Press_CAL_POINT_HI_page; \
	COMMAND trans7_Press_CAL_POINT_HI_read; \
	COMMAND trans7_Press_CAL_POINT_HI_write; \
	VARIABLE trans7_Press_CAL_POINT_LO; \
	MENU trans7_Press_CAL_POINT_LO_page; \
	COMMAND trans7_Press_CAL_POINT_LO_read; \
	COMMAND trans7_Press_CAL_POINT_LO_write; \
	VARIABLE trans7_Press_CAL_MIN_SPAN; \
	MENU trans7_Press_CAL_MIN_SPAN_page; \
	COMMAND trans7_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans7_Press_SENSOR_UNIT; \
	MENU trans7_Press_SENSOR_UNIT_page; \
	COMMAND trans7_Press_SENSOR_UNIT_read; \
	COMMAND trans7_Press_SENSOR_UNIT_write; \
	COLLECTION trans7_Press_TRIMMED_VALUE; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans7_Press_TRIMMED_VALUE_page; \
	COMMAND trans7_Press_TRIMMED_VALUE_read; \
	VARIABLE trans7_Press_SENSOR_TYPE; \
	MENU trans7_Press_SENSOR_TYPE_page; \
	COMMAND trans7_Press_SENSOR_TYPE_read; \
	VARIABLE trans7_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans7_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans7_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans7_Press_PRIMARY_VALUE; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans7_Press_PRIMARY_VALUE_page; \
	COMMAND trans7_Press_PRIMARY_VALUE_read; \
	VARIABLE trans7_Press_PRIMARY_VALUE_UNIT; \
	MENU trans7_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans7_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans7_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans7_Press_PRIMARY_VALUE_TYPE; \
	MENU trans7_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans7_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans7_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans7_Press_LIN_TYPE; \
	MENU trans7_Press_LIN_TYPE_page; \
	COMMAND trans7_Press_LIN_TYPE_read; \
	COMMAND trans7_Press_LIN_TYPE_write; \
	COLLECTION trans7_Press_VIEW_1; \
	MENU trans7_Press_VIEW_1_page; \
	MENU trans7_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans7_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans7_Press_Sensor_unit_1; \
	MENU trans7_Press_Tab_s_mandatory_B; \
	MENU trans7_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans7_Press_Tab_s_input_table_mandatory_B; \
	MENU trans7_Press_Tab_m_mandatory_B; \
	MENU trans7_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans7_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS7_PRESS_OPTIONAL_BOTH \
	VARIABLE trans7_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans7_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans7_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans7_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans7_Press_SENSOR_FILL_FLUID; \
	MENU trans7_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans7_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans7_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans7_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans7_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans7_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans7_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans7_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans7_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans7_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans7_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans7_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans7_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans7_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans7_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans7_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans7_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans7_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans7_Press_TEMPERATURE; \
	VARIABLE trans7_Press_TEMPERATURE_Value; \
	VARIABLE trans7_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans7_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans7_Press_TEMPERATURE_Status_Limit; \
	MENU trans7_Press_TEMPERATURE_page; \
	COMMAND trans7_Press_TEMPERATURE_read; \
	VARIABLE trans7_Press_TEMPERATURE_UNIT; \
	MENU trans7_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans7_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans7_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans7_Press_SECONDARY_VALUE_1; \
	VARIABLE trans7_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans7_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans7_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans7_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans7_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans7_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans7_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans7_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans7_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans7_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans7_Press_SECONDARY_VALUE_2; \
	VARIABLE trans7_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans7_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans7_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans7_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans7_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans7_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans7_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans7_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans7_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans7_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans7_Press_SCALE_IN; \
	VARIABLE trans7_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans7_Press_SCALE_IN_Lower_Value; \
	MENU trans7_Press_SCALE_IN_page; \
	COMMAND trans7_Press_SCALE_IN_read; \
	COMMAND trans7_Press_SCALE_IN_write; \
	COLLECTION trans7_Press_SCALE_OUT; \
	VARIABLE trans7_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans7_Press_SCALE_OUT_Lower_Value; \
	MENU trans7_Press_SCALE_OUT_page; \
	COMMAND trans7_Press_SCALE_OUT_read; \
	COMMAND trans7_Press_SCALE_OUT_write; \
	VARIABLE trans7_Press_LOW_FLOW_CUT_OFF; \
	MENU trans7_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans7_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans7_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans7_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans7_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans7_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans7_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans7_Press_TAB_ACTUAL_NUMBER; \
	MENU trans7_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans7_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans7_Press_TAB_ENTRY; \
	MENU trans7_Press_TAB_ENTRY_page; \
	COMMAND trans7_Press_TAB_ENTRY_read; \
	COMMAND trans7_Press_TAB_ENTRY_write; \
	VARIABLE trans7_Press_TAB_MAX_NUMBER; \
	MENU trans7_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans7_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans7_Press_TAB_MIN_NUMBER; \
	MENU trans7_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans7_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans7_Press_TAB_OP_CODE; \
	MENU trans7_Press_TAB_OP_CODE_page; \
	COMMAND trans7_Press_TAB_OP_CODE_read; \
	COMMAND trans7_Press_TAB_OP_CODE_write; \
	VARIABLE trans7_Press_TAB_STATUS; \
	MENU trans7_Press_TAB_STATUS_page; \
	COMMAND trans7_Press_TAB_STATUS_read; \
	COLLECTION trans7_Press_TAB_X_Y_VALUE; \
	VARIABLE trans7_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans7_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans7_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans7_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans7_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans7_Press_MAX_SENSOR_VALUE; \
	MENU trans7_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans7_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans7_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans7_Press_MIN_SENSOR_VALUE; \
	MENU trans7_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans7_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans7_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans7_Press_MAX_TEMPERATURE; \
	MENU trans7_Press_MAX_TEMPERATURE_page; \
	COMMAND trans7_Press_MAX_TEMPERATURE_read; \
	COMMAND trans7_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans7_Press_MIN_TEMPERATURE; \
	MENU trans7_Press_MIN_TEMPERATURE_page; \
	COMMAND trans7_Press_MIN_TEMPERATURE_read; \
	COMMAND trans7_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans7_Press_VIEW_2; \
	MENU trans7_Press_VIEW_2_page; \
	COLLECTION trans7_Press_VIEW_3; \
	MENU trans7_Press_VIEW_3_page; \
	UNIT trans7_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans7_Press_Sensor_unit_2; \
	UNIT trans7_Press_Temperature_unit; \
	UNIT trans7_Press_Secondary_Value_1_unit; \
	UNIT trans7_Press_Secondary_Value_2_unit

#define USE_TRANS7_PRESS_OPTIONAL_A \
	USE_TRANS7_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans7_Press_SENSOR_VALUE; \
	MENU trans7_Press_SENSOR_VALUE_page; \
	COMMAND trans7_Press_SENSOR_VALUE_read; \
	VARIABLE trans7_Press_SENSOR_HI_LIM; \
	MENU trans7_Press_SENSOR_HI_LIM_page; \
	COMMAND trans7_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans7_Press_SENSOR_LO_LIM; \
	MENU trans7_Press_SENSOR_LO_LIM_page; \
	COMMAND trans7_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans7_Press_CAL_POINT_HI; \
	MENU trans7_Press_CAL_POINT_HI_page; \
	COMMAND trans7_Press_CAL_POINT_HI_read; \
	COMMAND trans7_Press_CAL_POINT_HI_write; \
	VARIABLE trans7_Press_CAL_POINT_LO; \
	MENU trans7_Press_CAL_POINT_LO_page; \
	COMMAND trans7_Press_CAL_POINT_LO_read; \
	COMMAND trans7_Press_CAL_POINT_LO_write; \
	VARIABLE trans7_Press_CAL_MIN_SPAN; \
	MENU trans7_Press_CAL_MIN_SPAN_page; \
	COMMAND trans7_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans7_Press_SENSOR_UNIT; \
	MENU trans7_Press_SENSOR_UNIT_page; \
	COMMAND trans7_Press_SENSOR_UNIT_read; \
	COMMAND trans7_Press_SENSOR_UNIT_write; \
	COLLECTION trans7_Press_TRIMMED_VALUE; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans7_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans7_Press_TRIMMED_VALUE_page; \
	COMMAND trans7_Press_TRIMMED_VALUE_read; \
	VARIABLE trans7_Press_SENSOR_TYPE; \
	MENU trans7_Press_SENSOR_TYPE_page; \
	COMMAND trans7_Press_SENSOR_TYPE_read; \
	VARIABLE trans7_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans7_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans7_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans7_Press_PRIMARY_VALUE; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans7_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans7_Press_PRIMARY_VALUE_page; \
	COMMAND trans7_Press_PRIMARY_VALUE_read; \
	VARIABLE trans7_Press_PRIMARY_VALUE_UNIT; \
	MENU trans7_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans7_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans7_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans7_Press_PRIMARY_VALUE_TYPE; \
	MENU trans7_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans7_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans7_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans7_Press_LIN_TYPE; \
	MENU trans7_Press_LIN_TYPE_page; \
	COMMAND trans7_Press_LIN_TYPE_read; \
	COMMAND trans7_Press_LIN_TYPE_write; \
	COLLECTION trans7_Press_VIEW_1; \
	MENU trans7_Press_VIEW_1_page; \
	MENU trans7_Press_Simple_Dialog_Optional_A; \
	UNIT trans7_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans7_Press_Sensor_unit_1

#define USE_TRANS7_PRESS_OPTIONAL_B \
	USE_TRANS7_PRESS_OPTIONAL_BOTH; \
	MENU trans7_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans7_Press_)
#define USE_TRANS7_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans7_Press_)
#define USE_TRANS7_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans7_Press_)
#define USE_TRANS7_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans7_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_PRESS_MANDATORY_BOTH \
	BLOCK trans8_Press_block; \
	COLLECTION trans8_Press_BLOCK_OBJECT; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Press_BLOCK_OBJECT_page; \
	COMMAND trans8_Press_BLOCK_OBJECT_read; \
	VARIABLE trans8_Press_ST_REV; \
	MENU trans8_Press_ST_REV_page; \
	COMMAND trans8_Press_ST_REV_read; \
	VARIABLE trans8_Press_TAG_DESC; \
	MENU trans8_Press_TAG_DESC_page; \
	COMMAND trans8_Press_TAG_DESC_read; \
	COMMAND trans8_Press_TAG_DESC_write; \
	VARIABLE trans8_Press_STRATEGY; \
	MENU trans8_Press_STRATEGY_page; \
	COMMAND trans8_Press_STRATEGY_read; \
	COMMAND trans8_Press_STRATEGY_write; \
	VARIABLE trans8_Press_ALERT_KEY; \
	MENU trans8_Press_ALERT_KEY_page; \
	COMMAND trans8_Press_ALERT_KEY_read; \
	COMMAND trans8_Press_ALERT_KEY_write; \
	VARIABLE trans8_Press_TARGET_MODE; \
	MENU trans8_Press_TARGET_MODE_page; \
	COMMAND trans8_Press_TARGET_MODE_read; \
	COMMAND trans8_Press_TARGET_MODE_write; \
	COLLECTION trans8_Press_MODE_BLK; \
	VARIABLE trans8_Press_MODE_BLK_Actual; \
	VARIABLE trans8_Press_MODE_BLK_Permitted; \
	VARIABLE trans8_Press_MODE_BLK_Normal; \
	MENU trans8_Press_MODE_BLK_page; \
	COMMAND trans8_Press_MODE_BLK_read; \
	COLLECTION trans8_Press_ALARM_SUM; \
	VARIABLE trans8_Press_ALARM_SUM_Current; \
	VARIABLE trans8_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Press_ALARM_SUM_Unreported; \
	VARIABLE trans8_Press_ALARM_SUM_Disabled; \
	MENU trans8_Press_ALARM_SUM_page; \
	COMMAND trans8_Press_ALARM_SUM_read

#define USE_TRANS8_PRESS_MANDATORY_A \
	USE_TRANS8_PRESS_MANDATORY_BOTH; \
	MENU trans8_Press_Simple_Dialog_Mandatory_A; \
	MENU trans8_Press_Tab_s_mandatory_A; \
	MENU trans8_Press_Tab_m_mandatory_A

#define USE_TRANS8_PRESS_MANDATORY_B \
	USE_TRANS8_PRESS_MANDATORY_BOTH; \
	VARIABLE trans8_Press_SENSOR_VALUE; \
	MENU trans8_Press_SENSOR_VALUE_page; \
	COMMAND trans8_Press_SENSOR_VALUE_read; \
	VARIABLE trans8_Press_SENSOR_HI_LIM; \
	MENU trans8_Press_SENSOR_HI_LIM_page; \
	COMMAND trans8_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans8_Press_SENSOR_LO_LIM; \
	MENU trans8_Press_SENSOR_LO_LIM_page; \
	COMMAND trans8_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans8_Press_CAL_POINT_HI; \
	MENU trans8_Press_CAL_POINT_HI_page; \
	COMMAND trans8_Press_CAL_POINT_HI_read; \
	COMMAND trans8_Press_CAL_POINT_HI_write; \
	VARIABLE trans8_Press_CAL_POINT_LO; \
	MENU trans8_Press_CAL_POINT_LO_page; \
	COMMAND trans8_Press_CAL_POINT_LO_read; \
	COMMAND trans8_Press_CAL_POINT_LO_write; \
	VARIABLE trans8_Press_CAL_MIN_SPAN; \
	MENU trans8_Press_CAL_MIN_SPAN_page; \
	COMMAND trans8_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans8_Press_SENSOR_UNIT; \
	MENU trans8_Press_SENSOR_UNIT_page; \
	COMMAND trans8_Press_SENSOR_UNIT_read; \
	COMMAND trans8_Press_SENSOR_UNIT_write; \
	COLLECTION trans8_Press_TRIMMED_VALUE; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans8_Press_TRIMMED_VALUE_page; \
	COMMAND trans8_Press_TRIMMED_VALUE_read; \
	VARIABLE trans8_Press_SENSOR_TYPE; \
	MENU trans8_Press_SENSOR_TYPE_page; \
	COMMAND trans8_Press_SENSOR_TYPE_read; \
	VARIABLE trans8_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans8_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans8_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans8_Press_PRIMARY_VALUE; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans8_Press_PRIMARY_VALUE_page; \
	COMMAND trans8_Press_PRIMARY_VALUE_read; \
	VARIABLE trans8_Press_PRIMARY_VALUE_UNIT; \
	MENU trans8_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans8_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans8_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans8_Press_PRIMARY_VALUE_TYPE; \
	MENU trans8_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans8_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans8_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans8_Press_LIN_TYPE; \
	MENU trans8_Press_LIN_TYPE_page; \
	COMMAND trans8_Press_LIN_TYPE_read; \
	COMMAND trans8_Press_LIN_TYPE_write; \
	COLLECTION trans8_Press_VIEW_1; \
	MENU trans8_Press_VIEW_1_page; \
	MENU trans8_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans8_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans8_Press_Sensor_unit_1; \
	MENU trans8_Press_Tab_s_mandatory_B; \
	MENU trans8_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans8_Press_Tab_s_input_table_mandatory_B; \
	MENU trans8_Press_Tab_m_mandatory_B; \
	MENU trans8_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans8_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS8_PRESS_OPTIONAL_BOTH \
	VARIABLE trans8_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans8_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans8_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans8_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans8_Press_SENSOR_FILL_FLUID; \
	MENU trans8_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans8_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans8_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans8_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans8_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans8_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans8_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans8_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans8_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans8_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans8_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans8_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans8_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans8_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans8_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans8_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans8_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans8_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans8_Press_TEMPERATURE; \
	VARIABLE trans8_Press_TEMPERATURE_Value; \
	VARIABLE trans8_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans8_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans8_Press_TEMPERATURE_Status_Limit; \
	MENU trans8_Press_TEMPERATURE_page; \
	COMMAND trans8_Press_TEMPERATURE_read; \
	VARIABLE trans8_Press_TEMPERATURE_UNIT; \
	MENU trans8_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans8_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans8_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans8_Press_SECONDARY_VALUE_1; \
	VARIABLE trans8_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans8_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans8_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans8_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans8_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans8_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans8_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans8_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans8_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans8_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans8_Press_SECONDARY_VALUE_2; \
	VARIABLE trans8_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans8_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans8_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans8_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans8_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans8_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans8_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans8_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans8_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans8_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans8_Press_SCALE_IN; \
	VARIABLE trans8_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans8_Press_SCALE_IN_Lower_Value; \
	MENU trans8_Press_SCALE_IN_page; \
	COMMAND trans8_Press_SCALE_IN_read; \
	COMMAND trans8_Press_SCALE_IN_write; \
	COLLECTION trans8_Press_SCALE_OUT; \
	VARIABLE trans8_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans8_Press_SCALE_OUT_Lower_Value; \
	MENU trans8_Press_SCALE_OUT_page; \
	COMMAND trans8_Press_SCALE_OUT_read; \
	COMMAND trans8_Press_SCALE_OUT_write; \
	VARIABLE trans8_Press_LOW_FLOW_CUT_OFF; \
	MENU trans8_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans8_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans8_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans8_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans8_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans8_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans8_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans8_Press_TAB_ACTUAL_NUMBER; \
	MENU trans8_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans8_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans8_Press_TAB_ENTRY; \
	MENU trans8_Press_TAB_ENTRY_page; \
	COMMAND trans8_Press_TAB_ENTRY_read; \
	COMMAND trans8_Press_TAB_ENTRY_write; \
	VARIABLE trans8_Press_TAB_MAX_NUMBER; \
	MENU trans8_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans8_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans8_Press_TAB_MIN_NUMBER; \
	MENU trans8_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans8_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans8_Press_TAB_OP_CODE; \
	MENU trans8_Press_TAB_OP_CODE_page; \
	COMMAND trans8_Press_TAB_OP_CODE_read; \
	COMMAND trans8_Press_TAB_OP_CODE_write; \
	VARIABLE trans8_Press_TAB_STATUS; \
	MENU trans8_Press_TAB_STATUS_page; \
	COMMAND trans8_Press_TAB_STATUS_read; \
	COLLECTION trans8_Press_TAB_X_Y_VALUE; \
	VARIABLE trans8_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans8_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans8_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans8_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans8_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans8_Press_MAX_SENSOR_VALUE; \
	MENU trans8_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans8_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans8_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans8_Press_MIN_SENSOR_VALUE; \
	MENU trans8_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans8_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans8_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans8_Press_MAX_TEMPERATURE; \
	MENU trans8_Press_MAX_TEMPERATURE_page; \
	COMMAND trans8_Press_MAX_TEMPERATURE_read; \
	COMMAND trans8_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans8_Press_MIN_TEMPERATURE; \
	MENU trans8_Press_MIN_TEMPERATURE_page; \
	COMMAND trans8_Press_MIN_TEMPERATURE_read; \
	COMMAND trans8_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans8_Press_VIEW_2; \
	MENU trans8_Press_VIEW_2_page; \
	COLLECTION trans8_Press_VIEW_3; \
	MENU trans8_Press_VIEW_3_page; \
	UNIT trans8_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans8_Press_Sensor_unit_2; \
	UNIT trans8_Press_Temperature_unit; \
	UNIT trans8_Press_Secondary_Value_1_unit; \
	UNIT trans8_Press_Secondary_Value_2_unit

#define USE_TRANS8_PRESS_OPTIONAL_A \
	USE_TRANS8_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans8_Press_SENSOR_VALUE; \
	MENU trans8_Press_SENSOR_VALUE_page; \
	COMMAND trans8_Press_SENSOR_VALUE_read; \
	VARIABLE trans8_Press_SENSOR_HI_LIM; \
	MENU trans8_Press_SENSOR_HI_LIM_page; \
	COMMAND trans8_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans8_Press_SENSOR_LO_LIM; \
	MENU trans8_Press_SENSOR_LO_LIM_page; \
	COMMAND trans8_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans8_Press_CAL_POINT_HI; \
	MENU trans8_Press_CAL_POINT_HI_page; \
	COMMAND trans8_Press_CAL_POINT_HI_read; \
	COMMAND trans8_Press_CAL_POINT_HI_write; \
	VARIABLE trans8_Press_CAL_POINT_LO; \
	MENU trans8_Press_CAL_POINT_LO_page; \
	COMMAND trans8_Press_CAL_POINT_LO_read; \
	COMMAND trans8_Press_CAL_POINT_LO_write; \
	VARIABLE trans8_Press_CAL_MIN_SPAN; \
	MENU trans8_Press_CAL_MIN_SPAN_page; \
	COMMAND trans8_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans8_Press_SENSOR_UNIT; \
	MENU trans8_Press_SENSOR_UNIT_page; \
	COMMAND trans8_Press_SENSOR_UNIT_read; \
	COMMAND trans8_Press_SENSOR_UNIT_write; \
	COLLECTION trans8_Press_TRIMMED_VALUE; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans8_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans8_Press_TRIMMED_VALUE_page; \
	COMMAND trans8_Press_TRIMMED_VALUE_read; \
	VARIABLE trans8_Press_SENSOR_TYPE; \
	MENU trans8_Press_SENSOR_TYPE_page; \
	COMMAND trans8_Press_SENSOR_TYPE_read; \
	VARIABLE trans8_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans8_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans8_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans8_Press_PRIMARY_VALUE; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans8_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans8_Press_PRIMARY_VALUE_page; \
	COMMAND trans8_Press_PRIMARY_VALUE_read; \
	VARIABLE trans8_Press_PRIMARY_VALUE_UNIT; \
	MENU trans8_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans8_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans8_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans8_Press_PRIMARY_VALUE_TYPE; \
	MENU trans8_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans8_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans8_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans8_Press_LIN_TYPE; \
	MENU trans8_Press_LIN_TYPE_page; \
	COMMAND trans8_Press_LIN_TYPE_read; \
	COMMAND trans8_Press_LIN_TYPE_write; \
	COLLECTION trans8_Press_VIEW_1; \
	MENU trans8_Press_VIEW_1_page; \
	MENU trans8_Press_Simple_Dialog_Optional_A; \
	UNIT trans8_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans8_Press_Sensor_unit_1

#define USE_TRANS8_PRESS_OPTIONAL_B \
	USE_TRANS8_PRESS_OPTIONAL_BOTH; \
	MENU trans8_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans8_Press_)
#define USE_TRANS8_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans8_Press_)
#define USE_TRANS8_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans8_Press_)
#define USE_TRANS8_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans8_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_PRESS_MANDATORY_BOTH \
	BLOCK trans9_Press_block; \
	COLLECTION trans9_Press_BLOCK_OBJECT; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Press_BLOCK_OBJECT_page; \
	COMMAND trans9_Press_BLOCK_OBJECT_read; \
	VARIABLE trans9_Press_ST_REV; \
	MENU trans9_Press_ST_REV_page; \
	COMMAND trans9_Press_ST_REV_read; \
	VARIABLE trans9_Press_TAG_DESC; \
	MENU trans9_Press_TAG_DESC_page; \
	COMMAND trans9_Press_TAG_DESC_read; \
	COMMAND trans9_Press_TAG_DESC_write; \
	VARIABLE trans9_Press_STRATEGY; \
	MENU trans9_Press_STRATEGY_page; \
	COMMAND trans9_Press_STRATEGY_read; \
	COMMAND trans9_Press_STRATEGY_write; \
	VARIABLE trans9_Press_ALERT_KEY; \
	MENU trans9_Press_ALERT_KEY_page; \
	COMMAND trans9_Press_ALERT_KEY_read; \
	COMMAND trans9_Press_ALERT_KEY_write; \
	VARIABLE trans9_Press_TARGET_MODE; \
	MENU trans9_Press_TARGET_MODE_page; \
	COMMAND trans9_Press_TARGET_MODE_read; \
	COMMAND trans9_Press_TARGET_MODE_write; \
	COLLECTION trans9_Press_MODE_BLK; \
	VARIABLE trans9_Press_MODE_BLK_Actual; \
	VARIABLE trans9_Press_MODE_BLK_Permitted; \
	VARIABLE trans9_Press_MODE_BLK_Normal; \
	MENU trans9_Press_MODE_BLK_page; \
	COMMAND trans9_Press_MODE_BLK_read; \
	COLLECTION trans9_Press_ALARM_SUM; \
	VARIABLE trans9_Press_ALARM_SUM_Current; \
	VARIABLE trans9_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Press_ALARM_SUM_Unreported; \
	VARIABLE trans9_Press_ALARM_SUM_Disabled; \
	MENU trans9_Press_ALARM_SUM_page; \
	COMMAND trans9_Press_ALARM_SUM_read

#define USE_TRANS9_PRESS_MANDATORY_A \
	USE_TRANS9_PRESS_MANDATORY_BOTH; \
	MENU trans9_Press_Simple_Dialog_Mandatory_A; \
	MENU trans9_Press_Tab_s_mandatory_A; \
	MENU trans9_Press_Tab_m_mandatory_A

#define USE_TRANS9_PRESS_MANDATORY_B \
	USE_TRANS9_PRESS_MANDATORY_BOTH; \
	VARIABLE trans9_Press_SENSOR_VALUE; \
	MENU trans9_Press_SENSOR_VALUE_page; \
	COMMAND trans9_Press_SENSOR_VALUE_read; \
	VARIABLE trans9_Press_SENSOR_HI_LIM; \
	MENU trans9_Press_SENSOR_HI_LIM_page; \
	COMMAND trans9_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans9_Press_SENSOR_LO_LIM; \
	MENU trans9_Press_SENSOR_LO_LIM_page; \
	COMMAND trans9_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans9_Press_CAL_POINT_HI; \
	MENU trans9_Press_CAL_POINT_HI_page; \
	COMMAND trans9_Press_CAL_POINT_HI_read; \
	COMMAND trans9_Press_CAL_POINT_HI_write; \
	VARIABLE trans9_Press_CAL_POINT_LO; \
	MENU trans9_Press_CAL_POINT_LO_page; \
	COMMAND trans9_Press_CAL_POINT_LO_read; \
	COMMAND trans9_Press_CAL_POINT_LO_write; \
	VARIABLE trans9_Press_CAL_MIN_SPAN; \
	MENU trans9_Press_CAL_MIN_SPAN_page; \
	COMMAND trans9_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans9_Press_SENSOR_UNIT; \
	MENU trans9_Press_SENSOR_UNIT_page; \
	COMMAND trans9_Press_SENSOR_UNIT_read; \
	COMMAND trans9_Press_SENSOR_UNIT_write; \
	COLLECTION trans9_Press_TRIMMED_VALUE; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans9_Press_TRIMMED_VALUE_page; \
	COMMAND trans9_Press_TRIMMED_VALUE_read; \
	VARIABLE trans9_Press_SENSOR_TYPE; \
	MENU trans9_Press_SENSOR_TYPE_page; \
	COMMAND trans9_Press_SENSOR_TYPE_read; \
	VARIABLE trans9_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans9_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans9_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans9_Press_PRIMARY_VALUE; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans9_Press_PRIMARY_VALUE_page; \
	COMMAND trans9_Press_PRIMARY_VALUE_read; \
	VARIABLE trans9_Press_PRIMARY_VALUE_UNIT; \
	MENU trans9_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans9_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans9_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans9_Press_PRIMARY_VALUE_TYPE; \
	MENU trans9_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans9_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans9_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans9_Press_LIN_TYPE; \
	MENU trans9_Press_LIN_TYPE_page; \
	COMMAND trans9_Press_LIN_TYPE_read; \
	COMMAND trans9_Press_LIN_TYPE_write; \
	COLLECTION trans9_Press_VIEW_1; \
	MENU trans9_Press_VIEW_1_page; \
	MENU trans9_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans9_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans9_Press_Sensor_unit_1; \
	MENU trans9_Press_Tab_s_mandatory_B; \
	MENU trans9_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans9_Press_Tab_s_input_table_mandatory_B; \
	MENU trans9_Press_Tab_m_mandatory_B; \
	MENU trans9_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans9_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS9_PRESS_OPTIONAL_BOTH \
	VARIABLE trans9_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans9_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans9_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans9_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans9_Press_SENSOR_FILL_FLUID; \
	MENU trans9_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans9_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans9_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans9_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans9_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans9_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans9_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans9_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans9_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans9_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans9_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans9_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans9_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans9_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans9_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans9_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans9_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans9_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans9_Press_TEMPERATURE; \
	VARIABLE trans9_Press_TEMPERATURE_Value; \
	VARIABLE trans9_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans9_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans9_Press_TEMPERATURE_Status_Limit; \
	MENU trans9_Press_TEMPERATURE_page; \
	COMMAND trans9_Press_TEMPERATURE_read; \
	VARIABLE trans9_Press_TEMPERATURE_UNIT; \
	MENU trans9_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans9_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans9_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans9_Press_SECONDARY_VALUE_1; \
	VARIABLE trans9_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans9_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans9_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans9_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans9_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans9_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans9_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans9_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans9_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans9_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans9_Press_SECONDARY_VALUE_2; \
	VARIABLE trans9_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans9_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans9_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans9_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans9_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans9_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans9_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans9_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans9_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans9_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans9_Press_SCALE_IN; \
	VARIABLE trans9_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans9_Press_SCALE_IN_Lower_Value; \
	MENU trans9_Press_SCALE_IN_page; \
	COMMAND trans9_Press_SCALE_IN_read; \
	COMMAND trans9_Press_SCALE_IN_write; \
	COLLECTION trans9_Press_SCALE_OUT; \
	VARIABLE trans9_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans9_Press_SCALE_OUT_Lower_Value; \
	MENU trans9_Press_SCALE_OUT_page; \
	COMMAND trans9_Press_SCALE_OUT_read; \
	COMMAND trans9_Press_SCALE_OUT_write; \
	VARIABLE trans9_Press_LOW_FLOW_CUT_OFF; \
	MENU trans9_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans9_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans9_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans9_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans9_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans9_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans9_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans9_Press_TAB_ACTUAL_NUMBER; \
	MENU trans9_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans9_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans9_Press_TAB_ENTRY; \
	MENU trans9_Press_TAB_ENTRY_page; \
	COMMAND trans9_Press_TAB_ENTRY_read; \
	COMMAND trans9_Press_TAB_ENTRY_write; \
	VARIABLE trans9_Press_TAB_MAX_NUMBER; \
	MENU trans9_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans9_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans9_Press_TAB_MIN_NUMBER; \
	MENU trans9_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans9_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans9_Press_TAB_OP_CODE; \
	MENU trans9_Press_TAB_OP_CODE_page; \
	COMMAND trans9_Press_TAB_OP_CODE_read; \
	COMMAND trans9_Press_TAB_OP_CODE_write; \
	VARIABLE trans9_Press_TAB_STATUS; \
	MENU trans9_Press_TAB_STATUS_page; \
	COMMAND trans9_Press_TAB_STATUS_read; \
	COLLECTION trans9_Press_TAB_X_Y_VALUE; \
	VARIABLE trans9_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans9_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans9_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans9_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans9_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans9_Press_MAX_SENSOR_VALUE; \
	MENU trans9_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans9_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans9_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans9_Press_MIN_SENSOR_VALUE; \
	MENU trans9_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans9_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans9_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans9_Press_MAX_TEMPERATURE; \
	MENU trans9_Press_MAX_TEMPERATURE_page; \
	COMMAND trans9_Press_MAX_TEMPERATURE_read; \
	COMMAND trans9_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans9_Press_MIN_TEMPERATURE; \
	MENU trans9_Press_MIN_TEMPERATURE_page; \
	COMMAND trans9_Press_MIN_TEMPERATURE_read; \
	COMMAND trans9_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans9_Press_VIEW_2; \
	MENU trans9_Press_VIEW_2_page; \
	COLLECTION trans9_Press_VIEW_3; \
	MENU trans9_Press_VIEW_3_page; \
	UNIT trans9_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans9_Press_Sensor_unit_2; \
	UNIT trans9_Press_Temperature_unit; \
	UNIT trans9_Press_Secondary_Value_1_unit; \
	UNIT trans9_Press_Secondary_Value_2_unit

#define USE_TRANS9_PRESS_OPTIONAL_A \
	USE_TRANS9_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans9_Press_SENSOR_VALUE; \
	MENU trans9_Press_SENSOR_VALUE_page; \
	COMMAND trans9_Press_SENSOR_VALUE_read; \
	VARIABLE trans9_Press_SENSOR_HI_LIM; \
	MENU trans9_Press_SENSOR_HI_LIM_page; \
	COMMAND trans9_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans9_Press_SENSOR_LO_LIM; \
	MENU trans9_Press_SENSOR_LO_LIM_page; \
	COMMAND trans9_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans9_Press_CAL_POINT_HI; \
	MENU trans9_Press_CAL_POINT_HI_page; \
	COMMAND trans9_Press_CAL_POINT_HI_read; \
	COMMAND trans9_Press_CAL_POINT_HI_write; \
	VARIABLE trans9_Press_CAL_POINT_LO; \
	MENU trans9_Press_CAL_POINT_LO_page; \
	COMMAND trans9_Press_CAL_POINT_LO_read; \
	COMMAND trans9_Press_CAL_POINT_LO_write; \
	VARIABLE trans9_Press_CAL_MIN_SPAN; \
	MENU trans9_Press_CAL_MIN_SPAN_page; \
	COMMAND trans9_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans9_Press_SENSOR_UNIT; \
	MENU trans9_Press_SENSOR_UNIT_page; \
	COMMAND trans9_Press_SENSOR_UNIT_read; \
	COMMAND trans9_Press_SENSOR_UNIT_write; \
	COLLECTION trans9_Press_TRIMMED_VALUE; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans9_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans9_Press_TRIMMED_VALUE_page; \
	COMMAND trans9_Press_TRIMMED_VALUE_read; \
	VARIABLE trans9_Press_SENSOR_TYPE; \
	MENU trans9_Press_SENSOR_TYPE_page; \
	COMMAND trans9_Press_SENSOR_TYPE_read; \
	VARIABLE trans9_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans9_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans9_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans9_Press_PRIMARY_VALUE; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans9_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans9_Press_PRIMARY_VALUE_page; \
	COMMAND trans9_Press_PRIMARY_VALUE_read; \
	VARIABLE trans9_Press_PRIMARY_VALUE_UNIT; \
	MENU trans9_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans9_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans9_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans9_Press_PRIMARY_VALUE_TYPE; \
	MENU trans9_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans9_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans9_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans9_Press_LIN_TYPE; \
	MENU trans9_Press_LIN_TYPE_page; \
	COMMAND trans9_Press_LIN_TYPE_read; \
	COMMAND trans9_Press_LIN_TYPE_write; \
	COLLECTION trans9_Press_VIEW_1; \
	MENU trans9_Press_VIEW_1_page; \
	MENU trans9_Press_Simple_Dialog_Optional_A; \
	UNIT trans9_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans9_Press_Sensor_unit_1

#define USE_TRANS9_PRESS_OPTIONAL_B \
	USE_TRANS9_PRESS_OPTIONAL_BOTH; \
	MENU trans9_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans9_Press_)
#define USE_TRANS9_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans9_Press_)
#define USE_TRANS9_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans9_Press_)
#define USE_TRANS9_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans9_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_PRESS_MANDATORY_BOTH \
	BLOCK trans10_Press_block; \
	COLLECTION trans10_Press_BLOCK_OBJECT; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Press_BLOCK_OBJECT_page; \
	COMMAND trans10_Press_BLOCK_OBJECT_read; \
	VARIABLE trans10_Press_ST_REV; \
	MENU trans10_Press_ST_REV_page; \
	COMMAND trans10_Press_ST_REV_read; \
	VARIABLE trans10_Press_TAG_DESC; \
	MENU trans10_Press_TAG_DESC_page; \
	COMMAND trans10_Press_TAG_DESC_read; \
	COMMAND trans10_Press_TAG_DESC_write; \
	VARIABLE trans10_Press_STRATEGY; \
	MENU trans10_Press_STRATEGY_page; \
	COMMAND trans10_Press_STRATEGY_read; \
	COMMAND trans10_Press_STRATEGY_write; \
	VARIABLE trans10_Press_ALERT_KEY; \
	MENU trans10_Press_ALERT_KEY_page; \
	COMMAND trans10_Press_ALERT_KEY_read; \
	COMMAND trans10_Press_ALERT_KEY_write; \
	VARIABLE trans10_Press_TARGET_MODE; \
	MENU trans10_Press_TARGET_MODE_page; \
	COMMAND trans10_Press_TARGET_MODE_read; \
	COMMAND trans10_Press_TARGET_MODE_write; \
	COLLECTION trans10_Press_MODE_BLK; \
	VARIABLE trans10_Press_MODE_BLK_Actual; \
	VARIABLE trans10_Press_MODE_BLK_Permitted; \
	VARIABLE trans10_Press_MODE_BLK_Normal; \
	MENU trans10_Press_MODE_BLK_page; \
	COMMAND trans10_Press_MODE_BLK_read; \
	COLLECTION trans10_Press_ALARM_SUM; \
	VARIABLE trans10_Press_ALARM_SUM_Current; \
	VARIABLE trans10_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Press_ALARM_SUM_Unreported; \
	VARIABLE trans10_Press_ALARM_SUM_Disabled; \
	MENU trans10_Press_ALARM_SUM_page; \
	COMMAND trans10_Press_ALARM_SUM_read

#define USE_TRANS10_PRESS_MANDATORY_A \
	USE_TRANS10_PRESS_MANDATORY_BOTH; \
	MENU trans10_Press_Simple_Dialog_Mandatory_A; \
	MENU trans10_Press_Tab_s_mandatory_A; \
	MENU trans10_Press_Tab_m_mandatory_A

#define USE_TRANS10_PRESS_MANDATORY_B \
	USE_TRANS10_PRESS_MANDATORY_BOTH; \
	VARIABLE trans10_Press_SENSOR_VALUE; \
	MENU trans10_Press_SENSOR_VALUE_page; \
	COMMAND trans10_Press_SENSOR_VALUE_read; \
	VARIABLE trans10_Press_SENSOR_HI_LIM; \
	MENU trans10_Press_SENSOR_HI_LIM_page; \
	COMMAND trans10_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans10_Press_SENSOR_LO_LIM; \
	MENU trans10_Press_SENSOR_LO_LIM_page; \
	COMMAND trans10_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans10_Press_CAL_POINT_HI; \
	MENU trans10_Press_CAL_POINT_HI_page; \
	COMMAND trans10_Press_CAL_POINT_HI_read; \
	COMMAND trans10_Press_CAL_POINT_HI_write; \
	VARIABLE trans10_Press_CAL_POINT_LO; \
	MENU trans10_Press_CAL_POINT_LO_page; \
	COMMAND trans10_Press_CAL_POINT_LO_read; \
	COMMAND trans10_Press_CAL_POINT_LO_write; \
	VARIABLE trans10_Press_CAL_MIN_SPAN; \
	MENU trans10_Press_CAL_MIN_SPAN_page; \
	COMMAND trans10_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans10_Press_SENSOR_UNIT; \
	MENU trans10_Press_SENSOR_UNIT_page; \
	COMMAND trans10_Press_SENSOR_UNIT_read; \
	COMMAND trans10_Press_SENSOR_UNIT_write; \
	COLLECTION trans10_Press_TRIMMED_VALUE; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans10_Press_TRIMMED_VALUE_page; \
	COMMAND trans10_Press_TRIMMED_VALUE_read; \
	VARIABLE trans10_Press_SENSOR_TYPE; \
	MENU trans10_Press_SENSOR_TYPE_page; \
	COMMAND trans10_Press_SENSOR_TYPE_read; \
	VARIABLE trans10_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans10_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans10_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans10_Press_PRIMARY_VALUE; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans10_Press_PRIMARY_VALUE_page; \
	COMMAND trans10_Press_PRIMARY_VALUE_read; \
	VARIABLE trans10_Press_PRIMARY_VALUE_UNIT; \
	MENU trans10_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans10_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans10_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans10_Press_PRIMARY_VALUE_TYPE; \
	MENU trans10_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans10_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans10_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans10_Press_LIN_TYPE; \
	MENU trans10_Press_LIN_TYPE_page; \
	COMMAND trans10_Press_LIN_TYPE_read; \
	COMMAND trans10_Press_LIN_TYPE_write; \
	COLLECTION trans10_Press_VIEW_1; \
	MENU trans10_Press_VIEW_1_page; \
	MENU trans10_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans10_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans10_Press_Sensor_unit_1; \
	MENU trans10_Press_Tab_s_mandatory_B; \
	MENU trans10_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans10_Press_Tab_s_input_table_mandatory_B; \
	MENU trans10_Press_Tab_m_mandatory_B; \
	MENU trans10_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans10_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS10_PRESS_OPTIONAL_BOTH \
	VARIABLE trans10_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans10_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans10_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans10_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans10_Press_SENSOR_FILL_FLUID; \
	MENU trans10_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans10_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans10_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans10_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans10_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans10_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans10_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans10_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans10_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans10_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans10_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans10_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans10_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans10_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans10_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans10_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans10_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans10_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans10_Press_TEMPERATURE; \
	VARIABLE trans10_Press_TEMPERATURE_Value; \
	VARIABLE trans10_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans10_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans10_Press_TEMPERATURE_Status_Limit; \
	MENU trans10_Press_TEMPERATURE_page; \
	COMMAND trans10_Press_TEMPERATURE_read; \
	VARIABLE trans10_Press_TEMPERATURE_UNIT; \
	MENU trans10_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans10_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans10_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans10_Press_SECONDARY_VALUE_1; \
	VARIABLE trans10_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans10_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans10_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans10_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans10_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans10_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans10_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans10_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans10_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans10_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans10_Press_SECONDARY_VALUE_2; \
	VARIABLE trans10_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans10_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans10_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans10_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans10_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans10_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans10_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans10_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans10_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans10_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans10_Press_SCALE_IN; \
	VARIABLE trans10_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans10_Press_SCALE_IN_Lower_Value; \
	MENU trans10_Press_SCALE_IN_page; \
	COMMAND trans10_Press_SCALE_IN_read; \
	COMMAND trans10_Press_SCALE_IN_write; \
	COLLECTION trans10_Press_SCALE_OUT; \
	VARIABLE trans10_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans10_Press_SCALE_OUT_Lower_Value; \
	MENU trans10_Press_SCALE_OUT_page; \
	COMMAND trans10_Press_SCALE_OUT_read; \
	COMMAND trans10_Press_SCALE_OUT_write; \
	VARIABLE trans10_Press_LOW_FLOW_CUT_OFF; \
	MENU trans10_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans10_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans10_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans10_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans10_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans10_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans10_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans10_Press_TAB_ACTUAL_NUMBER; \
	MENU trans10_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans10_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans10_Press_TAB_ENTRY; \
	MENU trans10_Press_TAB_ENTRY_page; \
	COMMAND trans10_Press_TAB_ENTRY_read; \
	COMMAND trans10_Press_TAB_ENTRY_write; \
	VARIABLE trans10_Press_TAB_MAX_NUMBER; \
	MENU trans10_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans10_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans10_Press_TAB_MIN_NUMBER; \
	MENU trans10_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans10_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans10_Press_TAB_OP_CODE; \
	MENU trans10_Press_TAB_OP_CODE_page; \
	COMMAND trans10_Press_TAB_OP_CODE_read; \
	COMMAND trans10_Press_TAB_OP_CODE_write; \
	VARIABLE trans10_Press_TAB_STATUS; \
	MENU trans10_Press_TAB_STATUS_page; \
	COMMAND trans10_Press_TAB_STATUS_read; \
	COLLECTION trans10_Press_TAB_X_Y_VALUE; \
	VARIABLE trans10_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans10_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans10_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans10_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans10_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans10_Press_MAX_SENSOR_VALUE; \
	MENU trans10_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans10_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans10_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans10_Press_MIN_SENSOR_VALUE; \
	MENU trans10_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans10_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans10_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans10_Press_MAX_TEMPERATURE; \
	MENU trans10_Press_MAX_TEMPERATURE_page; \
	COMMAND trans10_Press_MAX_TEMPERATURE_read; \
	COMMAND trans10_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans10_Press_MIN_TEMPERATURE; \
	MENU trans10_Press_MIN_TEMPERATURE_page; \
	COMMAND trans10_Press_MIN_TEMPERATURE_read; \
	COMMAND trans10_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans10_Press_VIEW_2; \
	MENU trans10_Press_VIEW_2_page; \
	COLLECTION trans10_Press_VIEW_3; \
	MENU trans10_Press_VIEW_3_page; \
	UNIT trans10_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans10_Press_Sensor_unit_2; \
	UNIT trans10_Press_Temperature_unit; \
	UNIT trans10_Press_Secondary_Value_1_unit; \
	UNIT trans10_Press_Secondary_Value_2_unit

#define USE_TRANS10_PRESS_OPTIONAL_A \
	USE_TRANS10_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans10_Press_SENSOR_VALUE; \
	MENU trans10_Press_SENSOR_VALUE_page; \
	COMMAND trans10_Press_SENSOR_VALUE_read; \
	VARIABLE trans10_Press_SENSOR_HI_LIM; \
	MENU trans10_Press_SENSOR_HI_LIM_page; \
	COMMAND trans10_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans10_Press_SENSOR_LO_LIM; \
	MENU trans10_Press_SENSOR_LO_LIM_page; \
	COMMAND trans10_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans10_Press_CAL_POINT_HI; \
	MENU trans10_Press_CAL_POINT_HI_page; \
	COMMAND trans10_Press_CAL_POINT_HI_read; \
	COMMAND trans10_Press_CAL_POINT_HI_write; \
	VARIABLE trans10_Press_CAL_POINT_LO; \
	MENU trans10_Press_CAL_POINT_LO_page; \
	COMMAND trans10_Press_CAL_POINT_LO_read; \
	COMMAND trans10_Press_CAL_POINT_LO_write; \
	VARIABLE trans10_Press_CAL_MIN_SPAN; \
	MENU trans10_Press_CAL_MIN_SPAN_page; \
	COMMAND trans10_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans10_Press_SENSOR_UNIT; \
	MENU trans10_Press_SENSOR_UNIT_page; \
	COMMAND trans10_Press_SENSOR_UNIT_read; \
	COMMAND trans10_Press_SENSOR_UNIT_write; \
	COLLECTION trans10_Press_TRIMMED_VALUE; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans10_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans10_Press_TRIMMED_VALUE_page; \
	COMMAND trans10_Press_TRIMMED_VALUE_read; \
	VARIABLE trans10_Press_SENSOR_TYPE; \
	MENU trans10_Press_SENSOR_TYPE_page; \
	COMMAND trans10_Press_SENSOR_TYPE_read; \
	VARIABLE trans10_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans10_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans10_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans10_Press_PRIMARY_VALUE; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans10_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans10_Press_PRIMARY_VALUE_page; \
	COMMAND trans10_Press_PRIMARY_VALUE_read; \
	VARIABLE trans10_Press_PRIMARY_VALUE_UNIT; \
	MENU trans10_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans10_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans10_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans10_Press_PRIMARY_VALUE_TYPE; \
	MENU trans10_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans10_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans10_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans10_Press_LIN_TYPE; \
	MENU trans10_Press_LIN_TYPE_page; \
	COMMAND trans10_Press_LIN_TYPE_read; \
	COMMAND trans10_Press_LIN_TYPE_write; \
	COLLECTION trans10_Press_VIEW_1; \
	MENU trans10_Press_VIEW_1_page; \
	MENU trans10_Press_Simple_Dialog_Optional_A; \
	UNIT trans10_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans10_Press_Sensor_unit_1

#define USE_TRANS10_PRESS_OPTIONAL_B \
	USE_TRANS10_PRESS_OPTIONAL_BOTH; \
	MENU trans10_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans10_Press_)
#define USE_TRANS10_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans10_Press_)
#define USE_TRANS10_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans10_Press_)
#define USE_TRANS10_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans10_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_PRESS_MANDATORY_BOTH \
	BLOCK trans11_Press_block; \
	COLLECTION trans11_Press_BLOCK_OBJECT; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Press_BLOCK_OBJECT_page; \
	COMMAND trans11_Press_BLOCK_OBJECT_read; \
	VARIABLE trans11_Press_ST_REV; \
	MENU trans11_Press_ST_REV_page; \
	COMMAND trans11_Press_ST_REV_read; \
	VARIABLE trans11_Press_TAG_DESC; \
	MENU trans11_Press_TAG_DESC_page; \
	COMMAND trans11_Press_TAG_DESC_read; \
	COMMAND trans11_Press_TAG_DESC_write; \
	VARIABLE trans11_Press_STRATEGY; \
	MENU trans11_Press_STRATEGY_page; \
	COMMAND trans11_Press_STRATEGY_read; \
	COMMAND trans11_Press_STRATEGY_write; \
	VARIABLE trans11_Press_ALERT_KEY; \
	MENU trans11_Press_ALERT_KEY_page; \
	COMMAND trans11_Press_ALERT_KEY_read; \
	COMMAND trans11_Press_ALERT_KEY_write; \
	VARIABLE trans11_Press_TARGET_MODE; \
	MENU trans11_Press_TARGET_MODE_page; \
	COMMAND trans11_Press_TARGET_MODE_read; \
	COMMAND trans11_Press_TARGET_MODE_write; \
	COLLECTION trans11_Press_MODE_BLK; \
	VARIABLE trans11_Press_MODE_BLK_Actual; \
	VARIABLE trans11_Press_MODE_BLK_Permitted; \
	VARIABLE trans11_Press_MODE_BLK_Normal; \
	MENU trans11_Press_MODE_BLK_page; \
	COMMAND trans11_Press_MODE_BLK_read; \
	COLLECTION trans11_Press_ALARM_SUM; \
	VARIABLE trans11_Press_ALARM_SUM_Current; \
	VARIABLE trans11_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Press_ALARM_SUM_Unreported; \
	VARIABLE trans11_Press_ALARM_SUM_Disabled; \
	MENU trans11_Press_ALARM_SUM_page; \
	COMMAND trans11_Press_ALARM_SUM_read

#define USE_TRANS11_PRESS_MANDATORY_A \
	USE_TRANS11_PRESS_MANDATORY_BOTH; \
	MENU trans11_Press_Simple_Dialog_Mandatory_A; \
	MENU trans11_Press_Tab_s_mandatory_A; \
	MENU trans11_Press_Tab_m_mandatory_A

#define USE_TRANS11_PRESS_MANDATORY_B \
	USE_TRANS11_PRESS_MANDATORY_BOTH; \
	VARIABLE trans11_Press_SENSOR_VALUE; \
	MENU trans11_Press_SENSOR_VALUE_page; \
	COMMAND trans11_Press_SENSOR_VALUE_read; \
	VARIABLE trans11_Press_SENSOR_HI_LIM; \
	MENU trans11_Press_SENSOR_HI_LIM_page; \
	COMMAND trans11_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans11_Press_SENSOR_LO_LIM; \
	MENU trans11_Press_SENSOR_LO_LIM_page; \
	COMMAND trans11_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans11_Press_CAL_POINT_HI; \
	MENU trans11_Press_CAL_POINT_HI_page; \
	COMMAND trans11_Press_CAL_POINT_HI_read; \
	COMMAND trans11_Press_CAL_POINT_HI_write; \
	VARIABLE trans11_Press_CAL_POINT_LO; \
	MENU trans11_Press_CAL_POINT_LO_page; \
	COMMAND trans11_Press_CAL_POINT_LO_read; \
	COMMAND trans11_Press_CAL_POINT_LO_write; \
	VARIABLE trans11_Press_CAL_MIN_SPAN; \
	MENU trans11_Press_CAL_MIN_SPAN_page; \
	COMMAND trans11_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans11_Press_SENSOR_UNIT; \
	MENU trans11_Press_SENSOR_UNIT_page; \
	COMMAND trans11_Press_SENSOR_UNIT_read; \
	COMMAND trans11_Press_SENSOR_UNIT_write; \
	COLLECTION trans11_Press_TRIMMED_VALUE; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans11_Press_TRIMMED_VALUE_page; \
	COMMAND trans11_Press_TRIMMED_VALUE_read; \
	VARIABLE trans11_Press_SENSOR_TYPE; \
	MENU trans11_Press_SENSOR_TYPE_page; \
	COMMAND trans11_Press_SENSOR_TYPE_read; \
	VARIABLE trans11_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans11_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans11_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans11_Press_PRIMARY_VALUE; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans11_Press_PRIMARY_VALUE_page; \
	COMMAND trans11_Press_PRIMARY_VALUE_read; \
	VARIABLE trans11_Press_PRIMARY_VALUE_UNIT; \
	MENU trans11_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans11_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans11_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans11_Press_PRIMARY_VALUE_TYPE; \
	MENU trans11_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans11_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans11_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans11_Press_LIN_TYPE; \
	MENU trans11_Press_LIN_TYPE_page; \
	COMMAND trans11_Press_LIN_TYPE_read; \
	COMMAND trans11_Press_LIN_TYPE_write; \
	COLLECTION trans11_Press_VIEW_1; \
	MENU trans11_Press_VIEW_1_page; \
	MENU trans11_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans11_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans11_Press_Sensor_unit_1; \
	MENU trans11_Press_Tab_s_mandatory_B; \
	MENU trans11_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans11_Press_Tab_s_input_table_mandatory_B; \
	MENU trans11_Press_Tab_m_mandatory_B; \
	MENU trans11_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans11_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS11_PRESS_OPTIONAL_BOTH \
	VARIABLE trans11_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans11_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans11_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans11_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans11_Press_SENSOR_FILL_FLUID; \
	MENU trans11_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans11_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans11_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans11_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans11_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans11_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans11_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans11_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans11_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans11_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans11_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans11_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans11_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans11_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans11_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans11_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans11_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans11_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans11_Press_TEMPERATURE; \
	VARIABLE trans11_Press_TEMPERATURE_Value; \
	VARIABLE trans11_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans11_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans11_Press_TEMPERATURE_Status_Limit; \
	MENU trans11_Press_TEMPERATURE_page; \
	COMMAND trans11_Press_TEMPERATURE_read; \
	VARIABLE trans11_Press_TEMPERATURE_UNIT; \
	MENU trans11_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans11_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans11_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans11_Press_SECONDARY_VALUE_1; \
	VARIABLE trans11_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans11_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans11_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans11_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans11_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans11_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans11_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans11_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans11_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans11_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans11_Press_SECONDARY_VALUE_2; \
	VARIABLE trans11_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans11_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans11_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans11_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans11_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans11_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans11_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans11_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans11_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans11_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans11_Press_SCALE_IN; \
	VARIABLE trans11_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans11_Press_SCALE_IN_Lower_Value; \
	MENU trans11_Press_SCALE_IN_page; \
	COMMAND trans11_Press_SCALE_IN_read; \
	COMMAND trans11_Press_SCALE_IN_write; \
	COLLECTION trans11_Press_SCALE_OUT; \
	VARIABLE trans11_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans11_Press_SCALE_OUT_Lower_Value; \
	MENU trans11_Press_SCALE_OUT_page; \
	COMMAND trans11_Press_SCALE_OUT_read; \
	COMMAND trans11_Press_SCALE_OUT_write; \
	VARIABLE trans11_Press_LOW_FLOW_CUT_OFF; \
	MENU trans11_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans11_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans11_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans11_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans11_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans11_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans11_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans11_Press_TAB_ACTUAL_NUMBER; \
	MENU trans11_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans11_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans11_Press_TAB_ENTRY; \
	MENU trans11_Press_TAB_ENTRY_page; \
	COMMAND trans11_Press_TAB_ENTRY_read; \
	COMMAND trans11_Press_TAB_ENTRY_write; \
	VARIABLE trans11_Press_TAB_MAX_NUMBER; \
	MENU trans11_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans11_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans11_Press_TAB_MIN_NUMBER; \
	MENU trans11_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans11_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans11_Press_TAB_OP_CODE; \
	MENU trans11_Press_TAB_OP_CODE_page; \
	COMMAND trans11_Press_TAB_OP_CODE_read; \
	COMMAND trans11_Press_TAB_OP_CODE_write; \
	VARIABLE trans11_Press_TAB_STATUS; \
	MENU trans11_Press_TAB_STATUS_page; \
	COMMAND trans11_Press_TAB_STATUS_read; \
	COLLECTION trans11_Press_TAB_X_Y_VALUE; \
	VARIABLE trans11_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans11_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans11_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans11_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans11_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans11_Press_MAX_SENSOR_VALUE; \
	MENU trans11_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans11_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans11_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans11_Press_MIN_SENSOR_VALUE; \
	MENU trans11_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans11_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans11_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans11_Press_MAX_TEMPERATURE; \
	MENU trans11_Press_MAX_TEMPERATURE_page; \
	COMMAND trans11_Press_MAX_TEMPERATURE_read; \
	COMMAND trans11_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans11_Press_MIN_TEMPERATURE; \
	MENU trans11_Press_MIN_TEMPERATURE_page; \
	COMMAND trans11_Press_MIN_TEMPERATURE_read; \
	COMMAND trans11_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans11_Press_VIEW_2; \
	MENU trans11_Press_VIEW_2_page; \
	COLLECTION trans11_Press_VIEW_3; \
	MENU trans11_Press_VIEW_3_page; \
	UNIT trans11_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans11_Press_Sensor_unit_2; \
	UNIT trans11_Press_Temperature_unit; \
	UNIT trans11_Press_Secondary_Value_1_unit; \
	UNIT trans11_Press_Secondary_Value_2_unit

#define USE_TRANS11_PRESS_OPTIONAL_A \
	USE_TRANS11_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans11_Press_SENSOR_VALUE; \
	MENU trans11_Press_SENSOR_VALUE_page; \
	COMMAND trans11_Press_SENSOR_VALUE_read; \
	VARIABLE trans11_Press_SENSOR_HI_LIM; \
	MENU trans11_Press_SENSOR_HI_LIM_page; \
	COMMAND trans11_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans11_Press_SENSOR_LO_LIM; \
	MENU trans11_Press_SENSOR_LO_LIM_page; \
	COMMAND trans11_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans11_Press_CAL_POINT_HI; \
	MENU trans11_Press_CAL_POINT_HI_page; \
	COMMAND trans11_Press_CAL_POINT_HI_read; \
	COMMAND trans11_Press_CAL_POINT_HI_write; \
	VARIABLE trans11_Press_CAL_POINT_LO; \
	MENU trans11_Press_CAL_POINT_LO_page; \
	COMMAND trans11_Press_CAL_POINT_LO_read; \
	COMMAND trans11_Press_CAL_POINT_LO_write; \
	VARIABLE trans11_Press_CAL_MIN_SPAN; \
	MENU trans11_Press_CAL_MIN_SPAN_page; \
	COMMAND trans11_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans11_Press_SENSOR_UNIT; \
	MENU trans11_Press_SENSOR_UNIT_page; \
	COMMAND trans11_Press_SENSOR_UNIT_read; \
	COMMAND trans11_Press_SENSOR_UNIT_write; \
	COLLECTION trans11_Press_TRIMMED_VALUE; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans11_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans11_Press_TRIMMED_VALUE_page; \
	COMMAND trans11_Press_TRIMMED_VALUE_read; \
	VARIABLE trans11_Press_SENSOR_TYPE; \
	MENU trans11_Press_SENSOR_TYPE_page; \
	COMMAND trans11_Press_SENSOR_TYPE_read; \
	VARIABLE trans11_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans11_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans11_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans11_Press_PRIMARY_VALUE; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans11_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans11_Press_PRIMARY_VALUE_page; \
	COMMAND trans11_Press_PRIMARY_VALUE_read; \
	VARIABLE trans11_Press_PRIMARY_VALUE_UNIT; \
	MENU trans11_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans11_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans11_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans11_Press_PRIMARY_VALUE_TYPE; \
	MENU trans11_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans11_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans11_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans11_Press_LIN_TYPE; \
	MENU trans11_Press_LIN_TYPE_page; \
	COMMAND trans11_Press_LIN_TYPE_read; \
	COMMAND trans11_Press_LIN_TYPE_write; \
	COLLECTION trans11_Press_VIEW_1; \
	MENU trans11_Press_VIEW_1_page; \
	MENU trans11_Press_Simple_Dialog_Optional_A; \
	UNIT trans11_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans11_Press_Sensor_unit_1

#define USE_TRANS11_PRESS_OPTIONAL_B \
	USE_TRANS11_PRESS_OPTIONAL_BOTH; \
	MENU trans11_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans11_Press_)
#define USE_TRANS11_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans11_Press_)
#define USE_TRANS11_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans11_Press_)
#define USE_TRANS11_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans11_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_PRESS_MANDATORY_BOTH \
	BLOCK trans12_Press_block; \
	COLLECTION trans12_Press_BLOCK_OBJECT; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Press_BLOCK_OBJECT_page; \
	COMMAND trans12_Press_BLOCK_OBJECT_read; \
	VARIABLE trans12_Press_ST_REV; \
	MENU trans12_Press_ST_REV_page; \
	COMMAND trans12_Press_ST_REV_read; \
	VARIABLE trans12_Press_TAG_DESC; \
	MENU trans12_Press_TAG_DESC_page; \
	COMMAND trans12_Press_TAG_DESC_read; \
	COMMAND trans12_Press_TAG_DESC_write; \
	VARIABLE trans12_Press_STRATEGY; \
	MENU trans12_Press_STRATEGY_page; \
	COMMAND trans12_Press_STRATEGY_read; \
	COMMAND trans12_Press_STRATEGY_write; \
	VARIABLE trans12_Press_ALERT_KEY; \
	MENU trans12_Press_ALERT_KEY_page; \
	COMMAND trans12_Press_ALERT_KEY_read; \
	COMMAND trans12_Press_ALERT_KEY_write; \
	VARIABLE trans12_Press_TARGET_MODE; \
	MENU trans12_Press_TARGET_MODE_page; \
	COMMAND trans12_Press_TARGET_MODE_read; \
	COMMAND trans12_Press_TARGET_MODE_write; \
	COLLECTION trans12_Press_MODE_BLK; \
	VARIABLE trans12_Press_MODE_BLK_Actual; \
	VARIABLE trans12_Press_MODE_BLK_Permitted; \
	VARIABLE trans12_Press_MODE_BLK_Normal; \
	MENU trans12_Press_MODE_BLK_page; \
	COMMAND trans12_Press_MODE_BLK_read; \
	COLLECTION trans12_Press_ALARM_SUM; \
	VARIABLE trans12_Press_ALARM_SUM_Current; \
	VARIABLE trans12_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Press_ALARM_SUM_Unreported; \
	VARIABLE trans12_Press_ALARM_SUM_Disabled; \
	MENU trans12_Press_ALARM_SUM_page; \
	COMMAND trans12_Press_ALARM_SUM_read

#define USE_TRANS12_PRESS_MANDATORY_A \
	USE_TRANS12_PRESS_MANDATORY_BOTH; \
	MENU trans12_Press_Simple_Dialog_Mandatory_A; \
	MENU trans12_Press_Tab_s_mandatory_A; \
	MENU trans12_Press_Tab_m_mandatory_A

#define USE_TRANS12_PRESS_MANDATORY_B \
	USE_TRANS12_PRESS_MANDATORY_BOTH; \
	VARIABLE trans12_Press_SENSOR_VALUE; \
	MENU trans12_Press_SENSOR_VALUE_page; \
	COMMAND trans12_Press_SENSOR_VALUE_read; \
	VARIABLE trans12_Press_SENSOR_HI_LIM; \
	MENU trans12_Press_SENSOR_HI_LIM_page; \
	COMMAND trans12_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans12_Press_SENSOR_LO_LIM; \
	MENU trans12_Press_SENSOR_LO_LIM_page; \
	COMMAND trans12_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans12_Press_CAL_POINT_HI; \
	MENU trans12_Press_CAL_POINT_HI_page; \
	COMMAND trans12_Press_CAL_POINT_HI_read; \
	COMMAND trans12_Press_CAL_POINT_HI_write; \
	VARIABLE trans12_Press_CAL_POINT_LO; \
	MENU trans12_Press_CAL_POINT_LO_page; \
	COMMAND trans12_Press_CAL_POINT_LO_read; \
	COMMAND trans12_Press_CAL_POINT_LO_write; \
	VARIABLE trans12_Press_CAL_MIN_SPAN; \
	MENU trans12_Press_CAL_MIN_SPAN_page; \
	COMMAND trans12_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans12_Press_SENSOR_UNIT; \
	MENU trans12_Press_SENSOR_UNIT_page; \
	COMMAND trans12_Press_SENSOR_UNIT_read; \
	COMMAND trans12_Press_SENSOR_UNIT_write; \
	COLLECTION trans12_Press_TRIMMED_VALUE; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans12_Press_TRIMMED_VALUE_page; \
	COMMAND trans12_Press_TRIMMED_VALUE_read; \
	VARIABLE trans12_Press_SENSOR_TYPE; \
	MENU trans12_Press_SENSOR_TYPE_page; \
	COMMAND trans12_Press_SENSOR_TYPE_read; \
	VARIABLE trans12_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans12_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans12_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans12_Press_PRIMARY_VALUE; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans12_Press_PRIMARY_VALUE_page; \
	COMMAND trans12_Press_PRIMARY_VALUE_read; \
	VARIABLE trans12_Press_PRIMARY_VALUE_UNIT; \
	MENU trans12_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans12_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans12_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans12_Press_PRIMARY_VALUE_TYPE; \
	MENU trans12_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans12_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans12_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans12_Press_LIN_TYPE; \
	MENU trans12_Press_LIN_TYPE_page; \
	COMMAND trans12_Press_LIN_TYPE_read; \
	COMMAND trans12_Press_LIN_TYPE_write; \
	COLLECTION trans12_Press_VIEW_1; \
	MENU trans12_Press_VIEW_1_page; \
	MENU trans12_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans12_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans12_Press_Sensor_unit_1; \
	MENU trans12_Press_Tab_s_mandatory_B; \
	MENU trans12_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans12_Press_Tab_s_input_table_mandatory_B; \
	MENU trans12_Press_Tab_m_mandatory_B; \
	MENU trans12_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans12_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS12_PRESS_OPTIONAL_BOTH \
	VARIABLE trans12_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans12_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans12_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans12_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans12_Press_SENSOR_FILL_FLUID; \
	MENU trans12_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans12_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans12_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans12_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans12_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans12_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans12_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans12_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans12_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans12_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans12_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans12_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans12_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans12_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans12_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans12_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans12_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans12_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans12_Press_TEMPERATURE; \
	VARIABLE trans12_Press_TEMPERATURE_Value; \
	VARIABLE trans12_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans12_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans12_Press_TEMPERATURE_Status_Limit; \
	MENU trans12_Press_TEMPERATURE_page; \
	COMMAND trans12_Press_TEMPERATURE_read; \
	VARIABLE trans12_Press_TEMPERATURE_UNIT; \
	MENU trans12_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans12_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans12_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans12_Press_SECONDARY_VALUE_1; \
	VARIABLE trans12_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans12_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans12_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans12_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans12_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans12_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans12_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans12_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans12_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans12_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans12_Press_SECONDARY_VALUE_2; \
	VARIABLE trans12_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans12_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans12_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans12_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans12_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans12_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans12_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans12_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans12_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans12_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans12_Press_SCALE_IN; \
	VARIABLE trans12_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans12_Press_SCALE_IN_Lower_Value; \
	MENU trans12_Press_SCALE_IN_page; \
	COMMAND trans12_Press_SCALE_IN_read; \
	COMMAND trans12_Press_SCALE_IN_write; \
	COLLECTION trans12_Press_SCALE_OUT; \
	VARIABLE trans12_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans12_Press_SCALE_OUT_Lower_Value; \
	MENU trans12_Press_SCALE_OUT_page; \
	COMMAND trans12_Press_SCALE_OUT_read; \
	COMMAND trans12_Press_SCALE_OUT_write; \
	VARIABLE trans12_Press_LOW_FLOW_CUT_OFF; \
	MENU trans12_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans12_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans12_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans12_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans12_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans12_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans12_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans12_Press_TAB_ACTUAL_NUMBER; \
	MENU trans12_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans12_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans12_Press_TAB_ENTRY; \
	MENU trans12_Press_TAB_ENTRY_page; \
	COMMAND trans12_Press_TAB_ENTRY_read; \
	COMMAND trans12_Press_TAB_ENTRY_write; \
	VARIABLE trans12_Press_TAB_MAX_NUMBER; \
	MENU trans12_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans12_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans12_Press_TAB_MIN_NUMBER; \
	MENU trans12_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans12_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans12_Press_TAB_OP_CODE; \
	MENU trans12_Press_TAB_OP_CODE_page; \
	COMMAND trans12_Press_TAB_OP_CODE_read; \
	COMMAND trans12_Press_TAB_OP_CODE_write; \
	VARIABLE trans12_Press_TAB_STATUS; \
	MENU trans12_Press_TAB_STATUS_page; \
	COMMAND trans12_Press_TAB_STATUS_read; \
	COLLECTION trans12_Press_TAB_X_Y_VALUE; \
	VARIABLE trans12_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans12_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans12_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans12_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans12_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans12_Press_MAX_SENSOR_VALUE; \
	MENU trans12_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans12_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans12_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans12_Press_MIN_SENSOR_VALUE; \
	MENU trans12_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans12_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans12_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans12_Press_MAX_TEMPERATURE; \
	MENU trans12_Press_MAX_TEMPERATURE_page; \
	COMMAND trans12_Press_MAX_TEMPERATURE_read; \
	COMMAND trans12_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans12_Press_MIN_TEMPERATURE; \
	MENU trans12_Press_MIN_TEMPERATURE_page; \
	COMMAND trans12_Press_MIN_TEMPERATURE_read; \
	COMMAND trans12_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans12_Press_VIEW_2; \
	MENU trans12_Press_VIEW_2_page; \
	COLLECTION trans12_Press_VIEW_3; \
	MENU trans12_Press_VIEW_3_page; \
	UNIT trans12_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans12_Press_Sensor_unit_2; \
	UNIT trans12_Press_Temperature_unit; \
	UNIT trans12_Press_Secondary_Value_1_unit; \
	UNIT trans12_Press_Secondary_Value_2_unit

#define USE_TRANS12_PRESS_OPTIONAL_A \
	USE_TRANS12_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans12_Press_SENSOR_VALUE; \
	MENU trans12_Press_SENSOR_VALUE_page; \
	COMMAND trans12_Press_SENSOR_VALUE_read; \
	VARIABLE trans12_Press_SENSOR_HI_LIM; \
	MENU trans12_Press_SENSOR_HI_LIM_page; \
	COMMAND trans12_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans12_Press_SENSOR_LO_LIM; \
	MENU trans12_Press_SENSOR_LO_LIM_page; \
	COMMAND trans12_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans12_Press_CAL_POINT_HI; \
	MENU trans12_Press_CAL_POINT_HI_page; \
	COMMAND trans12_Press_CAL_POINT_HI_read; \
	COMMAND trans12_Press_CAL_POINT_HI_write; \
	VARIABLE trans12_Press_CAL_POINT_LO; \
	MENU trans12_Press_CAL_POINT_LO_page; \
	COMMAND trans12_Press_CAL_POINT_LO_read; \
	COMMAND trans12_Press_CAL_POINT_LO_write; \
	VARIABLE trans12_Press_CAL_MIN_SPAN; \
	MENU trans12_Press_CAL_MIN_SPAN_page; \
	COMMAND trans12_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans12_Press_SENSOR_UNIT; \
	MENU trans12_Press_SENSOR_UNIT_page; \
	COMMAND trans12_Press_SENSOR_UNIT_read; \
	COMMAND trans12_Press_SENSOR_UNIT_write; \
	COLLECTION trans12_Press_TRIMMED_VALUE; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans12_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans12_Press_TRIMMED_VALUE_page; \
	COMMAND trans12_Press_TRIMMED_VALUE_read; \
	VARIABLE trans12_Press_SENSOR_TYPE; \
	MENU trans12_Press_SENSOR_TYPE_page; \
	COMMAND trans12_Press_SENSOR_TYPE_read; \
	VARIABLE trans12_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans12_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans12_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans12_Press_PRIMARY_VALUE; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans12_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans12_Press_PRIMARY_VALUE_page; \
	COMMAND trans12_Press_PRIMARY_VALUE_read; \
	VARIABLE trans12_Press_PRIMARY_VALUE_UNIT; \
	MENU trans12_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans12_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans12_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans12_Press_PRIMARY_VALUE_TYPE; \
	MENU trans12_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans12_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans12_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans12_Press_LIN_TYPE; \
	MENU trans12_Press_LIN_TYPE_page; \
	COMMAND trans12_Press_LIN_TYPE_read; \
	COMMAND trans12_Press_LIN_TYPE_write; \
	COLLECTION trans12_Press_VIEW_1; \
	MENU trans12_Press_VIEW_1_page; \
	MENU trans12_Press_Simple_Dialog_Optional_A; \
	UNIT trans12_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans12_Press_Sensor_unit_1

#define USE_TRANS12_PRESS_OPTIONAL_B \
	USE_TRANS12_PRESS_OPTIONAL_BOTH; \
	MENU trans12_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans12_Press_)
#define USE_TRANS12_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans12_Press_)
#define USE_TRANS12_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans12_Press_)
#define USE_TRANS12_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans12_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_PRESS_MANDATORY_BOTH \
	BLOCK trans13_Press_block; \
	COLLECTION trans13_Press_BLOCK_OBJECT; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Press_BLOCK_OBJECT_page; \
	COMMAND trans13_Press_BLOCK_OBJECT_read; \
	VARIABLE trans13_Press_ST_REV; \
	MENU trans13_Press_ST_REV_page; \
	COMMAND trans13_Press_ST_REV_read; \
	VARIABLE trans13_Press_TAG_DESC; \
	MENU trans13_Press_TAG_DESC_page; \
	COMMAND trans13_Press_TAG_DESC_read; \
	COMMAND trans13_Press_TAG_DESC_write; \
	VARIABLE trans13_Press_STRATEGY; \
	MENU trans13_Press_STRATEGY_page; \
	COMMAND trans13_Press_STRATEGY_read; \
	COMMAND trans13_Press_STRATEGY_write; \
	VARIABLE trans13_Press_ALERT_KEY; \
	MENU trans13_Press_ALERT_KEY_page; \
	COMMAND trans13_Press_ALERT_KEY_read; \
	COMMAND trans13_Press_ALERT_KEY_write; \
	VARIABLE trans13_Press_TARGET_MODE; \
	MENU trans13_Press_TARGET_MODE_page; \
	COMMAND trans13_Press_TARGET_MODE_read; \
	COMMAND trans13_Press_TARGET_MODE_write; \
	COLLECTION trans13_Press_MODE_BLK; \
	VARIABLE trans13_Press_MODE_BLK_Actual; \
	VARIABLE trans13_Press_MODE_BLK_Permitted; \
	VARIABLE trans13_Press_MODE_BLK_Normal; \
	MENU trans13_Press_MODE_BLK_page; \
	COMMAND trans13_Press_MODE_BLK_read; \
	COLLECTION trans13_Press_ALARM_SUM; \
	VARIABLE trans13_Press_ALARM_SUM_Current; \
	VARIABLE trans13_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Press_ALARM_SUM_Unreported; \
	VARIABLE trans13_Press_ALARM_SUM_Disabled; \
	MENU trans13_Press_ALARM_SUM_page; \
	COMMAND trans13_Press_ALARM_SUM_read

#define USE_TRANS13_PRESS_MANDATORY_A \
	USE_TRANS13_PRESS_MANDATORY_BOTH; \
	MENU trans13_Press_Simple_Dialog_Mandatory_A; \
	MENU trans13_Press_Tab_s_mandatory_A; \
	MENU trans13_Press_Tab_m_mandatory_A

#define USE_TRANS13_PRESS_MANDATORY_B \
	USE_TRANS13_PRESS_MANDATORY_BOTH; \
	VARIABLE trans13_Press_SENSOR_VALUE; \
	MENU trans13_Press_SENSOR_VALUE_page; \
	COMMAND trans13_Press_SENSOR_VALUE_read; \
	VARIABLE trans13_Press_SENSOR_HI_LIM; \
	MENU trans13_Press_SENSOR_HI_LIM_page; \
	COMMAND trans13_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans13_Press_SENSOR_LO_LIM; \
	MENU trans13_Press_SENSOR_LO_LIM_page; \
	COMMAND trans13_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans13_Press_CAL_POINT_HI; \
	MENU trans13_Press_CAL_POINT_HI_page; \
	COMMAND trans13_Press_CAL_POINT_HI_read; \
	COMMAND trans13_Press_CAL_POINT_HI_write; \
	VARIABLE trans13_Press_CAL_POINT_LO; \
	MENU trans13_Press_CAL_POINT_LO_page; \
	COMMAND trans13_Press_CAL_POINT_LO_read; \
	COMMAND trans13_Press_CAL_POINT_LO_write; \
	VARIABLE trans13_Press_CAL_MIN_SPAN; \
	MENU trans13_Press_CAL_MIN_SPAN_page; \
	COMMAND trans13_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans13_Press_SENSOR_UNIT; \
	MENU trans13_Press_SENSOR_UNIT_page; \
	COMMAND trans13_Press_SENSOR_UNIT_read; \
	COMMAND trans13_Press_SENSOR_UNIT_write; \
	COLLECTION trans13_Press_TRIMMED_VALUE; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans13_Press_TRIMMED_VALUE_page; \
	COMMAND trans13_Press_TRIMMED_VALUE_read; \
	VARIABLE trans13_Press_SENSOR_TYPE; \
	MENU trans13_Press_SENSOR_TYPE_page; \
	COMMAND trans13_Press_SENSOR_TYPE_read; \
	VARIABLE trans13_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans13_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans13_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans13_Press_PRIMARY_VALUE; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans13_Press_PRIMARY_VALUE_page; \
	COMMAND trans13_Press_PRIMARY_VALUE_read; \
	VARIABLE trans13_Press_PRIMARY_VALUE_UNIT; \
	MENU trans13_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans13_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans13_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans13_Press_PRIMARY_VALUE_TYPE; \
	MENU trans13_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans13_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans13_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans13_Press_LIN_TYPE; \
	MENU trans13_Press_LIN_TYPE_page; \
	COMMAND trans13_Press_LIN_TYPE_read; \
	COMMAND trans13_Press_LIN_TYPE_write; \
	COLLECTION trans13_Press_VIEW_1; \
	MENU trans13_Press_VIEW_1_page; \
	MENU trans13_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans13_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans13_Press_Sensor_unit_1; \
	MENU trans13_Press_Tab_s_mandatory_B; \
	MENU trans13_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans13_Press_Tab_s_input_table_mandatory_B; \
	MENU trans13_Press_Tab_m_mandatory_B; \
	MENU trans13_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans13_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS13_PRESS_OPTIONAL_BOTH \
	VARIABLE trans13_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans13_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans13_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans13_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans13_Press_SENSOR_FILL_FLUID; \
	MENU trans13_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans13_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans13_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans13_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans13_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans13_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans13_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans13_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans13_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans13_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans13_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans13_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans13_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans13_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans13_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans13_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans13_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans13_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans13_Press_TEMPERATURE; \
	VARIABLE trans13_Press_TEMPERATURE_Value; \
	VARIABLE trans13_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans13_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans13_Press_TEMPERATURE_Status_Limit; \
	MENU trans13_Press_TEMPERATURE_page; \
	COMMAND trans13_Press_TEMPERATURE_read; \
	VARIABLE trans13_Press_TEMPERATURE_UNIT; \
	MENU trans13_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans13_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans13_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans13_Press_SECONDARY_VALUE_1; \
	VARIABLE trans13_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans13_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans13_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans13_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans13_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans13_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans13_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans13_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans13_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans13_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans13_Press_SECONDARY_VALUE_2; \
	VARIABLE trans13_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans13_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans13_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans13_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans13_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans13_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans13_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans13_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans13_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans13_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans13_Press_SCALE_IN; \
	VARIABLE trans13_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans13_Press_SCALE_IN_Lower_Value; \
	MENU trans13_Press_SCALE_IN_page; \
	COMMAND trans13_Press_SCALE_IN_read; \
	COMMAND trans13_Press_SCALE_IN_write; \
	COLLECTION trans13_Press_SCALE_OUT; \
	VARIABLE trans13_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans13_Press_SCALE_OUT_Lower_Value; \
	MENU trans13_Press_SCALE_OUT_page; \
	COMMAND trans13_Press_SCALE_OUT_read; \
	COMMAND trans13_Press_SCALE_OUT_write; \
	VARIABLE trans13_Press_LOW_FLOW_CUT_OFF; \
	MENU trans13_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans13_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans13_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans13_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans13_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans13_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans13_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans13_Press_TAB_ACTUAL_NUMBER; \
	MENU trans13_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans13_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans13_Press_TAB_ENTRY; \
	MENU trans13_Press_TAB_ENTRY_page; \
	COMMAND trans13_Press_TAB_ENTRY_read; \
	COMMAND trans13_Press_TAB_ENTRY_write; \
	VARIABLE trans13_Press_TAB_MAX_NUMBER; \
	MENU trans13_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans13_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans13_Press_TAB_MIN_NUMBER; \
	MENU trans13_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans13_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans13_Press_TAB_OP_CODE; \
	MENU trans13_Press_TAB_OP_CODE_page; \
	COMMAND trans13_Press_TAB_OP_CODE_read; \
	COMMAND trans13_Press_TAB_OP_CODE_write; \
	VARIABLE trans13_Press_TAB_STATUS; \
	MENU trans13_Press_TAB_STATUS_page; \
	COMMAND trans13_Press_TAB_STATUS_read; \
	COLLECTION trans13_Press_TAB_X_Y_VALUE; \
	VARIABLE trans13_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans13_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans13_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans13_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans13_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans13_Press_MAX_SENSOR_VALUE; \
	MENU trans13_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans13_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans13_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans13_Press_MIN_SENSOR_VALUE; \
	MENU trans13_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans13_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans13_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans13_Press_MAX_TEMPERATURE; \
	MENU trans13_Press_MAX_TEMPERATURE_page; \
	COMMAND trans13_Press_MAX_TEMPERATURE_read; \
	COMMAND trans13_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans13_Press_MIN_TEMPERATURE; \
	MENU trans13_Press_MIN_TEMPERATURE_page; \
	COMMAND trans13_Press_MIN_TEMPERATURE_read; \
	COMMAND trans13_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans13_Press_VIEW_2; \
	MENU trans13_Press_VIEW_2_page; \
	COLLECTION trans13_Press_VIEW_3; \
	MENU trans13_Press_VIEW_3_page; \
	UNIT trans13_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans13_Press_Sensor_unit_2; \
	UNIT trans13_Press_Temperature_unit; \
	UNIT trans13_Press_Secondary_Value_1_unit; \
	UNIT trans13_Press_Secondary_Value_2_unit

#define USE_TRANS13_PRESS_OPTIONAL_A \
	USE_TRANS13_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans13_Press_SENSOR_VALUE; \
	MENU trans13_Press_SENSOR_VALUE_page; \
	COMMAND trans13_Press_SENSOR_VALUE_read; \
	VARIABLE trans13_Press_SENSOR_HI_LIM; \
	MENU trans13_Press_SENSOR_HI_LIM_page; \
	COMMAND trans13_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans13_Press_SENSOR_LO_LIM; \
	MENU trans13_Press_SENSOR_LO_LIM_page; \
	COMMAND trans13_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans13_Press_CAL_POINT_HI; \
	MENU trans13_Press_CAL_POINT_HI_page; \
	COMMAND trans13_Press_CAL_POINT_HI_read; \
	COMMAND trans13_Press_CAL_POINT_HI_write; \
	VARIABLE trans13_Press_CAL_POINT_LO; \
	MENU trans13_Press_CAL_POINT_LO_page; \
	COMMAND trans13_Press_CAL_POINT_LO_read; \
	COMMAND trans13_Press_CAL_POINT_LO_write; \
	VARIABLE trans13_Press_CAL_MIN_SPAN; \
	MENU trans13_Press_CAL_MIN_SPAN_page; \
	COMMAND trans13_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans13_Press_SENSOR_UNIT; \
	MENU trans13_Press_SENSOR_UNIT_page; \
	COMMAND trans13_Press_SENSOR_UNIT_read; \
	COMMAND trans13_Press_SENSOR_UNIT_write; \
	COLLECTION trans13_Press_TRIMMED_VALUE; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans13_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans13_Press_TRIMMED_VALUE_page; \
	COMMAND trans13_Press_TRIMMED_VALUE_read; \
	VARIABLE trans13_Press_SENSOR_TYPE; \
	MENU trans13_Press_SENSOR_TYPE_page; \
	COMMAND trans13_Press_SENSOR_TYPE_read; \
	VARIABLE trans13_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans13_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans13_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans13_Press_PRIMARY_VALUE; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans13_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans13_Press_PRIMARY_VALUE_page; \
	COMMAND trans13_Press_PRIMARY_VALUE_read; \
	VARIABLE trans13_Press_PRIMARY_VALUE_UNIT; \
	MENU trans13_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans13_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans13_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans13_Press_PRIMARY_VALUE_TYPE; \
	MENU trans13_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans13_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans13_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans13_Press_LIN_TYPE; \
	MENU trans13_Press_LIN_TYPE_page; \
	COMMAND trans13_Press_LIN_TYPE_read; \
	COMMAND trans13_Press_LIN_TYPE_write; \
	COLLECTION trans13_Press_VIEW_1; \
	MENU trans13_Press_VIEW_1_page; \
	MENU trans13_Press_Simple_Dialog_Optional_A; \
	UNIT trans13_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans13_Press_Sensor_unit_1

#define USE_TRANS13_PRESS_OPTIONAL_B \
	USE_TRANS13_PRESS_OPTIONAL_BOTH; \
	MENU trans13_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans13_Press_)
#define USE_TRANS13_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans13_Press_)
#define USE_TRANS13_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans13_Press_)
#define USE_TRANS13_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans13_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_PRESS_MANDATORY_BOTH \
	BLOCK trans14_Press_block; \
	COLLECTION trans14_Press_BLOCK_OBJECT; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Press_BLOCK_OBJECT_page; \
	COMMAND trans14_Press_BLOCK_OBJECT_read; \
	VARIABLE trans14_Press_ST_REV; \
	MENU trans14_Press_ST_REV_page; \
	COMMAND trans14_Press_ST_REV_read; \
	VARIABLE trans14_Press_TAG_DESC; \
	MENU trans14_Press_TAG_DESC_page; \
	COMMAND trans14_Press_TAG_DESC_read; \
	COMMAND trans14_Press_TAG_DESC_write; \
	VARIABLE trans14_Press_STRATEGY; \
	MENU trans14_Press_STRATEGY_page; \
	COMMAND trans14_Press_STRATEGY_read; \
	COMMAND trans14_Press_STRATEGY_write; \
	VARIABLE trans14_Press_ALERT_KEY; \
	MENU trans14_Press_ALERT_KEY_page; \
	COMMAND trans14_Press_ALERT_KEY_read; \
	COMMAND trans14_Press_ALERT_KEY_write; \
	VARIABLE trans14_Press_TARGET_MODE; \
	MENU trans14_Press_TARGET_MODE_page; \
	COMMAND trans14_Press_TARGET_MODE_read; \
	COMMAND trans14_Press_TARGET_MODE_write; \
	COLLECTION trans14_Press_MODE_BLK; \
	VARIABLE trans14_Press_MODE_BLK_Actual; \
	VARIABLE trans14_Press_MODE_BLK_Permitted; \
	VARIABLE trans14_Press_MODE_BLK_Normal; \
	MENU trans14_Press_MODE_BLK_page; \
	COMMAND trans14_Press_MODE_BLK_read; \
	COLLECTION trans14_Press_ALARM_SUM; \
	VARIABLE trans14_Press_ALARM_SUM_Current; \
	VARIABLE trans14_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Press_ALARM_SUM_Unreported; \
	VARIABLE trans14_Press_ALARM_SUM_Disabled; \
	MENU trans14_Press_ALARM_SUM_page; \
	COMMAND trans14_Press_ALARM_SUM_read

#define USE_TRANS14_PRESS_MANDATORY_A \
	USE_TRANS14_PRESS_MANDATORY_BOTH; \
	MENU trans14_Press_Simple_Dialog_Mandatory_A; \
	MENU trans14_Press_Tab_s_mandatory_A; \
	MENU trans14_Press_Tab_m_mandatory_A

#define USE_TRANS14_PRESS_MANDATORY_B \
	USE_TRANS14_PRESS_MANDATORY_BOTH; \
	VARIABLE trans14_Press_SENSOR_VALUE; \
	MENU trans14_Press_SENSOR_VALUE_page; \
	COMMAND trans14_Press_SENSOR_VALUE_read; \
	VARIABLE trans14_Press_SENSOR_HI_LIM; \
	MENU trans14_Press_SENSOR_HI_LIM_page; \
	COMMAND trans14_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans14_Press_SENSOR_LO_LIM; \
	MENU trans14_Press_SENSOR_LO_LIM_page; \
	COMMAND trans14_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans14_Press_CAL_POINT_HI; \
	MENU trans14_Press_CAL_POINT_HI_page; \
	COMMAND trans14_Press_CAL_POINT_HI_read; \
	COMMAND trans14_Press_CAL_POINT_HI_write; \
	VARIABLE trans14_Press_CAL_POINT_LO; \
	MENU trans14_Press_CAL_POINT_LO_page; \
	COMMAND trans14_Press_CAL_POINT_LO_read; \
	COMMAND trans14_Press_CAL_POINT_LO_write; \
	VARIABLE trans14_Press_CAL_MIN_SPAN; \
	MENU trans14_Press_CAL_MIN_SPAN_page; \
	COMMAND trans14_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans14_Press_SENSOR_UNIT; \
	MENU trans14_Press_SENSOR_UNIT_page; \
	COMMAND trans14_Press_SENSOR_UNIT_read; \
	COMMAND trans14_Press_SENSOR_UNIT_write; \
	COLLECTION trans14_Press_TRIMMED_VALUE; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans14_Press_TRIMMED_VALUE_page; \
	COMMAND trans14_Press_TRIMMED_VALUE_read; \
	VARIABLE trans14_Press_SENSOR_TYPE; \
	MENU trans14_Press_SENSOR_TYPE_page; \
	COMMAND trans14_Press_SENSOR_TYPE_read; \
	VARIABLE trans14_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans14_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans14_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans14_Press_PRIMARY_VALUE; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans14_Press_PRIMARY_VALUE_page; \
	COMMAND trans14_Press_PRIMARY_VALUE_read; \
	VARIABLE trans14_Press_PRIMARY_VALUE_UNIT; \
	MENU trans14_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans14_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans14_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans14_Press_PRIMARY_VALUE_TYPE; \
	MENU trans14_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans14_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans14_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans14_Press_LIN_TYPE; \
	MENU trans14_Press_LIN_TYPE_page; \
	COMMAND trans14_Press_LIN_TYPE_read; \
	COMMAND trans14_Press_LIN_TYPE_write; \
	COLLECTION trans14_Press_VIEW_1; \
	MENU trans14_Press_VIEW_1_page; \
	MENU trans14_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans14_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans14_Press_Sensor_unit_1; \
	MENU trans14_Press_Tab_s_mandatory_B; \
	MENU trans14_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans14_Press_Tab_s_input_table_mandatory_B; \
	MENU trans14_Press_Tab_m_mandatory_B; \
	MENU trans14_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans14_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS14_PRESS_OPTIONAL_BOTH \
	VARIABLE trans14_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans14_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans14_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans14_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans14_Press_SENSOR_FILL_FLUID; \
	MENU trans14_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans14_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans14_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans14_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans14_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans14_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans14_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans14_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans14_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans14_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans14_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans14_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans14_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans14_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans14_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans14_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans14_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans14_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans14_Press_TEMPERATURE; \
	VARIABLE trans14_Press_TEMPERATURE_Value; \
	VARIABLE trans14_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans14_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans14_Press_TEMPERATURE_Status_Limit; \
	MENU trans14_Press_TEMPERATURE_page; \
	COMMAND trans14_Press_TEMPERATURE_read; \
	VARIABLE trans14_Press_TEMPERATURE_UNIT; \
	MENU trans14_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans14_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans14_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans14_Press_SECONDARY_VALUE_1; \
	VARIABLE trans14_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans14_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans14_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans14_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans14_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans14_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans14_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans14_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans14_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans14_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans14_Press_SECONDARY_VALUE_2; \
	VARIABLE trans14_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans14_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans14_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans14_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans14_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans14_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans14_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans14_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans14_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans14_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans14_Press_SCALE_IN; \
	VARIABLE trans14_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans14_Press_SCALE_IN_Lower_Value; \
	MENU trans14_Press_SCALE_IN_page; \
	COMMAND trans14_Press_SCALE_IN_read; \
	COMMAND trans14_Press_SCALE_IN_write; \
	COLLECTION trans14_Press_SCALE_OUT; \
	VARIABLE trans14_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans14_Press_SCALE_OUT_Lower_Value; \
	MENU trans14_Press_SCALE_OUT_page; \
	COMMAND trans14_Press_SCALE_OUT_read; \
	COMMAND trans14_Press_SCALE_OUT_write; \
	VARIABLE trans14_Press_LOW_FLOW_CUT_OFF; \
	MENU trans14_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans14_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans14_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans14_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans14_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans14_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans14_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans14_Press_TAB_ACTUAL_NUMBER; \
	MENU trans14_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans14_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans14_Press_TAB_ENTRY; \
	MENU trans14_Press_TAB_ENTRY_page; \
	COMMAND trans14_Press_TAB_ENTRY_read; \
	COMMAND trans14_Press_TAB_ENTRY_write; \
	VARIABLE trans14_Press_TAB_MAX_NUMBER; \
	MENU trans14_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans14_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans14_Press_TAB_MIN_NUMBER; \
	MENU trans14_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans14_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans14_Press_TAB_OP_CODE; \
	MENU trans14_Press_TAB_OP_CODE_page; \
	COMMAND trans14_Press_TAB_OP_CODE_read; \
	COMMAND trans14_Press_TAB_OP_CODE_write; \
	VARIABLE trans14_Press_TAB_STATUS; \
	MENU trans14_Press_TAB_STATUS_page; \
	COMMAND trans14_Press_TAB_STATUS_read; \
	COLLECTION trans14_Press_TAB_X_Y_VALUE; \
	VARIABLE trans14_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans14_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans14_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans14_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans14_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans14_Press_MAX_SENSOR_VALUE; \
	MENU trans14_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans14_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans14_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans14_Press_MIN_SENSOR_VALUE; \
	MENU trans14_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans14_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans14_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans14_Press_MAX_TEMPERATURE; \
	MENU trans14_Press_MAX_TEMPERATURE_page; \
	COMMAND trans14_Press_MAX_TEMPERATURE_read; \
	COMMAND trans14_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans14_Press_MIN_TEMPERATURE; \
	MENU trans14_Press_MIN_TEMPERATURE_page; \
	COMMAND trans14_Press_MIN_TEMPERATURE_read; \
	COMMAND trans14_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans14_Press_VIEW_2; \
	MENU trans14_Press_VIEW_2_page; \
	COLLECTION trans14_Press_VIEW_3; \
	MENU trans14_Press_VIEW_3_page; \
	UNIT trans14_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans14_Press_Sensor_unit_2; \
	UNIT trans14_Press_Temperature_unit; \
	UNIT trans14_Press_Secondary_Value_1_unit; \
	UNIT trans14_Press_Secondary_Value_2_unit

#define USE_TRANS14_PRESS_OPTIONAL_A \
	USE_TRANS14_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans14_Press_SENSOR_VALUE; \
	MENU trans14_Press_SENSOR_VALUE_page; \
	COMMAND trans14_Press_SENSOR_VALUE_read; \
	VARIABLE trans14_Press_SENSOR_HI_LIM; \
	MENU trans14_Press_SENSOR_HI_LIM_page; \
	COMMAND trans14_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans14_Press_SENSOR_LO_LIM; \
	MENU trans14_Press_SENSOR_LO_LIM_page; \
	COMMAND trans14_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans14_Press_CAL_POINT_HI; \
	MENU trans14_Press_CAL_POINT_HI_page; \
	COMMAND trans14_Press_CAL_POINT_HI_read; \
	COMMAND trans14_Press_CAL_POINT_HI_write; \
	VARIABLE trans14_Press_CAL_POINT_LO; \
	MENU trans14_Press_CAL_POINT_LO_page; \
	COMMAND trans14_Press_CAL_POINT_LO_read; \
	COMMAND trans14_Press_CAL_POINT_LO_write; \
	VARIABLE trans14_Press_CAL_MIN_SPAN; \
	MENU trans14_Press_CAL_MIN_SPAN_page; \
	COMMAND trans14_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans14_Press_SENSOR_UNIT; \
	MENU trans14_Press_SENSOR_UNIT_page; \
	COMMAND trans14_Press_SENSOR_UNIT_read; \
	COMMAND trans14_Press_SENSOR_UNIT_write; \
	COLLECTION trans14_Press_TRIMMED_VALUE; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans14_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans14_Press_TRIMMED_VALUE_page; \
	COMMAND trans14_Press_TRIMMED_VALUE_read; \
	VARIABLE trans14_Press_SENSOR_TYPE; \
	MENU trans14_Press_SENSOR_TYPE_page; \
	COMMAND trans14_Press_SENSOR_TYPE_read; \
	VARIABLE trans14_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans14_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans14_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans14_Press_PRIMARY_VALUE; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans14_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans14_Press_PRIMARY_VALUE_page; \
	COMMAND trans14_Press_PRIMARY_VALUE_read; \
	VARIABLE trans14_Press_PRIMARY_VALUE_UNIT; \
	MENU trans14_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans14_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans14_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans14_Press_PRIMARY_VALUE_TYPE; \
	MENU trans14_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans14_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans14_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans14_Press_LIN_TYPE; \
	MENU trans14_Press_LIN_TYPE_page; \
	COMMAND trans14_Press_LIN_TYPE_read; \
	COMMAND trans14_Press_LIN_TYPE_write; \
	COLLECTION trans14_Press_VIEW_1; \
	MENU trans14_Press_VIEW_1_page; \
	MENU trans14_Press_Simple_Dialog_Optional_A; \
	UNIT trans14_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans14_Press_Sensor_unit_1

#define USE_TRANS14_PRESS_OPTIONAL_B \
	USE_TRANS14_PRESS_OPTIONAL_BOTH; \
	MENU trans14_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans14_Press_)
#define USE_TRANS14_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans14_Press_)
#define USE_TRANS14_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans14_Press_)
#define USE_TRANS14_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans14_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_PRESS_MANDATORY_BOTH \
	BLOCK trans15_Press_block; \
	COLLECTION trans15_Press_BLOCK_OBJECT; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Press_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Press_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Press_BLOCK_OBJECT_page; \
	COMMAND trans15_Press_BLOCK_OBJECT_read; \
	VARIABLE trans15_Press_ST_REV; \
	MENU trans15_Press_ST_REV_page; \
	COMMAND trans15_Press_ST_REV_read; \
	VARIABLE trans15_Press_TAG_DESC; \
	MENU trans15_Press_TAG_DESC_page; \
	COMMAND trans15_Press_TAG_DESC_read; \
	COMMAND trans15_Press_TAG_DESC_write; \
	VARIABLE trans15_Press_STRATEGY; \
	MENU trans15_Press_STRATEGY_page; \
	COMMAND trans15_Press_STRATEGY_read; \
	COMMAND trans15_Press_STRATEGY_write; \
	VARIABLE trans15_Press_ALERT_KEY; \
	MENU trans15_Press_ALERT_KEY_page; \
	COMMAND trans15_Press_ALERT_KEY_read; \
	COMMAND trans15_Press_ALERT_KEY_write; \
	VARIABLE trans15_Press_TARGET_MODE; \
	MENU trans15_Press_TARGET_MODE_page; \
	COMMAND trans15_Press_TARGET_MODE_read; \
	COMMAND trans15_Press_TARGET_MODE_write; \
	COLLECTION trans15_Press_MODE_BLK; \
	VARIABLE trans15_Press_MODE_BLK_Actual; \
	VARIABLE trans15_Press_MODE_BLK_Permitted; \
	VARIABLE trans15_Press_MODE_BLK_Normal; \
	MENU trans15_Press_MODE_BLK_page; \
	COMMAND trans15_Press_MODE_BLK_read; \
	COLLECTION trans15_Press_ALARM_SUM; \
	VARIABLE trans15_Press_ALARM_SUM_Current; \
	VARIABLE trans15_Press_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Press_ALARM_SUM_Unreported; \
	VARIABLE trans15_Press_ALARM_SUM_Disabled; \
	MENU trans15_Press_ALARM_SUM_page; \
	COMMAND trans15_Press_ALARM_SUM_read

#define USE_TRANS15_PRESS_MANDATORY_A \
	USE_TRANS15_PRESS_MANDATORY_BOTH; \
	MENU trans15_Press_Simple_Dialog_Mandatory_A; \
	MENU trans15_Press_Tab_s_mandatory_A; \
	MENU trans15_Press_Tab_m_mandatory_A

#define USE_TRANS15_PRESS_MANDATORY_B \
	USE_TRANS15_PRESS_MANDATORY_BOTH; \
	VARIABLE trans15_Press_SENSOR_VALUE; \
	MENU trans15_Press_SENSOR_VALUE_page; \
	COMMAND trans15_Press_SENSOR_VALUE_read; \
	VARIABLE trans15_Press_SENSOR_HI_LIM; \
	MENU trans15_Press_SENSOR_HI_LIM_page; \
	COMMAND trans15_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans15_Press_SENSOR_LO_LIM; \
	MENU trans15_Press_SENSOR_LO_LIM_page; \
	COMMAND trans15_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans15_Press_CAL_POINT_HI; \
	MENU trans15_Press_CAL_POINT_HI_page; \
	COMMAND trans15_Press_CAL_POINT_HI_read; \
	COMMAND trans15_Press_CAL_POINT_HI_write; \
	VARIABLE trans15_Press_CAL_POINT_LO; \
	MENU trans15_Press_CAL_POINT_LO_page; \
	COMMAND trans15_Press_CAL_POINT_LO_read; \
	COMMAND trans15_Press_CAL_POINT_LO_write; \
	VARIABLE trans15_Press_CAL_MIN_SPAN; \
	MENU trans15_Press_CAL_MIN_SPAN_page; \
	COMMAND trans15_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans15_Press_SENSOR_UNIT; \
	MENU trans15_Press_SENSOR_UNIT_page; \
	COMMAND trans15_Press_SENSOR_UNIT_read; \
	COMMAND trans15_Press_SENSOR_UNIT_write; \
	COLLECTION trans15_Press_TRIMMED_VALUE; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans15_Press_TRIMMED_VALUE_page; \
	COMMAND trans15_Press_TRIMMED_VALUE_read; \
	VARIABLE trans15_Press_SENSOR_TYPE; \
	MENU trans15_Press_SENSOR_TYPE_page; \
	COMMAND trans15_Press_SENSOR_TYPE_read; \
	VARIABLE trans15_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans15_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans15_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans15_Press_PRIMARY_VALUE; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans15_Press_PRIMARY_VALUE_page; \
	COMMAND trans15_Press_PRIMARY_VALUE_read; \
	VARIABLE trans15_Press_PRIMARY_VALUE_UNIT; \
	MENU trans15_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans15_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans15_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans15_Press_PRIMARY_VALUE_TYPE; \
	MENU trans15_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans15_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans15_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans15_Press_LIN_TYPE; \
	MENU trans15_Press_LIN_TYPE_page; \
	COMMAND trans15_Press_LIN_TYPE_read; \
	COMMAND trans15_Press_LIN_TYPE_write; \
	COLLECTION trans15_Press_VIEW_1; \
	MENU trans15_Press_VIEW_1_page; \
	MENU trans15_Press_Simple_Dialog_Mandatory_B; \
	UNIT trans15_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans15_Press_Sensor_unit_1; \
	MENU trans15_Press_Tab_s_mandatory_B; \
	MENU trans15_Press_Tab_s_input_meassurelimit_mandatory_B; \
	MENU trans15_Press_Tab_s_input_table_mandatory_B; \
	MENU trans15_Press_Tab_m_mandatory_B; \
	MENU trans15_Press_Tab_m_input_meassurelimit_mandatory_B; \
	MENU trans15_Press_Tab_m_input_table_mandatory_B

#define USE_TRANS15_PRESS_OPTIONAL_BOTH \
	VARIABLE trans15_Press_SENSOR_DIAPHRAGM_MATERIAL; \
	MENU trans15_Press_SENSOR_DIAPHRAGM_MATERIAL_page; \
	COMMAND trans15_Press_SENSOR_DIAPHRAGM_MATERIAL_read; \
	COMMAND trans15_Press_SENSOR_DIAPHRAGM_MATERIAL_write; \
	VARIABLE trans15_Press_SENSOR_FILL_FLUID; \
	MENU trans15_Press_SENSOR_FILL_FLUID_page; \
	COMMAND trans15_Press_SENSOR_FILL_FLUID_read; \
	COMMAND trans15_Press_SENSOR_FILL_FLUID_write; \
	VARIABLE trans15_Press_SENSOR_MAX_STATIC_PRESSURE; \
	MENU trans15_Press_SENSOR_MAX_STATIC_PRESSURE_page; \
	COMMAND trans15_Press_SENSOR_MAX_STATIC_PRESSURE_read; \
	VARIABLE trans15_Press_SENSOR_O_RING_MATERIAL; \
	MENU trans15_Press_SENSOR_O_RING_MATERIAL_page; \
	COMMAND trans15_Press_SENSOR_O_RING_MATERIAL_read; \
	COMMAND trans15_Press_SENSOR_O_RING_MATERIAL_write; \
	VARIABLE trans15_Press_PROCESS_CONNECTION_TYPE; \
	MENU trans15_Press_PROCESS_CONNECTION_TYPE_page; \
	COMMAND trans15_Press_PROCESS_CONNECTION_TYPE_read; \
	COMMAND trans15_Press_PROCESS_CONNECTION_TYPE_write; \
	VARIABLE trans15_Press_PROCESS_CONNECTION_MATERIAL; \
	MENU trans15_Press_PROCESS_CONNECTION_MATERIAL_page; \
	COMMAND trans15_Press_PROCESS_CONNECTION_MATERIAL_read; \
	COMMAND trans15_Press_PROCESS_CONNECTION_MATERIAL_write; \
	COLLECTION trans15_Press_TEMPERATURE; \
	VARIABLE trans15_Press_TEMPERATURE_Value; \
	VARIABLE trans15_Press_TEMPERATURE_Status_Condensed; \
	VARIABLE trans15_Press_TEMPERATURE_Status_Quality; \
	VARIABLE trans15_Press_TEMPERATURE_Status_Limit; \
	MENU trans15_Press_TEMPERATURE_page; \
	COMMAND trans15_Press_TEMPERATURE_read; \
	VARIABLE trans15_Press_TEMPERATURE_UNIT; \
	MENU trans15_Press_TEMPERATURE_UNIT_page; \
	COMMAND trans15_Press_TEMPERATURE_UNIT_read; \
	COMMAND trans15_Press_TEMPERATURE_UNIT_write; \
	COLLECTION trans15_Press_SECONDARY_VALUE_1; \
	VARIABLE trans15_Press_SECONDARY_VALUE_1_Value; \
	VARIABLE trans15_Press_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans15_Press_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans15_Press_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans15_Press_SECONDARY_VALUE_1_page; \
	COMMAND trans15_Press_SECONDARY_VALUE_1_read; \
	VARIABLE trans15_Press_SECONDARY_VALUE_1_UNIT; \
	MENU trans15_Press_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans15_Press_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans15_Press_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans15_Press_SECONDARY_VALUE_2; \
	VARIABLE trans15_Press_SECONDARY_VALUE_2_Value; \
	VARIABLE trans15_Press_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans15_Press_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans15_Press_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans15_Press_SECONDARY_VALUE_2_page; \
	COMMAND trans15_Press_SECONDARY_VALUE_2_read; \
	VARIABLE trans15_Press_SECONDARY_VALUE_2_UNIT; \
	MENU trans15_Press_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans15_Press_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans15_Press_SECONDARY_VALUE_2_UNIT_write; \
	COLLECTION trans15_Press_SCALE_IN; \
	VARIABLE trans15_Press_SCALE_IN_Upper_Value; \
	VARIABLE trans15_Press_SCALE_IN_Lower_Value; \
	MENU trans15_Press_SCALE_IN_page; \
	COMMAND trans15_Press_SCALE_IN_read; \
	COMMAND trans15_Press_SCALE_IN_write; \
	COLLECTION trans15_Press_SCALE_OUT; \
	VARIABLE trans15_Press_SCALE_OUT_Upper_Value; \
	VARIABLE trans15_Press_SCALE_OUT_Lower_Value; \
	MENU trans15_Press_SCALE_OUT_page; \
	COMMAND trans15_Press_SCALE_OUT_read; \
	COMMAND trans15_Press_SCALE_OUT_write; \
	VARIABLE trans15_Press_LOW_FLOW_CUT_OFF; \
	MENU trans15_Press_LOW_FLOW_CUT_OFF_page; \
	COMMAND trans15_Press_LOW_FLOW_CUT_OFF_read; \
	COMMAND trans15_Press_LOW_FLOW_CUT_OFF_write; \
	VARIABLE trans15_Press_FLOW_LIN_SQRT_POINT; \
	MENU trans15_Press_FLOW_LIN_SQRT_POINT_page; \
	COMMAND trans15_Press_FLOW_LIN_SQRT_POINT_read; \
	COMMAND trans15_Press_FLOW_LIN_SQRT_POINT_write; \
	VARIABLE trans15_Press_TAB_ACTUAL_NUMBER; \
	MENU trans15_Press_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans15_Press_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans15_Press_TAB_ENTRY; \
	MENU trans15_Press_TAB_ENTRY_page; \
	COMMAND trans15_Press_TAB_ENTRY_read; \
	COMMAND trans15_Press_TAB_ENTRY_write; \
	VARIABLE trans15_Press_TAB_MAX_NUMBER; \
	MENU trans15_Press_TAB_MAX_NUMBER_page; \
	COMMAND trans15_Press_TAB_MAX_NUMBER_read; \
	VARIABLE trans15_Press_TAB_MIN_NUMBER; \
	MENU trans15_Press_TAB_MIN_NUMBER_page; \
	COMMAND trans15_Press_TAB_MIN_NUMBER_read; \
	VARIABLE trans15_Press_TAB_OP_CODE; \
	MENU trans15_Press_TAB_OP_CODE_page; \
	COMMAND trans15_Press_TAB_OP_CODE_read; \
	COMMAND trans15_Press_TAB_OP_CODE_write; \
	VARIABLE trans15_Press_TAB_STATUS; \
	MENU trans15_Press_TAB_STATUS_page; \
	COMMAND trans15_Press_TAB_STATUS_read; \
	COLLECTION trans15_Press_TAB_X_Y_VALUE; \
	VARIABLE trans15_Press_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans15_Press_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans15_Press_TAB_X_Y_VALUE_page; \
	COMMAND trans15_Press_TAB_X_Y_VALUE_read; \
	COMMAND trans15_Press_TAB_X_Y_VALUE_write; \
	VARIABLE trans15_Press_MAX_SENSOR_VALUE; \
	MENU trans15_Press_MAX_SENSOR_VALUE_page; \
	COMMAND trans15_Press_MAX_SENSOR_VALUE_read; \
	COMMAND trans15_Press_MAX_SENSOR_VALUE_write; \
	VARIABLE trans15_Press_MIN_SENSOR_VALUE; \
	MENU trans15_Press_MIN_SENSOR_VALUE_page; \
	COMMAND trans15_Press_MIN_SENSOR_VALUE_read; \
	COMMAND trans15_Press_MIN_SENSOR_VALUE_write; \
	VARIABLE trans15_Press_MAX_TEMPERATURE; \
	MENU trans15_Press_MAX_TEMPERATURE_page; \
	COMMAND trans15_Press_MAX_TEMPERATURE_read; \
	COMMAND trans15_Press_MAX_TEMPERATURE_write; \
	VARIABLE trans15_Press_MIN_TEMPERATURE; \
	MENU trans15_Press_MIN_TEMPERATURE_page; \
	COMMAND trans15_Press_MIN_TEMPERATURE_read; \
	COMMAND trans15_Press_MIN_TEMPERATURE_write; \
	COLLECTION trans15_Press_VIEW_2; \
	MENU trans15_Press_VIEW_2_page; \
	COLLECTION trans15_Press_VIEW_3; \
	MENU trans15_Press_VIEW_3_page; \
	UNIT trans15_Press_PRIMARY_VALUE_UNIT_unit_2; \
	UNIT trans15_Press_Sensor_unit_2; \
	UNIT trans15_Press_Temperature_unit; \
	UNIT trans15_Press_Secondary_Value_1_unit; \
	UNIT trans15_Press_Secondary_Value_2_unit

#define USE_TRANS15_PRESS_OPTIONAL_A \
	USE_TRANS15_PRESS_OPTIONAL_BOTH; \
	VARIABLE trans15_Press_SENSOR_VALUE; \
	MENU trans15_Press_SENSOR_VALUE_page; \
	COMMAND trans15_Press_SENSOR_VALUE_read; \
	VARIABLE trans15_Press_SENSOR_HI_LIM; \
	MENU trans15_Press_SENSOR_HI_LIM_page; \
	COMMAND trans15_Press_SENSOR_HI_LIM_read; \
	VARIABLE trans15_Press_SENSOR_LO_LIM; \
	MENU trans15_Press_SENSOR_LO_LIM_page; \
	COMMAND trans15_Press_SENSOR_LO_LIM_read; \
	VARIABLE trans15_Press_CAL_POINT_HI; \
	MENU trans15_Press_CAL_POINT_HI_page; \
	COMMAND trans15_Press_CAL_POINT_HI_read; \
	COMMAND trans15_Press_CAL_POINT_HI_write; \
	VARIABLE trans15_Press_CAL_POINT_LO; \
	MENU trans15_Press_CAL_POINT_LO_page; \
	COMMAND trans15_Press_CAL_POINT_LO_read; \
	COMMAND trans15_Press_CAL_POINT_LO_write; \
	VARIABLE trans15_Press_CAL_MIN_SPAN; \
	MENU trans15_Press_CAL_MIN_SPAN_page; \
	COMMAND trans15_Press_CAL_MIN_SPAN_read; \
	VARIABLE trans15_Press_SENSOR_UNIT; \
	MENU trans15_Press_SENSOR_UNIT_page; \
	COMMAND trans15_Press_SENSOR_UNIT_read; \
	COMMAND trans15_Press_SENSOR_UNIT_write; \
	COLLECTION trans15_Press_TRIMMED_VALUE; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Value; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Status_Condensed; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Status_Quality; \
	VARIABLE trans15_Press_TRIMMED_VALUE_Status_Limit; \
	MENU trans15_Press_TRIMMED_VALUE_page; \
	COMMAND trans15_Press_TRIMMED_VALUE_read; \
	VARIABLE trans15_Press_SENSOR_TYPE; \
	MENU trans15_Press_SENSOR_TYPE_page; \
	COMMAND trans15_Press_SENSOR_TYPE_read; \
	VARIABLE trans15_Press_SENSOR_SERIAL_NUMBER; \
	MENU trans15_Press_SENSOR_SERIAL_NUMBER_page; \
	COMMAND trans15_Press_SENSOR_SERIAL_NUMBER_read; \
	COLLECTION trans15_Press_PRIMARY_VALUE; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Value; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans15_Press_PRIMARY_VALUE_Status_Limit; \
	MENU trans15_Press_PRIMARY_VALUE_page; \
	COMMAND trans15_Press_PRIMARY_VALUE_read; \
	VARIABLE trans15_Press_PRIMARY_VALUE_UNIT; \
	MENU trans15_Press_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans15_Press_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans15_Press_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans15_Press_PRIMARY_VALUE_TYPE; \
	MENU trans15_Press_PRIMARY_VALUE_TYPE_page; \
	COMMAND trans15_Press_PRIMARY_VALUE_TYPE_read; \
	COMMAND trans15_Press_PRIMARY_VALUE_TYPE_write; \
	VARIABLE trans15_Press_LIN_TYPE; \
	MENU trans15_Press_LIN_TYPE_page; \
	COMMAND trans15_Press_LIN_TYPE_read; \
	COMMAND trans15_Press_LIN_TYPE_write; \
	COLLECTION trans15_Press_VIEW_1; \
	MENU trans15_Press_VIEW_1_page; \
	MENU trans15_Press_Simple_Dialog_Optional_A; \
	UNIT trans15_Press_PRIMARY_VALUE_UNIT_unit_1; \
	UNIT trans15_Press_Sensor_unit_1

#define USE_TRANS15_PRESS_OPTIONAL_B \
	USE_TRANS15_PRESS_OPTIONAL_BOTH; \
	MENU trans15_Press_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_PRESS_MANDATORY_A USE_TRANS_PRESS_MANDATORY_A(trans15_Press_)
#define USE_TRANS15_PRESS_MANDATORY_B USE_TRANS_PRESS_MANDATORY_B(trans15_Press_)
#define USE_TRANS15_PRESS_OPTIONAL_A  USE_TRANS_PRESS_OPTIONAL_A(trans15_Press_)
#define USE_TRANS15_PRESS_OPTIONAL_B  USE_TRANS_PRESS_OPTIONAL_B(trans15_Press_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC1_AI_MANDATORY_BOTH \
	BLOCK func1_AI_block; \
	COLLECTION func1_AI_BLOCK_OBJECT; \
	VARIABLE func1_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func1_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func1_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func1_AI_BLOCK_OBJECT_Class; \
	VARIABLE func1_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func1_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func1_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func1_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func1_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func1_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func1_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func1_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func1_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func1_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func1_AI_BLOCK_OBJECT_page; \
	COMMAND func1_AI_BLOCK_OBJECT_read; \
	VARIABLE func1_AI_ST_REV; \
	MENU func1_AI_ST_REV_page; \
	COMMAND func1_AI_ST_REV_read; \
	VARIABLE func1_AI_TAG_DESC; \
	MENU func1_AI_TAG_DESC_page; \
	COMMAND func1_AI_TAG_DESC_read; \
	COMMAND func1_AI_TAG_DESC_write; \
	VARIABLE func1_AI_STRATEGY; \
	MENU func1_AI_STRATEGY_page; \
	COMMAND func1_AI_STRATEGY_read; \
	COMMAND func1_AI_STRATEGY_write; \
	VARIABLE func1_AI_ALERT_KEY; \
	MENU func1_AI_ALERT_KEY_page; \
	COMMAND func1_AI_ALERT_KEY_read; \
	COMMAND func1_AI_ALERT_KEY_write; \
	VARIABLE func1_AI_TARGET_MODE; \
	MENU func1_AI_TARGET_MODE_page; \
	COMMAND func1_AI_TARGET_MODE_read; \
	COMMAND func1_AI_TARGET_MODE_write; \
	COLLECTION func1_AI_MODE_BLK; \
	VARIABLE func1_AI_MODE_BLK_Actual; \
	VARIABLE func1_AI_MODE_BLK_Permitted; \
	VARIABLE func1_AI_MODE_BLK_Normal; \
	MENU func1_AI_MODE_BLK_page; \
	COMMAND func1_AI_MODE_BLK_read; \
	COLLECTION func1_AI_ALARM_SUM; \
	VARIABLE func1_AI_ALARM_SUM_Current; \
	VARIABLE func1_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func1_AI_ALARM_SUM_Unreported; \
	VARIABLE func1_AI_ALARM_SUM_Disabled; \
	MENU func1_AI_ALARM_SUM_page; \
	COMMAND func1_AI_ALARM_SUM_read; \
	COLLECTION func1_AI_BATCH; \
	VARIABLE func1_AI_BATCH_Batch_ID; \
	VARIABLE func1_AI_BATCH_Rup; \
	VARIABLE func1_AI_BATCH_Operation; \
	VARIABLE func1_AI_BATCH_Phase; \
	MENU func1_AI_BATCH_page; \
	COMMAND func1_AI_BATCH_read; \
	COMMAND func1_AI_BATCH_write; \
	COLLECTION func1_AI_OUT; \
	VARIABLE func1_AI_OUT_Value; \
	VARIABLE func1_AI_OUT_Status_Condensed; \
	VARIABLE func1_AI_OUT_Status_Quality; \
	VARIABLE func1_AI_OUT_Status_Limit; \
	MENU func1_AI_OUT_page; \
	COMMAND func1_AI_OUT_read; \
	COMMAND func1_AI_OUT_write; \
	COLLECTION func1_AI_PV_SCALE; \
	VARIABLE func1_AI_PV_SCALE_Upper_Value; \
	VARIABLE func1_AI_PV_SCALE_Lower_Value; \
	MENU func1_AI_PV_SCALE_page; \
	COMMAND func1_AI_PV_SCALE_read; \
	COMMAND func1_AI_PV_SCALE_write; \
	VARIABLE func1_AI_PV_FTIME; \
	MENU func1_AI_PV_FTIME_page; \
	COMMAND func1_AI_PV_FTIME_read; \
	COMMAND func1_AI_PV_FTIME_write; \
	VARIABLE func1_AI_ALARM_HYS; \
	MENU func1_AI_ALARM_HYS_page; \
	COMMAND func1_AI_ALARM_HYS_read; \
	COMMAND func1_AI_ALARM_HYS_write; \
	VARIABLE func1_AI_HI_HI_LIM; \
	MENU func1_AI_HI_HI_LIM_page; \
	COMMAND func1_AI_HI_HI_LIM_read; \
	COMMAND func1_AI_HI_HI_LIM_write; \
	VARIABLE func1_AI_HI_LIM; \
	MENU func1_AI_HI_LIM_page; \
	COMMAND func1_AI_HI_LIM_read; \
	COMMAND func1_AI_HI_LIM_write; \
	VARIABLE func1_AI_LO_LIM; \
	MENU func1_AI_LO_LIM_page; \
	COMMAND func1_AI_LO_LIM_read; \
	COMMAND func1_AI_LO_LIM_write; \
	VARIABLE func1_AI_LO_LO_LIM; \
	MENU func1_AI_LO_LO_LIM_page; \
	COMMAND func1_AI_LO_LO_LIM_read; \
	COMMAND func1_AI_LO_LO_LIM_write

#define USE_FUNC1_AI_MANDATORY_A \
	USE_FUNC1_AI_MANDATORY_BOTH; \
	MENU func1_AI_Simple_Dialog_Mandatory_A; \
	MENU func1_AI_Display_mandatory_A; \
	CHART func1_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func1_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func1_AI_Display_out_mandatory_A; \
	MENU func1_AI_Tab_s_mandatory_A; \
	MENU func1_AI_Tab_s_pv_range_mandatory_A; \
	MENU func1_AI_Tab_s_limits_mandatory_A; \
	MENU func1_AI_Tab_m_mandatory_A; \
	MENU func1_AI_Tab_m_pv_range_mandatory_A; \
	MENU func1_AI_Tab_m_limits_mandatory_A

#define USE_FUNC1_AI_MANDATORY_B \
	USE_FUNC1_AI_MANDATORY_BOTH; \
	COLLECTION func1_AI_OUT_SCALE; \
	VARIABLE func1_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func1_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func1_AI_OUT_SCALE_Units_Index; \
	VARIABLE func1_AI_OUT_SCALE_Decimal_Point; \
	MENU func1_AI_OUT_SCALE_page; \
	COMMAND func1_AI_OUT_SCALE_read; \
	COMMAND func1_AI_OUT_SCALE_write; \
	VARIABLE func1_AI_LIN_TYPE; \
	MENU func1_AI_LIN_TYPE_page; \
	COMMAND func1_AI_LIN_TYPE_read; \
	COMMAND func1_AI_LIN_TYPE_write; \
	VARIABLE func1_AI_CHANNEL; \
	MENU func1_AI_CHANNEL_page; \
	COMMAND func1_AI_CHANNEL_read; \
	COMMAND func1_AI_CHANNEL_write; \
	COLLECTION func1_AI_SIMULATE; \
	VARIABLE func1_AI_SIMULATE_Status_Condensed; \
	VARIABLE func1_AI_SIMULATE_Value; \
	VARIABLE func1_AI_SIMULATE_Enabled; \
	VARIABLE func1_AI_SIMULATE_Status_Quality; \
	VARIABLE func1_AI_SIMULATE_Status_Limit; \
	MENU func1_AI_SIMULATE_page; \
	COMMAND func1_AI_SIMULATE_read; \
	COMMAND func1_AI_SIMULATE_write; \
	COLLECTION func1_AI_VIEW_1; \
	MENU func1_AI_VIEW_1_page; \
	MENU func1_AI_Simple_Dialog_Mandatory_B; \
	UNIT func1_AI_OUT_SCALE_unit_1; \
	MENU func1_AI_Simulation; \
	MENU func1_AI_Simulation_input; \
	MENU func1_AI_Simulation_input_group; \
	MENU func1_AI_Simulation_output; \
	MENU func1_AI_Simulation_output_group; \
	MENU func1_AI_Display_mandatory_B; \
	CHART func1_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func1_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func1_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func1_AI_Display_out_mandatory_B; \
	MENU func1_AI_Display_in_mandatory_B; \
	MENU func1_AI_Tab_s_mandatory_B; \
	MENU func1_AI_Tab_s_pv_range_mandatory_B; \
	MENU func1_AI_Tab_s_outscale_mandatory_B; \
	MENU func1_AI_Tab_s_limits_mandatory_B; \
	MENU func1_AI_Tab_s_interface_mandatory_B; \
	MENU func1_AI_Tab_m_mandatory_B; \
	MENU func1_AI_Tab_m_pv_range_mandatory_B; \
	MENU func1_AI_Tab_m_outscale_mandatory_B; \
	MENU func1_AI_Tab_m_limits_mandatory_B

#define USE_FUNC1_AI_OPTIONAL_BOTH \
	VARIABLE func1_AI_FSAFE_TYPE; \
	MENU func1_AI_FSAFE_TYPE_page; \
	COMMAND func1_AI_FSAFE_TYPE_read; \
	COMMAND func1_AI_FSAFE_TYPE_write; \
	VARIABLE func1_AI_FSAFE_VALUE; \
	MENU func1_AI_FSAFE_VALUE_page; \
	COMMAND func1_AI_FSAFE_VALUE_read; \
	COMMAND func1_AI_FSAFE_VALUE_write; \
	COLLECTION func1_AI_HI_HI_ALM; \
	VARIABLE func1_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func1_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func1_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func1_AI_HI_HI_ALM_Subcode; \
	VARIABLE func1_AI_HI_HI_ALM_Value; \
	MENU func1_AI_HI_HI_ALM_page; \
	COMMAND func1_AI_HI_HI_ALM_read; \
	COLLECTION func1_AI_HI_ALM; \
	VARIABLE func1_AI_HI_ALM_Unacknowledged; \
	VARIABLE func1_AI_HI_ALM_Alarm_State; \
	VARIABLE func1_AI_HI_ALM_Time_Stamp; \
	VARIABLE func1_AI_HI_ALM_Subcode; \
	VARIABLE func1_AI_HI_ALM_Value; \
	MENU func1_AI_HI_ALM_page; \
	COMMAND func1_AI_HI_ALM_read; \
	COLLECTION func1_AI_LO_ALM; \
	VARIABLE func1_AI_LO_ALM_Unacknowledged; \
	VARIABLE func1_AI_LO_ALM_Alarm_State; \
	VARIABLE func1_AI_LO_ALM_Time_Stamp; \
	VARIABLE func1_AI_LO_ALM_Subcode; \
	VARIABLE func1_AI_LO_ALM_Value; \
	MENU func1_AI_LO_ALM_page; \
	COMMAND func1_AI_LO_ALM_read; \
	COLLECTION func1_AI_LO_LO_ALM; \
	VARIABLE func1_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func1_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func1_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func1_AI_LO_LO_ALM_Subcode; \
	VARIABLE func1_AI_LO_LO_ALM_Value; \
	MENU func1_AI_LO_LO_ALM_page; \
	COMMAND func1_AI_LO_LO_ALM_read; \
	VARIABLE func1_AI_OUT_UNIT_TEXT; \
	MENU func1_AI_OUT_UNIT_TEXT_page; \
	COMMAND func1_AI_OUT_UNIT_TEXT_read; \
	COMMAND func1_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func1_AI_VIEW_2; \
	MENU func1_AI_VIEW_2_page; \
	COLLECTION func1_AI_VIEW_3; \
	MENU func1_AI_VIEW_3_page

#define USE_FUNC1_AI_OPTIONAL_A \
	USE_FUNC1_AI_OPTIONAL_BOTH; \
	COLLECTION func1_AI_OUT_SCALE; \
	VARIABLE func1_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func1_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func1_AI_OUT_SCALE_Units_Index; \
	VARIABLE func1_AI_OUT_SCALE_Decimal_Point; \
	MENU func1_AI_OUT_SCALE_page; \
	COMMAND func1_AI_OUT_SCALE_read; \
	COMMAND func1_AI_OUT_SCALE_write; \
	VARIABLE func1_AI_LIN_TYPE; \
	MENU func1_AI_LIN_TYPE_page; \
	COMMAND func1_AI_LIN_TYPE_read; \
	COMMAND func1_AI_LIN_TYPE_write; \
	VARIABLE func1_AI_CHANNEL; \
	MENU func1_AI_CHANNEL_page; \
	COMMAND func1_AI_CHANNEL_read; \
	COMMAND func1_AI_CHANNEL_write; \
	COLLECTION func1_AI_SIMULATE; \
	VARIABLE func1_AI_SIMULATE_Status_Condensed; \
	VARIABLE func1_AI_SIMULATE_Value; \
	VARIABLE func1_AI_SIMULATE_Enabled; \
	VARIABLE func1_AI_SIMULATE_Status_Quality; \
	VARIABLE func1_AI_SIMULATE_Status_Limit; \
	MENU func1_AI_SIMULATE_page; \
	COMMAND func1_AI_SIMULATE_read; \
	COMMAND func1_AI_SIMULATE_write; \
	COLLECTION func1_AI_VIEW_1; \
	MENU func1_AI_VIEW_1_page; \
	MENU func1_AI_Simple_Dialog_Optional_A; \
	UNIT func1_AI_OUT_SCALE_unit_1; \
	UNIT func1_AI_OUT_SCALE_unit_2

#define USE_FUNC1_AI_OPTIONAL_B \
	USE_FUNC1_AI_OPTIONAL_BOTH; \
	MENU func1_AI_Simple_Dialog_Optional_B; \
	UNIT func1_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC_AI_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## BATCH; \
	VARIABLE prefix ## BATCH_Batch_ID; \
	VARIABLE prefix ## BATCH_Rup; \
	VARIABLE prefix ## BATCH_Operation; \
	VARIABLE prefix ## BATCH_Phase; \
	MENU prefix ## BATCH_page; \
	COMMAND prefix ## BATCH_read; \
	COMMAND prefix ## BATCH_write; \
	COLLECTION prefix ## OUT; \
	VARIABLE prefix ## OUT_Value; \
	VARIABLE prefix ## OUT_Status_Condensed; \
	VARIABLE prefix ## OUT_Status_Quality; \
	VARIABLE prefix ## OUT_Status_Limit; \
	MENU prefix ## OUT_page; \
	COMMAND prefix ## OUT_read; \
	COMMAND prefix ## OUT_write; \
	COLLECTION prefix ## PV_SCALE; \
	VARIABLE prefix ## PV_SCALE_Upper_Value; \
	VARIABLE prefix ## PV_SCALE_Lower_Value; \
	MENU prefix ## PV_SCALE_page; \
	COMMAND prefix ## PV_SCALE_read; \
	COMMAND prefix ## PV_SCALE_write; \
	VARIABLE prefix ## PV_FTIME; \
	MENU prefix ## PV_FTIME_page; \
	COMMAND prefix ## PV_FTIME_read; \
	COMMAND prefix ## PV_FTIME_write; \
	VARIABLE prefix ## ALARM_HYS; \
	MENU prefix ## ALARM_HYS_page; \
	COMMAND prefix ## ALARM_HYS_read; \
	COMMAND prefix ## ALARM_HYS_write; \
	VARIABLE prefix ## HI_HI_LIM; \
	MENU prefix ## HI_HI_LIM_page; \
	COMMAND prefix ## HI_HI_LIM_read; \
	COMMAND prefix ## HI_HI_LIM_write; \
	VARIABLE prefix ## HI_LIM; \
	MENU prefix ## HI_LIM_page; \
	COMMAND prefix ## HI_LIM_read; \
	COMMAND prefix ## HI_LIM_write; \
	VARIABLE prefix ## LO_LIM; \
	MENU prefix ## LO_LIM_page; \
	COMMAND prefix ## LO_LIM_read; \
	COMMAND prefix ## LO_LIM_write; \
	VARIABLE prefix ## LO_LO_LIM; \
	MENU prefix ## LO_LO_LIM_page; \
	COMMAND prefix ## LO_LO_LIM_read; \
	COMMAND prefix ## LO_LO_LIM_write

#define USE_FUNC_AI_MANDATORY_A(prefix) \
	USE_FUNC_AI_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A; \
	MENU prefix ## Display_mandatory_A; \
	CHART prefix ## Display_BarVal_out_mandatory_A; \
	SOURCE prefix ## Display_BarVal_out_source_mandatory_A; \
	MENU prefix ## Display_out_mandatory_A; \
	MENU prefix ## Tab_s_mandatory_A; \
	MENU prefix ## Tab_s_pv_range_mandatory_A; \
	MENU prefix ## Tab_s_limits_mandatory_A; \
	MENU prefix ## Tab_m_mandatory_A; \
	MENU prefix ## Tab_m_pv_range_mandatory_A; \
	MENU prefix ## Tab_m_limits_mandatory_A

#define USE_FUNC_AI_MANDATORY_B(prefix) \
	USE_FUNC_AI_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## OUT_SCALE; \
	VARIABLE prefix ## OUT_SCALE_Upper_Value; \
	VARIABLE prefix ## OUT_SCALE_Lower_Value; \
	VARIABLE prefix ## OUT_SCALE_Units_Index; \
	VARIABLE prefix ## OUT_SCALE_Decimal_Point; \
	MENU prefix ## OUT_SCALE_page; \
	COMMAND prefix ## OUT_SCALE_read; \
	COMMAND prefix ## OUT_SCALE_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B; \
	UNIT prefix ## OUT_SCALE_unit_1; \
	MENU prefix ## Simulation; \
	MENU prefix ## Simulation_input; \
	MENU prefix ## Simulation_input_group; \
	MENU prefix ## Simulation_output; \
	MENU prefix ## Simulation_output_group; \
	MENU prefix ## Display_mandatory_B; \
	CHART prefix ## Display_BarVal_out_mandatory_B; \
	SOURCE prefix ## Display_BarVal_out_source_mandatory_B; \
	AXIS prefix ## Display_BarVal_out_axis_mandatory_B; \
	MENU prefix ## Display_out_mandatory_B; \
	MENU prefix ## Display_in_mandatory_B; \
	MENU prefix ## Tab_s_mandatory_B; \
	MENU prefix ## Tab_s_pv_range_mandatory_B; \
	MENU prefix ## Tab_s_outscale_mandatory_B; \
	MENU prefix ## Tab_s_limits_mandatory_B; \
	MENU prefix ## Tab_s_interface_mandatory_B; \
	MENU prefix ## Tab_m_mandatory_B; \
	MENU prefix ## Tab_m_pv_range_mandatory_B; \
	MENU prefix ## Tab_m_outscale_mandatory_B; \
	MENU prefix ## Tab_m_limits_mandatory_B

#define USE_FUNC_AI_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	VARIABLE prefix ## FSAFE_VALUE; \
	MENU prefix ## FSAFE_VALUE_page; \
	COMMAND prefix ## FSAFE_VALUE_read; \
	COMMAND prefix ## FSAFE_VALUE_write; \
	COLLECTION prefix ## HI_HI_ALM; \
	VARIABLE prefix ## HI_HI_ALM_Unacknowledged; \
	VARIABLE prefix ## HI_HI_ALM_Alarm_State; \
	VARIABLE prefix ## HI_HI_ALM_Time_Stamp; \
	VARIABLE prefix ## HI_HI_ALM_Subcode; \
	VARIABLE prefix ## HI_HI_ALM_Value; \
	MENU prefix ## HI_HI_ALM_page; \
	COMMAND prefix ## HI_HI_ALM_read; \
	COLLECTION prefix ## HI_ALM; \
	VARIABLE prefix ## HI_ALM_Unacknowledged; \
	VARIABLE prefix ## HI_ALM_Alarm_State; \
	VARIABLE prefix ## HI_ALM_Time_Stamp; \
	VARIABLE prefix ## HI_ALM_Subcode; \
	VARIABLE prefix ## HI_ALM_Value; \
	MENU prefix ## HI_ALM_page; \
	COMMAND prefix ## HI_ALM_read; \
	COLLECTION prefix ## LO_ALM; \
	VARIABLE prefix ## LO_ALM_Unacknowledged; \
	VARIABLE prefix ## LO_ALM_Alarm_State; \
	VARIABLE prefix ## LO_ALM_Time_Stamp; \
	VARIABLE prefix ## LO_ALM_Subcode; \
	VARIABLE prefix ## LO_ALM_Value; \
	MENU prefix ## LO_ALM_page; \
	COMMAND prefix ## LO_ALM_read; \
	COLLECTION prefix ## LO_LO_ALM; \
	VARIABLE prefix ## LO_LO_ALM_Unacknowledged; \
	VARIABLE prefix ## LO_LO_ALM_Alarm_State; \
	VARIABLE prefix ## LO_LO_ALM_Time_Stamp; \
	VARIABLE prefix ## LO_LO_ALM_Subcode; \
	VARIABLE prefix ## LO_LO_ALM_Value; \
	MENU prefix ## LO_LO_ALM_page; \
	COMMAND prefix ## LO_LO_ALM_read; \
	VARIABLE prefix ## OUT_UNIT_TEXT; \
	MENU prefix ## OUT_UNIT_TEXT_page; \
	COMMAND prefix ## OUT_UNIT_TEXT_read; \
	COMMAND prefix ## OUT_UNIT_TEXT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_FUNC_AI_OPTIONAL_A(prefix) \
	USE_FUNC_AI_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## OUT_SCALE; \
	VARIABLE prefix ## OUT_SCALE_Upper_Value; \
	VARIABLE prefix ## OUT_SCALE_Lower_Value; \
	VARIABLE prefix ## OUT_SCALE_Units_Index; \
	VARIABLE prefix ## OUT_SCALE_Decimal_Point; \
	MENU prefix ## OUT_SCALE_page; \
	COMMAND prefix ## OUT_SCALE_read; \
	COMMAND prefix ## OUT_SCALE_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A; \
	UNIT prefix ## OUT_SCALE_unit_1; \
	UNIT prefix ## OUT_SCALE_unit_2

#define USE_FUNC_AI_OPTIONAL_B(prefix) \
	USE_FUNC_AI_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B; \
	UNIT prefix ## OUT_SCALE_unit_2

#define USE_FUNC1_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func1_AI_)
#define USE_FUNC1_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func1_AI_)
#define USE_FUNC1_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func1_AI_)
#define USE_FUNC1_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func1_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC2_AI_MANDATORY_BOTH \
	BLOCK func2_AI_block; \
	COLLECTION func2_AI_BLOCK_OBJECT; \
	VARIABLE func2_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func2_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func2_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func2_AI_BLOCK_OBJECT_Class; \
	VARIABLE func2_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func2_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func2_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func2_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func2_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func2_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func2_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func2_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func2_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func2_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func2_AI_BLOCK_OBJECT_page; \
	COMMAND func2_AI_BLOCK_OBJECT_read; \
	VARIABLE func2_AI_ST_REV; \
	MENU func2_AI_ST_REV_page; \
	COMMAND func2_AI_ST_REV_read; \
	VARIABLE func2_AI_TAG_DESC; \
	MENU func2_AI_TAG_DESC_page; \
	COMMAND func2_AI_TAG_DESC_read; \
	COMMAND func2_AI_TAG_DESC_write; \
	VARIABLE func2_AI_STRATEGY; \
	MENU func2_AI_STRATEGY_page; \
	COMMAND func2_AI_STRATEGY_read; \
	COMMAND func2_AI_STRATEGY_write; \
	VARIABLE func2_AI_ALERT_KEY; \
	MENU func2_AI_ALERT_KEY_page; \
	COMMAND func2_AI_ALERT_KEY_read; \
	COMMAND func2_AI_ALERT_KEY_write; \
	VARIABLE func2_AI_TARGET_MODE; \
	MENU func2_AI_TARGET_MODE_page; \
	COMMAND func2_AI_TARGET_MODE_read; \
	COMMAND func2_AI_TARGET_MODE_write; \
	COLLECTION func2_AI_MODE_BLK; \
	VARIABLE func2_AI_MODE_BLK_Actual; \
	VARIABLE func2_AI_MODE_BLK_Permitted; \
	VARIABLE func2_AI_MODE_BLK_Normal; \
	MENU func2_AI_MODE_BLK_page; \
	COMMAND func2_AI_MODE_BLK_read; \
	COLLECTION func2_AI_ALARM_SUM; \
	VARIABLE func2_AI_ALARM_SUM_Current; \
	VARIABLE func2_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func2_AI_ALARM_SUM_Unreported; \
	VARIABLE func2_AI_ALARM_SUM_Disabled; \
	MENU func2_AI_ALARM_SUM_page; \
	COMMAND func2_AI_ALARM_SUM_read; \
	COLLECTION func2_AI_BATCH; \
	VARIABLE func2_AI_BATCH_Batch_ID; \
	VARIABLE func2_AI_BATCH_Rup; \
	VARIABLE func2_AI_BATCH_Operation; \
	VARIABLE func2_AI_BATCH_Phase; \
	MENU func2_AI_BATCH_page; \
	COMMAND func2_AI_BATCH_read; \
	COMMAND func2_AI_BATCH_write; \
	COLLECTION func2_AI_OUT; \
	VARIABLE func2_AI_OUT_Value; \
	VARIABLE func2_AI_OUT_Status_Condensed; \
	VARIABLE func2_AI_OUT_Status_Quality; \
	VARIABLE func2_AI_OUT_Status_Limit; \
	MENU func2_AI_OUT_page; \
	COMMAND func2_AI_OUT_read; \
	COMMAND func2_AI_OUT_write; \
	COLLECTION func2_AI_PV_SCALE; \
	VARIABLE func2_AI_PV_SCALE_Upper_Value; \
	VARIABLE func2_AI_PV_SCALE_Lower_Value; \
	MENU func2_AI_PV_SCALE_page; \
	COMMAND func2_AI_PV_SCALE_read; \
	COMMAND func2_AI_PV_SCALE_write; \
	VARIABLE func2_AI_PV_FTIME; \
	MENU func2_AI_PV_FTIME_page; \
	COMMAND func2_AI_PV_FTIME_read; \
	COMMAND func2_AI_PV_FTIME_write; \
	VARIABLE func2_AI_ALARM_HYS; \
	MENU func2_AI_ALARM_HYS_page; \
	COMMAND func2_AI_ALARM_HYS_read; \
	COMMAND func2_AI_ALARM_HYS_write; \
	VARIABLE func2_AI_HI_HI_LIM; \
	MENU func2_AI_HI_HI_LIM_page; \
	COMMAND func2_AI_HI_HI_LIM_read; \
	COMMAND func2_AI_HI_HI_LIM_write; \
	VARIABLE func2_AI_HI_LIM; \
	MENU func2_AI_HI_LIM_page; \
	COMMAND func2_AI_HI_LIM_read; \
	COMMAND func2_AI_HI_LIM_write; \
	VARIABLE func2_AI_LO_LIM; \
	MENU func2_AI_LO_LIM_page; \
	COMMAND func2_AI_LO_LIM_read; \
	COMMAND func2_AI_LO_LIM_write; \
	VARIABLE func2_AI_LO_LO_LIM; \
	MENU func2_AI_LO_LO_LIM_page; \
	COMMAND func2_AI_LO_LO_LIM_read; \
	COMMAND func2_AI_LO_LO_LIM_write

#define USE_FUNC2_AI_MANDATORY_A \
	USE_FUNC2_AI_MANDATORY_BOTH; \
	MENU func2_AI_Simple_Dialog_Mandatory_A; \
	MENU func2_AI_Display_mandatory_A; \
	CHART func2_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func2_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func2_AI_Display_out_mandatory_A; \
	MENU func2_AI_Tab_s_mandatory_A; \
	MENU func2_AI_Tab_s_pv_range_mandatory_A; \
	MENU func2_AI_Tab_s_limits_mandatory_A; \
	MENU func2_AI_Tab_m_mandatory_A; \
	MENU func2_AI_Tab_m_pv_range_mandatory_A; \
	MENU func2_AI_Tab_m_limits_mandatory_A

#define USE_FUNC2_AI_MANDATORY_B \
	USE_FUNC2_AI_MANDATORY_BOTH; \
	COLLECTION func2_AI_OUT_SCALE; \
	VARIABLE func2_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func2_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func2_AI_OUT_SCALE_Units_Index; \
	VARIABLE func2_AI_OUT_SCALE_Decimal_Point; \
	MENU func2_AI_OUT_SCALE_page; \
	COMMAND func2_AI_OUT_SCALE_read; \
	COMMAND func2_AI_OUT_SCALE_write; \
	VARIABLE func2_AI_LIN_TYPE; \
	MENU func2_AI_LIN_TYPE_page; \
	COMMAND func2_AI_LIN_TYPE_read; \
	COMMAND func2_AI_LIN_TYPE_write; \
	VARIABLE func2_AI_CHANNEL; \
	MENU func2_AI_CHANNEL_page; \
	COMMAND func2_AI_CHANNEL_read; \
	COMMAND func2_AI_CHANNEL_write; \
	COLLECTION func2_AI_SIMULATE; \
	VARIABLE func2_AI_SIMULATE_Status_Condensed; \
	VARIABLE func2_AI_SIMULATE_Value; \
	VARIABLE func2_AI_SIMULATE_Enabled; \
	VARIABLE func2_AI_SIMULATE_Status_Quality; \
	VARIABLE func2_AI_SIMULATE_Status_Limit; \
	MENU func2_AI_SIMULATE_page; \
	COMMAND func2_AI_SIMULATE_read; \
	COMMAND func2_AI_SIMULATE_write; \
	COLLECTION func2_AI_VIEW_1; \
	MENU func2_AI_VIEW_1_page; \
	MENU func2_AI_Simple_Dialog_Mandatory_B; \
	UNIT func2_AI_OUT_SCALE_unit_1; \
	MENU func2_AI_Simulation; \
	MENU func2_AI_Simulation_input; \
	MENU func2_AI_Simulation_input_group; \
	MENU func2_AI_Simulation_output; \
	MENU func2_AI_Simulation_output_group; \
	MENU func2_AI_Display_mandatory_B; \
	CHART func2_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func2_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func2_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func2_AI_Display_out_mandatory_B; \
	MENU func2_AI_Display_in_mandatory_B; \
	MENU func2_AI_Tab_s_mandatory_B; \
	MENU func2_AI_Tab_s_pv_range_mandatory_B; \
	MENU func2_AI_Tab_s_outscale_mandatory_B; \
	MENU func2_AI_Tab_s_limits_mandatory_B; \
	MENU func2_AI_Tab_s_interface_mandatory_B; \
	MENU func2_AI_Tab_m_mandatory_B; \
	MENU func2_AI_Tab_m_pv_range_mandatory_B; \
	MENU func2_AI_Tab_m_outscale_mandatory_B; \
	MENU func2_AI_Tab_m_limits_mandatory_B

#define USE_FUNC2_AI_OPTIONAL_BOTH \
	VARIABLE func2_AI_FSAFE_TYPE; \
	MENU func2_AI_FSAFE_TYPE_page; \
	COMMAND func2_AI_FSAFE_TYPE_read; \
	COMMAND func2_AI_FSAFE_TYPE_write; \
	VARIABLE func2_AI_FSAFE_VALUE; \
	MENU func2_AI_FSAFE_VALUE_page; \
	COMMAND func2_AI_FSAFE_VALUE_read; \
	COMMAND func2_AI_FSAFE_VALUE_write; \
	COLLECTION func2_AI_HI_HI_ALM; \
	VARIABLE func2_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func2_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func2_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func2_AI_HI_HI_ALM_Subcode; \
	VARIABLE func2_AI_HI_HI_ALM_Value; \
	MENU func2_AI_HI_HI_ALM_page; \
	COMMAND func2_AI_HI_HI_ALM_read; \
	COLLECTION func2_AI_HI_ALM; \
	VARIABLE func2_AI_HI_ALM_Unacknowledged; \
	VARIABLE func2_AI_HI_ALM_Alarm_State; \
	VARIABLE func2_AI_HI_ALM_Time_Stamp; \
	VARIABLE func2_AI_HI_ALM_Subcode; \
	VARIABLE func2_AI_HI_ALM_Value; \
	MENU func2_AI_HI_ALM_page; \
	COMMAND func2_AI_HI_ALM_read; \
	COLLECTION func2_AI_LO_ALM; \
	VARIABLE func2_AI_LO_ALM_Unacknowledged; \
	VARIABLE func2_AI_LO_ALM_Alarm_State; \
	VARIABLE func2_AI_LO_ALM_Time_Stamp; \
	VARIABLE func2_AI_LO_ALM_Subcode; \
	VARIABLE func2_AI_LO_ALM_Value; \
	MENU func2_AI_LO_ALM_page; \
	COMMAND func2_AI_LO_ALM_read; \
	COLLECTION func2_AI_LO_LO_ALM; \
	VARIABLE func2_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func2_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func2_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func2_AI_LO_LO_ALM_Subcode; \
	VARIABLE func2_AI_LO_LO_ALM_Value; \
	MENU func2_AI_LO_LO_ALM_page; \
	COMMAND func2_AI_LO_LO_ALM_read; \
	VARIABLE func2_AI_OUT_UNIT_TEXT; \
	MENU func2_AI_OUT_UNIT_TEXT_page; \
	COMMAND func2_AI_OUT_UNIT_TEXT_read; \
	COMMAND func2_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func2_AI_VIEW_2; \
	MENU func2_AI_VIEW_2_page; \
	COLLECTION func2_AI_VIEW_3; \
	MENU func2_AI_VIEW_3_page

#define USE_FUNC2_AI_OPTIONAL_A \
	USE_FUNC2_AI_OPTIONAL_BOTH; \
	COLLECTION func2_AI_OUT_SCALE; \
	VARIABLE func2_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func2_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func2_AI_OUT_SCALE_Units_Index; \
	VARIABLE func2_AI_OUT_SCALE_Decimal_Point; \
	MENU func2_AI_OUT_SCALE_page; \
	COMMAND func2_AI_OUT_SCALE_read; \
	COMMAND func2_AI_OUT_SCALE_write; \
	VARIABLE func2_AI_LIN_TYPE; \
	MENU func2_AI_LIN_TYPE_page; \
	COMMAND func2_AI_LIN_TYPE_read; \
	COMMAND func2_AI_LIN_TYPE_write; \
	VARIABLE func2_AI_CHANNEL; \
	MENU func2_AI_CHANNEL_page; \
	COMMAND func2_AI_CHANNEL_read; \
	COMMAND func2_AI_CHANNEL_write; \
	COLLECTION func2_AI_SIMULATE; \
	VARIABLE func2_AI_SIMULATE_Status_Condensed; \
	VARIABLE func2_AI_SIMULATE_Value; \
	VARIABLE func2_AI_SIMULATE_Enabled; \
	VARIABLE func2_AI_SIMULATE_Status_Quality; \
	VARIABLE func2_AI_SIMULATE_Status_Limit; \
	MENU func2_AI_SIMULATE_page; \
	COMMAND func2_AI_SIMULATE_read; \
	COMMAND func2_AI_SIMULATE_write; \
	COLLECTION func2_AI_VIEW_1; \
	MENU func2_AI_VIEW_1_page; \
	MENU func2_AI_Simple_Dialog_Optional_A; \
	UNIT func2_AI_OUT_SCALE_unit_1; \
	UNIT func2_AI_OUT_SCALE_unit_2

#define USE_FUNC2_AI_OPTIONAL_B \
	USE_FUNC2_AI_OPTIONAL_BOTH; \
	MENU func2_AI_Simple_Dialog_Optional_B; \
	UNIT func2_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC2_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func2_AI_)
#define USE_FUNC2_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func2_AI_)
#define USE_FUNC2_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func2_AI_)
#define USE_FUNC2_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func2_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC3_AI_MANDATORY_BOTH \
	BLOCK func3_AI_block; \
	COLLECTION func3_AI_BLOCK_OBJECT; \
	VARIABLE func3_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func3_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func3_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func3_AI_BLOCK_OBJECT_Class; \
	VARIABLE func3_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func3_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func3_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func3_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func3_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func3_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func3_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func3_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func3_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func3_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func3_AI_BLOCK_OBJECT_page; \
	COMMAND func3_AI_BLOCK_OBJECT_read; \
	VARIABLE func3_AI_ST_REV; \
	MENU func3_AI_ST_REV_page; \
	COMMAND func3_AI_ST_REV_read; \
	VARIABLE func3_AI_TAG_DESC; \
	MENU func3_AI_TAG_DESC_page; \
	COMMAND func3_AI_TAG_DESC_read; \
	COMMAND func3_AI_TAG_DESC_write; \
	VARIABLE func3_AI_STRATEGY; \
	MENU func3_AI_STRATEGY_page; \
	COMMAND func3_AI_STRATEGY_read; \
	COMMAND func3_AI_STRATEGY_write; \
	VARIABLE func3_AI_ALERT_KEY; \
	MENU func3_AI_ALERT_KEY_page; \
	COMMAND func3_AI_ALERT_KEY_read; \
	COMMAND func3_AI_ALERT_KEY_write; \
	VARIABLE func3_AI_TARGET_MODE; \
	MENU func3_AI_TARGET_MODE_page; \
	COMMAND func3_AI_TARGET_MODE_read; \
	COMMAND func3_AI_TARGET_MODE_write; \
	COLLECTION func3_AI_MODE_BLK; \
	VARIABLE func3_AI_MODE_BLK_Actual; \
	VARIABLE func3_AI_MODE_BLK_Permitted; \
	VARIABLE func3_AI_MODE_BLK_Normal; \
	MENU func3_AI_MODE_BLK_page; \
	COMMAND func3_AI_MODE_BLK_read; \
	COLLECTION func3_AI_ALARM_SUM; \
	VARIABLE func3_AI_ALARM_SUM_Current; \
	VARIABLE func3_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func3_AI_ALARM_SUM_Unreported; \
	VARIABLE func3_AI_ALARM_SUM_Disabled; \
	MENU func3_AI_ALARM_SUM_page; \
	COMMAND func3_AI_ALARM_SUM_read; \
	COLLECTION func3_AI_BATCH; \
	VARIABLE func3_AI_BATCH_Batch_ID; \
	VARIABLE func3_AI_BATCH_Rup; \
	VARIABLE func3_AI_BATCH_Operation; \
	VARIABLE func3_AI_BATCH_Phase; \
	MENU func3_AI_BATCH_page; \
	COMMAND func3_AI_BATCH_read; \
	COMMAND func3_AI_BATCH_write; \
	COLLECTION func3_AI_OUT; \
	VARIABLE func3_AI_OUT_Value; \
	VARIABLE func3_AI_OUT_Status_Condensed; \
	VARIABLE func3_AI_OUT_Status_Quality; \
	VARIABLE func3_AI_OUT_Status_Limit; \
	MENU func3_AI_OUT_page; \
	COMMAND func3_AI_OUT_read; \
	COMMAND func3_AI_OUT_write; \
	COLLECTION func3_AI_PV_SCALE; \
	VARIABLE func3_AI_PV_SCALE_Upper_Value; \
	VARIABLE func3_AI_PV_SCALE_Lower_Value; \
	MENU func3_AI_PV_SCALE_page; \
	COMMAND func3_AI_PV_SCALE_read; \
	COMMAND func3_AI_PV_SCALE_write; \
	VARIABLE func3_AI_PV_FTIME; \
	MENU func3_AI_PV_FTIME_page; \
	COMMAND func3_AI_PV_FTIME_read; \
	COMMAND func3_AI_PV_FTIME_write; \
	VARIABLE func3_AI_ALARM_HYS; \
	MENU func3_AI_ALARM_HYS_page; \
	COMMAND func3_AI_ALARM_HYS_read; \
	COMMAND func3_AI_ALARM_HYS_write; \
	VARIABLE func3_AI_HI_HI_LIM; \
	MENU func3_AI_HI_HI_LIM_page; \
	COMMAND func3_AI_HI_HI_LIM_read; \
	COMMAND func3_AI_HI_HI_LIM_write; \
	VARIABLE func3_AI_HI_LIM; \
	MENU func3_AI_HI_LIM_page; \
	COMMAND func3_AI_HI_LIM_read; \
	COMMAND func3_AI_HI_LIM_write; \
	VARIABLE func3_AI_LO_LIM; \
	MENU func3_AI_LO_LIM_page; \
	COMMAND func3_AI_LO_LIM_read; \
	COMMAND func3_AI_LO_LIM_write; \
	VARIABLE func3_AI_LO_LO_LIM; \
	MENU func3_AI_LO_LO_LIM_page; \
	COMMAND func3_AI_LO_LO_LIM_read; \
	COMMAND func3_AI_LO_LO_LIM_write

#define USE_FUNC3_AI_MANDATORY_A \
	USE_FUNC3_AI_MANDATORY_BOTH; \
	MENU func3_AI_Simple_Dialog_Mandatory_A; \
	MENU func3_AI_Display_mandatory_A; \
	CHART func3_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func3_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func3_AI_Display_out_mandatory_A; \
	MENU func3_AI_Tab_s_mandatory_A; \
	MENU func3_AI_Tab_s_pv_range_mandatory_A; \
	MENU func3_AI_Tab_s_limits_mandatory_A; \
	MENU func3_AI_Tab_m_mandatory_A; \
	MENU func3_AI_Tab_m_pv_range_mandatory_A; \
	MENU func3_AI_Tab_m_limits_mandatory_A

#define USE_FUNC3_AI_MANDATORY_B \
	USE_FUNC3_AI_MANDATORY_BOTH; \
	COLLECTION func3_AI_OUT_SCALE; \
	VARIABLE func3_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func3_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func3_AI_OUT_SCALE_Units_Index; \
	VARIABLE func3_AI_OUT_SCALE_Decimal_Point; \
	MENU func3_AI_OUT_SCALE_page; \
	COMMAND func3_AI_OUT_SCALE_read; \
	COMMAND func3_AI_OUT_SCALE_write; \
	VARIABLE func3_AI_LIN_TYPE; \
	MENU func3_AI_LIN_TYPE_page; \
	COMMAND func3_AI_LIN_TYPE_read; \
	COMMAND func3_AI_LIN_TYPE_write; \
	VARIABLE func3_AI_CHANNEL; \
	MENU func3_AI_CHANNEL_page; \
	COMMAND func3_AI_CHANNEL_read; \
	COMMAND func3_AI_CHANNEL_write; \
	COLLECTION func3_AI_SIMULATE; \
	VARIABLE func3_AI_SIMULATE_Status_Condensed; \
	VARIABLE func3_AI_SIMULATE_Value; \
	VARIABLE func3_AI_SIMULATE_Enabled; \
	VARIABLE func3_AI_SIMULATE_Status_Quality; \
	VARIABLE func3_AI_SIMULATE_Status_Limit; \
	MENU func3_AI_SIMULATE_page; \
	COMMAND func3_AI_SIMULATE_read; \
	COMMAND func3_AI_SIMULATE_write; \
	COLLECTION func3_AI_VIEW_1; \
	MENU func3_AI_VIEW_1_page; \
	MENU func3_AI_Simple_Dialog_Mandatory_B; \
	UNIT func3_AI_OUT_SCALE_unit_1; \
	MENU func3_AI_Simulation; \
	MENU func3_AI_Simulation_input; \
	MENU func3_AI_Simulation_input_group; \
	MENU func3_AI_Simulation_output; \
	MENU func3_AI_Simulation_output_group; \
	MENU func3_AI_Display_mandatory_B; \
	CHART func3_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func3_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func3_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func3_AI_Display_out_mandatory_B; \
	MENU func3_AI_Display_in_mandatory_B; \
	MENU func3_AI_Tab_s_mandatory_B; \
	MENU func3_AI_Tab_s_pv_range_mandatory_B; \
	MENU func3_AI_Tab_s_outscale_mandatory_B; \
	MENU func3_AI_Tab_s_limits_mandatory_B; \
	MENU func3_AI_Tab_s_interface_mandatory_B; \
	MENU func3_AI_Tab_m_mandatory_B; \
	MENU func3_AI_Tab_m_pv_range_mandatory_B; \
	MENU func3_AI_Tab_m_outscale_mandatory_B; \
	MENU func3_AI_Tab_m_limits_mandatory_B

#define USE_FUNC3_AI_OPTIONAL_BOTH \
	VARIABLE func3_AI_FSAFE_TYPE; \
	MENU func3_AI_FSAFE_TYPE_page; \
	COMMAND func3_AI_FSAFE_TYPE_read; \
	COMMAND func3_AI_FSAFE_TYPE_write; \
	VARIABLE func3_AI_FSAFE_VALUE; \
	MENU func3_AI_FSAFE_VALUE_page; \
	COMMAND func3_AI_FSAFE_VALUE_read; \
	COMMAND func3_AI_FSAFE_VALUE_write; \
	COLLECTION func3_AI_HI_HI_ALM; \
	VARIABLE func3_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func3_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func3_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func3_AI_HI_HI_ALM_Subcode; \
	VARIABLE func3_AI_HI_HI_ALM_Value; \
	MENU func3_AI_HI_HI_ALM_page; \
	COMMAND func3_AI_HI_HI_ALM_read; \
	COLLECTION func3_AI_HI_ALM; \
	VARIABLE func3_AI_HI_ALM_Unacknowledged; \
	VARIABLE func3_AI_HI_ALM_Alarm_State; \
	VARIABLE func3_AI_HI_ALM_Time_Stamp; \
	VARIABLE func3_AI_HI_ALM_Subcode; \
	VARIABLE func3_AI_HI_ALM_Value; \
	MENU func3_AI_HI_ALM_page; \
	COMMAND func3_AI_HI_ALM_read; \
	COLLECTION func3_AI_LO_ALM; \
	VARIABLE func3_AI_LO_ALM_Unacknowledged; \
	VARIABLE func3_AI_LO_ALM_Alarm_State; \
	VARIABLE func3_AI_LO_ALM_Time_Stamp; \
	VARIABLE func3_AI_LO_ALM_Subcode; \
	VARIABLE func3_AI_LO_ALM_Value; \
	MENU func3_AI_LO_ALM_page; \
	COMMAND func3_AI_LO_ALM_read; \
	COLLECTION func3_AI_LO_LO_ALM; \
	VARIABLE func3_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func3_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func3_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func3_AI_LO_LO_ALM_Subcode; \
	VARIABLE func3_AI_LO_LO_ALM_Value; \
	MENU func3_AI_LO_LO_ALM_page; \
	COMMAND func3_AI_LO_LO_ALM_read; \
	VARIABLE func3_AI_OUT_UNIT_TEXT; \
	MENU func3_AI_OUT_UNIT_TEXT_page; \
	COMMAND func3_AI_OUT_UNIT_TEXT_read; \
	COMMAND func3_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func3_AI_VIEW_2; \
	MENU func3_AI_VIEW_2_page; \
	COLLECTION func3_AI_VIEW_3; \
	MENU func3_AI_VIEW_3_page

#define USE_FUNC3_AI_OPTIONAL_A \
	USE_FUNC3_AI_OPTIONAL_BOTH; \
	COLLECTION func3_AI_OUT_SCALE; \
	VARIABLE func3_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func3_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func3_AI_OUT_SCALE_Units_Index; \
	VARIABLE func3_AI_OUT_SCALE_Decimal_Point; \
	MENU func3_AI_OUT_SCALE_page; \
	COMMAND func3_AI_OUT_SCALE_read; \
	COMMAND func3_AI_OUT_SCALE_write; \
	VARIABLE func3_AI_LIN_TYPE; \
	MENU func3_AI_LIN_TYPE_page; \
	COMMAND func3_AI_LIN_TYPE_read; \
	COMMAND func3_AI_LIN_TYPE_write; \
	VARIABLE func3_AI_CHANNEL; \
	MENU func3_AI_CHANNEL_page; \
	COMMAND func3_AI_CHANNEL_read; \
	COMMAND func3_AI_CHANNEL_write; \
	COLLECTION func3_AI_SIMULATE; \
	VARIABLE func3_AI_SIMULATE_Status_Condensed; \
	VARIABLE func3_AI_SIMULATE_Value; \
	VARIABLE func3_AI_SIMULATE_Enabled; \
	VARIABLE func3_AI_SIMULATE_Status_Quality; \
	VARIABLE func3_AI_SIMULATE_Status_Limit; \
	MENU func3_AI_SIMULATE_page; \
	COMMAND func3_AI_SIMULATE_read; \
	COMMAND func3_AI_SIMULATE_write; \
	COLLECTION func3_AI_VIEW_1; \
	MENU func3_AI_VIEW_1_page; \
	MENU func3_AI_Simple_Dialog_Optional_A; \
	UNIT func3_AI_OUT_SCALE_unit_1; \
	UNIT func3_AI_OUT_SCALE_unit_2

#define USE_FUNC3_AI_OPTIONAL_B \
	USE_FUNC3_AI_OPTIONAL_BOTH; \
	MENU func3_AI_Simple_Dialog_Optional_B; \
	UNIT func3_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC3_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func3_AI_)
#define USE_FUNC3_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func3_AI_)
#define USE_FUNC3_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func3_AI_)
#define USE_FUNC3_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func3_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC4_AI_MANDATORY_BOTH \
	BLOCK func4_AI_block; \
	COLLECTION func4_AI_BLOCK_OBJECT; \
	VARIABLE func4_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func4_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func4_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func4_AI_BLOCK_OBJECT_Class; \
	VARIABLE func4_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func4_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func4_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func4_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func4_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func4_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func4_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func4_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func4_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func4_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func4_AI_BLOCK_OBJECT_page; \
	COMMAND func4_AI_BLOCK_OBJECT_read; \
	VARIABLE func4_AI_ST_REV; \
	MENU func4_AI_ST_REV_page; \
	COMMAND func4_AI_ST_REV_read; \
	VARIABLE func4_AI_TAG_DESC; \
	MENU func4_AI_TAG_DESC_page; \
	COMMAND func4_AI_TAG_DESC_read; \
	COMMAND func4_AI_TAG_DESC_write; \
	VARIABLE func4_AI_STRATEGY; \
	MENU func4_AI_STRATEGY_page; \
	COMMAND func4_AI_STRATEGY_read; \
	COMMAND func4_AI_STRATEGY_write; \
	VARIABLE func4_AI_ALERT_KEY; \
	MENU func4_AI_ALERT_KEY_page; \
	COMMAND func4_AI_ALERT_KEY_read; \
	COMMAND func4_AI_ALERT_KEY_write; \
	VARIABLE func4_AI_TARGET_MODE; \
	MENU func4_AI_TARGET_MODE_page; \
	COMMAND func4_AI_TARGET_MODE_read; \
	COMMAND func4_AI_TARGET_MODE_write; \
	COLLECTION func4_AI_MODE_BLK; \
	VARIABLE func4_AI_MODE_BLK_Actual; \
	VARIABLE func4_AI_MODE_BLK_Permitted; \
	VARIABLE func4_AI_MODE_BLK_Normal; \
	MENU func4_AI_MODE_BLK_page; \
	COMMAND func4_AI_MODE_BLK_read; \
	COLLECTION func4_AI_ALARM_SUM; \
	VARIABLE func4_AI_ALARM_SUM_Current; \
	VARIABLE func4_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func4_AI_ALARM_SUM_Unreported; \
	VARIABLE func4_AI_ALARM_SUM_Disabled; \
	MENU func4_AI_ALARM_SUM_page; \
	COMMAND func4_AI_ALARM_SUM_read; \
	COLLECTION func4_AI_BATCH; \
	VARIABLE func4_AI_BATCH_Batch_ID; \
	VARIABLE func4_AI_BATCH_Rup; \
	VARIABLE func4_AI_BATCH_Operation; \
	VARIABLE func4_AI_BATCH_Phase; \
	MENU func4_AI_BATCH_page; \
	COMMAND func4_AI_BATCH_read; \
	COMMAND func4_AI_BATCH_write; \
	COLLECTION func4_AI_OUT; \
	VARIABLE func4_AI_OUT_Value; \
	VARIABLE func4_AI_OUT_Status_Condensed; \
	VARIABLE func4_AI_OUT_Status_Quality; \
	VARIABLE func4_AI_OUT_Status_Limit; \
	MENU func4_AI_OUT_page; \
	COMMAND func4_AI_OUT_read; \
	COMMAND func4_AI_OUT_write; \
	COLLECTION func4_AI_PV_SCALE; \
	VARIABLE func4_AI_PV_SCALE_Upper_Value; \
	VARIABLE func4_AI_PV_SCALE_Lower_Value; \
	MENU func4_AI_PV_SCALE_page; \
	COMMAND func4_AI_PV_SCALE_read; \
	COMMAND func4_AI_PV_SCALE_write; \
	VARIABLE func4_AI_PV_FTIME; \
	MENU func4_AI_PV_FTIME_page; \
	COMMAND func4_AI_PV_FTIME_read; \
	COMMAND func4_AI_PV_FTIME_write; \
	VARIABLE func4_AI_ALARM_HYS; \
	MENU func4_AI_ALARM_HYS_page; \
	COMMAND func4_AI_ALARM_HYS_read; \
	COMMAND func4_AI_ALARM_HYS_write; \
	VARIABLE func4_AI_HI_HI_LIM; \
	MENU func4_AI_HI_HI_LIM_page; \
	COMMAND func4_AI_HI_HI_LIM_read; \
	COMMAND func4_AI_HI_HI_LIM_write; \
	VARIABLE func4_AI_HI_LIM; \
	MENU func4_AI_HI_LIM_page; \
	COMMAND func4_AI_HI_LIM_read; \
	COMMAND func4_AI_HI_LIM_write; \
	VARIABLE func4_AI_LO_LIM; \
	MENU func4_AI_LO_LIM_page; \
	COMMAND func4_AI_LO_LIM_read; \
	COMMAND func4_AI_LO_LIM_write; \
	VARIABLE func4_AI_LO_LO_LIM; \
	MENU func4_AI_LO_LO_LIM_page; \
	COMMAND func4_AI_LO_LO_LIM_read; \
	COMMAND func4_AI_LO_LO_LIM_write

#define USE_FUNC4_AI_MANDATORY_A \
	USE_FUNC4_AI_MANDATORY_BOTH; \
	MENU func4_AI_Simple_Dialog_Mandatory_A; \
	MENU func4_AI_Display_mandatory_A; \
	CHART func4_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func4_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func4_AI_Display_out_mandatory_A; \
	MENU func4_AI_Tab_s_mandatory_A; \
	MENU func4_AI_Tab_s_pv_range_mandatory_A; \
	MENU func4_AI_Tab_s_limits_mandatory_A; \
	MENU func4_AI_Tab_m_mandatory_A; \
	MENU func4_AI_Tab_m_pv_range_mandatory_A; \
	MENU func4_AI_Tab_m_limits_mandatory_A

#define USE_FUNC4_AI_MANDATORY_B \
	USE_FUNC4_AI_MANDATORY_BOTH; \
	COLLECTION func4_AI_OUT_SCALE; \
	VARIABLE func4_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func4_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func4_AI_OUT_SCALE_Units_Index; \
	VARIABLE func4_AI_OUT_SCALE_Decimal_Point; \
	MENU func4_AI_OUT_SCALE_page; \
	COMMAND func4_AI_OUT_SCALE_read; \
	COMMAND func4_AI_OUT_SCALE_write; \
	VARIABLE func4_AI_LIN_TYPE; \
	MENU func4_AI_LIN_TYPE_page; \
	COMMAND func4_AI_LIN_TYPE_read; \
	COMMAND func4_AI_LIN_TYPE_write; \
	VARIABLE func4_AI_CHANNEL; \
	MENU func4_AI_CHANNEL_page; \
	COMMAND func4_AI_CHANNEL_read; \
	COMMAND func4_AI_CHANNEL_write; \
	COLLECTION func4_AI_SIMULATE; \
	VARIABLE func4_AI_SIMULATE_Status_Condensed; \
	VARIABLE func4_AI_SIMULATE_Value; \
	VARIABLE func4_AI_SIMULATE_Enabled; \
	VARIABLE func4_AI_SIMULATE_Status_Quality; \
	VARIABLE func4_AI_SIMULATE_Status_Limit; \
	MENU func4_AI_SIMULATE_page; \
	COMMAND func4_AI_SIMULATE_read; \
	COMMAND func4_AI_SIMULATE_write; \
	COLLECTION func4_AI_VIEW_1; \
	MENU func4_AI_VIEW_1_page; \
	MENU func4_AI_Simple_Dialog_Mandatory_B; \
	UNIT func4_AI_OUT_SCALE_unit_1; \
	MENU func4_AI_Simulation; \
	MENU func4_AI_Simulation_input; \
	MENU func4_AI_Simulation_input_group; \
	MENU func4_AI_Simulation_output; \
	MENU func4_AI_Simulation_output_group; \
	MENU func4_AI_Display_mandatory_B; \
	CHART func4_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func4_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func4_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func4_AI_Display_out_mandatory_B; \
	MENU func4_AI_Display_in_mandatory_B; \
	MENU func4_AI_Tab_s_mandatory_B; \
	MENU func4_AI_Tab_s_pv_range_mandatory_B; \
	MENU func4_AI_Tab_s_outscale_mandatory_B; \
	MENU func4_AI_Tab_s_limits_mandatory_B; \
	MENU func4_AI_Tab_s_interface_mandatory_B; \
	MENU func4_AI_Tab_m_mandatory_B; \
	MENU func4_AI_Tab_m_pv_range_mandatory_B; \
	MENU func4_AI_Tab_m_outscale_mandatory_B; \
	MENU func4_AI_Tab_m_limits_mandatory_B

#define USE_FUNC4_AI_OPTIONAL_BOTH \
	VARIABLE func4_AI_FSAFE_TYPE; \
	MENU func4_AI_FSAFE_TYPE_page; \
	COMMAND func4_AI_FSAFE_TYPE_read; \
	COMMAND func4_AI_FSAFE_TYPE_write; \
	VARIABLE func4_AI_FSAFE_VALUE; \
	MENU func4_AI_FSAFE_VALUE_page; \
	COMMAND func4_AI_FSAFE_VALUE_read; \
	COMMAND func4_AI_FSAFE_VALUE_write; \
	COLLECTION func4_AI_HI_HI_ALM; \
	VARIABLE func4_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func4_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func4_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func4_AI_HI_HI_ALM_Subcode; \
	VARIABLE func4_AI_HI_HI_ALM_Value; \
	MENU func4_AI_HI_HI_ALM_page; \
	COMMAND func4_AI_HI_HI_ALM_read; \
	COLLECTION func4_AI_HI_ALM; \
	VARIABLE func4_AI_HI_ALM_Unacknowledged; \
	VARIABLE func4_AI_HI_ALM_Alarm_State; \
	VARIABLE func4_AI_HI_ALM_Time_Stamp; \
	VARIABLE func4_AI_HI_ALM_Subcode; \
	VARIABLE func4_AI_HI_ALM_Value; \
	MENU func4_AI_HI_ALM_page; \
	COMMAND func4_AI_HI_ALM_read; \
	COLLECTION func4_AI_LO_ALM; \
	VARIABLE func4_AI_LO_ALM_Unacknowledged; \
	VARIABLE func4_AI_LO_ALM_Alarm_State; \
	VARIABLE func4_AI_LO_ALM_Time_Stamp; \
	VARIABLE func4_AI_LO_ALM_Subcode; \
	VARIABLE func4_AI_LO_ALM_Value; \
	MENU func4_AI_LO_ALM_page; \
	COMMAND func4_AI_LO_ALM_read; \
	COLLECTION func4_AI_LO_LO_ALM; \
	VARIABLE func4_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func4_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func4_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func4_AI_LO_LO_ALM_Subcode; \
	VARIABLE func4_AI_LO_LO_ALM_Value; \
	MENU func4_AI_LO_LO_ALM_page; \
	COMMAND func4_AI_LO_LO_ALM_read; \
	VARIABLE func4_AI_OUT_UNIT_TEXT; \
	MENU func4_AI_OUT_UNIT_TEXT_page; \
	COMMAND func4_AI_OUT_UNIT_TEXT_read; \
	COMMAND func4_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func4_AI_VIEW_2; \
	MENU func4_AI_VIEW_2_page; \
	COLLECTION func4_AI_VIEW_3; \
	MENU func4_AI_VIEW_3_page

#define USE_FUNC4_AI_OPTIONAL_A \
	USE_FUNC4_AI_OPTIONAL_BOTH; \
	COLLECTION func4_AI_OUT_SCALE; \
	VARIABLE func4_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func4_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func4_AI_OUT_SCALE_Units_Index; \
	VARIABLE func4_AI_OUT_SCALE_Decimal_Point; \
	MENU func4_AI_OUT_SCALE_page; \
	COMMAND func4_AI_OUT_SCALE_read; \
	COMMAND func4_AI_OUT_SCALE_write; \
	VARIABLE func4_AI_LIN_TYPE; \
	MENU func4_AI_LIN_TYPE_page; \
	COMMAND func4_AI_LIN_TYPE_read; \
	COMMAND func4_AI_LIN_TYPE_write; \
	VARIABLE func4_AI_CHANNEL; \
	MENU func4_AI_CHANNEL_page; \
	COMMAND func4_AI_CHANNEL_read; \
	COMMAND func4_AI_CHANNEL_write; \
	COLLECTION func4_AI_SIMULATE; \
	VARIABLE func4_AI_SIMULATE_Status_Condensed; \
	VARIABLE func4_AI_SIMULATE_Value; \
	VARIABLE func4_AI_SIMULATE_Enabled; \
	VARIABLE func4_AI_SIMULATE_Status_Quality; \
	VARIABLE func4_AI_SIMULATE_Status_Limit; \
	MENU func4_AI_SIMULATE_page; \
	COMMAND func4_AI_SIMULATE_read; \
	COMMAND func4_AI_SIMULATE_write; \
	COLLECTION func4_AI_VIEW_1; \
	MENU func4_AI_VIEW_1_page; \
	MENU func4_AI_Simple_Dialog_Optional_A; \
	UNIT func4_AI_OUT_SCALE_unit_1; \
	UNIT func4_AI_OUT_SCALE_unit_2

#define USE_FUNC4_AI_OPTIONAL_B \
	USE_FUNC4_AI_OPTIONAL_BOTH; \
	MENU func4_AI_Simple_Dialog_Optional_B; \
	UNIT func4_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC4_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func4_AI_)
#define USE_FUNC4_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func4_AI_)
#define USE_FUNC4_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func4_AI_)
#define USE_FUNC4_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func4_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC5_AI_MANDATORY_BOTH \
	BLOCK func5_AI_block; \
	COLLECTION func5_AI_BLOCK_OBJECT; \
	VARIABLE func5_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func5_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func5_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func5_AI_BLOCK_OBJECT_Class; \
	VARIABLE func5_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func5_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func5_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func5_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func5_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func5_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func5_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func5_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func5_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func5_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func5_AI_BLOCK_OBJECT_page; \
	COMMAND func5_AI_BLOCK_OBJECT_read; \
	VARIABLE func5_AI_ST_REV; \
	MENU func5_AI_ST_REV_page; \
	COMMAND func5_AI_ST_REV_read; \
	VARIABLE func5_AI_TAG_DESC; \
	MENU func5_AI_TAG_DESC_page; \
	COMMAND func5_AI_TAG_DESC_read; \
	COMMAND func5_AI_TAG_DESC_write; \
	VARIABLE func5_AI_STRATEGY; \
	MENU func5_AI_STRATEGY_page; \
	COMMAND func5_AI_STRATEGY_read; \
	COMMAND func5_AI_STRATEGY_write; \
	VARIABLE func5_AI_ALERT_KEY; \
	MENU func5_AI_ALERT_KEY_page; \
	COMMAND func5_AI_ALERT_KEY_read; \
	COMMAND func5_AI_ALERT_KEY_write; \
	VARIABLE func5_AI_TARGET_MODE; \
	MENU func5_AI_TARGET_MODE_page; \
	COMMAND func5_AI_TARGET_MODE_read; \
	COMMAND func5_AI_TARGET_MODE_write; \
	COLLECTION func5_AI_MODE_BLK; \
	VARIABLE func5_AI_MODE_BLK_Actual; \
	VARIABLE func5_AI_MODE_BLK_Permitted; \
	VARIABLE func5_AI_MODE_BLK_Normal; \
	MENU func5_AI_MODE_BLK_page; \
	COMMAND func5_AI_MODE_BLK_read; \
	COLLECTION func5_AI_ALARM_SUM; \
	VARIABLE func5_AI_ALARM_SUM_Current; \
	VARIABLE func5_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func5_AI_ALARM_SUM_Unreported; \
	VARIABLE func5_AI_ALARM_SUM_Disabled; \
	MENU func5_AI_ALARM_SUM_page; \
	COMMAND func5_AI_ALARM_SUM_read; \
	COLLECTION func5_AI_BATCH; \
	VARIABLE func5_AI_BATCH_Batch_ID; \
	VARIABLE func5_AI_BATCH_Rup; \
	VARIABLE func5_AI_BATCH_Operation; \
	VARIABLE func5_AI_BATCH_Phase; \
	MENU func5_AI_BATCH_page; \
	COMMAND func5_AI_BATCH_read; \
	COMMAND func5_AI_BATCH_write; \
	COLLECTION func5_AI_OUT; \
	VARIABLE func5_AI_OUT_Value; \
	VARIABLE func5_AI_OUT_Status_Condensed; \
	VARIABLE func5_AI_OUT_Status_Quality; \
	VARIABLE func5_AI_OUT_Status_Limit; \
	MENU func5_AI_OUT_page; \
	COMMAND func5_AI_OUT_read; \
	COMMAND func5_AI_OUT_write; \
	COLLECTION func5_AI_PV_SCALE; \
	VARIABLE func5_AI_PV_SCALE_Upper_Value; \
	VARIABLE func5_AI_PV_SCALE_Lower_Value; \
	MENU func5_AI_PV_SCALE_page; \
	COMMAND func5_AI_PV_SCALE_read; \
	COMMAND func5_AI_PV_SCALE_write; \
	VARIABLE func5_AI_PV_FTIME; \
	MENU func5_AI_PV_FTIME_page; \
	COMMAND func5_AI_PV_FTIME_read; \
	COMMAND func5_AI_PV_FTIME_write; \
	VARIABLE func5_AI_ALARM_HYS; \
	MENU func5_AI_ALARM_HYS_page; \
	COMMAND func5_AI_ALARM_HYS_read; \
	COMMAND func5_AI_ALARM_HYS_write; \
	VARIABLE func5_AI_HI_HI_LIM; \
	MENU func5_AI_HI_HI_LIM_page; \
	COMMAND func5_AI_HI_HI_LIM_read; \
	COMMAND func5_AI_HI_HI_LIM_write; \
	VARIABLE func5_AI_HI_LIM; \
	MENU func5_AI_HI_LIM_page; \
	COMMAND func5_AI_HI_LIM_read; \
	COMMAND func5_AI_HI_LIM_write; \
	VARIABLE func5_AI_LO_LIM; \
	MENU func5_AI_LO_LIM_page; \
	COMMAND func5_AI_LO_LIM_read; \
	COMMAND func5_AI_LO_LIM_write; \
	VARIABLE func5_AI_LO_LO_LIM; \
	MENU func5_AI_LO_LO_LIM_page; \
	COMMAND func5_AI_LO_LO_LIM_read; \
	COMMAND func5_AI_LO_LO_LIM_write

#define USE_FUNC5_AI_MANDATORY_A \
	USE_FUNC5_AI_MANDATORY_BOTH; \
	MENU func5_AI_Simple_Dialog_Mandatory_A; \
	MENU func5_AI_Display_mandatory_A; \
	CHART func5_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func5_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func5_AI_Display_out_mandatory_A; \
	MENU func5_AI_Tab_s_mandatory_A; \
	MENU func5_AI_Tab_s_pv_range_mandatory_A; \
	MENU func5_AI_Tab_s_limits_mandatory_A; \
	MENU func5_AI_Tab_m_mandatory_A; \
	MENU func5_AI_Tab_m_pv_range_mandatory_A; \
	MENU func5_AI_Tab_m_limits_mandatory_A

#define USE_FUNC5_AI_MANDATORY_B \
	USE_FUNC5_AI_MANDATORY_BOTH; \
	COLLECTION func5_AI_OUT_SCALE; \
	VARIABLE func5_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func5_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func5_AI_OUT_SCALE_Units_Index; \
	VARIABLE func5_AI_OUT_SCALE_Decimal_Point; \
	MENU func5_AI_OUT_SCALE_page; \
	COMMAND func5_AI_OUT_SCALE_read; \
	COMMAND func5_AI_OUT_SCALE_write; \
	VARIABLE func5_AI_LIN_TYPE; \
	MENU func5_AI_LIN_TYPE_page; \
	COMMAND func5_AI_LIN_TYPE_read; \
	COMMAND func5_AI_LIN_TYPE_write; \
	VARIABLE func5_AI_CHANNEL; \
	MENU func5_AI_CHANNEL_page; \
	COMMAND func5_AI_CHANNEL_read; \
	COMMAND func5_AI_CHANNEL_write; \
	COLLECTION func5_AI_SIMULATE; \
	VARIABLE func5_AI_SIMULATE_Status_Condensed; \
	VARIABLE func5_AI_SIMULATE_Value; \
	VARIABLE func5_AI_SIMULATE_Enabled; \
	VARIABLE func5_AI_SIMULATE_Status_Quality; \
	VARIABLE func5_AI_SIMULATE_Status_Limit; \
	MENU func5_AI_SIMULATE_page; \
	COMMAND func5_AI_SIMULATE_read; \
	COMMAND func5_AI_SIMULATE_write; \
	COLLECTION func5_AI_VIEW_1; \
	MENU func5_AI_VIEW_1_page; \
	MENU func5_AI_Simple_Dialog_Mandatory_B; \
	UNIT func5_AI_OUT_SCALE_unit_1; \
	MENU func5_AI_Simulation; \
	MENU func5_AI_Simulation_input; \
	MENU func5_AI_Simulation_input_group; \
	MENU func5_AI_Simulation_output; \
	MENU func5_AI_Simulation_output_group; \
	MENU func5_AI_Display_mandatory_B; \
	CHART func5_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func5_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func5_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func5_AI_Display_out_mandatory_B; \
	MENU func5_AI_Display_in_mandatory_B; \
	MENU func5_AI_Tab_s_mandatory_B; \
	MENU func5_AI_Tab_s_pv_range_mandatory_B; \
	MENU func5_AI_Tab_s_outscale_mandatory_B; \
	MENU func5_AI_Tab_s_limits_mandatory_B; \
	MENU func5_AI_Tab_s_interface_mandatory_B; \
	MENU func5_AI_Tab_m_mandatory_B; \
	MENU func5_AI_Tab_m_pv_range_mandatory_B; \
	MENU func5_AI_Tab_m_outscale_mandatory_B; \
	MENU func5_AI_Tab_m_limits_mandatory_B

#define USE_FUNC5_AI_OPTIONAL_BOTH \
	VARIABLE func5_AI_FSAFE_TYPE; \
	MENU func5_AI_FSAFE_TYPE_page; \
	COMMAND func5_AI_FSAFE_TYPE_read; \
	COMMAND func5_AI_FSAFE_TYPE_write; \
	VARIABLE func5_AI_FSAFE_VALUE; \
	MENU func5_AI_FSAFE_VALUE_page; \
	COMMAND func5_AI_FSAFE_VALUE_read; \
	COMMAND func5_AI_FSAFE_VALUE_write; \
	COLLECTION func5_AI_HI_HI_ALM; \
	VARIABLE func5_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func5_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func5_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func5_AI_HI_HI_ALM_Subcode; \
	VARIABLE func5_AI_HI_HI_ALM_Value; \
	MENU func5_AI_HI_HI_ALM_page; \
	COMMAND func5_AI_HI_HI_ALM_read; \
	COLLECTION func5_AI_HI_ALM; \
	VARIABLE func5_AI_HI_ALM_Unacknowledged; \
	VARIABLE func5_AI_HI_ALM_Alarm_State; \
	VARIABLE func5_AI_HI_ALM_Time_Stamp; \
	VARIABLE func5_AI_HI_ALM_Subcode; \
	VARIABLE func5_AI_HI_ALM_Value; \
	MENU func5_AI_HI_ALM_page; \
	COMMAND func5_AI_HI_ALM_read; \
	COLLECTION func5_AI_LO_ALM; \
	VARIABLE func5_AI_LO_ALM_Unacknowledged; \
	VARIABLE func5_AI_LO_ALM_Alarm_State; \
	VARIABLE func5_AI_LO_ALM_Time_Stamp; \
	VARIABLE func5_AI_LO_ALM_Subcode; \
	VARIABLE func5_AI_LO_ALM_Value; \
	MENU func5_AI_LO_ALM_page; \
	COMMAND func5_AI_LO_ALM_read; \
	COLLECTION func5_AI_LO_LO_ALM; \
	VARIABLE func5_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func5_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func5_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func5_AI_LO_LO_ALM_Subcode; \
	VARIABLE func5_AI_LO_LO_ALM_Value; \
	MENU func5_AI_LO_LO_ALM_page; \
	COMMAND func5_AI_LO_LO_ALM_read; \
	VARIABLE func5_AI_OUT_UNIT_TEXT; \
	MENU func5_AI_OUT_UNIT_TEXT_page; \
	COMMAND func5_AI_OUT_UNIT_TEXT_read; \
	COMMAND func5_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func5_AI_VIEW_2; \
	MENU func5_AI_VIEW_2_page; \
	COLLECTION func5_AI_VIEW_3; \
	MENU func5_AI_VIEW_3_page

#define USE_FUNC5_AI_OPTIONAL_A \
	USE_FUNC5_AI_OPTIONAL_BOTH; \
	COLLECTION func5_AI_OUT_SCALE; \
	VARIABLE func5_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func5_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func5_AI_OUT_SCALE_Units_Index; \
	VARIABLE func5_AI_OUT_SCALE_Decimal_Point; \
	MENU func5_AI_OUT_SCALE_page; \
	COMMAND func5_AI_OUT_SCALE_read; \
	COMMAND func5_AI_OUT_SCALE_write; \
	VARIABLE func5_AI_LIN_TYPE; \
	MENU func5_AI_LIN_TYPE_page; \
	COMMAND func5_AI_LIN_TYPE_read; \
	COMMAND func5_AI_LIN_TYPE_write; \
	VARIABLE func5_AI_CHANNEL; \
	MENU func5_AI_CHANNEL_page; \
	COMMAND func5_AI_CHANNEL_read; \
	COMMAND func5_AI_CHANNEL_write; \
	COLLECTION func5_AI_SIMULATE; \
	VARIABLE func5_AI_SIMULATE_Status_Condensed; \
	VARIABLE func5_AI_SIMULATE_Value; \
	VARIABLE func5_AI_SIMULATE_Enabled; \
	VARIABLE func5_AI_SIMULATE_Status_Quality; \
	VARIABLE func5_AI_SIMULATE_Status_Limit; \
	MENU func5_AI_SIMULATE_page; \
	COMMAND func5_AI_SIMULATE_read; \
	COMMAND func5_AI_SIMULATE_write; \
	COLLECTION func5_AI_VIEW_1; \
	MENU func5_AI_VIEW_1_page; \
	MENU func5_AI_Simple_Dialog_Optional_A; \
	UNIT func5_AI_OUT_SCALE_unit_1; \
	UNIT func5_AI_OUT_SCALE_unit_2

#define USE_FUNC5_AI_OPTIONAL_B \
	USE_FUNC5_AI_OPTIONAL_BOTH; \
	MENU func5_AI_Simple_Dialog_Optional_B; \
	UNIT func5_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC5_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func5_AI_)
#define USE_FUNC5_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func5_AI_)
#define USE_FUNC5_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func5_AI_)
#define USE_FUNC5_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func5_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC6_AI_MANDATORY_BOTH \
	BLOCK func6_AI_block; \
	COLLECTION func6_AI_BLOCK_OBJECT; \
	VARIABLE func6_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func6_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func6_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func6_AI_BLOCK_OBJECT_Class; \
	VARIABLE func6_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func6_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func6_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func6_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func6_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func6_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func6_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func6_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func6_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func6_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func6_AI_BLOCK_OBJECT_page; \
	COMMAND func6_AI_BLOCK_OBJECT_read; \
	VARIABLE func6_AI_ST_REV; \
	MENU func6_AI_ST_REV_page; \
	COMMAND func6_AI_ST_REV_read; \
	VARIABLE func6_AI_TAG_DESC; \
	MENU func6_AI_TAG_DESC_page; \
	COMMAND func6_AI_TAG_DESC_read; \
	COMMAND func6_AI_TAG_DESC_write; \
	VARIABLE func6_AI_STRATEGY; \
	MENU func6_AI_STRATEGY_page; \
	COMMAND func6_AI_STRATEGY_read; \
	COMMAND func6_AI_STRATEGY_write; \
	VARIABLE func6_AI_ALERT_KEY; \
	MENU func6_AI_ALERT_KEY_page; \
	COMMAND func6_AI_ALERT_KEY_read; \
	COMMAND func6_AI_ALERT_KEY_write; \
	VARIABLE func6_AI_TARGET_MODE; \
	MENU func6_AI_TARGET_MODE_page; \
	COMMAND func6_AI_TARGET_MODE_read; \
	COMMAND func6_AI_TARGET_MODE_write; \
	COLLECTION func6_AI_MODE_BLK; \
	VARIABLE func6_AI_MODE_BLK_Actual; \
	VARIABLE func6_AI_MODE_BLK_Permitted; \
	VARIABLE func6_AI_MODE_BLK_Normal; \
	MENU func6_AI_MODE_BLK_page; \
	COMMAND func6_AI_MODE_BLK_read; \
	COLLECTION func6_AI_ALARM_SUM; \
	VARIABLE func6_AI_ALARM_SUM_Current; \
	VARIABLE func6_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func6_AI_ALARM_SUM_Unreported; \
	VARIABLE func6_AI_ALARM_SUM_Disabled; \
	MENU func6_AI_ALARM_SUM_page; \
	COMMAND func6_AI_ALARM_SUM_read; \
	COLLECTION func6_AI_BATCH; \
	VARIABLE func6_AI_BATCH_Batch_ID; \
	VARIABLE func6_AI_BATCH_Rup; \
	VARIABLE func6_AI_BATCH_Operation; \
	VARIABLE func6_AI_BATCH_Phase; \
	MENU func6_AI_BATCH_page; \
	COMMAND func6_AI_BATCH_read; \
	COMMAND func6_AI_BATCH_write; \
	COLLECTION func6_AI_OUT; \
	VARIABLE func6_AI_OUT_Value; \
	VARIABLE func6_AI_OUT_Status_Condensed; \
	VARIABLE func6_AI_OUT_Status_Quality; \
	VARIABLE func6_AI_OUT_Status_Limit; \
	MENU func6_AI_OUT_page; \
	COMMAND func6_AI_OUT_read; \
	COMMAND func6_AI_OUT_write; \
	COLLECTION func6_AI_PV_SCALE; \
	VARIABLE func6_AI_PV_SCALE_Upper_Value; \
	VARIABLE func6_AI_PV_SCALE_Lower_Value; \
	MENU func6_AI_PV_SCALE_page; \
	COMMAND func6_AI_PV_SCALE_read; \
	COMMAND func6_AI_PV_SCALE_write; \
	VARIABLE func6_AI_PV_FTIME; \
	MENU func6_AI_PV_FTIME_page; \
	COMMAND func6_AI_PV_FTIME_read; \
	COMMAND func6_AI_PV_FTIME_write; \
	VARIABLE func6_AI_ALARM_HYS; \
	MENU func6_AI_ALARM_HYS_page; \
	COMMAND func6_AI_ALARM_HYS_read; \
	COMMAND func6_AI_ALARM_HYS_write; \
	VARIABLE func6_AI_HI_HI_LIM; \
	MENU func6_AI_HI_HI_LIM_page; \
	COMMAND func6_AI_HI_HI_LIM_read; \
	COMMAND func6_AI_HI_HI_LIM_write; \
	VARIABLE func6_AI_HI_LIM; \
	MENU func6_AI_HI_LIM_page; \
	COMMAND func6_AI_HI_LIM_read; \
	COMMAND func6_AI_HI_LIM_write; \
	VARIABLE func6_AI_LO_LIM; \
	MENU func6_AI_LO_LIM_page; \
	COMMAND func6_AI_LO_LIM_read; \
	COMMAND func6_AI_LO_LIM_write; \
	VARIABLE func6_AI_LO_LO_LIM; \
	MENU func6_AI_LO_LO_LIM_page; \
	COMMAND func6_AI_LO_LO_LIM_read; \
	COMMAND func6_AI_LO_LO_LIM_write

#define USE_FUNC6_AI_MANDATORY_A \
	USE_FUNC6_AI_MANDATORY_BOTH; \
	MENU func6_AI_Simple_Dialog_Mandatory_A; \
	MENU func6_AI_Display_mandatory_A; \
	CHART func6_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func6_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func6_AI_Display_out_mandatory_A; \
	MENU func6_AI_Tab_s_mandatory_A; \
	MENU func6_AI_Tab_s_pv_range_mandatory_A; \
	MENU func6_AI_Tab_s_limits_mandatory_A; \
	MENU func6_AI_Tab_m_mandatory_A; \
	MENU func6_AI_Tab_m_pv_range_mandatory_A; \
	MENU func6_AI_Tab_m_limits_mandatory_A

#define USE_FUNC6_AI_MANDATORY_B \
	USE_FUNC6_AI_MANDATORY_BOTH; \
	COLLECTION func6_AI_OUT_SCALE; \
	VARIABLE func6_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func6_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func6_AI_OUT_SCALE_Units_Index; \
	VARIABLE func6_AI_OUT_SCALE_Decimal_Point; \
	MENU func6_AI_OUT_SCALE_page; \
	COMMAND func6_AI_OUT_SCALE_read; \
	COMMAND func6_AI_OUT_SCALE_write; \
	VARIABLE func6_AI_LIN_TYPE; \
	MENU func6_AI_LIN_TYPE_page; \
	COMMAND func6_AI_LIN_TYPE_read; \
	COMMAND func6_AI_LIN_TYPE_write; \
	VARIABLE func6_AI_CHANNEL; \
	MENU func6_AI_CHANNEL_page; \
	COMMAND func6_AI_CHANNEL_read; \
	COMMAND func6_AI_CHANNEL_write; \
	COLLECTION func6_AI_SIMULATE; \
	VARIABLE func6_AI_SIMULATE_Status_Condensed; \
	VARIABLE func6_AI_SIMULATE_Value; \
	VARIABLE func6_AI_SIMULATE_Enabled; \
	VARIABLE func6_AI_SIMULATE_Status_Quality; \
	VARIABLE func6_AI_SIMULATE_Status_Limit; \
	MENU func6_AI_SIMULATE_page; \
	COMMAND func6_AI_SIMULATE_read; \
	COMMAND func6_AI_SIMULATE_write; \
	COLLECTION func6_AI_VIEW_1; \
	MENU func6_AI_VIEW_1_page; \
	MENU func6_AI_Simple_Dialog_Mandatory_B; \
	UNIT func6_AI_OUT_SCALE_unit_1; \
	MENU func6_AI_Simulation; \
	MENU func6_AI_Simulation_input; \
	MENU func6_AI_Simulation_input_group; \
	MENU func6_AI_Simulation_output; \
	MENU func6_AI_Simulation_output_group; \
	MENU func6_AI_Display_mandatory_B; \
	CHART func6_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func6_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func6_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func6_AI_Display_out_mandatory_B; \
	MENU func6_AI_Display_in_mandatory_B; \
	MENU func6_AI_Tab_s_mandatory_B; \
	MENU func6_AI_Tab_s_pv_range_mandatory_B; \
	MENU func6_AI_Tab_s_outscale_mandatory_B; \
	MENU func6_AI_Tab_s_limits_mandatory_B; \
	MENU func6_AI_Tab_s_interface_mandatory_B; \
	MENU func6_AI_Tab_m_mandatory_B; \
	MENU func6_AI_Tab_m_pv_range_mandatory_B; \
	MENU func6_AI_Tab_m_outscale_mandatory_B; \
	MENU func6_AI_Tab_m_limits_mandatory_B

#define USE_FUNC6_AI_OPTIONAL_BOTH \
	VARIABLE func6_AI_FSAFE_TYPE; \
	MENU func6_AI_FSAFE_TYPE_page; \
	COMMAND func6_AI_FSAFE_TYPE_read; \
	COMMAND func6_AI_FSAFE_TYPE_write; \
	VARIABLE func6_AI_FSAFE_VALUE; \
	MENU func6_AI_FSAFE_VALUE_page; \
	COMMAND func6_AI_FSAFE_VALUE_read; \
	COMMAND func6_AI_FSAFE_VALUE_write; \
	COLLECTION func6_AI_HI_HI_ALM; \
	VARIABLE func6_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func6_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func6_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func6_AI_HI_HI_ALM_Subcode; \
	VARIABLE func6_AI_HI_HI_ALM_Value; \
	MENU func6_AI_HI_HI_ALM_page; \
	COMMAND func6_AI_HI_HI_ALM_read; \
	COLLECTION func6_AI_HI_ALM; \
	VARIABLE func6_AI_HI_ALM_Unacknowledged; \
	VARIABLE func6_AI_HI_ALM_Alarm_State; \
	VARIABLE func6_AI_HI_ALM_Time_Stamp; \
	VARIABLE func6_AI_HI_ALM_Subcode; \
	VARIABLE func6_AI_HI_ALM_Value; \
	MENU func6_AI_HI_ALM_page; \
	COMMAND func6_AI_HI_ALM_read; \
	COLLECTION func6_AI_LO_ALM; \
	VARIABLE func6_AI_LO_ALM_Unacknowledged; \
	VARIABLE func6_AI_LO_ALM_Alarm_State; \
	VARIABLE func6_AI_LO_ALM_Time_Stamp; \
	VARIABLE func6_AI_LO_ALM_Subcode; \
	VARIABLE func6_AI_LO_ALM_Value; \
	MENU func6_AI_LO_ALM_page; \
	COMMAND func6_AI_LO_ALM_read; \
	COLLECTION func6_AI_LO_LO_ALM; \
	VARIABLE func6_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func6_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func6_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func6_AI_LO_LO_ALM_Subcode; \
	VARIABLE func6_AI_LO_LO_ALM_Value; \
	MENU func6_AI_LO_LO_ALM_page; \
	COMMAND func6_AI_LO_LO_ALM_read; \
	VARIABLE func6_AI_OUT_UNIT_TEXT; \
	MENU func6_AI_OUT_UNIT_TEXT_page; \
	COMMAND func6_AI_OUT_UNIT_TEXT_read; \
	COMMAND func6_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func6_AI_VIEW_2; \
	MENU func6_AI_VIEW_2_page; \
	COLLECTION func6_AI_VIEW_3; \
	MENU func6_AI_VIEW_3_page

#define USE_FUNC6_AI_OPTIONAL_A \
	USE_FUNC6_AI_OPTIONAL_BOTH; \
	COLLECTION func6_AI_OUT_SCALE; \
	VARIABLE func6_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func6_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func6_AI_OUT_SCALE_Units_Index; \
	VARIABLE func6_AI_OUT_SCALE_Decimal_Point; \
	MENU func6_AI_OUT_SCALE_page; \
	COMMAND func6_AI_OUT_SCALE_read; \
	COMMAND func6_AI_OUT_SCALE_write; \
	VARIABLE func6_AI_LIN_TYPE; \
	MENU func6_AI_LIN_TYPE_page; \
	COMMAND func6_AI_LIN_TYPE_read; \
	COMMAND func6_AI_LIN_TYPE_write; \
	VARIABLE func6_AI_CHANNEL; \
	MENU func6_AI_CHANNEL_page; \
	COMMAND func6_AI_CHANNEL_read; \
	COMMAND func6_AI_CHANNEL_write; \
	COLLECTION func6_AI_SIMULATE; \
	VARIABLE func6_AI_SIMULATE_Status_Condensed; \
	VARIABLE func6_AI_SIMULATE_Value; \
	VARIABLE func6_AI_SIMULATE_Enabled; \
	VARIABLE func6_AI_SIMULATE_Status_Quality; \
	VARIABLE func6_AI_SIMULATE_Status_Limit; \
	MENU func6_AI_SIMULATE_page; \
	COMMAND func6_AI_SIMULATE_read; \
	COMMAND func6_AI_SIMULATE_write; \
	COLLECTION func6_AI_VIEW_1; \
	MENU func6_AI_VIEW_1_page; \
	MENU func6_AI_Simple_Dialog_Optional_A; \
	UNIT func6_AI_OUT_SCALE_unit_1; \
	UNIT func6_AI_OUT_SCALE_unit_2

#define USE_FUNC6_AI_OPTIONAL_B \
	USE_FUNC6_AI_OPTIONAL_BOTH; \
	MENU func6_AI_Simple_Dialog_Optional_B; \
	UNIT func6_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC6_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func6_AI_)
#define USE_FUNC6_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func6_AI_)
#define USE_FUNC6_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func6_AI_)
#define USE_FUNC6_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func6_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC7_AI_MANDATORY_BOTH \
	BLOCK func7_AI_block; \
	COLLECTION func7_AI_BLOCK_OBJECT; \
	VARIABLE func7_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func7_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func7_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func7_AI_BLOCK_OBJECT_Class; \
	VARIABLE func7_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func7_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func7_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func7_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func7_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func7_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func7_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func7_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func7_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func7_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func7_AI_BLOCK_OBJECT_page; \
	COMMAND func7_AI_BLOCK_OBJECT_read; \
	VARIABLE func7_AI_ST_REV; \
	MENU func7_AI_ST_REV_page; \
	COMMAND func7_AI_ST_REV_read; \
	VARIABLE func7_AI_TAG_DESC; \
	MENU func7_AI_TAG_DESC_page; \
	COMMAND func7_AI_TAG_DESC_read; \
	COMMAND func7_AI_TAG_DESC_write; \
	VARIABLE func7_AI_STRATEGY; \
	MENU func7_AI_STRATEGY_page; \
	COMMAND func7_AI_STRATEGY_read; \
	COMMAND func7_AI_STRATEGY_write; \
	VARIABLE func7_AI_ALERT_KEY; \
	MENU func7_AI_ALERT_KEY_page; \
	COMMAND func7_AI_ALERT_KEY_read; \
	COMMAND func7_AI_ALERT_KEY_write; \
	VARIABLE func7_AI_TARGET_MODE; \
	MENU func7_AI_TARGET_MODE_page; \
	COMMAND func7_AI_TARGET_MODE_read; \
	COMMAND func7_AI_TARGET_MODE_write; \
	COLLECTION func7_AI_MODE_BLK; \
	VARIABLE func7_AI_MODE_BLK_Actual; \
	VARIABLE func7_AI_MODE_BLK_Permitted; \
	VARIABLE func7_AI_MODE_BLK_Normal; \
	MENU func7_AI_MODE_BLK_page; \
	COMMAND func7_AI_MODE_BLK_read; \
	COLLECTION func7_AI_ALARM_SUM; \
	VARIABLE func7_AI_ALARM_SUM_Current; \
	VARIABLE func7_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func7_AI_ALARM_SUM_Unreported; \
	VARIABLE func7_AI_ALARM_SUM_Disabled; \
	MENU func7_AI_ALARM_SUM_page; \
	COMMAND func7_AI_ALARM_SUM_read; \
	COLLECTION func7_AI_BATCH; \
	VARIABLE func7_AI_BATCH_Batch_ID; \
	VARIABLE func7_AI_BATCH_Rup; \
	VARIABLE func7_AI_BATCH_Operation; \
	VARIABLE func7_AI_BATCH_Phase; \
	MENU func7_AI_BATCH_page; \
	COMMAND func7_AI_BATCH_read; \
	COMMAND func7_AI_BATCH_write; \
	COLLECTION func7_AI_OUT; \
	VARIABLE func7_AI_OUT_Value; \
	VARIABLE func7_AI_OUT_Status_Condensed; \
	VARIABLE func7_AI_OUT_Status_Quality; \
	VARIABLE func7_AI_OUT_Status_Limit; \
	MENU func7_AI_OUT_page; \
	COMMAND func7_AI_OUT_read; \
	COMMAND func7_AI_OUT_write; \
	COLLECTION func7_AI_PV_SCALE; \
	VARIABLE func7_AI_PV_SCALE_Upper_Value; \
	VARIABLE func7_AI_PV_SCALE_Lower_Value; \
	MENU func7_AI_PV_SCALE_page; \
	COMMAND func7_AI_PV_SCALE_read; \
	COMMAND func7_AI_PV_SCALE_write; \
	VARIABLE func7_AI_PV_FTIME; \
	MENU func7_AI_PV_FTIME_page; \
	COMMAND func7_AI_PV_FTIME_read; \
	COMMAND func7_AI_PV_FTIME_write; \
	VARIABLE func7_AI_ALARM_HYS; \
	MENU func7_AI_ALARM_HYS_page; \
	COMMAND func7_AI_ALARM_HYS_read; \
	COMMAND func7_AI_ALARM_HYS_write; \
	VARIABLE func7_AI_HI_HI_LIM; \
	MENU func7_AI_HI_HI_LIM_page; \
	COMMAND func7_AI_HI_HI_LIM_read; \
	COMMAND func7_AI_HI_HI_LIM_write; \
	VARIABLE func7_AI_HI_LIM; \
	MENU func7_AI_HI_LIM_page; \
	COMMAND func7_AI_HI_LIM_read; \
	COMMAND func7_AI_HI_LIM_write; \
	VARIABLE func7_AI_LO_LIM; \
	MENU func7_AI_LO_LIM_page; \
	COMMAND func7_AI_LO_LIM_read; \
	COMMAND func7_AI_LO_LIM_write; \
	VARIABLE func7_AI_LO_LO_LIM; \
	MENU func7_AI_LO_LO_LIM_page; \
	COMMAND func7_AI_LO_LO_LIM_read; \
	COMMAND func7_AI_LO_LO_LIM_write

#define USE_FUNC7_AI_MANDATORY_A \
	USE_FUNC7_AI_MANDATORY_BOTH; \
	MENU func7_AI_Simple_Dialog_Mandatory_A; \
	MENU func7_AI_Display_mandatory_A; \
	CHART func7_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func7_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func7_AI_Display_out_mandatory_A; \
	MENU func7_AI_Tab_s_mandatory_A; \
	MENU func7_AI_Tab_s_pv_range_mandatory_A; \
	MENU func7_AI_Tab_s_limits_mandatory_A; \
	MENU func7_AI_Tab_m_mandatory_A; \
	MENU func7_AI_Tab_m_pv_range_mandatory_A; \
	MENU func7_AI_Tab_m_limits_mandatory_A

#define USE_FUNC7_AI_MANDATORY_B \
	USE_FUNC7_AI_MANDATORY_BOTH; \
	COLLECTION func7_AI_OUT_SCALE; \
	VARIABLE func7_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func7_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func7_AI_OUT_SCALE_Units_Index; \
	VARIABLE func7_AI_OUT_SCALE_Decimal_Point; \
	MENU func7_AI_OUT_SCALE_page; \
	COMMAND func7_AI_OUT_SCALE_read; \
	COMMAND func7_AI_OUT_SCALE_write; \
	VARIABLE func7_AI_LIN_TYPE; \
	MENU func7_AI_LIN_TYPE_page; \
	COMMAND func7_AI_LIN_TYPE_read; \
	COMMAND func7_AI_LIN_TYPE_write; \
	VARIABLE func7_AI_CHANNEL; \
	MENU func7_AI_CHANNEL_page; \
	COMMAND func7_AI_CHANNEL_read; \
	COMMAND func7_AI_CHANNEL_write; \
	COLLECTION func7_AI_SIMULATE; \
	VARIABLE func7_AI_SIMULATE_Status_Condensed; \
	VARIABLE func7_AI_SIMULATE_Value; \
	VARIABLE func7_AI_SIMULATE_Enabled; \
	VARIABLE func7_AI_SIMULATE_Status_Quality; \
	VARIABLE func7_AI_SIMULATE_Status_Limit; \
	MENU func7_AI_SIMULATE_page; \
	COMMAND func7_AI_SIMULATE_read; \
	COMMAND func7_AI_SIMULATE_write; \
	COLLECTION func7_AI_VIEW_1; \
	MENU func7_AI_VIEW_1_page; \
	MENU func7_AI_Simple_Dialog_Mandatory_B; \
	UNIT func7_AI_OUT_SCALE_unit_1; \
	MENU func7_AI_Simulation; \
	MENU func7_AI_Simulation_input; \
	MENU func7_AI_Simulation_input_group; \
	MENU func7_AI_Simulation_output; \
	MENU func7_AI_Simulation_output_group; \
	MENU func7_AI_Display_mandatory_B; \
	CHART func7_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func7_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func7_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func7_AI_Display_out_mandatory_B; \
	MENU func7_AI_Display_in_mandatory_B; \
	MENU func7_AI_Tab_s_mandatory_B; \
	MENU func7_AI_Tab_s_pv_range_mandatory_B; \
	MENU func7_AI_Tab_s_outscale_mandatory_B; \
	MENU func7_AI_Tab_s_limits_mandatory_B; \
	MENU func7_AI_Tab_s_interface_mandatory_B; \
	MENU func7_AI_Tab_m_mandatory_B; \
	MENU func7_AI_Tab_m_pv_range_mandatory_B; \
	MENU func7_AI_Tab_m_outscale_mandatory_B; \
	MENU func7_AI_Tab_m_limits_mandatory_B

#define USE_FUNC7_AI_OPTIONAL_BOTH \
	VARIABLE func7_AI_FSAFE_TYPE; \
	MENU func7_AI_FSAFE_TYPE_page; \
	COMMAND func7_AI_FSAFE_TYPE_read; \
	COMMAND func7_AI_FSAFE_TYPE_write; \
	VARIABLE func7_AI_FSAFE_VALUE; \
	MENU func7_AI_FSAFE_VALUE_page; \
	COMMAND func7_AI_FSAFE_VALUE_read; \
	COMMAND func7_AI_FSAFE_VALUE_write; \
	COLLECTION func7_AI_HI_HI_ALM; \
	VARIABLE func7_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func7_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func7_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func7_AI_HI_HI_ALM_Subcode; \
	VARIABLE func7_AI_HI_HI_ALM_Value; \
	MENU func7_AI_HI_HI_ALM_page; \
	COMMAND func7_AI_HI_HI_ALM_read; \
	COLLECTION func7_AI_HI_ALM; \
	VARIABLE func7_AI_HI_ALM_Unacknowledged; \
	VARIABLE func7_AI_HI_ALM_Alarm_State; \
	VARIABLE func7_AI_HI_ALM_Time_Stamp; \
	VARIABLE func7_AI_HI_ALM_Subcode; \
	VARIABLE func7_AI_HI_ALM_Value; \
	MENU func7_AI_HI_ALM_page; \
	COMMAND func7_AI_HI_ALM_read; \
	COLLECTION func7_AI_LO_ALM; \
	VARIABLE func7_AI_LO_ALM_Unacknowledged; \
	VARIABLE func7_AI_LO_ALM_Alarm_State; \
	VARIABLE func7_AI_LO_ALM_Time_Stamp; \
	VARIABLE func7_AI_LO_ALM_Subcode; \
	VARIABLE func7_AI_LO_ALM_Value; \
	MENU func7_AI_LO_ALM_page; \
	COMMAND func7_AI_LO_ALM_read; \
	COLLECTION func7_AI_LO_LO_ALM; \
	VARIABLE func7_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func7_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func7_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func7_AI_LO_LO_ALM_Subcode; \
	VARIABLE func7_AI_LO_LO_ALM_Value; \
	MENU func7_AI_LO_LO_ALM_page; \
	COMMAND func7_AI_LO_LO_ALM_read; \
	VARIABLE func7_AI_OUT_UNIT_TEXT; \
	MENU func7_AI_OUT_UNIT_TEXT_page; \
	COMMAND func7_AI_OUT_UNIT_TEXT_read; \
	COMMAND func7_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func7_AI_VIEW_2; \
	MENU func7_AI_VIEW_2_page; \
	COLLECTION func7_AI_VIEW_3; \
	MENU func7_AI_VIEW_3_page

#define USE_FUNC7_AI_OPTIONAL_A \
	USE_FUNC7_AI_OPTIONAL_BOTH; \
	COLLECTION func7_AI_OUT_SCALE; \
	VARIABLE func7_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func7_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func7_AI_OUT_SCALE_Units_Index; \
	VARIABLE func7_AI_OUT_SCALE_Decimal_Point; \
	MENU func7_AI_OUT_SCALE_page; \
	COMMAND func7_AI_OUT_SCALE_read; \
	COMMAND func7_AI_OUT_SCALE_write; \
	VARIABLE func7_AI_LIN_TYPE; \
	MENU func7_AI_LIN_TYPE_page; \
	COMMAND func7_AI_LIN_TYPE_read; \
	COMMAND func7_AI_LIN_TYPE_write; \
	VARIABLE func7_AI_CHANNEL; \
	MENU func7_AI_CHANNEL_page; \
	COMMAND func7_AI_CHANNEL_read; \
	COMMAND func7_AI_CHANNEL_write; \
	COLLECTION func7_AI_SIMULATE; \
	VARIABLE func7_AI_SIMULATE_Status_Condensed; \
	VARIABLE func7_AI_SIMULATE_Value; \
	VARIABLE func7_AI_SIMULATE_Enabled; \
	VARIABLE func7_AI_SIMULATE_Status_Quality; \
	VARIABLE func7_AI_SIMULATE_Status_Limit; \
	MENU func7_AI_SIMULATE_page; \
	COMMAND func7_AI_SIMULATE_read; \
	COMMAND func7_AI_SIMULATE_write; \
	COLLECTION func7_AI_VIEW_1; \
	MENU func7_AI_VIEW_1_page; \
	MENU func7_AI_Simple_Dialog_Optional_A; \
	UNIT func7_AI_OUT_SCALE_unit_1; \
	UNIT func7_AI_OUT_SCALE_unit_2

#define USE_FUNC7_AI_OPTIONAL_B \
	USE_FUNC7_AI_OPTIONAL_BOTH; \
	MENU func7_AI_Simple_Dialog_Optional_B; \
	UNIT func7_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC7_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func7_AI_)
#define USE_FUNC7_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func7_AI_)
#define USE_FUNC7_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func7_AI_)
#define USE_FUNC7_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func7_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC8_AI_MANDATORY_BOTH \
	BLOCK func8_AI_block; \
	COLLECTION func8_AI_BLOCK_OBJECT; \
	VARIABLE func8_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func8_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func8_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func8_AI_BLOCK_OBJECT_Class; \
	VARIABLE func8_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func8_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func8_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func8_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func8_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func8_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func8_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func8_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func8_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func8_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func8_AI_BLOCK_OBJECT_page; \
	COMMAND func8_AI_BLOCK_OBJECT_read; \
	VARIABLE func8_AI_ST_REV; \
	MENU func8_AI_ST_REV_page; \
	COMMAND func8_AI_ST_REV_read; \
	VARIABLE func8_AI_TAG_DESC; \
	MENU func8_AI_TAG_DESC_page; \
	COMMAND func8_AI_TAG_DESC_read; \
	COMMAND func8_AI_TAG_DESC_write; \
	VARIABLE func8_AI_STRATEGY; \
	MENU func8_AI_STRATEGY_page; \
	COMMAND func8_AI_STRATEGY_read; \
	COMMAND func8_AI_STRATEGY_write; \
	VARIABLE func8_AI_ALERT_KEY; \
	MENU func8_AI_ALERT_KEY_page; \
	COMMAND func8_AI_ALERT_KEY_read; \
	COMMAND func8_AI_ALERT_KEY_write; \
	VARIABLE func8_AI_TARGET_MODE; \
	MENU func8_AI_TARGET_MODE_page; \
	COMMAND func8_AI_TARGET_MODE_read; \
	COMMAND func8_AI_TARGET_MODE_write; \
	COLLECTION func8_AI_MODE_BLK; \
	VARIABLE func8_AI_MODE_BLK_Actual; \
	VARIABLE func8_AI_MODE_BLK_Permitted; \
	VARIABLE func8_AI_MODE_BLK_Normal; \
	MENU func8_AI_MODE_BLK_page; \
	COMMAND func8_AI_MODE_BLK_read; \
	COLLECTION func8_AI_ALARM_SUM; \
	VARIABLE func8_AI_ALARM_SUM_Current; \
	VARIABLE func8_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func8_AI_ALARM_SUM_Unreported; \
	VARIABLE func8_AI_ALARM_SUM_Disabled; \
	MENU func8_AI_ALARM_SUM_page; \
	COMMAND func8_AI_ALARM_SUM_read; \
	COLLECTION func8_AI_BATCH; \
	VARIABLE func8_AI_BATCH_Batch_ID; \
	VARIABLE func8_AI_BATCH_Rup; \
	VARIABLE func8_AI_BATCH_Operation; \
	VARIABLE func8_AI_BATCH_Phase; \
	MENU func8_AI_BATCH_page; \
	COMMAND func8_AI_BATCH_read; \
	COMMAND func8_AI_BATCH_write; \
	COLLECTION func8_AI_OUT; \
	VARIABLE func8_AI_OUT_Value; \
	VARIABLE func8_AI_OUT_Status_Condensed; \
	VARIABLE func8_AI_OUT_Status_Quality; \
	VARIABLE func8_AI_OUT_Status_Limit; \
	MENU func8_AI_OUT_page; \
	COMMAND func8_AI_OUT_read; \
	COMMAND func8_AI_OUT_write; \
	COLLECTION func8_AI_PV_SCALE; \
	VARIABLE func8_AI_PV_SCALE_Upper_Value; \
	VARIABLE func8_AI_PV_SCALE_Lower_Value; \
	MENU func8_AI_PV_SCALE_page; \
	COMMAND func8_AI_PV_SCALE_read; \
	COMMAND func8_AI_PV_SCALE_write; \
	VARIABLE func8_AI_PV_FTIME; \
	MENU func8_AI_PV_FTIME_page; \
	COMMAND func8_AI_PV_FTIME_read; \
	COMMAND func8_AI_PV_FTIME_write; \
	VARIABLE func8_AI_ALARM_HYS; \
	MENU func8_AI_ALARM_HYS_page; \
	COMMAND func8_AI_ALARM_HYS_read; \
	COMMAND func8_AI_ALARM_HYS_write; \
	VARIABLE func8_AI_HI_HI_LIM; \
	MENU func8_AI_HI_HI_LIM_page; \
	COMMAND func8_AI_HI_HI_LIM_read; \
	COMMAND func8_AI_HI_HI_LIM_write; \
	VARIABLE func8_AI_HI_LIM; \
	MENU func8_AI_HI_LIM_page; \
	COMMAND func8_AI_HI_LIM_read; \
	COMMAND func8_AI_HI_LIM_write; \
	VARIABLE func8_AI_LO_LIM; \
	MENU func8_AI_LO_LIM_page; \
	COMMAND func8_AI_LO_LIM_read; \
	COMMAND func8_AI_LO_LIM_write; \
	VARIABLE func8_AI_LO_LO_LIM; \
	MENU func8_AI_LO_LO_LIM_page; \
	COMMAND func8_AI_LO_LO_LIM_read; \
	COMMAND func8_AI_LO_LO_LIM_write

#define USE_FUNC8_AI_MANDATORY_A \
	USE_FUNC8_AI_MANDATORY_BOTH; \
	MENU func8_AI_Simple_Dialog_Mandatory_A; \
	MENU func8_AI_Display_mandatory_A; \
	CHART func8_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func8_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func8_AI_Display_out_mandatory_A; \
	MENU func8_AI_Tab_s_mandatory_A; \
	MENU func8_AI_Tab_s_pv_range_mandatory_A; \
	MENU func8_AI_Tab_s_limits_mandatory_A; \
	MENU func8_AI_Tab_m_mandatory_A; \
	MENU func8_AI_Tab_m_pv_range_mandatory_A; \
	MENU func8_AI_Tab_m_limits_mandatory_A

#define USE_FUNC8_AI_MANDATORY_B \
	USE_FUNC8_AI_MANDATORY_BOTH; \
	COLLECTION func8_AI_OUT_SCALE; \
	VARIABLE func8_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func8_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func8_AI_OUT_SCALE_Units_Index; \
	VARIABLE func8_AI_OUT_SCALE_Decimal_Point; \
	MENU func8_AI_OUT_SCALE_page; \
	COMMAND func8_AI_OUT_SCALE_read; \
	COMMAND func8_AI_OUT_SCALE_write; \
	VARIABLE func8_AI_LIN_TYPE; \
	MENU func8_AI_LIN_TYPE_page; \
	COMMAND func8_AI_LIN_TYPE_read; \
	COMMAND func8_AI_LIN_TYPE_write; \
	VARIABLE func8_AI_CHANNEL; \
	MENU func8_AI_CHANNEL_page; \
	COMMAND func8_AI_CHANNEL_read; \
	COMMAND func8_AI_CHANNEL_write; \
	COLLECTION func8_AI_SIMULATE; \
	VARIABLE func8_AI_SIMULATE_Status_Condensed; \
	VARIABLE func8_AI_SIMULATE_Value; \
	VARIABLE func8_AI_SIMULATE_Enabled; \
	VARIABLE func8_AI_SIMULATE_Status_Quality; \
	VARIABLE func8_AI_SIMULATE_Status_Limit; \
	MENU func8_AI_SIMULATE_page; \
	COMMAND func8_AI_SIMULATE_read; \
	COMMAND func8_AI_SIMULATE_write; \
	COLLECTION func8_AI_VIEW_1; \
	MENU func8_AI_VIEW_1_page; \
	MENU func8_AI_Simple_Dialog_Mandatory_B; \
	UNIT func8_AI_OUT_SCALE_unit_1; \
	MENU func8_AI_Simulation; \
	MENU func8_AI_Simulation_input; \
	MENU func8_AI_Simulation_input_group; \
	MENU func8_AI_Simulation_output; \
	MENU func8_AI_Simulation_output_group; \
	MENU func8_AI_Display_mandatory_B; \
	CHART func8_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func8_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func8_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func8_AI_Display_out_mandatory_B; \
	MENU func8_AI_Display_in_mandatory_B; \
	MENU func8_AI_Tab_s_mandatory_B; \
	MENU func8_AI_Tab_s_pv_range_mandatory_B; \
	MENU func8_AI_Tab_s_outscale_mandatory_B; \
	MENU func8_AI_Tab_s_limits_mandatory_B; \
	MENU func8_AI_Tab_s_interface_mandatory_B; \
	MENU func8_AI_Tab_m_mandatory_B; \
	MENU func8_AI_Tab_m_pv_range_mandatory_B; \
	MENU func8_AI_Tab_m_outscale_mandatory_B; \
	MENU func8_AI_Tab_m_limits_mandatory_B

#define USE_FUNC8_AI_OPTIONAL_BOTH \
	VARIABLE func8_AI_FSAFE_TYPE; \
	MENU func8_AI_FSAFE_TYPE_page; \
	COMMAND func8_AI_FSAFE_TYPE_read; \
	COMMAND func8_AI_FSAFE_TYPE_write; \
	VARIABLE func8_AI_FSAFE_VALUE; \
	MENU func8_AI_FSAFE_VALUE_page; \
	COMMAND func8_AI_FSAFE_VALUE_read; \
	COMMAND func8_AI_FSAFE_VALUE_write; \
	COLLECTION func8_AI_HI_HI_ALM; \
	VARIABLE func8_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func8_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func8_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func8_AI_HI_HI_ALM_Subcode; \
	VARIABLE func8_AI_HI_HI_ALM_Value; \
	MENU func8_AI_HI_HI_ALM_page; \
	COMMAND func8_AI_HI_HI_ALM_read; \
	COLLECTION func8_AI_HI_ALM; \
	VARIABLE func8_AI_HI_ALM_Unacknowledged; \
	VARIABLE func8_AI_HI_ALM_Alarm_State; \
	VARIABLE func8_AI_HI_ALM_Time_Stamp; \
	VARIABLE func8_AI_HI_ALM_Subcode; \
	VARIABLE func8_AI_HI_ALM_Value; \
	MENU func8_AI_HI_ALM_page; \
	COMMAND func8_AI_HI_ALM_read; \
	COLLECTION func8_AI_LO_ALM; \
	VARIABLE func8_AI_LO_ALM_Unacknowledged; \
	VARIABLE func8_AI_LO_ALM_Alarm_State; \
	VARIABLE func8_AI_LO_ALM_Time_Stamp; \
	VARIABLE func8_AI_LO_ALM_Subcode; \
	VARIABLE func8_AI_LO_ALM_Value; \
	MENU func8_AI_LO_ALM_page; \
	COMMAND func8_AI_LO_ALM_read; \
	COLLECTION func8_AI_LO_LO_ALM; \
	VARIABLE func8_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func8_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func8_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func8_AI_LO_LO_ALM_Subcode; \
	VARIABLE func8_AI_LO_LO_ALM_Value; \
	MENU func8_AI_LO_LO_ALM_page; \
	COMMAND func8_AI_LO_LO_ALM_read; \
	VARIABLE func8_AI_OUT_UNIT_TEXT; \
	MENU func8_AI_OUT_UNIT_TEXT_page; \
	COMMAND func8_AI_OUT_UNIT_TEXT_read; \
	COMMAND func8_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func8_AI_VIEW_2; \
	MENU func8_AI_VIEW_2_page; \
	COLLECTION func8_AI_VIEW_3; \
	MENU func8_AI_VIEW_3_page

#define USE_FUNC8_AI_OPTIONAL_A \
	USE_FUNC8_AI_OPTIONAL_BOTH; \
	COLLECTION func8_AI_OUT_SCALE; \
	VARIABLE func8_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func8_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func8_AI_OUT_SCALE_Units_Index; \
	VARIABLE func8_AI_OUT_SCALE_Decimal_Point; \
	MENU func8_AI_OUT_SCALE_page; \
	COMMAND func8_AI_OUT_SCALE_read; \
	COMMAND func8_AI_OUT_SCALE_write; \
	VARIABLE func8_AI_LIN_TYPE; \
	MENU func8_AI_LIN_TYPE_page; \
	COMMAND func8_AI_LIN_TYPE_read; \
	COMMAND func8_AI_LIN_TYPE_write; \
	VARIABLE func8_AI_CHANNEL; \
	MENU func8_AI_CHANNEL_page; \
	COMMAND func8_AI_CHANNEL_read; \
	COMMAND func8_AI_CHANNEL_write; \
	COLLECTION func8_AI_SIMULATE; \
	VARIABLE func8_AI_SIMULATE_Status_Condensed; \
	VARIABLE func8_AI_SIMULATE_Value; \
	VARIABLE func8_AI_SIMULATE_Enabled; \
	VARIABLE func8_AI_SIMULATE_Status_Quality; \
	VARIABLE func8_AI_SIMULATE_Status_Limit; \
	MENU func8_AI_SIMULATE_page; \
	COMMAND func8_AI_SIMULATE_read; \
	COMMAND func8_AI_SIMULATE_write; \
	COLLECTION func8_AI_VIEW_1; \
	MENU func8_AI_VIEW_1_page; \
	MENU func8_AI_Simple_Dialog_Optional_A; \
	UNIT func8_AI_OUT_SCALE_unit_1; \
	UNIT func8_AI_OUT_SCALE_unit_2

#define USE_FUNC8_AI_OPTIONAL_B \
	USE_FUNC8_AI_OPTIONAL_BOTH; \
	MENU func8_AI_Simple_Dialog_Optional_B; \
	UNIT func8_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC8_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func8_AI_)
#define USE_FUNC8_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func8_AI_)
#define USE_FUNC8_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func8_AI_)
#define USE_FUNC8_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func8_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC9_AI_MANDATORY_BOTH \
	BLOCK func9_AI_block; \
	COLLECTION func9_AI_BLOCK_OBJECT; \
	VARIABLE func9_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func9_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func9_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func9_AI_BLOCK_OBJECT_Class; \
	VARIABLE func9_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func9_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func9_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func9_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func9_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func9_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func9_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func9_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func9_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func9_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func9_AI_BLOCK_OBJECT_page; \
	COMMAND func9_AI_BLOCK_OBJECT_read; \
	VARIABLE func9_AI_ST_REV; \
	MENU func9_AI_ST_REV_page; \
	COMMAND func9_AI_ST_REV_read; \
	VARIABLE func9_AI_TAG_DESC; \
	MENU func9_AI_TAG_DESC_page; \
	COMMAND func9_AI_TAG_DESC_read; \
	COMMAND func9_AI_TAG_DESC_write; \
	VARIABLE func9_AI_STRATEGY; \
	MENU func9_AI_STRATEGY_page; \
	COMMAND func9_AI_STRATEGY_read; \
	COMMAND func9_AI_STRATEGY_write; \
	VARIABLE func9_AI_ALERT_KEY; \
	MENU func9_AI_ALERT_KEY_page; \
	COMMAND func9_AI_ALERT_KEY_read; \
	COMMAND func9_AI_ALERT_KEY_write; \
	VARIABLE func9_AI_TARGET_MODE; \
	MENU func9_AI_TARGET_MODE_page; \
	COMMAND func9_AI_TARGET_MODE_read; \
	COMMAND func9_AI_TARGET_MODE_write; \
	COLLECTION func9_AI_MODE_BLK; \
	VARIABLE func9_AI_MODE_BLK_Actual; \
	VARIABLE func9_AI_MODE_BLK_Permitted; \
	VARIABLE func9_AI_MODE_BLK_Normal; \
	MENU func9_AI_MODE_BLK_page; \
	COMMAND func9_AI_MODE_BLK_read; \
	COLLECTION func9_AI_ALARM_SUM; \
	VARIABLE func9_AI_ALARM_SUM_Current; \
	VARIABLE func9_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func9_AI_ALARM_SUM_Unreported; \
	VARIABLE func9_AI_ALARM_SUM_Disabled; \
	MENU func9_AI_ALARM_SUM_page; \
	COMMAND func9_AI_ALARM_SUM_read; \
	COLLECTION func9_AI_BATCH; \
	VARIABLE func9_AI_BATCH_Batch_ID; \
	VARIABLE func9_AI_BATCH_Rup; \
	VARIABLE func9_AI_BATCH_Operation; \
	VARIABLE func9_AI_BATCH_Phase; \
	MENU func9_AI_BATCH_page; \
	COMMAND func9_AI_BATCH_read; \
	COMMAND func9_AI_BATCH_write; \
	COLLECTION func9_AI_OUT; \
	VARIABLE func9_AI_OUT_Value; \
	VARIABLE func9_AI_OUT_Status_Condensed; \
	VARIABLE func9_AI_OUT_Status_Quality; \
	VARIABLE func9_AI_OUT_Status_Limit; \
	MENU func9_AI_OUT_page; \
	COMMAND func9_AI_OUT_read; \
	COMMAND func9_AI_OUT_write; \
	COLLECTION func9_AI_PV_SCALE; \
	VARIABLE func9_AI_PV_SCALE_Upper_Value; \
	VARIABLE func9_AI_PV_SCALE_Lower_Value; \
	MENU func9_AI_PV_SCALE_page; \
	COMMAND func9_AI_PV_SCALE_read; \
	COMMAND func9_AI_PV_SCALE_write; \
	VARIABLE func9_AI_PV_FTIME; \
	MENU func9_AI_PV_FTIME_page; \
	COMMAND func9_AI_PV_FTIME_read; \
	COMMAND func9_AI_PV_FTIME_write; \
	VARIABLE func9_AI_ALARM_HYS; \
	MENU func9_AI_ALARM_HYS_page; \
	COMMAND func9_AI_ALARM_HYS_read; \
	COMMAND func9_AI_ALARM_HYS_write; \
	VARIABLE func9_AI_HI_HI_LIM; \
	MENU func9_AI_HI_HI_LIM_page; \
	COMMAND func9_AI_HI_HI_LIM_read; \
	COMMAND func9_AI_HI_HI_LIM_write; \
	VARIABLE func9_AI_HI_LIM; \
	MENU func9_AI_HI_LIM_page; \
	COMMAND func9_AI_HI_LIM_read; \
	COMMAND func9_AI_HI_LIM_write; \
	VARIABLE func9_AI_LO_LIM; \
	MENU func9_AI_LO_LIM_page; \
	COMMAND func9_AI_LO_LIM_read; \
	COMMAND func9_AI_LO_LIM_write; \
	VARIABLE func9_AI_LO_LO_LIM; \
	MENU func9_AI_LO_LO_LIM_page; \
	COMMAND func9_AI_LO_LO_LIM_read; \
	COMMAND func9_AI_LO_LO_LIM_write

#define USE_FUNC9_AI_MANDATORY_A \
	USE_FUNC9_AI_MANDATORY_BOTH; \
	MENU func9_AI_Simple_Dialog_Mandatory_A; \
	MENU func9_AI_Display_mandatory_A; \
	CHART func9_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func9_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func9_AI_Display_out_mandatory_A; \
	MENU func9_AI_Tab_s_mandatory_A; \
	MENU func9_AI_Tab_s_pv_range_mandatory_A; \
	MENU func9_AI_Tab_s_limits_mandatory_A; \
	MENU func9_AI_Tab_m_mandatory_A; \
	MENU func9_AI_Tab_m_pv_range_mandatory_A; \
	MENU func9_AI_Tab_m_limits_mandatory_A

#define USE_FUNC9_AI_MANDATORY_B \
	USE_FUNC9_AI_MANDATORY_BOTH; \
	COLLECTION func9_AI_OUT_SCALE; \
	VARIABLE func9_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func9_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func9_AI_OUT_SCALE_Units_Index; \
	VARIABLE func9_AI_OUT_SCALE_Decimal_Point; \
	MENU func9_AI_OUT_SCALE_page; \
	COMMAND func9_AI_OUT_SCALE_read; \
	COMMAND func9_AI_OUT_SCALE_write; \
	VARIABLE func9_AI_LIN_TYPE; \
	MENU func9_AI_LIN_TYPE_page; \
	COMMAND func9_AI_LIN_TYPE_read; \
	COMMAND func9_AI_LIN_TYPE_write; \
	VARIABLE func9_AI_CHANNEL; \
	MENU func9_AI_CHANNEL_page; \
	COMMAND func9_AI_CHANNEL_read; \
	COMMAND func9_AI_CHANNEL_write; \
	COLLECTION func9_AI_SIMULATE; \
	VARIABLE func9_AI_SIMULATE_Status_Condensed; \
	VARIABLE func9_AI_SIMULATE_Value; \
	VARIABLE func9_AI_SIMULATE_Enabled; \
	VARIABLE func9_AI_SIMULATE_Status_Quality; \
	VARIABLE func9_AI_SIMULATE_Status_Limit; \
	MENU func9_AI_SIMULATE_page; \
	COMMAND func9_AI_SIMULATE_read; \
	COMMAND func9_AI_SIMULATE_write; \
	COLLECTION func9_AI_VIEW_1; \
	MENU func9_AI_VIEW_1_page; \
	MENU func9_AI_Simple_Dialog_Mandatory_B; \
	UNIT func9_AI_OUT_SCALE_unit_1; \
	MENU func9_AI_Simulation; \
	MENU func9_AI_Simulation_input; \
	MENU func9_AI_Simulation_input_group; \
	MENU func9_AI_Simulation_output; \
	MENU func9_AI_Simulation_output_group; \
	MENU func9_AI_Display_mandatory_B; \
	CHART func9_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func9_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func9_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func9_AI_Display_out_mandatory_B; \
	MENU func9_AI_Display_in_mandatory_B; \
	MENU func9_AI_Tab_s_mandatory_B; \
	MENU func9_AI_Tab_s_pv_range_mandatory_B; \
	MENU func9_AI_Tab_s_outscale_mandatory_B; \
	MENU func9_AI_Tab_s_limits_mandatory_B; \
	MENU func9_AI_Tab_s_interface_mandatory_B; \
	MENU func9_AI_Tab_m_mandatory_B; \
	MENU func9_AI_Tab_m_pv_range_mandatory_B; \
	MENU func9_AI_Tab_m_outscale_mandatory_B; \
	MENU func9_AI_Tab_m_limits_mandatory_B

#define USE_FUNC9_AI_OPTIONAL_BOTH \
	VARIABLE func9_AI_FSAFE_TYPE; \
	MENU func9_AI_FSAFE_TYPE_page; \
	COMMAND func9_AI_FSAFE_TYPE_read; \
	COMMAND func9_AI_FSAFE_TYPE_write; \
	VARIABLE func9_AI_FSAFE_VALUE; \
	MENU func9_AI_FSAFE_VALUE_page; \
	COMMAND func9_AI_FSAFE_VALUE_read; \
	COMMAND func9_AI_FSAFE_VALUE_write; \
	COLLECTION func9_AI_HI_HI_ALM; \
	VARIABLE func9_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func9_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func9_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func9_AI_HI_HI_ALM_Subcode; \
	VARIABLE func9_AI_HI_HI_ALM_Value; \
	MENU func9_AI_HI_HI_ALM_page; \
	COMMAND func9_AI_HI_HI_ALM_read; \
	COLLECTION func9_AI_HI_ALM; \
	VARIABLE func9_AI_HI_ALM_Unacknowledged; \
	VARIABLE func9_AI_HI_ALM_Alarm_State; \
	VARIABLE func9_AI_HI_ALM_Time_Stamp; \
	VARIABLE func9_AI_HI_ALM_Subcode; \
	VARIABLE func9_AI_HI_ALM_Value; \
	MENU func9_AI_HI_ALM_page; \
	COMMAND func9_AI_HI_ALM_read; \
	COLLECTION func9_AI_LO_ALM; \
	VARIABLE func9_AI_LO_ALM_Unacknowledged; \
	VARIABLE func9_AI_LO_ALM_Alarm_State; \
	VARIABLE func9_AI_LO_ALM_Time_Stamp; \
	VARIABLE func9_AI_LO_ALM_Subcode; \
	VARIABLE func9_AI_LO_ALM_Value; \
	MENU func9_AI_LO_ALM_page; \
	COMMAND func9_AI_LO_ALM_read; \
	COLLECTION func9_AI_LO_LO_ALM; \
	VARIABLE func9_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func9_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func9_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func9_AI_LO_LO_ALM_Subcode; \
	VARIABLE func9_AI_LO_LO_ALM_Value; \
	MENU func9_AI_LO_LO_ALM_page; \
	COMMAND func9_AI_LO_LO_ALM_read; \
	VARIABLE func9_AI_OUT_UNIT_TEXT; \
	MENU func9_AI_OUT_UNIT_TEXT_page; \
	COMMAND func9_AI_OUT_UNIT_TEXT_read; \
	COMMAND func9_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func9_AI_VIEW_2; \
	MENU func9_AI_VIEW_2_page; \
	COLLECTION func9_AI_VIEW_3; \
	MENU func9_AI_VIEW_3_page

#define USE_FUNC9_AI_OPTIONAL_A \
	USE_FUNC9_AI_OPTIONAL_BOTH; \
	COLLECTION func9_AI_OUT_SCALE; \
	VARIABLE func9_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func9_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func9_AI_OUT_SCALE_Units_Index; \
	VARIABLE func9_AI_OUT_SCALE_Decimal_Point; \
	MENU func9_AI_OUT_SCALE_page; \
	COMMAND func9_AI_OUT_SCALE_read; \
	COMMAND func9_AI_OUT_SCALE_write; \
	VARIABLE func9_AI_LIN_TYPE; \
	MENU func9_AI_LIN_TYPE_page; \
	COMMAND func9_AI_LIN_TYPE_read; \
	COMMAND func9_AI_LIN_TYPE_write; \
	VARIABLE func9_AI_CHANNEL; \
	MENU func9_AI_CHANNEL_page; \
	COMMAND func9_AI_CHANNEL_read; \
	COMMAND func9_AI_CHANNEL_write; \
	COLLECTION func9_AI_SIMULATE; \
	VARIABLE func9_AI_SIMULATE_Status_Condensed; \
	VARIABLE func9_AI_SIMULATE_Value; \
	VARIABLE func9_AI_SIMULATE_Enabled; \
	VARIABLE func9_AI_SIMULATE_Status_Quality; \
	VARIABLE func9_AI_SIMULATE_Status_Limit; \
	MENU func9_AI_SIMULATE_page; \
	COMMAND func9_AI_SIMULATE_read; \
	COMMAND func9_AI_SIMULATE_write; \
	COLLECTION func9_AI_VIEW_1; \
	MENU func9_AI_VIEW_1_page; \
	MENU func9_AI_Simple_Dialog_Optional_A; \
	UNIT func9_AI_OUT_SCALE_unit_1; \
	UNIT func9_AI_OUT_SCALE_unit_2

#define USE_FUNC9_AI_OPTIONAL_B \
	USE_FUNC9_AI_OPTIONAL_BOTH; \
	MENU func9_AI_Simple_Dialog_Optional_B; \
	UNIT func9_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC9_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func9_AI_)
#define USE_FUNC9_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func9_AI_)
#define USE_FUNC9_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func9_AI_)
#define USE_FUNC9_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func9_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC10_AI_MANDATORY_BOTH \
	BLOCK func10_AI_block; \
	COLLECTION func10_AI_BLOCK_OBJECT; \
	VARIABLE func10_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func10_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func10_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func10_AI_BLOCK_OBJECT_Class; \
	VARIABLE func10_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func10_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func10_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func10_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func10_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func10_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func10_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func10_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func10_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func10_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func10_AI_BLOCK_OBJECT_page; \
	COMMAND func10_AI_BLOCK_OBJECT_read; \
	VARIABLE func10_AI_ST_REV; \
	MENU func10_AI_ST_REV_page; \
	COMMAND func10_AI_ST_REV_read; \
	VARIABLE func10_AI_TAG_DESC; \
	MENU func10_AI_TAG_DESC_page; \
	COMMAND func10_AI_TAG_DESC_read; \
	COMMAND func10_AI_TAG_DESC_write; \
	VARIABLE func10_AI_STRATEGY; \
	MENU func10_AI_STRATEGY_page; \
	COMMAND func10_AI_STRATEGY_read; \
	COMMAND func10_AI_STRATEGY_write; \
	VARIABLE func10_AI_ALERT_KEY; \
	MENU func10_AI_ALERT_KEY_page; \
	COMMAND func10_AI_ALERT_KEY_read; \
	COMMAND func10_AI_ALERT_KEY_write; \
	VARIABLE func10_AI_TARGET_MODE; \
	MENU func10_AI_TARGET_MODE_page; \
	COMMAND func10_AI_TARGET_MODE_read; \
	COMMAND func10_AI_TARGET_MODE_write; \
	COLLECTION func10_AI_MODE_BLK; \
	VARIABLE func10_AI_MODE_BLK_Actual; \
	VARIABLE func10_AI_MODE_BLK_Permitted; \
	VARIABLE func10_AI_MODE_BLK_Normal; \
	MENU func10_AI_MODE_BLK_page; \
	COMMAND func10_AI_MODE_BLK_read; \
	COLLECTION func10_AI_ALARM_SUM; \
	VARIABLE func10_AI_ALARM_SUM_Current; \
	VARIABLE func10_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func10_AI_ALARM_SUM_Unreported; \
	VARIABLE func10_AI_ALARM_SUM_Disabled; \
	MENU func10_AI_ALARM_SUM_page; \
	COMMAND func10_AI_ALARM_SUM_read; \
	COLLECTION func10_AI_BATCH; \
	VARIABLE func10_AI_BATCH_Batch_ID; \
	VARIABLE func10_AI_BATCH_Rup; \
	VARIABLE func10_AI_BATCH_Operation; \
	VARIABLE func10_AI_BATCH_Phase; \
	MENU func10_AI_BATCH_page; \
	COMMAND func10_AI_BATCH_read; \
	COMMAND func10_AI_BATCH_write; \
	COLLECTION func10_AI_OUT; \
	VARIABLE func10_AI_OUT_Value; \
	VARIABLE func10_AI_OUT_Status_Condensed; \
	VARIABLE func10_AI_OUT_Status_Quality; \
	VARIABLE func10_AI_OUT_Status_Limit; \
	MENU func10_AI_OUT_page; \
	COMMAND func10_AI_OUT_read; \
	COMMAND func10_AI_OUT_write; \
	COLLECTION func10_AI_PV_SCALE; \
	VARIABLE func10_AI_PV_SCALE_Upper_Value; \
	VARIABLE func10_AI_PV_SCALE_Lower_Value; \
	MENU func10_AI_PV_SCALE_page; \
	COMMAND func10_AI_PV_SCALE_read; \
	COMMAND func10_AI_PV_SCALE_write; \
	VARIABLE func10_AI_PV_FTIME; \
	MENU func10_AI_PV_FTIME_page; \
	COMMAND func10_AI_PV_FTIME_read; \
	COMMAND func10_AI_PV_FTIME_write; \
	VARIABLE func10_AI_ALARM_HYS; \
	MENU func10_AI_ALARM_HYS_page; \
	COMMAND func10_AI_ALARM_HYS_read; \
	COMMAND func10_AI_ALARM_HYS_write; \
	VARIABLE func10_AI_HI_HI_LIM; \
	MENU func10_AI_HI_HI_LIM_page; \
	COMMAND func10_AI_HI_HI_LIM_read; \
	COMMAND func10_AI_HI_HI_LIM_write; \
	VARIABLE func10_AI_HI_LIM; \
	MENU func10_AI_HI_LIM_page; \
	COMMAND func10_AI_HI_LIM_read; \
	COMMAND func10_AI_HI_LIM_write; \
	VARIABLE func10_AI_LO_LIM; \
	MENU func10_AI_LO_LIM_page; \
	COMMAND func10_AI_LO_LIM_read; \
	COMMAND func10_AI_LO_LIM_write; \
	VARIABLE func10_AI_LO_LO_LIM; \
	MENU func10_AI_LO_LO_LIM_page; \
	COMMAND func10_AI_LO_LO_LIM_read; \
	COMMAND func10_AI_LO_LO_LIM_write

#define USE_FUNC10_AI_MANDATORY_A \
	USE_FUNC10_AI_MANDATORY_BOTH; \
	MENU func10_AI_Simple_Dialog_Mandatory_A; \
	MENU func10_AI_Display_mandatory_A; \
	CHART func10_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func10_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func10_AI_Display_out_mandatory_A; \
	MENU func10_AI_Tab_s_mandatory_A; \
	MENU func10_AI_Tab_s_pv_range_mandatory_A; \
	MENU func10_AI_Tab_s_limits_mandatory_A; \
	MENU func10_AI_Tab_m_mandatory_A; \
	MENU func10_AI_Tab_m_pv_range_mandatory_A; \
	MENU func10_AI_Tab_m_limits_mandatory_A

#define USE_FUNC10_AI_MANDATORY_B \
	USE_FUNC10_AI_MANDATORY_BOTH; \
	COLLECTION func10_AI_OUT_SCALE; \
	VARIABLE func10_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func10_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func10_AI_OUT_SCALE_Units_Index; \
	VARIABLE func10_AI_OUT_SCALE_Decimal_Point; \
	MENU func10_AI_OUT_SCALE_page; \
	COMMAND func10_AI_OUT_SCALE_read; \
	COMMAND func10_AI_OUT_SCALE_write; \
	VARIABLE func10_AI_LIN_TYPE; \
	MENU func10_AI_LIN_TYPE_page; \
	COMMAND func10_AI_LIN_TYPE_read; \
	COMMAND func10_AI_LIN_TYPE_write; \
	VARIABLE func10_AI_CHANNEL; \
	MENU func10_AI_CHANNEL_page; \
	COMMAND func10_AI_CHANNEL_read; \
	COMMAND func10_AI_CHANNEL_write; \
	COLLECTION func10_AI_SIMULATE; \
	VARIABLE func10_AI_SIMULATE_Status_Condensed; \
	VARIABLE func10_AI_SIMULATE_Value; \
	VARIABLE func10_AI_SIMULATE_Enabled; \
	VARIABLE func10_AI_SIMULATE_Status_Quality; \
	VARIABLE func10_AI_SIMULATE_Status_Limit; \
	MENU func10_AI_SIMULATE_page; \
	COMMAND func10_AI_SIMULATE_read; \
	COMMAND func10_AI_SIMULATE_write; \
	COLLECTION func10_AI_VIEW_1; \
	MENU func10_AI_VIEW_1_page; \
	MENU func10_AI_Simple_Dialog_Mandatory_B; \
	UNIT func10_AI_OUT_SCALE_unit_1; \
	MENU func10_AI_Simulation; \
	MENU func10_AI_Simulation_input; \
	MENU func10_AI_Simulation_input_group; \
	MENU func10_AI_Simulation_output; \
	MENU func10_AI_Simulation_output_group; \
	MENU func10_AI_Display_mandatory_B; \
	CHART func10_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func10_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func10_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func10_AI_Display_out_mandatory_B; \
	MENU func10_AI_Display_in_mandatory_B; \
	MENU func10_AI_Tab_s_mandatory_B; \
	MENU func10_AI_Tab_s_pv_range_mandatory_B; \
	MENU func10_AI_Tab_s_outscale_mandatory_B; \
	MENU func10_AI_Tab_s_limits_mandatory_B; \
	MENU func10_AI_Tab_s_interface_mandatory_B; \
	MENU func10_AI_Tab_m_mandatory_B; \
	MENU func10_AI_Tab_m_pv_range_mandatory_B; \
	MENU func10_AI_Tab_m_outscale_mandatory_B; \
	MENU func10_AI_Tab_m_limits_mandatory_B

#define USE_FUNC10_AI_OPTIONAL_BOTH \
	VARIABLE func10_AI_FSAFE_TYPE; \
	MENU func10_AI_FSAFE_TYPE_page; \
	COMMAND func10_AI_FSAFE_TYPE_read; \
	COMMAND func10_AI_FSAFE_TYPE_write; \
	VARIABLE func10_AI_FSAFE_VALUE; \
	MENU func10_AI_FSAFE_VALUE_page; \
	COMMAND func10_AI_FSAFE_VALUE_read; \
	COMMAND func10_AI_FSAFE_VALUE_write; \
	COLLECTION func10_AI_HI_HI_ALM; \
	VARIABLE func10_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func10_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func10_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func10_AI_HI_HI_ALM_Subcode; \
	VARIABLE func10_AI_HI_HI_ALM_Value; \
	MENU func10_AI_HI_HI_ALM_page; \
	COMMAND func10_AI_HI_HI_ALM_read; \
	COLLECTION func10_AI_HI_ALM; \
	VARIABLE func10_AI_HI_ALM_Unacknowledged; \
	VARIABLE func10_AI_HI_ALM_Alarm_State; \
	VARIABLE func10_AI_HI_ALM_Time_Stamp; \
	VARIABLE func10_AI_HI_ALM_Subcode; \
	VARIABLE func10_AI_HI_ALM_Value; \
	MENU func10_AI_HI_ALM_page; \
	COMMAND func10_AI_HI_ALM_read; \
	COLLECTION func10_AI_LO_ALM; \
	VARIABLE func10_AI_LO_ALM_Unacknowledged; \
	VARIABLE func10_AI_LO_ALM_Alarm_State; \
	VARIABLE func10_AI_LO_ALM_Time_Stamp; \
	VARIABLE func10_AI_LO_ALM_Subcode; \
	VARIABLE func10_AI_LO_ALM_Value; \
	MENU func10_AI_LO_ALM_page; \
	COMMAND func10_AI_LO_ALM_read; \
	COLLECTION func10_AI_LO_LO_ALM; \
	VARIABLE func10_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func10_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func10_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func10_AI_LO_LO_ALM_Subcode; \
	VARIABLE func10_AI_LO_LO_ALM_Value; \
	MENU func10_AI_LO_LO_ALM_page; \
	COMMAND func10_AI_LO_LO_ALM_read; \
	VARIABLE func10_AI_OUT_UNIT_TEXT; \
	MENU func10_AI_OUT_UNIT_TEXT_page; \
	COMMAND func10_AI_OUT_UNIT_TEXT_read; \
	COMMAND func10_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func10_AI_VIEW_2; \
	MENU func10_AI_VIEW_2_page; \
	COLLECTION func10_AI_VIEW_3; \
	MENU func10_AI_VIEW_3_page

#define USE_FUNC10_AI_OPTIONAL_A \
	USE_FUNC10_AI_OPTIONAL_BOTH; \
	COLLECTION func10_AI_OUT_SCALE; \
	VARIABLE func10_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func10_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func10_AI_OUT_SCALE_Units_Index; \
	VARIABLE func10_AI_OUT_SCALE_Decimal_Point; \
	MENU func10_AI_OUT_SCALE_page; \
	COMMAND func10_AI_OUT_SCALE_read; \
	COMMAND func10_AI_OUT_SCALE_write; \
	VARIABLE func10_AI_LIN_TYPE; \
	MENU func10_AI_LIN_TYPE_page; \
	COMMAND func10_AI_LIN_TYPE_read; \
	COMMAND func10_AI_LIN_TYPE_write; \
	VARIABLE func10_AI_CHANNEL; \
	MENU func10_AI_CHANNEL_page; \
	COMMAND func10_AI_CHANNEL_read; \
	COMMAND func10_AI_CHANNEL_write; \
	COLLECTION func10_AI_SIMULATE; \
	VARIABLE func10_AI_SIMULATE_Status_Condensed; \
	VARIABLE func10_AI_SIMULATE_Value; \
	VARIABLE func10_AI_SIMULATE_Enabled; \
	VARIABLE func10_AI_SIMULATE_Status_Quality; \
	VARIABLE func10_AI_SIMULATE_Status_Limit; \
	MENU func10_AI_SIMULATE_page; \
	COMMAND func10_AI_SIMULATE_read; \
	COMMAND func10_AI_SIMULATE_write; \
	COLLECTION func10_AI_VIEW_1; \
	MENU func10_AI_VIEW_1_page; \
	MENU func10_AI_Simple_Dialog_Optional_A; \
	UNIT func10_AI_OUT_SCALE_unit_1; \
	UNIT func10_AI_OUT_SCALE_unit_2

#define USE_FUNC10_AI_OPTIONAL_B \
	USE_FUNC10_AI_OPTIONAL_BOTH; \
	MENU func10_AI_Simple_Dialog_Optional_B; \
	UNIT func10_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC10_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func10_AI_)
#define USE_FUNC10_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func10_AI_)
#define USE_FUNC10_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func10_AI_)
#define USE_FUNC10_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func10_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC11_AI_MANDATORY_BOTH \
	BLOCK func11_AI_block; \
	COLLECTION func11_AI_BLOCK_OBJECT; \
	VARIABLE func11_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func11_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func11_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func11_AI_BLOCK_OBJECT_Class; \
	VARIABLE func11_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func11_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func11_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func11_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func11_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func11_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func11_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func11_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func11_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func11_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func11_AI_BLOCK_OBJECT_page; \
	COMMAND func11_AI_BLOCK_OBJECT_read; \
	VARIABLE func11_AI_ST_REV; \
	MENU func11_AI_ST_REV_page; \
	COMMAND func11_AI_ST_REV_read; \
	VARIABLE func11_AI_TAG_DESC; \
	MENU func11_AI_TAG_DESC_page; \
	COMMAND func11_AI_TAG_DESC_read; \
	COMMAND func11_AI_TAG_DESC_write; \
	VARIABLE func11_AI_STRATEGY; \
	MENU func11_AI_STRATEGY_page; \
	COMMAND func11_AI_STRATEGY_read; \
	COMMAND func11_AI_STRATEGY_write; \
	VARIABLE func11_AI_ALERT_KEY; \
	MENU func11_AI_ALERT_KEY_page; \
	COMMAND func11_AI_ALERT_KEY_read; \
	COMMAND func11_AI_ALERT_KEY_write; \
	VARIABLE func11_AI_TARGET_MODE; \
	MENU func11_AI_TARGET_MODE_page; \
	COMMAND func11_AI_TARGET_MODE_read; \
	COMMAND func11_AI_TARGET_MODE_write; \
	COLLECTION func11_AI_MODE_BLK; \
	VARIABLE func11_AI_MODE_BLK_Actual; \
	VARIABLE func11_AI_MODE_BLK_Permitted; \
	VARIABLE func11_AI_MODE_BLK_Normal; \
	MENU func11_AI_MODE_BLK_page; \
	COMMAND func11_AI_MODE_BLK_read; \
	COLLECTION func11_AI_ALARM_SUM; \
	VARIABLE func11_AI_ALARM_SUM_Current; \
	VARIABLE func11_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func11_AI_ALARM_SUM_Unreported; \
	VARIABLE func11_AI_ALARM_SUM_Disabled; \
	MENU func11_AI_ALARM_SUM_page; \
	COMMAND func11_AI_ALARM_SUM_read; \
	COLLECTION func11_AI_BATCH; \
	VARIABLE func11_AI_BATCH_Batch_ID; \
	VARIABLE func11_AI_BATCH_Rup; \
	VARIABLE func11_AI_BATCH_Operation; \
	VARIABLE func11_AI_BATCH_Phase; \
	MENU func11_AI_BATCH_page; \
	COMMAND func11_AI_BATCH_read; \
	COMMAND func11_AI_BATCH_write; \
	COLLECTION func11_AI_OUT; \
	VARIABLE func11_AI_OUT_Value; \
	VARIABLE func11_AI_OUT_Status_Condensed; \
	VARIABLE func11_AI_OUT_Status_Quality; \
	VARIABLE func11_AI_OUT_Status_Limit; \
	MENU func11_AI_OUT_page; \
	COMMAND func11_AI_OUT_read; \
	COMMAND func11_AI_OUT_write; \
	COLLECTION func11_AI_PV_SCALE; \
	VARIABLE func11_AI_PV_SCALE_Upper_Value; \
	VARIABLE func11_AI_PV_SCALE_Lower_Value; \
	MENU func11_AI_PV_SCALE_page; \
	COMMAND func11_AI_PV_SCALE_read; \
	COMMAND func11_AI_PV_SCALE_write; \
	VARIABLE func11_AI_PV_FTIME; \
	MENU func11_AI_PV_FTIME_page; \
	COMMAND func11_AI_PV_FTIME_read; \
	COMMAND func11_AI_PV_FTIME_write; \
	VARIABLE func11_AI_ALARM_HYS; \
	MENU func11_AI_ALARM_HYS_page; \
	COMMAND func11_AI_ALARM_HYS_read; \
	COMMAND func11_AI_ALARM_HYS_write; \
	VARIABLE func11_AI_HI_HI_LIM; \
	MENU func11_AI_HI_HI_LIM_page; \
	COMMAND func11_AI_HI_HI_LIM_read; \
	COMMAND func11_AI_HI_HI_LIM_write; \
	VARIABLE func11_AI_HI_LIM; \
	MENU func11_AI_HI_LIM_page; \
	COMMAND func11_AI_HI_LIM_read; \
	COMMAND func11_AI_HI_LIM_write; \
	VARIABLE func11_AI_LO_LIM; \
	MENU func11_AI_LO_LIM_page; \
	COMMAND func11_AI_LO_LIM_read; \
	COMMAND func11_AI_LO_LIM_write; \
	VARIABLE func11_AI_LO_LO_LIM; \
	MENU func11_AI_LO_LO_LIM_page; \
	COMMAND func11_AI_LO_LO_LIM_read; \
	COMMAND func11_AI_LO_LO_LIM_write

#define USE_FUNC11_AI_MANDATORY_A \
	USE_FUNC11_AI_MANDATORY_BOTH; \
	MENU func11_AI_Simple_Dialog_Mandatory_A; \
	MENU func11_AI_Display_mandatory_A; \
	CHART func11_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func11_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func11_AI_Display_out_mandatory_A; \
	MENU func11_AI_Tab_s_mandatory_A; \
	MENU func11_AI_Tab_s_pv_range_mandatory_A; \
	MENU func11_AI_Tab_s_limits_mandatory_A; \
	MENU func11_AI_Tab_m_mandatory_A; \
	MENU func11_AI_Tab_m_pv_range_mandatory_A; \
	MENU func11_AI_Tab_m_limits_mandatory_A

#define USE_FUNC11_AI_MANDATORY_B \
	USE_FUNC11_AI_MANDATORY_BOTH; \
	COLLECTION func11_AI_OUT_SCALE; \
	VARIABLE func11_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func11_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func11_AI_OUT_SCALE_Units_Index; \
	VARIABLE func11_AI_OUT_SCALE_Decimal_Point; \
	MENU func11_AI_OUT_SCALE_page; \
	COMMAND func11_AI_OUT_SCALE_read; \
	COMMAND func11_AI_OUT_SCALE_write; \
	VARIABLE func11_AI_LIN_TYPE; \
	MENU func11_AI_LIN_TYPE_page; \
	COMMAND func11_AI_LIN_TYPE_read; \
	COMMAND func11_AI_LIN_TYPE_write; \
	VARIABLE func11_AI_CHANNEL; \
	MENU func11_AI_CHANNEL_page; \
	COMMAND func11_AI_CHANNEL_read; \
	COMMAND func11_AI_CHANNEL_write; \
	COLLECTION func11_AI_SIMULATE; \
	VARIABLE func11_AI_SIMULATE_Status_Condensed; \
	VARIABLE func11_AI_SIMULATE_Value; \
	VARIABLE func11_AI_SIMULATE_Enabled; \
	VARIABLE func11_AI_SIMULATE_Status_Quality; \
	VARIABLE func11_AI_SIMULATE_Status_Limit; \
	MENU func11_AI_SIMULATE_page; \
	COMMAND func11_AI_SIMULATE_read; \
	COMMAND func11_AI_SIMULATE_write; \
	COLLECTION func11_AI_VIEW_1; \
	MENU func11_AI_VIEW_1_page; \
	MENU func11_AI_Simple_Dialog_Mandatory_B; \
	UNIT func11_AI_OUT_SCALE_unit_1; \
	MENU func11_AI_Simulation; \
	MENU func11_AI_Simulation_input; \
	MENU func11_AI_Simulation_input_group; \
	MENU func11_AI_Simulation_output; \
	MENU func11_AI_Simulation_output_group; \
	MENU func11_AI_Display_mandatory_B; \
	CHART func11_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func11_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func11_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func11_AI_Display_out_mandatory_B; \
	MENU func11_AI_Display_in_mandatory_B; \
	MENU func11_AI_Tab_s_mandatory_B; \
	MENU func11_AI_Tab_s_pv_range_mandatory_B; \
	MENU func11_AI_Tab_s_outscale_mandatory_B; \
	MENU func11_AI_Tab_s_limits_mandatory_B; \
	MENU func11_AI_Tab_s_interface_mandatory_B; \
	MENU func11_AI_Tab_m_mandatory_B; \
	MENU func11_AI_Tab_m_pv_range_mandatory_B; \
	MENU func11_AI_Tab_m_outscale_mandatory_B; \
	MENU func11_AI_Tab_m_limits_mandatory_B

#define USE_FUNC11_AI_OPTIONAL_BOTH \
	VARIABLE func11_AI_FSAFE_TYPE; \
	MENU func11_AI_FSAFE_TYPE_page; \
	COMMAND func11_AI_FSAFE_TYPE_read; \
	COMMAND func11_AI_FSAFE_TYPE_write; \
	VARIABLE func11_AI_FSAFE_VALUE; \
	MENU func11_AI_FSAFE_VALUE_page; \
	COMMAND func11_AI_FSAFE_VALUE_read; \
	COMMAND func11_AI_FSAFE_VALUE_write; \
	COLLECTION func11_AI_HI_HI_ALM; \
	VARIABLE func11_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func11_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func11_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func11_AI_HI_HI_ALM_Subcode; \
	VARIABLE func11_AI_HI_HI_ALM_Value; \
	MENU func11_AI_HI_HI_ALM_page; \
	COMMAND func11_AI_HI_HI_ALM_read; \
	COLLECTION func11_AI_HI_ALM; \
	VARIABLE func11_AI_HI_ALM_Unacknowledged; \
	VARIABLE func11_AI_HI_ALM_Alarm_State; \
	VARIABLE func11_AI_HI_ALM_Time_Stamp; \
	VARIABLE func11_AI_HI_ALM_Subcode; \
	VARIABLE func11_AI_HI_ALM_Value; \
	MENU func11_AI_HI_ALM_page; \
	COMMAND func11_AI_HI_ALM_read; \
	COLLECTION func11_AI_LO_ALM; \
	VARIABLE func11_AI_LO_ALM_Unacknowledged; \
	VARIABLE func11_AI_LO_ALM_Alarm_State; \
	VARIABLE func11_AI_LO_ALM_Time_Stamp; \
	VARIABLE func11_AI_LO_ALM_Subcode; \
	VARIABLE func11_AI_LO_ALM_Value; \
	MENU func11_AI_LO_ALM_page; \
	COMMAND func11_AI_LO_ALM_read; \
	COLLECTION func11_AI_LO_LO_ALM; \
	VARIABLE func11_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func11_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func11_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func11_AI_LO_LO_ALM_Subcode; \
	VARIABLE func11_AI_LO_LO_ALM_Value; \
	MENU func11_AI_LO_LO_ALM_page; \
	COMMAND func11_AI_LO_LO_ALM_read; \
	VARIABLE func11_AI_OUT_UNIT_TEXT; \
	MENU func11_AI_OUT_UNIT_TEXT_page; \
	COMMAND func11_AI_OUT_UNIT_TEXT_read; \
	COMMAND func11_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func11_AI_VIEW_2; \
	MENU func11_AI_VIEW_2_page; \
	COLLECTION func11_AI_VIEW_3; \
	MENU func11_AI_VIEW_3_page

#define USE_FUNC11_AI_OPTIONAL_A \
	USE_FUNC11_AI_OPTIONAL_BOTH; \
	COLLECTION func11_AI_OUT_SCALE; \
	VARIABLE func11_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func11_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func11_AI_OUT_SCALE_Units_Index; \
	VARIABLE func11_AI_OUT_SCALE_Decimal_Point; \
	MENU func11_AI_OUT_SCALE_page; \
	COMMAND func11_AI_OUT_SCALE_read; \
	COMMAND func11_AI_OUT_SCALE_write; \
	VARIABLE func11_AI_LIN_TYPE; \
	MENU func11_AI_LIN_TYPE_page; \
	COMMAND func11_AI_LIN_TYPE_read; \
	COMMAND func11_AI_LIN_TYPE_write; \
	VARIABLE func11_AI_CHANNEL; \
	MENU func11_AI_CHANNEL_page; \
	COMMAND func11_AI_CHANNEL_read; \
	COMMAND func11_AI_CHANNEL_write; \
	COLLECTION func11_AI_SIMULATE; \
	VARIABLE func11_AI_SIMULATE_Status_Condensed; \
	VARIABLE func11_AI_SIMULATE_Value; \
	VARIABLE func11_AI_SIMULATE_Enabled; \
	VARIABLE func11_AI_SIMULATE_Status_Quality; \
	VARIABLE func11_AI_SIMULATE_Status_Limit; \
	MENU func11_AI_SIMULATE_page; \
	COMMAND func11_AI_SIMULATE_read; \
	COMMAND func11_AI_SIMULATE_write; \
	COLLECTION func11_AI_VIEW_1; \
	MENU func11_AI_VIEW_1_page; \
	MENU func11_AI_Simple_Dialog_Optional_A; \
	UNIT func11_AI_OUT_SCALE_unit_1; \
	UNIT func11_AI_OUT_SCALE_unit_2

#define USE_FUNC11_AI_OPTIONAL_B \
	USE_FUNC11_AI_OPTIONAL_BOTH; \
	MENU func11_AI_Simple_Dialog_Optional_B; \
	UNIT func11_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC11_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func11_AI_)
#define USE_FUNC11_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func11_AI_)
#define USE_FUNC11_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func11_AI_)
#define USE_FUNC11_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func11_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC12_AI_MANDATORY_BOTH \
	BLOCK func12_AI_block; \
	COLLECTION func12_AI_BLOCK_OBJECT; \
	VARIABLE func12_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func12_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func12_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func12_AI_BLOCK_OBJECT_Class; \
	VARIABLE func12_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func12_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func12_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func12_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func12_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func12_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func12_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func12_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func12_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func12_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func12_AI_BLOCK_OBJECT_page; \
	COMMAND func12_AI_BLOCK_OBJECT_read; \
	VARIABLE func12_AI_ST_REV; \
	MENU func12_AI_ST_REV_page; \
	COMMAND func12_AI_ST_REV_read; \
	VARIABLE func12_AI_TAG_DESC; \
	MENU func12_AI_TAG_DESC_page; \
	COMMAND func12_AI_TAG_DESC_read; \
	COMMAND func12_AI_TAG_DESC_write; \
	VARIABLE func12_AI_STRATEGY; \
	MENU func12_AI_STRATEGY_page; \
	COMMAND func12_AI_STRATEGY_read; \
	COMMAND func12_AI_STRATEGY_write; \
	VARIABLE func12_AI_ALERT_KEY; \
	MENU func12_AI_ALERT_KEY_page; \
	COMMAND func12_AI_ALERT_KEY_read; \
	COMMAND func12_AI_ALERT_KEY_write; \
	VARIABLE func12_AI_TARGET_MODE; \
	MENU func12_AI_TARGET_MODE_page; \
	COMMAND func12_AI_TARGET_MODE_read; \
	COMMAND func12_AI_TARGET_MODE_write; \
	COLLECTION func12_AI_MODE_BLK; \
	VARIABLE func12_AI_MODE_BLK_Actual; \
	VARIABLE func12_AI_MODE_BLK_Permitted; \
	VARIABLE func12_AI_MODE_BLK_Normal; \
	MENU func12_AI_MODE_BLK_page; \
	COMMAND func12_AI_MODE_BLK_read; \
	COLLECTION func12_AI_ALARM_SUM; \
	VARIABLE func12_AI_ALARM_SUM_Current; \
	VARIABLE func12_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func12_AI_ALARM_SUM_Unreported; \
	VARIABLE func12_AI_ALARM_SUM_Disabled; \
	MENU func12_AI_ALARM_SUM_page; \
	COMMAND func12_AI_ALARM_SUM_read; \
	COLLECTION func12_AI_BATCH; \
	VARIABLE func12_AI_BATCH_Batch_ID; \
	VARIABLE func12_AI_BATCH_Rup; \
	VARIABLE func12_AI_BATCH_Operation; \
	VARIABLE func12_AI_BATCH_Phase; \
	MENU func12_AI_BATCH_page; \
	COMMAND func12_AI_BATCH_read; \
	COMMAND func12_AI_BATCH_write; \
	COLLECTION func12_AI_OUT; \
	VARIABLE func12_AI_OUT_Value; \
	VARIABLE func12_AI_OUT_Status_Condensed; \
	VARIABLE func12_AI_OUT_Status_Quality; \
	VARIABLE func12_AI_OUT_Status_Limit; \
	MENU func12_AI_OUT_page; \
	COMMAND func12_AI_OUT_read; \
	COMMAND func12_AI_OUT_write; \
	COLLECTION func12_AI_PV_SCALE; \
	VARIABLE func12_AI_PV_SCALE_Upper_Value; \
	VARIABLE func12_AI_PV_SCALE_Lower_Value; \
	MENU func12_AI_PV_SCALE_page; \
	COMMAND func12_AI_PV_SCALE_read; \
	COMMAND func12_AI_PV_SCALE_write; \
	VARIABLE func12_AI_PV_FTIME; \
	MENU func12_AI_PV_FTIME_page; \
	COMMAND func12_AI_PV_FTIME_read; \
	COMMAND func12_AI_PV_FTIME_write; \
	VARIABLE func12_AI_ALARM_HYS; \
	MENU func12_AI_ALARM_HYS_page; \
	COMMAND func12_AI_ALARM_HYS_read; \
	COMMAND func12_AI_ALARM_HYS_write; \
	VARIABLE func12_AI_HI_HI_LIM; \
	MENU func12_AI_HI_HI_LIM_page; \
	COMMAND func12_AI_HI_HI_LIM_read; \
	COMMAND func12_AI_HI_HI_LIM_write; \
	VARIABLE func12_AI_HI_LIM; \
	MENU func12_AI_HI_LIM_page; \
	COMMAND func12_AI_HI_LIM_read; \
	COMMAND func12_AI_HI_LIM_write; \
	VARIABLE func12_AI_LO_LIM; \
	MENU func12_AI_LO_LIM_page; \
	COMMAND func12_AI_LO_LIM_read; \
	COMMAND func12_AI_LO_LIM_write; \
	VARIABLE func12_AI_LO_LO_LIM; \
	MENU func12_AI_LO_LO_LIM_page; \
	COMMAND func12_AI_LO_LO_LIM_read; \
	COMMAND func12_AI_LO_LO_LIM_write

#define USE_FUNC12_AI_MANDATORY_A \
	USE_FUNC12_AI_MANDATORY_BOTH; \
	MENU func12_AI_Simple_Dialog_Mandatory_A; \
	MENU func12_AI_Display_mandatory_A; \
	CHART func12_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func12_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func12_AI_Display_out_mandatory_A; \
	MENU func12_AI_Tab_s_mandatory_A; \
	MENU func12_AI_Tab_s_pv_range_mandatory_A; \
	MENU func12_AI_Tab_s_limits_mandatory_A; \
	MENU func12_AI_Tab_m_mandatory_A; \
	MENU func12_AI_Tab_m_pv_range_mandatory_A; \
	MENU func12_AI_Tab_m_limits_mandatory_A

#define USE_FUNC12_AI_MANDATORY_B \
	USE_FUNC12_AI_MANDATORY_BOTH; \
	COLLECTION func12_AI_OUT_SCALE; \
	VARIABLE func12_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func12_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func12_AI_OUT_SCALE_Units_Index; \
	VARIABLE func12_AI_OUT_SCALE_Decimal_Point; \
	MENU func12_AI_OUT_SCALE_page; \
	COMMAND func12_AI_OUT_SCALE_read; \
	COMMAND func12_AI_OUT_SCALE_write; \
	VARIABLE func12_AI_LIN_TYPE; \
	MENU func12_AI_LIN_TYPE_page; \
	COMMAND func12_AI_LIN_TYPE_read; \
	COMMAND func12_AI_LIN_TYPE_write; \
	VARIABLE func12_AI_CHANNEL; \
	MENU func12_AI_CHANNEL_page; \
	COMMAND func12_AI_CHANNEL_read; \
	COMMAND func12_AI_CHANNEL_write; \
	COLLECTION func12_AI_SIMULATE; \
	VARIABLE func12_AI_SIMULATE_Status_Condensed; \
	VARIABLE func12_AI_SIMULATE_Value; \
	VARIABLE func12_AI_SIMULATE_Enabled; \
	VARIABLE func12_AI_SIMULATE_Status_Quality; \
	VARIABLE func12_AI_SIMULATE_Status_Limit; \
	MENU func12_AI_SIMULATE_page; \
	COMMAND func12_AI_SIMULATE_read; \
	COMMAND func12_AI_SIMULATE_write; \
	COLLECTION func12_AI_VIEW_1; \
	MENU func12_AI_VIEW_1_page; \
	MENU func12_AI_Simple_Dialog_Mandatory_B; \
	UNIT func12_AI_OUT_SCALE_unit_1; \
	MENU func12_AI_Simulation; \
	MENU func12_AI_Simulation_input; \
	MENU func12_AI_Simulation_input_group; \
	MENU func12_AI_Simulation_output; \
	MENU func12_AI_Simulation_output_group; \
	MENU func12_AI_Display_mandatory_B; \
	CHART func12_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func12_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func12_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func12_AI_Display_out_mandatory_B; \
	MENU func12_AI_Display_in_mandatory_B; \
	MENU func12_AI_Tab_s_mandatory_B; \
	MENU func12_AI_Tab_s_pv_range_mandatory_B; \
	MENU func12_AI_Tab_s_outscale_mandatory_B; \
	MENU func12_AI_Tab_s_limits_mandatory_B; \
	MENU func12_AI_Tab_s_interface_mandatory_B; \
	MENU func12_AI_Tab_m_mandatory_B; \
	MENU func12_AI_Tab_m_pv_range_mandatory_B; \
	MENU func12_AI_Tab_m_outscale_mandatory_B; \
	MENU func12_AI_Tab_m_limits_mandatory_B

#define USE_FUNC12_AI_OPTIONAL_BOTH \
	VARIABLE func12_AI_FSAFE_TYPE; \
	MENU func12_AI_FSAFE_TYPE_page; \
	COMMAND func12_AI_FSAFE_TYPE_read; \
	COMMAND func12_AI_FSAFE_TYPE_write; \
	VARIABLE func12_AI_FSAFE_VALUE; \
	MENU func12_AI_FSAFE_VALUE_page; \
	COMMAND func12_AI_FSAFE_VALUE_read; \
	COMMAND func12_AI_FSAFE_VALUE_write; \
	COLLECTION func12_AI_HI_HI_ALM; \
	VARIABLE func12_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func12_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func12_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func12_AI_HI_HI_ALM_Subcode; \
	VARIABLE func12_AI_HI_HI_ALM_Value; \
	MENU func12_AI_HI_HI_ALM_page; \
	COMMAND func12_AI_HI_HI_ALM_read; \
	COLLECTION func12_AI_HI_ALM; \
	VARIABLE func12_AI_HI_ALM_Unacknowledged; \
	VARIABLE func12_AI_HI_ALM_Alarm_State; \
	VARIABLE func12_AI_HI_ALM_Time_Stamp; \
	VARIABLE func12_AI_HI_ALM_Subcode; \
	VARIABLE func12_AI_HI_ALM_Value; \
	MENU func12_AI_HI_ALM_page; \
	COMMAND func12_AI_HI_ALM_read; \
	COLLECTION func12_AI_LO_ALM; \
	VARIABLE func12_AI_LO_ALM_Unacknowledged; \
	VARIABLE func12_AI_LO_ALM_Alarm_State; \
	VARIABLE func12_AI_LO_ALM_Time_Stamp; \
	VARIABLE func12_AI_LO_ALM_Subcode; \
	VARIABLE func12_AI_LO_ALM_Value; \
	MENU func12_AI_LO_ALM_page; \
	COMMAND func12_AI_LO_ALM_read; \
	COLLECTION func12_AI_LO_LO_ALM; \
	VARIABLE func12_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func12_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func12_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func12_AI_LO_LO_ALM_Subcode; \
	VARIABLE func12_AI_LO_LO_ALM_Value; \
	MENU func12_AI_LO_LO_ALM_page; \
	COMMAND func12_AI_LO_LO_ALM_read; \
	VARIABLE func12_AI_OUT_UNIT_TEXT; \
	MENU func12_AI_OUT_UNIT_TEXT_page; \
	COMMAND func12_AI_OUT_UNIT_TEXT_read; \
	COMMAND func12_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func12_AI_VIEW_2; \
	MENU func12_AI_VIEW_2_page; \
	COLLECTION func12_AI_VIEW_3; \
	MENU func12_AI_VIEW_3_page

#define USE_FUNC12_AI_OPTIONAL_A \
	USE_FUNC12_AI_OPTIONAL_BOTH; \
	COLLECTION func12_AI_OUT_SCALE; \
	VARIABLE func12_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func12_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func12_AI_OUT_SCALE_Units_Index; \
	VARIABLE func12_AI_OUT_SCALE_Decimal_Point; \
	MENU func12_AI_OUT_SCALE_page; \
	COMMAND func12_AI_OUT_SCALE_read; \
	COMMAND func12_AI_OUT_SCALE_write; \
	VARIABLE func12_AI_LIN_TYPE; \
	MENU func12_AI_LIN_TYPE_page; \
	COMMAND func12_AI_LIN_TYPE_read; \
	COMMAND func12_AI_LIN_TYPE_write; \
	VARIABLE func12_AI_CHANNEL; \
	MENU func12_AI_CHANNEL_page; \
	COMMAND func12_AI_CHANNEL_read; \
	COMMAND func12_AI_CHANNEL_write; \
	COLLECTION func12_AI_SIMULATE; \
	VARIABLE func12_AI_SIMULATE_Status_Condensed; \
	VARIABLE func12_AI_SIMULATE_Value; \
	VARIABLE func12_AI_SIMULATE_Enabled; \
	VARIABLE func12_AI_SIMULATE_Status_Quality; \
	VARIABLE func12_AI_SIMULATE_Status_Limit; \
	MENU func12_AI_SIMULATE_page; \
	COMMAND func12_AI_SIMULATE_read; \
	COMMAND func12_AI_SIMULATE_write; \
	COLLECTION func12_AI_VIEW_1; \
	MENU func12_AI_VIEW_1_page; \
	MENU func12_AI_Simple_Dialog_Optional_A; \
	UNIT func12_AI_OUT_SCALE_unit_1; \
	UNIT func12_AI_OUT_SCALE_unit_2

#define USE_FUNC12_AI_OPTIONAL_B \
	USE_FUNC12_AI_OPTIONAL_BOTH; \
	MENU func12_AI_Simple_Dialog_Optional_B; \
	UNIT func12_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC12_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func12_AI_)
#define USE_FUNC12_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func12_AI_)
#define USE_FUNC12_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func12_AI_)
#define USE_FUNC12_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func12_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC13_AI_MANDATORY_BOTH \
	BLOCK func13_AI_block; \
	COLLECTION func13_AI_BLOCK_OBJECT; \
	VARIABLE func13_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func13_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func13_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func13_AI_BLOCK_OBJECT_Class; \
	VARIABLE func13_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func13_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func13_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func13_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func13_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func13_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func13_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func13_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func13_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func13_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func13_AI_BLOCK_OBJECT_page; \
	COMMAND func13_AI_BLOCK_OBJECT_read; \
	VARIABLE func13_AI_ST_REV; \
	MENU func13_AI_ST_REV_page; \
	COMMAND func13_AI_ST_REV_read; \
	VARIABLE func13_AI_TAG_DESC; \
	MENU func13_AI_TAG_DESC_page; \
	COMMAND func13_AI_TAG_DESC_read; \
	COMMAND func13_AI_TAG_DESC_write; \
	VARIABLE func13_AI_STRATEGY; \
	MENU func13_AI_STRATEGY_page; \
	COMMAND func13_AI_STRATEGY_read; \
	COMMAND func13_AI_STRATEGY_write; \
	VARIABLE func13_AI_ALERT_KEY; \
	MENU func13_AI_ALERT_KEY_page; \
	COMMAND func13_AI_ALERT_KEY_read; \
	COMMAND func13_AI_ALERT_KEY_write; \
	VARIABLE func13_AI_TARGET_MODE; \
	MENU func13_AI_TARGET_MODE_page; \
	COMMAND func13_AI_TARGET_MODE_read; \
	COMMAND func13_AI_TARGET_MODE_write; \
	COLLECTION func13_AI_MODE_BLK; \
	VARIABLE func13_AI_MODE_BLK_Actual; \
	VARIABLE func13_AI_MODE_BLK_Permitted; \
	VARIABLE func13_AI_MODE_BLK_Normal; \
	MENU func13_AI_MODE_BLK_page; \
	COMMAND func13_AI_MODE_BLK_read; \
	COLLECTION func13_AI_ALARM_SUM; \
	VARIABLE func13_AI_ALARM_SUM_Current; \
	VARIABLE func13_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func13_AI_ALARM_SUM_Unreported; \
	VARIABLE func13_AI_ALARM_SUM_Disabled; \
	MENU func13_AI_ALARM_SUM_page; \
	COMMAND func13_AI_ALARM_SUM_read; \
	COLLECTION func13_AI_BATCH; \
	VARIABLE func13_AI_BATCH_Batch_ID; \
	VARIABLE func13_AI_BATCH_Rup; \
	VARIABLE func13_AI_BATCH_Operation; \
	VARIABLE func13_AI_BATCH_Phase; \
	MENU func13_AI_BATCH_page; \
	COMMAND func13_AI_BATCH_read; \
	COMMAND func13_AI_BATCH_write; \
	COLLECTION func13_AI_OUT; \
	VARIABLE func13_AI_OUT_Value; \
	VARIABLE func13_AI_OUT_Status_Condensed; \
	VARIABLE func13_AI_OUT_Status_Quality; \
	VARIABLE func13_AI_OUT_Status_Limit; \
	MENU func13_AI_OUT_page; \
	COMMAND func13_AI_OUT_read; \
	COMMAND func13_AI_OUT_write; \
	COLLECTION func13_AI_PV_SCALE; \
	VARIABLE func13_AI_PV_SCALE_Upper_Value; \
	VARIABLE func13_AI_PV_SCALE_Lower_Value; \
	MENU func13_AI_PV_SCALE_page; \
	COMMAND func13_AI_PV_SCALE_read; \
	COMMAND func13_AI_PV_SCALE_write; \
	VARIABLE func13_AI_PV_FTIME; \
	MENU func13_AI_PV_FTIME_page; \
	COMMAND func13_AI_PV_FTIME_read; \
	COMMAND func13_AI_PV_FTIME_write; \
	VARIABLE func13_AI_ALARM_HYS; \
	MENU func13_AI_ALARM_HYS_page; \
	COMMAND func13_AI_ALARM_HYS_read; \
	COMMAND func13_AI_ALARM_HYS_write; \
	VARIABLE func13_AI_HI_HI_LIM; \
	MENU func13_AI_HI_HI_LIM_page; \
	COMMAND func13_AI_HI_HI_LIM_read; \
	COMMAND func13_AI_HI_HI_LIM_write; \
	VARIABLE func13_AI_HI_LIM; \
	MENU func13_AI_HI_LIM_page; \
	COMMAND func13_AI_HI_LIM_read; \
	COMMAND func13_AI_HI_LIM_write; \
	VARIABLE func13_AI_LO_LIM; \
	MENU func13_AI_LO_LIM_page; \
	COMMAND func13_AI_LO_LIM_read; \
	COMMAND func13_AI_LO_LIM_write; \
	VARIABLE func13_AI_LO_LO_LIM; \
	MENU func13_AI_LO_LO_LIM_page; \
	COMMAND func13_AI_LO_LO_LIM_read; \
	COMMAND func13_AI_LO_LO_LIM_write

#define USE_FUNC13_AI_MANDATORY_A \
	USE_FUNC13_AI_MANDATORY_BOTH; \
	MENU func13_AI_Simple_Dialog_Mandatory_A; \
	MENU func13_AI_Display_mandatory_A; \
	CHART func13_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func13_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func13_AI_Display_out_mandatory_A; \
	MENU func13_AI_Tab_s_mandatory_A; \
	MENU func13_AI_Tab_s_pv_range_mandatory_A; \
	MENU func13_AI_Tab_s_limits_mandatory_A; \
	MENU func13_AI_Tab_m_mandatory_A; \
	MENU func13_AI_Tab_m_pv_range_mandatory_A; \
	MENU func13_AI_Tab_m_limits_mandatory_A

#define USE_FUNC13_AI_MANDATORY_B \
	USE_FUNC13_AI_MANDATORY_BOTH; \
	COLLECTION func13_AI_OUT_SCALE; \
	VARIABLE func13_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func13_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func13_AI_OUT_SCALE_Units_Index; \
	VARIABLE func13_AI_OUT_SCALE_Decimal_Point; \
	MENU func13_AI_OUT_SCALE_page; \
	COMMAND func13_AI_OUT_SCALE_read; \
	COMMAND func13_AI_OUT_SCALE_write; \
	VARIABLE func13_AI_LIN_TYPE; \
	MENU func13_AI_LIN_TYPE_page; \
	COMMAND func13_AI_LIN_TYPE_read; \
	COMMAND func13_AI_LIN_TYPE_write; \
	VARIABLE func13_AI_CHANNEL; \
	MENU func13_AI_CHANNEL_page; \
	COMMAND func13_AI_CHANNEL_read; \
	COMMAND func13_AI_CHANNEL_write; \
	COLLECTION func13_AI_SIMULATE; \
	VARIABLE func13_AI_SIMULATE_Status_Condensed; \
	VARIABLE func13_AI_SIMULATE_Value; \
	VARIABLE func13_AI_SIMULATE_Enabled; \
	VARIABLE func13_AI_SIMULATE_Status_Quality; \
	VARIABLE func13_AI_SIMULATE_Status_Limit; \
	MENU func13_AI_SIMULATE_page; \
	COMMAND func13_AI_SIMULATE_read; \
	COMMAND func13_AI_SIMULATE_write; \
	COLLECTION func13_AI_VIEW_1; \
	MENU func13_AI_VIEW_1_page; \
	MENU func13_AI_Simple_Dialog_Mandatory_B; \
	UNIT func13_AI_OUT_SCALE_unit_1; \
	MENU func13_AI_Simulation; \
	MENU func13_AI_Simulation_input; \
	MENU func13_AI_Simulation_input_group; \
	MENU func13_AI_Simulation_output; \
	MENU func13_AI_Simulation_output_group; \
	MENU func13_AI_Display_mandatory_B; \
	CHART func13_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func13_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func13_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func13_AI_Display_out_mandatory_B; \
	MENU func13_AI_Display_in_mandatory_B; \
	MENU func13_AI_Tab_s_mandatory_B; \
	MENU func13_AI_Tab_s_pv_range_mandatory_B; \
	MENU func13_AI_Tab_s_outscale_mandatory_B; \
	MENU func13_AI_Tab_s_limits_mandatory_B; \
	MENU func13_AI_Tab_s_interface_mandatory_B; \
	MENU func13_AI_Tab_m_mandatory_B; \
	MENU func13_AI_Tab_m_pv_range_mandatory_B; \
	MENU func13_AI_Tab_m_outscale_mandatory_B; \
	MENU func13_AI_Tab_m_limits_mandatory_B

#define USE_FUNC13_AI_OPTIONAL_BOTH \
	VARIABLE func13_AI_FSAFE_TYPE; \
	MENU func13_AI_FSAFE_TYPE_page; \
	COMMAND func13_AI_FSAFE_TYPE_read; \
	COMMAND func13_AI_FSAFE_TYPE_write; \
	VARIABLE func13_AI_FSAFE_VALUE; \
	MENU func13_AI_FSAFE_VALUE_page; \
	COMMAND func13_AI_FSAFE_VALUE_read; \
	COMMAND func13_AI_FSAFE_VALUE_write; \
	COLLECTION func13_AI_HI_HI_ALM; \
	VARIABLE func13_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func13_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func13_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func13_AI_HI_HI_ALM_Subcode; \
	VARIABLE func13_AI_HI_HI_ALM_Value; \
	MENU func13_AI_HI_HI_ALM_page; \
	COMMAND func13_AI_HI_HI_ALM_read; \
	COLLECTION func13_AI_HI_ALM; \
	VARIABLE func13_AI_HI_ALM_Unacknowledged; \
	VARIABLE func13_AI_HI_ALM_Alarm_State; \
	VARIABLE func13_AI_HI_ALM_Time_Stamp; \
	VARIABLE func13_AI_HI_ALM_Subcode; \
	VARIABLE func13_AI_HI_ALM_Value; \
	MENU func13_AI_HI_ALM_page; \
	COMMAND func13_AI_HI_ALM_read; \
	COLLECTION func13_AI_LO_ALM; \
	VARIABLE func13_AI_LO_ALM_Unacknowledged; \
	VARIABLE func13_AI_LO_ALM_Alarm_State; \
	VARIABLE func13_AI_LO_ALM_Time_Stamp; \
	VARIABLE func13_AI_LO_ALM_Subcode; \
	VARIABLE func13_AI_LO_ALM_Value; \
	MENU func13_AI_LO_ALM_page; \
	COMMAND func13_AI_LO_ALM_read; \
	COLLECTION func13_AI_LO_LO_ALM; \
	VARIABLE func13_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func13_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func13_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func13_AI_LO_LO_ALM_Subcode; \
	VARIABLE func13_AI_LO_LO_ALM_Value; \
	MENU func13_AI_LO_LO_ALM_page; \
	COMMAND func13_AI_LO_LO_ALM_read; \
	VARIABLE func13_AI_OUT_UNIT_TEXT; \
	MENU func13_AI_OUT_UNIT_TEXT_page; \
	COMMAND func13_AI_OUT_UNIT_TEXT_read; \
	COMMAND func13_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func13_AI_VIEW_2; \
	MENU func13_AI_VIEW_2_page; \
	COLLECTION func13_AI_VIEW_3; \
	MENU func13_AI_VIEW_3_page

#define USE_FUNC13_AI_OPTIONAL_A \
	USE_FUNC13_AI_OPTIONAL_BOTH; \
	COLLECTION func13_AI_OUT_SCALE; \
	VARIABLE func13_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func13_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func13_AI_OUT_SCALE_Units_Index; \
	VARIABLE func13_AI_OUT_SCALE_Decimal_Point; \
	MENU func13_AI_OUT_SCALE_page; \
	COMMAND func13_AI_OUT_SCALE_read; \
	COMMAND func13_AI_OUT_SCALE_write; \
	VARIABLE func13_AI_LIN_TYPE; \
	MENU func13_AI_LIN_TYPE_page; \
	COMMAND func13_AI_LIN_TYPE_read; \
	COMMAND func13_AI_LIN_TYPE_write; \
	VARIABLE func13_AI_CHANNEL; \
	MENU func13_AI_CHANNEL_page; \
	COMMAND func13_AI_CHANNEL_read; \
	COMMAND func13_AI_CHANNEL_write; \
	COLLECTION func13_AI_SIMULATE; \
	VARIABLE func13_AI_SIMULATE_Status_Condensed; \
	VARIABLE func13_AI_SIMULATE_Value; \
	VARIABLE func13_AI_SIMULATE_Enabled; \
	VARIABLE func13_AI_SIMULATE_Status_Quality; \
	VARIABLE func13_AI_SIMULATE_Status_Limit; \
	MENU func13_AI_SIMULATE_page; \
	COMMAND func13_AI_SIMULATE_read; \
	COMMAND func13_AI_SIMULATE_write; \
	COLLECTION func13_AI_VIEW_1; \
	MENU func13_AI_VIEW_1_page; \
	MENU func13_AI_Simple_Dialog_Optional_A; \
	UNIT func13_AI_OUT_SCALE_unit_1; \
	UNIT func13_AI_OUT_SCALE_unit_2

#define USE_FUNC13_AI_OPTIONAL_B \
	USE_FUNC13_AI_OPTIONAL_BOTH; \
	MENU func13_AI_Simple_Dialog_Optional_B; \
	UNIT func13_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC13_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func13_AI_)
#define USE_FUNC13_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func13_AI_)
#define USE_FUNC13_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func13_AI_)
#define USE_FUNC13_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func13_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC14_AI_MANDATORY_BOTH \
	BLOCK func14_AI_block; \
	COLLECTION func14_AI_BLOCK_OBJECT; \
	VARIABLE func14_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func14_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func14_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func14_AI_BLOCK_OBJECT_Class; \
	VARIABLE func14_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func14_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func14_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func14_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func14_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func14_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func14_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func14_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func14_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func14_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func14_AI_BLOCK_OBJECT_page; \
	COMMAND func14_AI_BLOCK_OBJECT_read; \
	VARIABLE func14_AI_ST_REV; \
	MENU func14_AI_ST_REV_page; \
	COMMAND func14_AI_ST_REV_read; \
	VARIABLE func14_AI_TAG_DESC; \
	MENU func14_AI_TAG_DESC_page; \
	COMMAND func14_AI_TAG_DESC_read; \
	COMMAND func14_AI_TAG_DESC_write; \
	VARIABLE func14_AI_STRATEGY; \
	MENU func14_AI_STRATEGY_page; \
	COMMAND func14_AI_STRATEGY_read; \
	COMMAND func14_AI_STRATEGY_write; \
	VARIABLE func14_AI_ALERT_KEY; \
	MENU func14_AI_ALERT_KEY_page; \
	COMMAND func14_AI_ALERT_KEY_read; \
	COMMAND func14_AI_ALERT_KEY_write; \
	VARIABLE func14_AI_TARGET_MODE; \
	MENU func14_AI_TARGET_MODE_page; \
	COMMAND func14_AI_TARGET_MODE_read; \
	COMMAND func14_AI_TARGET_MODE_write; \
	COLLECTION func14_AI_MODE_BLK; \
	VARIABLE func14_AI_MODE_BLK_Actual; \
	VARIABLE func14_AI_MODE_BLK_Permitted; \
	VARIABLE func14_AI_MODE_BLK_Normal; \
	MENU func14_AI_MODE_BLK_page; \
	COMMAND func14_AI_MODE_BLK_read; \
	COLLECTION func14_AI_ALARM_SUM; \
	VARIABLE func14_AI_ALARM_SUM_Current; \
	VARIABLE func14_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func14_AI_ALARM_SUM_Unreported; \
	VARIABLE func14_AI_ALARM_SUM_Disabled; \
	MENU func14_AI_ALARM_SUM_page; \
	COMMAND func14_AI_ALARM_SUM_read; \
	COLLECTION func14_AI_BATCH; \
	VARIABLE func14_AI_BATCH_Batch_ID; \
	VARIABLE func14_AI_BATCH_Rup; \
	VARIABLE func14_AI_BATCH_Operation; \
	VARIABLE func14_AI_BATCH_Phase; \
	MENU func14_AI_BATCH_page; \
	COMMAND func14_AI_BATCH_read; \
	COMMAND func14_AI_BATCH_write; \
	COLLECTION func14_AI_OUT; \
	VARIABLE func14_AI_OUT_Value; \
	VARIABLE func14_AI_OUT_Status_Condensed; \
	VARIABLE func14_AI_OUT_Status_Quality; \
	VARIABLE func14_AI_OUT_Status_Limit; \
	MENU func14_AI_OUT_page; \
	COMMAND func14_AI_OUT_read; \
	COMMAND func14_AI_OUT_write; \
	COLLECTION func14_AI_PV_SCALE; \
	VARIABLE func14_AI_PV_SCALE_Upper_Value; \
	VARIABLE func14_AI_PV_SCALE_Lower_Value; \
	MENU func14_AI_PV_SCALE_page; \
	COMMAND func14_AI_PV_SCALE_read; \
	COMMAND func14_AI_PV_SCALE_write; \
	VARIABLE func14_AI_PV_FTIME; \
	MENU func14_AI_PV_FTIME_page; \
	COMMAND func14_AI_PV_FTIME_read; \
	COMMAND func14_AI_PV_FTIME_write; \
	VARIABLE func14_AI_ALARM_HYS; \
	MENU func14_AI_ALARM_HYS_page; \
	COMMAND func14_AI_ALARM_HYS_read; \
	COMMAND func14_AI_ALARM_HYS_write; \
	VARIABLE func14_AI_HI_HI_LIM; \
	MENU func14_AI_HI_HI_LIM_page; \
	COMMAND func14_AI_HI_HI_LIM_read; \
	COMMAND func14_AI_HI_HI_LIM_write; \
	VARIABLE func14_AI_HI_LIM; \
	MENU func14_AI_HI_LIM_page; \
	COMMAND func14_AI_HI_LIM_read; \
	COMMAND func14_AI_HI_LIM_write; \
	VARIABLE func14_AI_LO_LIM; \
	MENU func14_AI_LO_LIM_page; \
	COMMAND func14_AI_LO_LIM_read; \
	COMMAND func14_AI_LO_LIM_write; \
	VARIABLE func14_AI_LO_LO_LIM; \
	MENU func14_AI_LO_LO_LIM_page; \
	COMMAND func14_AI_LO_LO_LIM_read; \
	COMMAND func14_AI_LO_LO_LIM_write

#define USE_FUNC14_AI_MANDATORY_A \
	USE_FUNC14_AI_MANDATORY_BOTH; \
	MENU func14_AI_Simple_Dialog_Mandatory_A; \
	MENU func14_AI_Display_mandatory_A; \
	CHART func14_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func14_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func14_AI_Display_out_mandatory_A; \
	MENU func14_AI_Tab_s_mandatory_A; \
	MENU func14_AI_Tab_s_pv_range_mandatory_A; \
	MENU func14_AI_Tab_s_limits_mandatory_A; \
	MENU func14_AI_Tab_m_mandatory_A; \
	MENU func14_AI_Tab_m_pv_range_mandatory_A; \
	MENU func14_AI_Tab_m_limits_mandatory_A

#define USE_FUNC14_AI_MANDATORY_B \
	USE_FUNC14_AI_MANDATORY_BOTH; \
	COLLECTION func14_AI_OUT_SCALE; \
	VARIABLE func14_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func14_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func14_AI_OUT_SCALE_Units_Index; \
	VARIABLE func14_AI_OUT_SCALE_Decimal_Point; \
	MENU func14_AI_OUT_SCALE_page; \
	COMMAND func14_AI_OUT_SCALE_read; \
	COMMAND func14_AI_OUT_SCALE_write; \
	VARIABLE func14_AI_LIN_TYPE; \
	MENU func14_AI_LIN_TYPE_page; \
	COMMAND func14_AI_LIN_TYPE_read; \
	COMMAND func14_AI_LIN_TYPE_write; \
	VARIABLE func14_AI_CHANNEL; \
	MENU func14_AI_CHANNEL_page; \
	COMMAND func14_AI_CHANNEL_read; \
	COMMAND func14_AI_CHANNEL_write; \
	COLLECTION func14_AI_SIMULATE; \
	VARIABLE func14_AI_SIMULATE_Status_Condensed; \
	VARIABLE func14_AI_SIMULATE_Value; \
	VARIABLE func14_AI_SIMULATE_Enabled; \
	VARIABLE func14_AI_SIMULATE_Status_Quality; \
	VARIABLE func14_AI_SIMULATE_Status_Limit; \
	MENU func14_AI_SIMULATE_page; \
	COMMAND func14_AI_SIMULATE_read; \
	COMMAND func14_AI_SIMULATE_write; \
	COLLECTION func14_AI_VIEW_1; \
	MENU func14_AI_VIEW_1_page; \
	MENU func14_AI_Simple_Dialog_Mandatory_B; \
	UNIT func14_AI_OUT_SCALE_unit_1; \
	MENU func14_AI_Simulation; \
	MENU func14_AI_Simulation_input; \
	MENU func14_AI_Simulation_input_group; \
	MENU func14_AI_Simulation_output; \
	MENU func14_AI_Simulation_output_group; \
	MENU func14_AI_Display_mandatory_B; \
	CHART func14_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func14_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func14_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func14_AI_Display_out_mandatory_B; \
	MENU func14_AI_Display_in_mandatory_B; \
	MENU func14_AI_Tab_s_mandatory_B; \
	MENU func14_AI_Tab_s_pv_range_mandatory_B; \
	MENU func14_AI_Tab_s_outscale_mandatory_B; \
	MENU func14_AI_Tab_s_limits_mandatory_B; \
	MENU func14_AI_Tab_s_interface_mandatory_B; \
	MENU func14_AI_Tab_m_mandatory_B; \
	MENU func14_AI_Tab_m_pv_range_mandatory_B; \
	MENU func14_AI_Tab_m_outscale_mandatory_B; \
	MENU func14_AI_Tab_m_limits_mandatory_B

#define USE_FUNC14_AI_OPTIONAL_BOTH \
	VARIABLE func14_AI_FSAFE_TYPE; \
	MENU func14_AI_FSAFE_TYPE_page; \
	COMMAND func14_AI_FSAFE_TYPE_read; \
	COMMAND func14_AI_FSAFE_TYPE_write; \
	VARIABLE func14_AI_FSAFE_VALUE; \
	MENU func14_AI_FSAFE_VALUE_page; \
	COMMAND func14_AI_FSAFE_VALUE_read; \
	COMMAND func14_AI_FSAFE_VALUE_write; \
	COLLECTION func14_AI_HI_HI_ALM; \
	VARIABLE func14_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func14_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func14_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func14_AI_HI_HI_ALM_Subcode; \
	VARIABLE func14_AI_HI_HI_ALM_Value; \
	MENU func14_AI_HI_HI_ALM_page; \
	COMMAND func14_AI_HI_HI_ALM_read; \
	COLLECTION func14_AI_HI_ALM; \
	VARIABLE func14_AI_HI_ALM_Unacknowledged; \
	VARIABLE func14_AI_HI_ALM_Alarm_State; \
	VARIABLE func14_AI_HI_ALM_Time_Stamp; \
	VARIABLE func14_AI_HI_ALM_Subcode; \
	VARIABLE func14_AI_HI_ALM_Value; \
	MENU func14_AI_HI_ALM_page; \
	COMMAND func14_AI_HI_ALM_read; \
	COLLECTION func14_AI_LO_ALM; \
	VARIABLE func14_AI_LO_ALM_Unacknowledged; \
	VARIABLE func14_AI_LO_ALM_Alarm_State; \
	VARIABLE func14_AI_LO_ALM_Time_Stamp; \
	VARIABLE func14_AI_LO_ALM_Subcode; \
	VARIABLE func14_AI_LO_ALM_Value; \
	MENU func14_AI_LO_ALM_page; \
	COMMAND func14_AI_LO_ALM_read; \
	COLLECTION func14_AI_LO_LO_ALM; \
	VARIABLE func14_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func14_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func14_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func14_AI_LO_LO_ALM_Subcode; \
	VARIABLE func14_AI_LO_LO_ALM_Value; \
	MENU func14_AI_LO_LO_ALM_page; \
	COMMAND func14_AI_LO_LO_ALM_read; \
	VARIABLE func14_AI_OUT_UNIT_TEXT; \
	MENU func14_AI_OUT_UNIT_TEXT_page; \
	COMMAND func14_AI_OUT_UNIT_TEXT_read; \
	COMMAND func14_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func14_AI_VIEW_2; \
	MENU func14_AI_VIEW_2_page; \
	COLLECTION func14_AI_VIEW_3; \
	MENU func14_AI_VIEW_3_page

#define USE_FUNC14_AI_OPTIONAL_A \
	USE_FUNC14_AI_OPTIONAL_BOTH; \
	COLLECTION func14_AI_OUT_SCALE; \
	VARIABLE func14_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func14_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func14_AI_OUT_SCALE_Units_Index; \
	VARIABLE func14_AI_OUT_SCALE_Decimal_Point; \
	MENU func14_AI_OUT_SCALE_page; \
	COMMAND func14_AI_OUT_SCALE_read; \
	COMMAND func14_AI_OUT_SCALE_write; \
	VARIABLE func14_AI_LIN_TYPE; \
	MENU func14_AI_LIN_TYPE_page; \
	COMMAND func14_AI_LIN_TYPE_read; \
	COMMAND func14_AI_LIN_TYPE_write; \
	VARIABLE func14_AI_CHANNEL; \
	MENU func14_AI_CHANNEL_page; \
	COMMAND func14_AI_CHANNEL_read; \
	COMMAND func14_AI_CHANNEL_write; \
	COLLECTION func14_AI_SIMULATE; \
	VARIABLE func14_AI_SIMULATE_Status_Condensed; \
	VARIABLE func14_AI_SIMULATE_Value; \
	VARIABLE func14_AI_SIMULATE_Enabled; \
	VARIABLE func14_AI_SIMULATE_Status_Quality; \
	VARIABLE func14_AI_SIMULATE_Status_Limit; \
	MENU func14_AI_SIMULATE_page; \
	COMMAND func14_AI_SIMULATE_read; \
	COMMAND func14_AI_SIMULATE_write; \
	COLLECTION func14_AI_VIEW_1; \
	MENU func14_AI_VIEW_1_page; \
	MENU func14_AI_Simple_Dialog_Optional_A; \
	UNIT func14_AI_OUT_SCALE_unit_1; \
	UNIT func14_AI_OUT_SCALE_unit_2

#define USE_FUNC14_AI_OPTIONAL_B \
	USE_FUNC14_AI_OPTIONAL_BOTH; \
	MENU func14_AI_Simple_Dialog_Optional_B; \
	UNIT func14_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC14_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func14_AI_)
#define USE_FUNC14_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func14_AI_)
#define USE_FUNC14_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func14_AI_)
#define USE_FUNC14_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func14_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC15_AI_MANDATORY_BOTH \
	BLOCK func15_AI_block; \
	COLLECTION func15_AI_BLOCK_OBJECT; \
	VARIABLE func15_AI_BLOCK_OBJECT_Reserved; \
	VARIABLE func15_AI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func15_AI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func15_AI_BLOCK_OBJECT_Class; \
	VARIABLE func15_AI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func15_AI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func15_AI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func15_AI_BLOCK_OBJECT_Profile; \
	VARIABLE func15_AI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func15_AI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func15_AI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func15_AI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func15_AI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func15_AI_BLOCK_OBJECT_Number_of_Views; \
	MENU func15_AI_BLOCK_OBJECT_page; \
	COMMAND func15_AI_BLOCK_OBJECT_read; \
	VARIABLE func15_AI_ST_REV; \
	MENU func15_AI_ST_REV_page; \
	COMMAND func15_AI_ST_REV_read; \
	VARIABLE func15_AI_TAG_DESC; \
	MENU func15_AI_TAG_DESC_page; \
	COMMAND func15_AI_TAG_DESC_read; \
	COMMAND func15_AI_TAG_DESC_write; \
	VARIABLE func15_AI_STRATEGY; \
	MENU func15_AI_STRATEGY_page; \
	COMMAND func15_AI_STRATEGY_read; \
	COMMAND func15_AI_STRATEGY_write; \
	VARIABLE func15_AI_ALERT_KEY; \
	MENU func15_AI_ALERT_KEY_page; \
	COMMAND func15_AI_ALERT_KEY_read; \
	COMMAND func15_AI_ALERT_KEY_write; \
	VARIABLE func15_AI_TARGET_MODE; \
	MENU func15_AI_TARGET_MODE_page; \
	COMMAND func15_AI_TARGET_MODE_read; \
	COMMAND func15_AI_TARGET_MODE_write; \
	COLLECTION func15_AI_MODE_BLK; \
	VARIABLE func15_AI_MODE_BLK_Actual; \
	VARIABLE func15_AI_MODE_BLK_Permitted; \
	VARIABLE func15_AI_MODE_BLK_Normal; \
	MENU func15_AI_MODE_BLK_page; \
	COMMAND func15_AI_MODE_BLK_read; \
	COLLECTION func15_AI_ALARM_SUM; \
	VARIABLE func15_AI_ALARM_SUM_Current; \
	VARIABLE func15_AI_ALARM_SUM_Unacknowledged; \
	VARIABLE func15_AI_ALARM_SUM_Unreported; \
	VARIABLE func15_AI_ALARM_SUM_Disabled; \
	MENU func15_AI_ALARM_SUM_page; \
	COMMAND func15_AI_ALARM_SUM_read; \
	COLLECTION func15_AI_BATCH; \
	VARIABLE func15_AI_BATCH_Batch_ID; \
	VARIABLE func15_AI_BATCH_Rup; \
	VARIABLE func15_AI_BATCH_Operation; \
	VARIABLE func15_AI_BATCH_Phase; \
	MENU func15_AI_BATCH_page; \
	COMMAND func15_AI_BATCH_read; \
	COMMAND func15_AI_BATCH_write; \
	COLLECTION func15_AI_OUT; \
	VARIABLE func15_AI_OUT_Value; \
	VARIABLE func15_AI_OUT_Status_Condensed; \
	VARIABLE func15_AI_OUT_Status_Quality; \
	VARIABLE func15_AI_OUT_Status_Limit; \
	MENU func15_AI_OUT_page; \
	COMMAND func15_AI_OUT_read; \
	COMMAND func15_AI_OUT_write; \
	COLLECTION func15_AI_PV_SCALE; \
	VARIABLE func15_AI_PV_SCALE_Upper_Value; \
	VARIABLE func15_AI_PV_SCALE_Lower_Value; \
	MENU func15_AI_PV_SCALE_page; \
	COMMAND func15_AI_PV_SCALE_read; \
	COMMAND func15_AI_PV_SCALE_write; \
	VARIABLE func15_AI_PV_FTIME; \
	MENU func15_AI_PV_FTIME_page; \
	COMMAND func15_AI_PV_FTIME_read; \
	COMMAND func15_AI_PV_FTIME_write; \
	VARIABLE func15_AI_ALARM_HYS; \
	MENU func15_AI_ALARM_HYS_page; \
	COMMAND func15_AI_ALARM_HYS_read; \
	COMMAND func15_AI_ALARM_HYS_write; \
	VARIABLE func15_AI_HI_HI_LIM; \
	MENU func15_AI_HI_HI_LIM_page; \
	COMMAND func15_AI_HI_HI_LIM_read; \
	COMMAND func15_AI_HI_HI_LIM_write; \
	VARIABLE func15_AI_HI_LIM; \
	MENU func15_AI_HI_LIM_page; \
	COMMAND func15_AI_HI_LIM_read; \
	COMMAND func15_AI_HI_LIM_write; \
	VARIABLE func15_AI_LO_LIM; \
	MENU func15_AI_LO_LIM_page; \
	COMMAND func15_AI_LO_LIM_read; \
	COMMAND func15_AI_LO_LIM_write; \
	VARIABLE func15_AI_LO_LO_LIM; \
	MENU func15_AI_LO_LO_LIM_page; \
	COMMAND func15_AI_LO_LO_LIM_read; \
	COMMAND func15_AI_LO_LO_LIM_write

#define USE_FUNC15_AI_MANDATORY_A \
	USE_FUNC15_AI_MANDATORY_BOTH; \
	MENU func15_AI_Simple_Dialog_Mandatory_A; \
	MENU func15_AI_Display_mandatory_A; \
	CHART func15_AI_Display_BarVal_out_mandatory_A; \
	SOURCE func15_AI_Display_BarVal_out_source_mandatory_A; \
	MENU func15_AI_Display_out_mandatory_A; \
	MENU func15_AI_Tab_s_mandatory_A; \
	MENU func15_AI_Tab_s_pv_range_mandatory_A; \
	MENU func15_AI_Tab_s_limits_mandatory_A; \
	MENU func15_AI_Tab_m_mandatory_A; \
	MENU func15_AI_Tab_m_pv_range_mandatory_A; \
	MENU func15_AI_Tab_m_limits_mandatory_A

#define USE_FUNC15_AI_MANDATORY_B \
	USE_FUNC15_AI_MANDATORY_BOTH; \
	COLLECTION func15_AI_OUT_SCALE; \
	VARIABLE func15_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func15_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func15_AI_OUT_SCALE_Units_Index; \
	VARIABLE func15_AI_OUT_SCALE_Decimal_Point; \
	MENU func15_AI_OUT_SCALE_page; \
	COMMAND func15_AI_OUT_SCALE_read; \
	COMMAND func15_AI_OUT_SCALE_write; \
	VARIABLE func15_AI_LIN_TYPE; \
	MENU func15_AI_LIN_TYPE_page; \
	COMMAND func15_AI_LIN_TYPE_read; \
	COMMAND func15_AI_LIN_TYPE_write; \
	VARIABLE func15_AI_CHANNEL; \
	MENU func15_AI_CHANNEL_page; \
	COMMAND func15_AI_CHANNEL_read; \
	COMMAND func15_AI_CHANNEL_write; \
	COLLECTION func15_AI_SIMULATE; \
	VARIABLE func15_AI_SIMULATE_Status_Condensed; \
	VARIABLE func15_AI_SIMULATE_Value; \
	VARIABLE func15_AI_SIMULATE_Enabled; \
	VARIABLE func15_AI_SIMULATE_Status_Quality; \
	VARIABLE func15_AI_SIMULATE_Status_Limit; \
	MENU func15_AI_SIMULATE_page; \
	COMMAND func15_AI_SIMULATE_read; \
	COMMAND func15_AI_SIMULATE_write; \
	COLLECTION func15_AI_VIEW_1; \
	MENU func15_AI_VIEW_1_page; \
	MENU func15_AI_Simple_Dialog_Mandatory_B; \
	UNIT func15_AI_OUT_SCALE_unit_1; \
	MENU func15_AI_Simulation; \
	MENU func15_AI_Simulation_input; \
	MENU func15_AI_Simulation_input_group; \
	MENU func15_AI_Simulation_output; \
	MENU func15_AI_Simulation_output_group; \
	MENU func15_AI_Display_mandatory_B; \
	CHART func15_AI_Display_BarVal_out_mandatory_B; \
	SOURCE func15_AI_Display_BarVal_out_source_mandatory_B; \
	AXIS func15_AI_Display_BarVal_out_axis_mandatory_B; \
	MENU func15_AI_Display_out_mandatory_B; \
	MENU func15_AI_Display_in_mandatory_B; \
	MENU func15_AI_Tab_s_mandatory_B; \
	MENU func15_AI_Tab_s_pv_range_mandatory_B; \
	MENU func15_AI_Tab_s_outscale_mandatory_B; \
	MENU func15_AI_Tab_s_limits_mandatory_B; \
	MENU func15_AI_Tab_s_interface_mandatory_B; \
	MENU func15_AI_Tab_m_mandatory_B; \
	MENU func15_AI_Tab_m_pv_range_mandatory_B; \
	MENU func15_AI_Tab_m_outscale_mandatory_B; \
	MENU func15_AI_Tab_m_limits_mandatory_B

#define USE_FUNC15_AI_OPTIONAL_BOTH \
	VARIABLE func15_AI_FSAFE_TYPE; \
	MENU func15_AI_FSAFE_TYPE_page; \
	COMMAND func15_AI_FSAFE_TYPE_read; \
	COMMAND func15_AI_FSAFE_TYPE_write; \
	VARIABLE func15_AI_FSAFE_VALUE; \
	MENU func15_AI_FSAFE_VALUE_page; \
	COMMAND func15_AI_FSAFE_VALUE_read; \
	COMMAND func15_AI_FSAFE_VALUE_write; \
	COLLECTION func15_AI_HI_HI_ALM; \
	VARIABLE func15_AI_HI_HI_ALM_Unacknowledged; \
	VARIABLE func15_AI_HI_HI_ALM_Alarm_State; \
	VARIABLE func15_AI_HI_HI_ALM_Time_Stamp; \
	VARIABLE func15_AI_HI_HI_ALM_Subcode; \
	VARIABLE func15_AI_HI_HI_ALM_Value; \
	MENU func15_AI_HI_HI_ALM_page; \
	COMMAND func15_AI_HI_HI_ALM_read; \
	COLLECTION func15_AI_HI_ALM; \
	VARIABLE func15_AI_HI_ALM_Unacknowledged; \
	VARIABLE func15_AI_HI_ALM_Alarm_State; \
	VARIABLE func15_AI_HI_ALM_Time_Stamp; \
	VARIABLE func15_AI_HI_ALM_Subcode; \
	VARIABLE func15_AI_HI_ALM_Value; \
	MENU func15_AI_HI_ALM_page; \
	COMMAND func15_AI_HI_ALM_read; \
	COLLECTION func15_AI_LO_ALM; \
	VARIABLE func15_AI_LO_ALM_Unacknowledged; \
	VARIABLE func15_AI_LO_ALM_Alarm_State; \
	VARIABLE func15_AI_LO_ALM_Time_Stamp; \
	VARIABLE func15_AI_LO_ALM_Subcode; \
	VARIABLE func15_AI_LO_ALM_Value; \
	MENU func15_AI_LO_ALM_page; \
	COMMAND func15_AI_LO_ALM_read; \
	COLLECTION func15_AI_LO_LO_ALM; \
	VARIABLE func15_AI_LO_LO_ALM_Unacknowledged; \
	VARIABLE func15_AI_LO_LO_ALM_Alarm_State; \
	VARIABLE func15_AI_LO_LO_ALM_Time_Stamp; \
	VARIABLE func15_AI_LO_LO_ALM_Subcode; \
	VARIABLE func15_AI_LO_LO_ALM_Value; \
	MENU func15_AI_LO_LO_ALM_page; \
	COMMAND func15_AI_LO_LO_ALM_read; \
	VARIABLE func15_AI_OUT_UNIT_TEXT; \
	MENU func15_AI_OUT_UNIT_TEXT_page; \
	COMMAND func15_AI_OUT_UNIT_TEXT_read; \
	COMMAND func15_AI_OUT_UNIT_TEXT_write; \
	COLLECTION func15_AI_VIEW_2; \
	MENU func15_AI_VIEW_2_page; \
	COLLECTION func15_AI_VIEW_3; \
	MENU func15_AI_VIEW_3_page

#define USE_FUNC15_AI_OPTIONAL_A \
	USE_FUNC15_AI_OPTIONAL_BOTH; \
	COLLECTION func15_AI_OUT_SCALE; \
	VARIABLE func15_AI_OUT_SCALE_Upper_Value; \
	VARIABLE func15_AI_OUT_SCALE_Lower_Value; \
	VARIABLE func15_AI_OUT_SCALE_Units_Index; \
	VARIABLE func15_AI_OUT_SCALE_Decimal_Point; \
	MENU func15_AI_OUT_SCALE_page; \
	COMMAND func15_AI_OUT_SCALE_read; \
	COMMAND func15_AI_OUT_SCALE_write; \
	VARIABLE func15_AI_LIN_TYPE; \
	MENU func15_AI_LIN_TYPE_page; \
	COMMAND func15_AI_LIN_TYPE_read; \
	COMMAND func15_AI_LIN_TYPE_write; \
	VARIABLE func15_AI_CHANNEL; \
	MENU func15_AI_CHANNEL_page; \
	COMMAND func15_AI_CHANNEL_read; \
	COMMAND func15_AI_CHANNEL_write; \
	COLLECTION func15_AI_SIMULATE; \
	VARIABLE func15_AI_SIMULATE_Status_Condensed; \
	VARIABLE func15_AI_SIMULATE_Value; \
	VARIABLE func15_AI_SIMULATE_Enabled; \
	VARIABLE func15_AI_SIMULATE_Status_Quality; \
	VARIABLE func15_AI_SIMULATE_Status_Limit; \
	MENU func15_AI_SIMULATE_page; \
	COMMAND func15_AI_SIMULATE_read; \
	COMMAND func15_AI_SIMULATE_write; \
	COLLECTION func15_AI_VIEW_1; \
	MENU func15_AI_VIEW_1_page; \
	MENU func15_AI_Simple_Dialog_Optional_A; \
	UNIT func15_AI_OUT_SCALE_unit_1; \
	UNIT func15_AI_OUT_SCALE_unit_2

#define USE_FUNC15_AI_OPTIONAL_B \
	USE_FUNC15_AI_OPTIONAL_BOTH; \
	MENU func15_AI_Simple_Dialog_Optional_B; \
	UNIT func15_AI_OUT_SCALE_unit_2

#else /* CPP_CANT_CONCAT */

#define USE_FUNC15_AI_MANDATORY_A USE_FUNC_AI_MANDATORY_A(func15_AI_)
#define USE_FUNC15_AI_MANDATORY_B USE_FUNC_AI_MANDATORY_B(func15_AI_)
#define USE_FUNC15_AI_OPTIONAL_A  USE_FUNC_AI_OPTIONAL_A(func15_AI_)
#define USE_FUNC15_AI_OPTIONAL_B  USE_FUNC_AI_OPTIONAL_B(func15_AI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC1_TOT_MANDATORY_BOTH \
	BLOCK func1_TOT_block; \
	COLLECTION func1_TOT_BLOCK_OBJECT; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func1_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func1_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func1_TOT_BLOCK_OBJECT_page; \
	COMMAND func1_TOT_BLOCK_OBJECT_read; \
	VARIABLE func1_TOT_ST_REV; \
	MENU func1_TOT_ST_REV_page; \
	COMMAND func1_TOT_ST_REV_read; \
	VARIABLE func1_TOT_TAG_DESC; \
	MENU func1_TOT_TAG_DESC_page; \
	COMMAND func1_TOT_TAG_DESC_read; \
	COMMAND func1_TOT_TAG_DESC_write; \
	VARIABLE func1_TOT_STRATEGY; \
	MENU func1_TOT_STRATEGY_page; \
	COMMAND func1_TOT_STRATEGY_read; \
	COMMAND func1_TOT_STRATEGY_write; \
	VARIABLE func1_TOT_ALERT_KEY; \
	MENU func1_TOT_ALERT_KEY_page; \
	COMMAND func1_TOT_ALERT_KEY_read; \
	COMMAND func1_TOT_ALERT_KEY_write; \
	VARIABLE func1_TOT_TARGET_MODE; \
	MENU func1_TOT_TARGET_MODE_page; \
	COMMAND func1_TOT_TARGET_MODE_read; \
	COMMAND func1_TOT_TARGET_MODE_write; \
	COLLECTION func1_TOT_MODE_BLK; \
	VARIABLE func1_TOT_MODE_BLK_Actual; \
	VARIABLE func1_TOT_MODE_BLK_Permitted; \
	VARIABLE func1_TOT_MODE_BLK_Normal; \
	MENU func1_TOT_MODE_BLK_page; \
	COMMAND func1_TOT_MODE_BLK_read; \
	COLLECTION func1_TOT_ALARM_SUM; \
	VARIABLE func1_TOT_ALARM_SUM_Current; \
	VARIABLE func1_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func1_TOT_ALARM_SUM_Unreported; \
	VARIABLE func1_TOT_ALARM_SUM_Disabled; \
	MENU func1_TOT_ALARM_SUM_page; \
	COMMAND func1_TOT_ALARM_SUM_read; \
	COLLECTION func1_TOT_BATCH; \
	VARIABLE func1_TOT_BATCH_Batch_ID; \
	VARIABLE func1_TOT_BATCH_Rup; \
	VARIABLE func1_TOT_BATCH_Operation; \
	VARIABLE func1_TOT_BATCH_Phase; \
	MENU func1_TOT_BATCH_page; \
	COMMAND func1_TOT_BATCH_read; \
	COMMAND func1_TOT_BATCH_write; \
	COLLECTION func1_TOT_TOTAL; \
	VARIABLE func1_TOT_TOTAL_Value; \
	VARIABLE func1_TOT_TOTAL_Status_Condensed; \
	VARIABLE func1_TOT_TOTAL_Status_Quality; \
	VARIABLE func1_TOT_TOTAL_Status_Limit; \
	MENU func1_TOT_TOTAL_page; \
	COMMAND func1_TOT_TOTAL_read; \
	COMMAND func1_TOT_TOTAL_write; \
	VARIABLE func1_TOT_UNIT_TOT; \
	MENU func1_TOT_UNIT_TOT_page; \
	COMMAND func1_TOT_UNIT_TOT_read; \
	COMMAND func1_TOT_UNIT_TOT_write; \
	VARIABLE func1_TOT_ALARM_HYS; \
	MENU func1_TOT_ALARM_HYS_page; \
	COMMAND func1_TOT_ALARM_HYS_read; \
	COMMAND func1_TOT_ALARM_HYS_write; \
	VARIABLE func1_TOT_HI_HI_LIM; \
	MENU func1_TOT_HI_HI_LIM_page; \
	COMMAND func1_TOT_HI_HI_LIM_read; \
	COMMAND func1_TOT_HI_HI_LIM_write; \
	VARIABLE func1_TOT_HI_LIM; \
	MENU func1_TOT_HI_LIM_page; \
	COMMAND func1_TOT_HI_LIM_read; \
	COMMAND func1_TOT_HI_LIM_write; \
	VARIABLE func1_TOT_LO_LIM; \
	MENU func1_TOT_LO_LIM_page; \
	COMMAND func1_TOT_LO_LIM_read; \
	COMMAND func1_TOT_LO_LIM_write; \
	VARIABLE func1_TOT_LO_LO_LIM; \
	MENU func1_TOT_LO_LO_LIM_page; \
	COMMAND func1_TOT_LO_LO_LIM_read; \
	COMMAND func1_TOT_LO_LO_LIM_write; \
	UNIT func1_TOT_unit_1; \
	MENU func1_TOT_Display; \
	MENU func1_TOT_Display_out; \
	MENU func1_TOT_Tab_s_tot_limits

#define USE_FUNC1_TOT_MANDATORY_A \
	USE_FUNC1_TOT_MANDATORY_BOTH; \
	MENU func1_TOT_Simple_Dialog_Mandatory_A; \
	MENU func1_TOT_Tab_s_mandatory_A; \
	MENU func1_TOT_Tab_m_mandatory_A

#define USE_FUNC1_TOT_MANDATORY_B \
	USE_FUNC1_TOT_MANDATORY_BOTH; \
	VARIABLE func1_TOT_CHANNEL; \
	MENU func1_TOT_CHANNEL_page; \
	COMMAND func1_TOT_CHANNEL_read; \
	COMMAND func1_TOT_CHANNEL_write; \
	VARIABLE func1_TOT_SET_TOT; \
	MENU func1_TOT_SET_TOT_page; \
	COMMAND func1_TOT_SET_TOT_read; \
	COMMAND func1_TOT_SET_TOT_write; \
	VARIABLE func1_TOT_MODE_TOT; \
	MENU func1_TOT_MODE_TOT_page; \
	COMMAND func1_TOT_MODE_TOT_read; \
	COMMAND func1_TOT_MODE_TOT_write; \
	VARIABLE func1_TOT_FAIL_TOT; \
	MENU func1_TOT_FAIL_TOT_page; \
	COMMAND func1_TOT_FAIL_TOT_read; \
	COMMAND func1_TOT_FAIL_TOT_write; \
	VARIABLE func1_TOT_PRESET_TOT; \
	MENU func1_TOT_PRESET_TOT_page; \
	COMMAND func1_TOT_PRESET_TOT_read; \
	COMMAND func1_TOT_PRESET_TOT_write; \
	COLLECTION func1_TOT_VIEW_1; \
	MENU func1_TOT_VIEW_1_page; \
	MENU func1_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func1_TOT_unit_2; \
	MENU func1_TOT_Reset; \
	MENU func1_TOT_Reset_page; \
	METHOD func1_TOT_Reset_totalizer; \
	METHOD func1_TOT_Preset_totalizer; \
	MENU func1_TOT_Tab_s_mandatory_B; \
	MENU func1_TOT_Tab_m_mandatory_B

#define USE_FUNC1_TOT_OPTIONAL_BOTH \
	COLLECTION func1_TOT_HI_HI_ALM; \
	VARIABLE func1_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func1_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func1_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func1_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func1_TOT_HI_HI_ALM_Value; \
	MENU func1_TOT_HI_HI_ALM_page; \
	COMMAND func1_TOT_HI_HI_ALM_read; \
	COLLECTION func1_TOT_HI_ALM; \
	VARIABLE func1_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func1_TOT_HI_ALM_Alarm_State; \
	VARIABLE func1_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func1_TOT_HI_ALM_Subcode; \
	VARIABLE func1_TOT_HI_ALM_Value; \
	MENU func1_TOT_HI_ALM_page; \
	COMMAND func1_TOT_HI_ALM_read; \
	COLLECTION func1_TOT_LO_ALM; \
	VARIABLE func1_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func1_TOT_LO_ALM_Alarm_State; \
	VARIABLE func1_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func1_TOT_LO_ALM_Subcode; \
	VARIABLE func1_TOT_LO_ALM_Value; \
	MENU func1_TOT_LO_ALM_page; \
	COMMAND func1_TOT_LO_ALM_read; \
	COLLECTION func1_TOT_LO_LO_ALM; \
	VARIABLE func1_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func1_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func1_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func1_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func1_TOT_LO_LO_ALM_Value; \
	MENU func1_TOT_LO_LO_ALM_page; \
	COMMAND func1_TOT_LO_LO_ALM_read; \
	COLLECTION func1_TOT_VIEW_2; \
	MENU func1_TOT_VIEW_2_page; \
	COLLECTION func1_TOT_VIEW_3; \
	MENU func1_TOT_VIEW_3_page

#define USE_FUNC1_TOT_OPTIONAL_A \
	USE_FUNC1_TOT_OPTIONAL_BOTH; \
	VARIABLE func1_TOT_CHANNEL; \
	MENU func1_TOT_CHANNEL_page; \
	COMMAND func1_TOT_CHANNEL_read; \
	COMMAND func1_TOT_CHANNEL_write; \
	VARIABLE func1_TOT_SET_TOT; \
	MENU func1_TOT_SET_TOT_page; \
	COMMAND func1_TOT_SET_TOT_read; \
	COMMAND func1_TOT_SET_TOT_write; \
	VARIABLE func1_TOT_MODE_TOT; \
	MENU func1_TOT_MODE_TOT_page; \
	COMMAND func1_TOT_MODE_TOT_read; \
	COMMAND func1_TOT_MODE_TOT_write; \
	VARIABLE func1_TOT_FAIL_TOT; \
	MENU func1_TOT_FAIL_TOT_page; \
	COMMAND func1_TOT_FAIL_TOT_read; \
	COMMAND func1_TOT_FAIL_TOT_write; \
	VARIABLE func1_TOT_PRESET_TOT; \
	MENU func1_TOT_PRESET_TOT_page; \
	COMMAND func1_TOT_PRESET_TOT_read; \
	COMMAND func1_TOT_PRESET_TOT_write; \
	COLLECTION func1_TOT_VIEW_1; \
	MENU func1_TOT_VIEW_1_page; \
	MENU func1_TOT_Simple_Dialog_Optional_A

#define USE_FUNC1_TOT_OPTIONAL_B \
	USE_FUNC1_TOT_OPTIONAL_BOTH; \
	MENU func1_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC_TOT_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## BATCH; \
	VARIABLE prefix ## BATCH_Batch_ID; \
	VARIABLE prefix ## BATCH_Rup; \
	VARIABLE prefix ## BATCH_Operation; \
	VARIABLE prefix ## BATCH_Phase; \
	MENU prefix ## BATCH_page; \
	COMMAND prefix ## BATCH_read; \
	COMMAND prefix ## BATCH_write; \
	COLLECTION prefix ## TOTAL; \
	VARIABLE prefix ## TOTAL_Value; \
	VARIABLE prefix ## TOTAL_Status_Condensed; \
	VARIABLE prefix ## TOTAL_Status_Quality; \
	VARIABLE prefix ## TOTAL_Status_Limit; \
	MENU prefix ## TOTAL_page; \
	COMMAND prefix ## TOTAL_read; \
	COMMAND prefix ## TOTAL_write; \
	VARIABLE prefix ## UNIT_TOT; \
	MENU prefix ## UNIT_TOT_page; \
	COMMAND prefix ## UNIT_TOT_read; \
	COMMAND prefix ## UNIT_TOT_write; \
	VARIABLE prefix ## ALARM_HYS; \
	MENU prefix ## ALARM_HYS_page; \
	COMMAND prefix ## ALARM_HYS_read; \
	COMMAND prefix ## ALARM_HYS_write; \
	VARIABLE prefix ## HI_HI_LIM; \
	MENU prefix ## HI_HI_LIM_page; \
	COMMAND prefix ## HI_HI_LIM_read; \
	COMMAND prefix ## HI_HI_LIM_write; \
	VARIABLE prefix ## HI_LIM; \
	MENU prefix ## HI_LIM_page; \
	COMMAND prefix ## HI_LIM_read; \
	COMMAND prefix ## HI_LIM_write; \
	VARIABLE prefix ## LO_LIM; \
	MENU prefix ## LO_LIM_page; \
	COMMAND prefix ## LO_LIM_read; \
	COMMAND prefix ## LO_LIM_write; \
	VARIABLE prefix ## LO_LO_LIM; \
	MENU prefix ## LO_LO_LIM_page; \
	COMMAND prefix ## LO_LO_LIM_read; \
	COMMAND prefix ## LO_LO_LIM_write; \
	UNIT prefix ## unit_1; \
	MENU prefix ## Display; \
	MENU prefix ## Display_out; \
	MENU prefix ## Tab_s_tot_limits

#define USE_FUNC_TOT_MANDATORY_A(prefix) \
	USE_FUNC_TOT_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A; \
	MENU prefix ## Tab_s_mandatory_A; \
	MENU prefix ## Tab_m_mandatory_A

#define USE_FUNC_TOT_MANDATORY_B(prefix) \
	USE_FUNC_TOT_MANDATORY_BOTH(prefix); \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	VARIABLE prefix ## SET_TOT; \
	MENU prefix ## SET_TOT_page; \
	COMMAND prefix ## SET_TOT_read; \
	COMMAND prefix ## SET_TOT_write; \
	VARIABLE prefix ## MODE_TOT; \
	MENU prefix ## MODE_TOT_page; \
	COMMAND prefix ## MODE_TOT_read; \
	COMMAND prefix ## MODE_TOT_write; \
	VARIABLE prefix ## FAIL_TOT; \
	MENU prefix ## FAIL_TOT_page; \
	COMMAND prefix ## FAIL_TOT_read; \
	COMMAND prefix ## FAIL_TOT_write; \
	VARIABLE prefix ## PRESET_TOT; \
	MENU prefix ## PRESET_TOT_page; \
	COMMAND prefix ## PRESET_TOT_read; \
	COMMAND prefix ## PRESET_TOT_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B; \
	UNIT prefix ## unit_2; \
	MENU prefix ## Reset; \
	MENU prefix ## Reset_page; \
	METHOD prefix ## Reset_totalizer; \
	METHOD prefix ## Preset_totalizer; \
	MENU prefix ## Tab_s_mandatory_B; \
	MENU prefix ## Tab_m_mandatory_B

#define USE_FUNC_TOT_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## HI_HI_ALM; \
	VARIABLE prefix ## HI_HI_ALM_Unacknowledged; \
	VARIABLE prefix ## HI_HI_ALM_Alarm_State; \
	VARIABLE prefix ## HI_HI_ALM_Time_Stamp; \
	VARIABLE prefix ## HI_HI_ALM_Subcode; \
	VARIABLE prefix ## HI_HI_ALM_Value; \
	MENU prefix ## HI_HI_ALM_page; \
	COMMAND prefix ## HI_HI_ALM_read; \
	COLLECTION prefix ## HI_ALM; \
	VARIABLE prefix ## HI_ALM_Unacknowledged; \
	VARIABLE prefix ## HI_ALM_Alarm_State; \
	VARIABLE prefix ## HI_ALM_Time_Stamp; \
	VARIABLE prefix ## HI_ALM_Subcode; \
	VARIABLE prefix ## HI_ALM_Value; \
	MENU prefix ## HI_ALM_page; \
	COMMAND prefix ## HI_ALM_read; \
	COLLECTION prefix ## LO_ALM; \
	VARIABLE prefix ## LO_ALM_Unacknowledged; \
	VARIABLE prefix ## LO_ALM_Alarm_State; \
	VARIABLE prefix ## LO_ALM_Time_Stamp; \
	VARIABLE prefix ## LO_ALM_Subcode; \
	VARIABLE prefix ## LO_ALM_Value; \
	MENU prefix ## LO_ALM_page; \
	COMMAND prefix ## LO_ALM_read; \
	COLLECTION prefix ## LO_LO_ALM; \
	VARIABLE prefix ## LO_LO_ALM_Unacknowledged; \
	VARIABLE prefix ## LO_LO_ALM_Alarm_State; \
	VARIABLE prefix ## LO_LO_ALM_Time_Stamp; \
	VARIABLE prefix ## LO_LO_ALM_Subcode; \
	VARIABLE prefix ## LO_LO_ALM_Value; \
	MENU prefix ## LO_LO_ALM_page; \
	COMMAND prefix ## LO_LO_ALM_read; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_FUNC_TOT_OPTIONAL_A(prefix) \
	USE_FUNC_TOT_OPTIONAL_BOTH(prefix); \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	VARIABLE prefix ## SET_TOT; \
	MENU prefix ## SET_TOT_page; \
	COMMAND prefix ## SET_TOT_read; \
	COMMAND prefix ## SET_TOT_write; \
	VARIABLE prefix ## MODE_TOT; \
	MENU prefix ## MODE_TOT_page; \
	COMMAND prefix ## MODE_TOT_read; \
	COMMAND prefix ## MODE_TOT_write; \
	VARIABLE prefix ## FAIL_TOT; \
	MENU prefix ## FAIL_TOT_page; \
	COMMAND prefix ## FAIL_TOT_read; \
	COMMAND prefix ## FAIL_TOT_write; \
	VARIABLE prefix ## PRESET_TOT; \
	MENU prefix ## PRESET_TOT_page; \
	COMMAND prefix ## PRESET_TOT_read; \
	COMMAND prefix ## PRESET_TOT_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_FUNC_TOT_OPTIONAL_B(prefix) \
	USE_FUNC_TOT_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_FUNC1_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func1_TOT_)
#define USE_FUNC1_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func1_TOT_)
#define USE_FUNC1_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func1_TOT_)
#define USE_FUNC1_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func1_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC2_TOT_MANDATORY_BOTH \
	BLOCK func2_TOT_block; \
	COLLECTION func2_TOT_BLOCK_OBJECT; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func2_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func2_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func2_TOT_BLOCK_OBJECT_page; \
	COMMAND func2_TOT_BLOCK_OBJECT_read; \
	VARIABLE func2_TOT_ST_REV; \
	MENU func2_TOT_ST_REV_page; \
	COMMAND func2_TOT_ST_REV_read; \
	VARIABLE func2_TOT_TAG_DESC; \
	MENU func2_TOT_TAG_DESC_page; \
	COMMAND func2_TOT_TAG_DESC_read; \
	COMMAND func2_TOT_TAG_DESC_write; \
	VARIABLE func2_TOT_STRATEGY; \
	MENU func2_TOT_STRATEGY_page; \
	COMMAND func2_TOT_STRATEGY_read; \
	COMMAND func2_TOT_STRATEGY_write; \
	VARIABLE func2_TOT_ALERT_KEY; \
	MENU func2_TOT_ALERT_KEY_page; \
	COMMAND func2_TOT_ALERT_KEY_read; \
	COMMAND func2_TOT_ALERT_KEY_write; \
	VARIABLE func2_TOT_TARGET_MODE; \
	MENU func2_TOT_TARGET_MODE_page; \
	COMMAND func2_TOT_TARGET_MODE_read; \
	COMMAND func2_TOT_TARGET_MODE_write; \
	COLLECTION func2_TOT_MODE_BLK; \
	VARIABLE func2_TOT_MODE_BLK_Actual; \
	VARIABLE func2_TOT_MODE_BLK_Permitted; \
	VARIABLE func2_TOT_MODE_BLK_Normal; \
	MENU func2_TOT_MODE_BLK_page; \
	COMMAND func2_TOT_MODE_BLK_read; \
	COLLECTION func2_TOT_ALARM_SUM; \
	VARIABLE func2_TOT_ALARM_SUM_Current; \
	VARIABLE func2_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func2_TOT_ALARM_SUM_Unreported; \
	VARIABLE func2_TOT_ALARM_SUM_Disabled; \
	MENU func2_TOT_ALARM_SUM_page; \
	COMMAND func2_TOT_ALARM_SUM_read; \
	COLLECTION func2_TOT_BATCH; \
	VARIABLE func2_TOT_BATCH_Batch_ID; \
	VARIABLE func2_TOT_BATCH_Rup; \
	VARIABLE func2_TOT_BATCH_Operation; \
	VARIABLE func2_TOT_BATCH_Phase; \
	MENU func2_TOT_BATCH_page; \
	COMMAND func2_TOT_BATCH_read; \
	COMMAND func2_TOT_BATCH_write; \
	COLLECTION func2_TOT_TOTAL; \
	VARIABLE func2_TOT_TOTAL_Value; \
	VARIABLE func2_TOT_TOTAL_Status_Condensed; \
	VARIABLE func2_TOT_TOTAL_Status_Quality; \
	VARIABLE func2_TOT_TOTAL_Status_Limit; \
	MENU func2_TOT_TOTAL_page; \
	COMMAND func2_TOT_TOTAL_read; \
	COMMAND func2_TOT_TOTAL_write; \
	VARIABLE func2_TOT_UNIT_TOT; \
	MENU func2_TOT_UNIT_TOT_page; \
	COMMAND func2_TOT_UNIT_TOT_read; \
	COMMAND func2_TOT_UNIT_TOT_write; \
	VARIABLE func2_TOT_ALARM_HYS; \
	MENU func2_TOT_ALARM_HYS_page; \
	COMMAND func2_TOT_ALARM_HYS_read; \
	COMMAND func2_TOT_ALARM_HYS_write; \
	VARIABLE func2_TOT_HI_HI_LIM; \
	MENU func2_TOT_HI_HI_LIM_page; \
	COMMAND func2_TOT_HI_HI_LIM_read; \
	COMMAND func2_TOT_HI_HI_LIM_write; \
	VARIABLE func2_TOT_HI_LIM; \
	MENU func2_TOT_HI_LIM_page; \
	COMMAND func2_TOT_HI_LIM_read; \
	COMMAND func2_TOT_HI_LIM_write; \
	VARIABLE func2_TOT_LO_LIM; \
	MENU func2_TOT_LO_LIM_page; \
	COMMAND func2_TOT_LO_LIM_read; \
	COMMAND func2_TOT_LO_LIM_write; \
	VARIABLE func2_TOT_LO_LO_LIM; \
	MENU func2_TOT_LO_LO_LIM_page; \
	COMMAND func2_TOT_LO_LO_LIM_read; \
	COMMAND func2_TOT_LO_LO_LIM_write; \
	UNIT func2_TOT_unit_1; \
	MENU func2_TOT_Display; \
	MENU func2_TOT_Display_out; \
	MENU func2_TOT_Tab_s_tot_limits

#define USE_FUNC2_TOT_MANDATORY_A \
	USE_FUNC2_TOT_MANDATORY_BOTH; \
	MENU func2_TOT_Simple_Dialog_Mandatory_A; \
	MENU func2_TOT_Tab_s_mandatory_A; \
	MENU func2_TOT_Tab_m_mandatory_A

#define USE_FUNC2_TOT_MANDATORY_B \
	USE_FUNC2_TOT_MANDATORY_BOTH; \
	VARIABLE func2_TOT_CHANNEL; \
	MENU func2_TOT_CHANNEL_page; \
	COMMAND func2_TOT_CHANNEL_read; \
	COMMAND func2_TOT_CHANNEL_write; \
	VARIABLE func2_TOT_SET_TOT; \
	MENU func2_TOT_SET_TOT_page; \
	COMMAND func2_TOT_SET_TOT_read; \
	COMMAND func2_TOT_SET_TOT_write; \
	VARIABLE func2_TOT_MODE_TOT; \
	MENU func2_TOT_MODE_TOT_page; \
	COMMAND func2_TOT_MODE_TOT_read; \
	COMMAND func2_TOT_MODE_TOT_write; \
	VARIABLE func2_TOT_FAIL_TOT; \
	MENU func2_TOT_FAIL_TOT_page; \
	COMMAND func2_TOT_FAIL_TOT_read; \
	COMMAND func2_TOT_FAIL_TOT_write; \
	VARIABLE func2_TOT_PRESET_TOT; \
	MENU func2_TOT_PRESET_TOT_page; \
	COMMAND func2_TOT_PRESET_TOT_read; \
	COMMAND func2_TOT_PRESET_TOT_write; \
	COLLECTION func2_TOT_VIEW_1; \
	MENU func2_TOT_VIEW_1_page; \
	MENU func2_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func2_TOT_unit_2; \
	MENU func2_TOT_Reset; \
	MENU func2_TOT_Reset_page; \
	METHOD func2_TOT_Reset_totalizer; \
	METHOD func2_TOT_Preset_totalizer; \
	MENU func2_TOT_Tab_s_mandatory_B; \
	MENU func2_TOT_Tab_m_mandatory_B

#define USE_FUNC2_TOT_OPTIONAL_BOTH \
	COLLECTION func2_TOT_HI_HI_ALM; \
	VARIABLE func2_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func2_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func2_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func2_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func2_TOT_HI_HI_ALM_Value; \
	MENU func2_TOT_HI_HI_ALM_page; \
	COMMAND func2_TOT_HI_HI_ALM_read; \
	COLLECTION func2_TOT_HI_ALM; \
	VARIABLE func2_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func2_TOT_HI_ALM_Alarm_State; \
	VARIABLE func2_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func2_TOT_HI_ALM_Subcode; \
	VARIABLE func2_TOT_HI_ALM_Value; \
	MENU func2_TOT_HI_ALM_page; \
	COMMAND func2_TOT_HI_ALM_read; \
	COLLECTION func2_TOT_LO_ALM; \
	VARIABLE func2_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func2_TOT_LO_ALM_Alarm_State; \
	VARIABLE func2_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func2_TOT_LO_ALM_Subcode; \
	VARIABLE func2_TOT_LO_ALM_Value; \
	MENU func2_TOT_LO_ALM_page; \
	COMMAND func2_TOT_LO_ALM_read; \
	COLLECTION func2_TOT_LO_LO_ALM; \
	VARIABLE func2_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func2_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func2_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func2_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func2_TOT_LO_LO_ALM_Value; \
	MENU func2_TOT_LO_LO_ALM_page; \
	COMMAND func2_TOT_LO_LO_ALM_read; \
	COLLECTION func2_TOT_VIEW_2; \
	MENU func2_TOT_VIEW_2_page; \
	COLLECTION func2_TOT_VIEW_3; \
	MENU func2_TOT_VIEW_3_page

#define USE_FUNC2_TOT_OPTIONAL_A \
	USE_FUNC2_TOT_OPTIONAL_BOTH; \
	VARIABLE func2_TOT_CHANNEL; \
	MENU func2_TOT_CHANNEL_page; \
	COMMAND func2_TOT_CHANNEL_read; \
	COMMAND func2_TOT_CHANNEL_write; \
	VARIABLE func2_TOT_SET_TOT; \
	MENU func2_TOT_SET_TOT_page; \
	COMMAND func2_TOT_SET_TOT_read; \
	COMMAND func2_TOT_SET_TOT_write; \
	VARIABLE func2_TOT_MODE_TOT; \
	MENU func2_TOT_MODE_TOT_page; \
	COMMAND func2_TOT_MODE_TOT_read; \
	COMMAND func2_TOT_MODE_TOT_write; \
	VARIABLE func2_TOT_FAIL_TOT; \
	MENU func2_TOT_FAIL_TOT_page; \
	COMMAND func2_TOT_FAIL_TOT_read; \
	COMMAND func2_TOT_FAIL_TOT_write; \
	VARIABLE func2_TOT_PRESET_TOT; \
	MENU func2_TOT_PRESET_TOT_page; \
	COMMAND func2_TOT_PRESET_TOT_read; \
	COMMAND func2_TOT_PRESET_TOT_write; \
	COLLECTION func2_TOT_VIEW_1; \
	MENU func2_TOT_VIEW_1_page; \
	MENU func2_TOT_Simple_Dialog_Optional_A

#define USE_FUNC2_TOT_OPTIONAL_B \
	USE_FUNC2_TOT_OPTIONAL_BOTH; \
	MENU func2_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC2_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func2_TOT_)
#define USE_FUNC2_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func2_TOT_)
#define USE_FUNC2_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func2_TOT_)
#define USE_FUNC2_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func2_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC3_TOT_MANDATORY_BOTH \
	BLOCK func3_TOT_block; \
	COLLECTION func3_TOT_BLOCK_OBJECT; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func3_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func3_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func3_TOT_BLOCK_OBJECT_page; \
	COMMAND func3_TOT_BLOCK_OBJECT_read; \
	VARIABLE func3_TOT_ST_REV; \
	MENU func3_TOT_ST_REV_page; \
	COMMAND func3_TOT_ST_REV_read; \
	VARIABLE func3_TOT_TAG_DESC; \
	MENU func3_TOT_TAG_DESC_page; \
	COMMAND func3_TOT_TAG_DESC_read; \
	COMMAND func3_TOT_TAG_DESC_write; \
	VARIABLE func3_TOT_STRATEGY; \
	MENU func3_TOT_STRATEGY_page; \
	COMMAND func3_TOT_STRATEGY_read; \
	COMMAND func3_TOT_STRATEGY_write; \
	VARIABLE func3_TOT_ALERT_KEY; \
	MENU func3_TOT_ALERT_KEY_page; \
	COMMAND func3_TOT_ALERT_KEY_read; \
	COMMAND func3_TOT_ALERT_KEY_write; \
	VARIABLE func3_TOT_TARGET_MODE; \
	MENU func3_TOT_TARGET_MODE_page; \
	COMMAND func3_TOT_TARGET_MODE_read; \
	COMMAND func3_TOT_TARGET_MODE_write; \
	COLLECTION func3_TOT_MODE_BLK; \
	VARIABLE func3_TOT_MODE_BLK_Actual; \
	VARIABLE func3_TOT_MODE_BLK_Permitted; \
	VARIABLE func3_TOT_MODE_BLK_Normal; \
	MENU func3_TOT_MODE_BLK_page; \
	COMMAND func3_TOT_MODE_BLK_read; \
	COLLECTION func3_TOT_ALARM_SUM; \
	VARIABLE func3_TOT_ALARM_SUM_Current; \
	VARIABLE func3_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func3_TOT_ALARM_SUM_Unreported; \
	VARIABLE func3_TOT_ALARM_SUM_Disabled; \
	MENU func3_TOT_ALARM_SUM_page; \
	COMMAND func3_TOT_ALARM_SUM_read; \
	COLLECTION func3_TOT_BATCH; \
	VARIABLE func3_TOT_BATCH_Batch_ID; \
	VARIABLE func3_TOT_BATCH_Rup; \
	VARIABLE func3_TOT_BATCH_Operation; \
	VARIABLE func3_TOT_BATCH_Phase; \
	MENU func3_TOT_BATCH_page; \
	COMMAND func3_TOT_BATCH_read; \
	COMMAND func3_TOT_BATCH_write; \
	COLLECTION func3_TOT_TOTAL; \
	VARIABLE func3_TOT_TOTAL_Value; \
	VARIABLE func3_TOT_TOTAL_Status_Condensed; \
	VARIABLE func3_TOT_TOTAL_Status_Quality; \
	VARIABLE func3_TOT_TOTAL_Status_Limit; \
	MENU func3_TOT_TOTAL_page; \
	COMMAND func3_TOT_TOTAL_read; \
	COMMAND func3_TOT_TOTAL_write; \
	VARIABLE func3_TOT_UNIT_TOT; \
	MENU func3_TOT_UNIT_TOT_page; \
	COMMAND func3_TOT_UNIT_TOT_read; \
	COMMAND func3_TOT_UNIT_TOT_write; \
	VARIABLE func3_TOT_ALARM_HYS; \
	MENU func3_TOT_ALARM_HYS_page; \
	COMMAND func3_TOT_ALARM_HYS_read; \
	COMMAND func3_TOT_ALARM_HYS_write; \
	VARIABLE func3_TOT_HI_HI_LIM; \
	MENU func3_TOT_HI_HI_LIM_page; \
	COMMAND func3_TOT_HI_HI_LIM_read; \
	COMMAND func3_TOT_HI_HI_LIM_write; \
	VARIABLE func3_TOT_HI_LIM; \
	MENU func3_TOT_HI_LIM_page; \
	COMMAND func3_TOT_HI_LIM_read; \
	COMMAND func3_TOT_HI_LIM_write; \
	VARIABLE func3_TOT_LO_LIM; \
	MENU func3_TOT_LO_LIM_page; \
	COMMAND func3_TOT_LO_LIM_read; \
	COMMAND func3_TOT_LO_LIM_write; \
	VARIABLE func3_TOT_LO_LO_LIM; \
	MENU func3_TOT_LO_LO_LIM_page; \
	COMMAND func3_TOT_LO_LO_LIM_read; \
	COMMAND func3_TOT_LO_LO_LIM_write; \
	UNIT func3_TOT_unit_1; \
	MENU func3_TOT_Display; \
	MENU func3_TOT_Display_out; \
	MENU func3_TOT_Tab_s_tot_limits

#define USE_FUNC3_TOT_MANDATORY_A \
	USE_FUNC3_TOT_MANDATORY_BOTH; \
	MENU func3_TOT_Simple_Dialog_Mandatory_A; \
	MENU func3_TOT_Tab_s_mandatory_A; \
	MENU func3_TOT_Tab_m_mandatory_A

#define USE_FUNC3_TOT_MANDATORY_B \
	USE_FUNC3_TOT_MANDATORY_BOTH; \
	VARIABLE func3_TOT_CHANNEL; \
	MENU func3_TOT_CHANNEL_page; \
	COMMAND func3_TOT_CHANNEL_read; \
	COMMAND func3_TOT_CHANNEL_write; \
	VARIABLE func3_TOT_SET_TOT; \
	MENU func3_TOT_SET_TOT_page; \
	COMMAND func3_TOT_SET_TOT_read; \
	COMMAND func3_TOT_SET_TOT_write; \
	VARIABLE func3_TOT_MODE_TOT; \
	MENU func3_TOT_MODE_TOT_page; \
	COMMAND func3_TOT_MODE_TOT_read; \
	COMMAND func3_TOT_MODE_TOT_write; \
	VARIABLE func3_TOT_FAIL_TOT; \
	MENU func3_TOT_FAIL_TOT_page; \
	COMMAND func3_TOT_FAIL_TOT_read; \
	COMMAND func3_TOT_FAIL_TOT_write; \
	VARIABLE func3_TOT_PRESET_TOT; \
	MENU func3_TOT_PRESET_TOT_page; \
	COMMAND func3_TOT_PRESET_TOT_read; \
	COMMAND func3_TOT_PRESET_TOT_write; \
	COLLECTION func3_TOT_VIEW_1; \
	MENU func3_TOT_VIEW_1_page; \
	MENU func3_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func3_TOT_unit_2; \
	MENU func3_TOT_Reset; \
	MENU func3_TOT_Reset_page; \
	METHOD func3_TOT_Reset_totalizer; \
	METHOD func3_TOT_Preset_totalizer; \
	MENU func3_TOT_Tab_s_mandatory_B; \
	MENU func3_TOT_Tab_m_mandatory_B

#define USE_FUNC3_TOT_OPTIONAL_BOTH \
	COLLECTION func3_TOT_HI_HI_ALM; \
	VARIABLE func3_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func3_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func3_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func3_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func3_TOT_HI_HI_ALM_Value; \
	MENU func3_TOT_HI_HI_ALM_page; \
	COMMAND func3_TOT_HI_HI_ALM_read; \
	COLLECTION func3_TOT_HI_ALM; \
	VARIABLE func3_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func3_TOT_HI_ALM_Alarm_State; \
	VARIABLE func3_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func3_TOT_HI_ALM_Subcode; \
	VARIABLE func3_TOT_HI_ALM_Value; \
	MENU func3_TOT_HI_ALM_page; \
	COMMAND func3_TOT_HI_ALM_read; \
	COLLECTION func3_TOT_LO_ALM; \
	VARIABLE func3_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func3_TOT_LO_ALM_Alarm_State; \
	VARIABLE func3_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func3_TOT_LO_ALM_Subcode; \
	VARIABLE func3_TOT_LO_ALM_Value; \
	MENU func3_TOT_LO_ALM_page; \
	COMMAND func3_TOT_LO_ALM_read; \
	COLLECTION func3_TOT_LO_LO_ALM; \
	VARIABLE func3_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func3_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func3_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func3_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func3_TOT_LO_LO_ALM_Value; \
	MENU func3_TOT_LO_LO_ALM_page; \
	COMMAND func3_TOT_LO_LO_ALM_read; \
	COLLECTION func3_TOT_VIEW_2; \
	MENU func3_TOT_VIEW_2_page; \
	COLLECTION func3_TOT_VIEW_3; \
	MENU func3_TOT_VIEW_3_page

#define USE_FUNC3_TOT_OPTIONAL_A \
	USE_FUNC3_TOT_OPTIONAL_BOTH; \
	VARIABLE func3_TOT_CHANNEL; \
	MENU func3_TOT_CHANNEL_page; \
	COMMAND func3_TOT_CHANNEL_read; \
	COMMAND func3_TOT_CHANNEL_write; \
	VARIABLE func3_TOT_SET_TOT; \
	MENU func3_TOT_SET_TOT_page; \
	COMMAND func3_TOT_SET_TOT_read; \
	COMMAND func3_TOT_SET_TOT_write; \
	VARIABLE func3_TOT_MODE_TOT; \
	MENU func3_TOT_MODE_TOT_page; \
	COMMAND func3_TOT_MODE_TOT_read; \
	COMMAND func3_TOT_MODE_TOT_write; \
	VARIABLE func3_TOT_FAIL_TOT; \
	MENU func3_TOT_FAIL_TOT_page; \
	COMMAND func3_TOT_FAIL_TOT_read; \
	COMMAND func3_TOT_FAIL_TOT_write; \
	VARIABLE func3_TOT_PRESET_TOT; \
	MENU func3_TOT_PRESET_TOT_page; \
	COMMAND func3_TOT_PRESET_TOT_read; \
	COMMAND func3_TOT_PRESET_TOT_write; \
	COLLECTION func3_TOT_VIEW_1; \
	MENU func3_TOT_VIEW_1_page; \
	MENU func3_TOT_Simple_Dialog_Optional_A

#define USE_FUNC3_TOT_OPTIONAL_B \
	USE_FUNC3_TOT_OPTIONAL_BOTH; \
	MENU func3_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC3_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func3_TOT_)
#define USE_FUNC3_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func3_TOT_)
#define USE_FUNC3_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func3_TOT_)
#define USE_FUNC3_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func3_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC4_TOT_MANDATORY_BOTH \
	BLOCK func4_TOT_block; \
	COLLECTION func4_TOT_BLOCK_OBJECT; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func4_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func4_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func4_TOT_BLOCK_OBJECT_page; \
	COMMAND func4_TOT_BLOCK_OBJECT_read; \
	VARIABLE func4_TOT_ST_REV; \
	MENU func4_TOT_ST_REV_page; \
	COMMAND func4_TOT_ST_REV_read; \
	VARIABLE func4_TOT_TAG_DESC; \
	MENU func4_TOT_TAG_DESC_page; \
	COMMAND func4_TOT_TAG_DESC_read; \
	COMMAND func4_TOT_TAG_DESC_write; \
	VARIABLE func4_TOT_STRATEGY; \
	MENU func4_TOT_STRATEGY_page; \
	COMMAND func4_TOT_STRATEGY_read; \
	COMMAND func4_TOT_STRATEGY_write; \
	VARIABLE func4_TOT_ALERT_KEY; \
	MENU func4_TOT_ALERT_KEY_page; \
	COMMAND func4_TOT_ALERT_KEY_read; \
	COMMAND func4_TOT_ALERT_KEY_write; \
	VARIABLE func4_TOT_TARGET_MODE; \
	MENU func4_TOT_TARGET_MODE_page; \
	COMMAND func4_TOT_TARGET_MODE_read; \
	COMMAND func4_TOT_TARGET_MODE_write; \
	COLLECTION func4_TOT_MODE_BLK; \
	VARIABLE func4_TOT_MODE_BLK_Actual; \
	VARIABLE func4_TOT_MODE_BLK_Permitted; \
	VARIABLE func4_TOT_MODE_BLK_Normal; \
	MENU func4_TOT_MODE_BLK_page; \
	COMMAND func4_TOT_MODE_BLK_read; \
	COLLECTION func4_TOT_ALARM_SUM; \
	VARIABLE func4_TOT_ALARM_SUM_Current; \
	VARIABLE func4_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func4_TOT_ALARM_SUM_Unreported; \
	VARIABLE func4_TOT_ALARM_SUM_Disabled; \
	MENU func4_TOT_ALARM_SUM_page; \
	COMMAND func4_TOT_ALARM_SUM_read; \
	COLLECTION func4_TOT_BATCH; \
	VARIABLE func4_TOT_BATCH_Batch_ID; \
	VARIABLE func4_TOT_BATCH_Rup; \
	VARIABLE func4_TOT_BATCH_Operation; \
	VARIABLE func4_TOT_BATCH_Phase; \
	MENU func4_TOT_BATCH_page; \
	COMMAND func4_TOT_BATCH_read; \
	COMMAND func4_TOT_BATCH_write; \
	COLLECTION func4_TOT_TOTAL; \
	VARIABLE func4_TOT_TOTAL_Value; \
	VARIABLE func4_TOT_TOTAL_Status_Condensed; \
	VARIABLE func4_TOT_TOTAL_Status_Quality; \
	VARIABLE func4_TOT_TOTAL_Status_Limit; \
	MENU func4_TOT_TOTAL_page; \
	COMMAND func4_TOT_TOTAL_read; \
	COMMAND func4_TOT_TOTAL_write; \
	VARIABLE func4_TOT_UNIT_TOT; \
	MENU func4_TOT_UNIT_TOT_page; \
	COMMAND func4_TOT_UNIT_TOT_read; \
	COMMAND func4_TOT_UNIT_TOT_write; \
	VARIABLE func4_TOT_ALARM_HYS; \
	MENU func4_TOT_ALARM_HYS_page; \
	COMMAND func4_TOT_ALARM_HYS_read; \
	COMMAND func4_TOT_ALARM_HYS_write; \
	VARIABLE func4_TOT_HI_HI_LIM; \
	MENU func4_TOT_HI_HI_LIM_page; \
	COMMAND func4_TOT_HI_HI_LIM_read; \
	COMMAND func4_TOT_HI_HI_LIM_write; \
	VARIABLE func4_TOT_HI_LIM; \
	MENU func4_TOT_HI_LIM_page; \
	COMMAND func4_TOT_HI_LIM_read; \
	COMMAND func4_TOT_HI_LIM_write; \
	VARIABLE func4_TOT_LO_LIM; \
	MENU func4_TOT_LO_LIM_page; \
	COMMAND func4_TOT_LO_LIM_read; \
	COMMAND func4_TOT_LO_LIM_write; \
	VARIABLE func4_TOT_LO_LO_LIM; \
	MENU func4_TOT_LO_LO_LIM_page; \
	COMMAND func4_TOT_LO_LO_LIM_read; \
	COMMAND func4_TOT_LO_LO_LIM_write; \
	UNIT func4_TOT_unit_1; \
	MENU func4_TOT_Display; \
	MENU func4_TOT_Display_out; \
	MENU func4_TOT_Tab_s_tot_limits

#define USE_FUNC4_TOT_MANDATORY_A \
	USE_FUNC4_TOT_MANDATORY_BOTH; \
	MENU func4_TOT_Simple_Dialog_Mandatory_A; \
	MENU func4_TOT_Tab_s_mandatory_A; \
	MENU func4_TOT_Tab_m_mandatory_A

#define USE_FUNC4_TOT_MANDATORY_B \
	USE_FUNC4_TOT_MANDATORY_BOTH; \
	VARIABLE func4_TOT_CHANNEL; \
	MENU func4_TOT_CHANNEL_page; \
	COMMAND func4_TOT_CHANNEL_read; \
	COMMAND func4_TOT_CHANNEL_write; \
	VARIABLE func4_TOT_SET_TOT; \
	MENU func4_TOT_SET_TOT_page; \
	COMMAND func4_TOT_SET_TOT_read; \
	COMMAND func4_TOT_SET_TOT_write; \
	VARIABLE func4_TOT_MODE_TOT; \
	MENU func4_TOT_MODE_TOT_page; \
	COMMAND func4_TOT_MODE_TOT_read; \
	COMMAND func4_TOT_MODE_TOT_write; \
	VARIABLE func4_TOT_FAIL_TOT; \
	MENU func4_TOT_FAIL_TOT_page; \
	COMMAND func4_TOT_FAIL_TOT_read; \
	COMMAND func4_TOT_FAIL_TOT_write; \
	VARIABLE func4_TOT_PRESET_TOT; \
	MENU func4_TOT_PRESET_TOT_page; \
	COMMAND func4_TOT_PRESET_TOT_read; \
	COMMAND func4_TOT_PRESET_TOT_write; \
	COLLECTION func4_TOT_VIEW_1; \
	MENU func4_TOT_VIEW_1_page; \
	MENU func4_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func4_TOT_unit_2; \
	MENU func4_TOT_Reset; \
	MENU func4_TOT_Reset_page; \
	METHOD func4_TOT_Reset_totalizer; \
	METHOD func4_TOT_Preset_totalizer; \
	MENU func4_TOT_Tab_s_mandatory_B; \
	MENU func4_TOT_Tab_m_mandatory_B

#define USE_FUNC4_TOT_OPTIONAL_BOTH \
	COLLECTION func4_TOT_HI_HI_ALM; \
	VARIABLE func4_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func4_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func4_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func4_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func4_TOT_HI_HI_ALM_Value; \
	MENU func4_TOT_HI_HI_ALM_page; \
	COMMAND func4_TOT_HI_HI_ALM_read; \
	COLLECTION func4_TOT_HI_ALM; \
	VARIABLE func4_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func4_TOT_HI_ALM_Alarm_State; \
	VARIABLE func4_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func4_TOT_HI_ALM_Subcode; \
	VARIABLE func4_TOT_HI_ALM_Value; \
	MENU func4_TOT_HI_ALM_page; \
	COMMAND func4_TOT_HI_ALM_read; \
	COLLECTION func4_TOT_LO_ALM; \
	VARIABLE func4_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func4_TOT_LO_ALM_Alarm_State; \
	VARIABLE func4_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func4_TOT_LO_ALM_Subcode; \
	VARIABLE func4_TOT_LO_ALM_Value; \
	MENU func4_TOT_LO_ALM_page; \
	COMMAND func4_TOT_LO_ALM_read; \
	COLLECTION func4_TOT_LO_LO_ALM; \
	VARIABLE func4_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func4_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func4_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func4_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func4_TOT_LO_LO_ALM_Value; \
	MENU func4_TOT_LO_LO_ALM_page; \
	COMMAND func4_TOT_LO_LO_ALM_read; \
	COLLECTION func4_TOT_VIEW_2; \
	MENU func4_TOT_VIEW_2_page; \
	COLLECTION func4_TOT_VIEW_3; \
	MENU func4_TOT_VIEW_3_page

#define USE_FUNC4_TOT_OPTIONAL_A \
	USE_FUNC4_TOT_OPTIONAL_BOTH; \
	VARIABLE func4_TOT_CHANNEL; \
	MENU func4_TOT_CHANNEL_page; \
	COMMAND func4_TOT_CHANNEL_read; \
	COMMAND func4_TOT_CHANNEL_write; \
	VARIABLE func4_TOT_SET_TOT; \
	MENU func4_TOT_SET_TOT_page; \
	COMMAND func4_TOT_SET_TOT_read; \
	COMMAND func4_TOT_SET_TOT_write; \
	VARIABLE func4_TOT_MODE_TOT; \
	MENU func4_TOT_MODE_TOT_page; \
	COMMAND func4_TOT_MODE_TOT_read; \
	COMMAND func4_TOT_MODE_TOT_write; \
	VARIABLE func4_TOT_FAIL_TOT; \
	MENU func4_TOT_FAIL_TOT_page; \
	COMMAND func4_TOT_FAIL_TOT_read; \
	COMMAND func4_TOT_FAIL_TOT_write; \
	VARIABLE func4_TOT_PRESET_TOT; \
	MENU func4_TOT_PRESET_TOT_page; \
	COMMAND func4_TOT_PRESET_TOT_read; \
	COMMAND func4_TOT_PRESET_TOT_write; \
	COLLECTION func4_TOT_VIEW_1; \
	MENU func4_TOT_VIEW_1_page; \
	MENU func4_TOT_Simple_Dialog_Optional_A

#define USE_FUNC4_TOT_OPTIONAL_B \
	USE_FUNC4_TOT_OPTIONAL_BOTH; \
	MENU func4_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC4_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func4_TOT_)
#define USE_FUNC4_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func4_TOT_)
#define USE_FUNC4_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func4_TOT_)
#define USE_FUNC4_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func4_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC5_TOT_MANDATORY_BOTH \
	BLOCK func5_TOT_block; \
	COLLECTION func5_TOT_BLOCK_OBJECT; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func5_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func5_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func5_TOT_BLOCK_OBJECT_page; \
	COMMAND func5_TOT_BLOCK_OBJECT_read; \
	VARIABLE func5_TOT_ST_REV; \
	MENU func5_TOT_ST_REV_page; \
	COMMAND func5_TOT_ST_REV_read; \
	VARIABLE func5_TOT_TAG_DESC; \
	MENU func5_TOT_TAG_DESC_page; \
	COMMAND func5_TOT_TAG_DESC_read; \
	COMMAND func5_TOT_TAG_DESC_write; \
	VARIABLE func5_TOT_STRATEGY; \
	MENU func5_TOT_STRATEGY_page; \
	COMMAND func5_TOT_STRATEGY_read; \
	COMMAND func5_TOT_STRATEGY_write; \
	VARIABLE func5_TOT_ALERT_KEY; \
	MENU func5_TOT_ALERT_KEY_page; \
	COMMAND func5_TOT_ALERT_KEY_read; \
	COMMAND func5_TOT_ALERT_KEY_write; \
	VARIABLE func5_TOT_TARGET_MODE; \
	MENU func5_TOT_TARGET_MODE_page; \
	COMMAND func5_TOT_TARGET_MODE_read; \
	COMMAND func5_TOT_TARGET_MODE_write; \
	COLLECTION func5_TOT_MODE_BLK; \
	VARIABLE func5_TOT_MODE_BLK_Actual; \
	VARIABLE func5_TOT_MODE_BLK_Permitted; \
	VARIABLE func5_TOT_MODE_BLK_Normal; \
	MENU func5_TOT_MODE_BLK_page; \
	COMMAND func5_TOT_MODE_BLK_read; \
	COLLECTION func5_TOT_ALARM_SUM; \
	VARIABLE func5_TOT_ALARM_SUM_Current; \
	VARIABLE func5_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func5_TOT_ALARM_SUM_Unreported; \
	VARIABLE func5_TOT_ALARM_SUM_Disabled; \
	MENU func5_TOT_ALARM_SUM_page; \
	COMMAND func5_TOT_ALARM_SUM_read; \
	COLLECTION func5_TOT_BATCH; \
	VARIABLE func5_TOT_BATCH_Batch_ID; \
	VARIABLE func5_TOT_BATCH_Rup; \
	VARIABLE func5_TOT_BATCH_Operation; \
	VARIABLE func5_TOT_BATCH_Phase; \
	MENU func5_TOT_BATCH_page; \
	COMMAND func5_TOT_BATCH_read; \
	COMMAND func5_TOT_BATCH_write; \
	COLLECTION func5_TOT_TOTAL; \
	VARIABLE func5_TOT_TOTAL_Value; \
	VARIABLE func5_TOT_TOTAL_Status_Condensed; \
	VARIABLE func5_TOT_TOTAL_Status_Quality; \
	VARIABLE func5_TOT_TOTAL_Status_Limit; \
	MENU func5_TOT_TOTAL_page; \
	COMMAND func5_TOT_TOTAL_read; \
	COMMAND func5_TOT_TOTAL_write; \
	VARIABLE func5_TOT_UNIT_TOT; \
	MENU func5_TOT_UNIT_TOT_page; \
	COMMAND func5_TOT_UNIT_TOT_read; \
	COMMAND func5_TOT_UNIT_TOT_write; \
	VARIABLE func5_TOT_ALARM_HYS; \
	MENU func5_TOT_ALARM_HYS_page; \
	COMMAND func5_TOT_ALARM_HYS_read; \
	COMMAND func5_TOT_ALARM_HYS_write; \
	VARIABLE func5_TOT_HI_HI_LIM; \
	MENU func5_TOT_HI_HI_LIM_page; \
	COMMAND func5_TOT_HI_HI_LIM_read; \
	COMMAND func5_TOT_HI_HI_LIM_write; \
	VARIABLE func5_TOT_HI_LIM; \
	MENU func5_TOT_HI_LIM_page; \
	COMMAND func5_TOT_HI_LIM_read; \
	COMMAND func5_TOT_HI_LIM_write; \
	VARIABLE func5_TOT_LO_LIM; \
	MENU func5_TOT_LO_LIM_page; \
	COMMAND func5_TOT_LO_LIM_read; \
	COMMAND func5_TOT_LO_LIM_write; \
	VARIABLE func5_TOT_LO_LO_LIM; \
	MENU func5_TOT_LO_LO_LIM_page; \
	COMMAND func5_TOT_LO_LO_LIM_read; \
	COMMAND func5_TOT_LO_LO_LIM_write; \
	UNIT func5_TOT_unit_1; \
	MENU func5_TOT_Display; \
	MENU func5_TOT_Display_out; \
	MENU func5_TOT_Tab_s_tot_limits

#define USE_FUNC5_TOT_MANDATORY_A \
	USE_FUNC5_TOT_MANDATORY_BOTH; \
	MENU func5_TOT_Simple_Dialog_Mandatory_A; \
	MENU func5_TOT_Tab_s_mandatory_A; \
	MENU func5_TOT_Tab_m_mandatory_A

#define USE_FUNC5_TOT_MANDATORY_B \
	USE_FUNC5_TOT_MANDATORY_BOTH; \
	VARIABLE func5_TOT_CHANNEL; \
	MENU func5_TOT_CHANNEL_page; \
	COMMAND func5_TOT_CHANNEL_read; \
	COMMAND func5_TOT_CHANNEL_write; \
	VARIABLE func5_TOT_SET_TOT; \
	MENU func5_TOT_SET_TOT_page; \
	COMMAND func5_TOT_SET_TOT_read; \
	COMMAND func5_TOT_SET_TOT_write; \
	VARIABLE func5_TOT_MODE_TOT; \
	MENU func5_TOT_MODE_TOT_page; \
	COMMAND func5_TOT_MODE_TOT_read; \
	COMMAND func5_TOT_MODE_TOT_write; \
	VARIABLE func5_TOT_FAIL_TOT; \
	MENU func5_TOT_FAIL_TOT_page; \
	COMMAND func5_TOT_FAIL_TOT_read; \
	COMMAND func5_TOT_FAIL_TOT_write; \
	VARIABLE func5_TOT_PRESET_TOT; \
	MENU func5_TOT_PRESET_TOT_page; \
	COMMAND func5_TOT_PRESET_TOT_read; \
	COMMAND func5_TOT_PRESET_TOT_write; \
	COLLECTION func5_TOT_VIEW_1; \
	MENU func5_TOT_VIEW_1_page; \
	MENU func5_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func5_TOT_unit_2; \
	MENU func5_TOT_Reset; \
	MENU func5_TOT_Reset_page; \
	METHOD func5_TOT_Reset_totalizer; \
	METHOD func5_TOT_Preset_totalizer; \
	MENU func5_TOT_Tab_s_mandatory_B; \
	MENU func5_TOT_Tab_m_mandatory_B

#define USE_FUNC5_TOT_OPTIONAL_BOTH \
	COLLECTION func5_TOT_HI_HI_ALM; \
	VARIABLE func5_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func5_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func5_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func5_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func5_TOT_HI_HI_ALM_Value; \
	MENU func5_TOT_HI_HI_ALM_page; \
	COMMAND func5_TOT_HI_HI_ALM_read; \
	COLLECTION func5_TOT_HI_ALM; \
	VARIABLE func5_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func5_TOT_HI_ALM_Alarm_State; \
	VARIABLE func5_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func5_TOT_HI_ALM_Subcode; \
	VARIABLE func5_TOT_HI_ALM_Value; \
	MENU func5_TOT_HI_ALM_page; \
	COMMAND func5_TOT_HI_ALM_read; \
	COLLECTION func5_TOT_LO_ALM; \
	VARIABLE func5_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func5_TOT_LO_ALM_Alarm_State; \
	VARIABLE func5_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func5_TOT_LO_ALM_Subcode; \
	VARIABLE func5_TOT_LO_ALM_Value; \
	MENU func5_TOT_LO_ALM_page; \
	COMMAND func5_TOT_LO_ALM_read; \
	COLLECTION func5_TOT_LO_LO_ALM; \
	VARIABLE func5_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func5_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func5_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func5_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func5_TOT_LO_LO_ALM_Value; \
	MENU func5_TOT_LO_LO_ALM_page; \
	COMMAND func5_TOT_LO_LO_ALM_read; \
	COLLECTION func5_TOT_VIEW_2; \
	MENU func5_TOT_VIEW_2_page; \
	COLLECTION func5_TOT_VIEW_3; \
	MENU func5_TOT_VIEW_3_page

#define USE_FUNC5_TOT_OPTIONAL_A \
	USE_FUNC5_TOT_OPTIONAL_BOTH; \
	VARIABLE func5_TOT_CHANNEL; \
	MENU func5_TOT_CHANNEL_page; \
	COMMAND func5_TOT_CHANNEL_read; \
	COMMAND func5_TOT_CHANNEL_write; \
	VARIABLE func5_TOT_SET_TOT; \
	MENU func5_TOT_SET_TOT_page; \
	COMMAND func5_TOT_SET_TOT_read; \
	COMMAND func5_TOT_SET_TOT_write; \
	VARIABLE func5_TOT_MODE_TOT; \
	MENU func5_TOT_MODE_TOT_page; \
	COMMAND func5_TOT_MODE_TOT_read; \
	COMMAND func5_TOT_MODE_TOT_write; \
	VARIABLE func5_TOT_FAIL_TOT; \
	MENU func5_TOT_FAIL_TOT_page; \
	COMMAND func5_TOT_FAIL_TOT_read; \
	COMMAND func5_TOT_FAIL_TOT_write; \
	VARIABLE func5_TOT_PRESET_TOT; \
	MENU func5_TOT_PRESET_TOT_page; \
	COMMAND func5_TOT_PRESET_TOT_read; \
	COMMAND func5_TOT_PRESET_TOT_write; \
	COLLECTION func5_TOT_VIEW_1; \
	MENU func5_TOT_VIEW_1_page; \
	MENU func5_TOT_Simple_Dialog_Optional_A

#define USE_FUNC5_TOT_OPTIONAL_B \
	USE_FUNC5_TOT_OPTIONAL_BOTH; \
	MENU func5_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC5_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func5_TOT_)
#define USE_FUNC5_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func5_TOT_)
#define USE_FUNC5_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func5_TOT_)
#define USE_FUNC5_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func5_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC6_TOT_MANDATORY_BOTH \
	BLOCK func6_TOT_block; \
	COLLECTION func6_TOT_BLOCK_OBJECT; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func6_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func6_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func6_TOT_BLOCK_OBJECT_page; \
	COMMAND func6_TOT_BLOCK_OBJECT_read; \
	VARIABLE func6_TOT_ST_REV; \
	MENU func6_TOT_ST_REV_page; \
	COMMAND func6_TOT_ST_REV_read; \
	VARIABLE func6_TOT_TAG_DESC; \
	MENU func6_TOT_TAG_DESC_page; \
	COMMAND func6_TOT_TAG_DESC_read; \
	COMMAND func6_TOT_TAG_DESC_write; \
	VARIABLE func6_TOT_STRATEGY; \
	MENU func6_TOT_STRATEGY_page; \
	COMMAND func6_TOT_STRATEGY_read; \
	COMMAND func6_TOT_STRATEGY_write; \
	VARIABLE func6_TOT_ALERT_KEY; \
	MENU func6_TOT_ALERT_KEY_page; \
	COMMAND func6_TOT_ALERT_KEY_read; \
	COMMAND func6_TOT_ALERT_KEY_write; \
	VARIABLE func6_TOT_TARGET_MODE; \
	MENU func6_TOT_TARGET_MODE_page; \
	COMMAND func6_TOT_TARGET_MODE_read; \
	COMMAND func6_TOT_TARGET_MODE_write; \
	COLLECTION func6_TOT_MODE_BLK; \
	VARIABLE func6_TOT_MODE_BLK_Actual; \
	VARIABLE func6_TOT_MODE_BLK_Permitted; \
	VARIABLE func6_TOT_MODE_BLK_Normal; \
	MENU func6_TOT_MODE_BLK_page; \
	COMMAND func6_TOT_MODE_BLK_read; \
	COLLECTION func6_TOT_ALARM_SUM; \
	VARIABLE func6_TOT_ALARM_SUM_Current; \
	VARIABLE func6_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func6_TOT_ALARM_SUM_Unreported; \
	VARIABLE func6_TOT_ALARM_SUM_Disabled; \
	MENU func6_TOT_ALARM_SUM_page; \
	COMMAND func6_TOT_ALARM_SUM_read; \
	COLLECTION func6_TOT_BATCH; \
	VARIABLE func6_TOT_BATCH_Batch_ID; \
	VARIABLE func6_TOT_BATCH_Rup; \
	VARIABLE func6_TOT_BATCH_Operation; \
	VARIABLE func6_TOT_BATCH_Phase; \
	MENU func6_TOT_BATCH_page; \
	COMMAND func6_TOT_BATCH_read; \
	COMMAND func6_TOT_BATCH_write; \
	COLLECTION func6_TOT_TOTAL; \
	VARIABLE func6_TOT_TOTAL_Value; \
	VARIABLE func6_TOT_TOTAL_Status_Condensed; \
	VARIABLE func6_TOT_TOTAL_Status_Quality; \
	VARIABLE func6_TOT_TOTAL_Status_Limit; \
	MENU func6_TOT_TOTAL_page; \
	COMMAND func6_TOT_TOTAL_read; \
	COMMAND func6_TOT_TOTAL_write; \
	VARIABLE func6_TOT_UNIT_TOT; \
	MENU func6_TOT_UNIT_TOT_page; \
	COMMAND func6_TOT_UNIT_TOT_read; \
	COMMAND func6_TOT_UNIT_TOT_write; \
	VARIABLE func6_TOT_ALARM_HYS; \
	MENU func6_TOT_ALARM_HYS_page; \
	COMMAND func6_TOT_ALARM_HYS_read; \
	COMMAND func6_TOT_ALARM_HYS_write; \
	VARIABLE func6_TOT_HI_HI_LIM; \
	MENU func6_TOT_HI_HI_LIM_page; \
	COMMAND func6_TOT_HI_HI_LIM_read; \
	COMMAND func6_TOT_HI_HI_LIM_write; \
	VARIABLE func6_TOT_HI_LIM; \
	MENU func6_TOT_HI_LIM_page; \
	COMMAND func6_TOT_HI_LIM_read; \
	COMMAND func6_TOT_HI_LIM_write; \
	VARIABLE func6_TOT_LO_LIM; \
	MENU func6_TOT_LO_LIM_page; \
	COMMAND func6_TOT_LO_LIM_read; \
	COMMAND func6_TOT_LO_LIM_write; \
	VARIABLE func6_TOT_LO_LO_LIM; \
	MENU func6_TOT_LO_LO_LIM_page; \
	COMMAND func6_TOT_LO_LO_LIM_read; \
	COMMAND func6_TOT_LO_LO_LIM_write; \
	UNIT func6_TOT_unit_1; \
	MENU func6_TOT_Display; \
	MENU func6_TOT_Display_out; \
	MENU func6_TOT_Tab_s_tot_limits

#define USE_FUNC6_TOT_MANDATORY_A \
	USE_FUNC6_TOT_MANDATORY_BOTH; \
	MENU func6_TOT_Simple_Dialog_Mandatory_A; \
	MENU func6_TOT_Tab_s_mandatory_A; \
	MENU func6_TOT_Tab_m_mandatory_A

#define USE_FUNC6_TOT_MANDATORY_B \
	USE_FUNC6_TOT_MANDATORY_BOTH; \
	VARIABLE func6_TOT_CHANNEL; \
	MENU func6_TOT_CHANNEL_page; \
	COMMAND func6_TOT_CHANNEL_read; \
	COMMAND func6_TOT_CHANNEL_write; \
	VARIABLE func6_TOT_SET_TOT; \
	MENU func6_TOT_SET_TOT_page; \
	COMMAND func6_TOT_SET_TOT_read; \
	COMMAND func6_TOT_SET_TOT_write; \
	VARIABLE func6_TOT_MODE_TOT; \
	MENU func6_TOT_MODE_TOT_page; \
	COMMAND func6_TOT_MODE_TOT_read; \
	COMMAND func6_TOT_MODE_TOT_write; \
	VARIABLE func6_TOT_FAIL_TOT; \
	MENU func6_TOT_FAIL_TOT_page; \
	COMMAND func6_TOT_FAIL_TOT_read; \
	COMMAND func6_TOT_FAIL_TOT_write; \
	VARIABLE func6_TOT_PRESET_TOT; \
	MENU func6_TOT_PRESET_TOT_page; \
	COMMAND func6_TOT_PRESET_TOT_read; \
	COMMAND func6_TOT_PRESET_TOT_write; \
	COLLECTION func6_TOT_VIEW_1; \
	MENU func6_TOT_VIEW_1_page; \
	MENU func6_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func6_TOT_unit_2; \
	MENU func6_TOT_Reset; \
	MENU func6_TOT_Reset_page; \
	METHOD func6_TOT_Reset_totalizer; \
	METHOD func6_TOT_Preset_totalizer; \
	MENU func6_TOT_Tab_s_mandatory_B; \
	MENU func6_TOT_Tab_m_mandatory_B

#define USE_FUNC6_TOT_OPTIONAL_BOTH \
	COLLECTION func6_TOT_HI_HI_ALM; \
	VARIABLE func6_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func6_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func6_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func6_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func6_TOT_HI_HI_ALM_Value; \
	MENU func6_TOT_HI_HI_ALM_page; \
	COMMAND func6_TOT_HI_HI_ALM_read; \
	COLLECTION func6_TOT_HI_ALM; \
	VARIABLE func6_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func6_TOT_HI_ALM_Alarm_State; \
	VARIABLE func6_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func6_TOT_HI_ALM_Subcode; \
	VARIABLE func6_TOT_HI_ALM_Value; \
	MENU func6_TOT_HI_ALM_page; \
	COMMAND func6_TOT_HI_ALM_read; \
	COLLECTION func6_TOT_LO_ALM; \
	VARIABLE func6_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func6_TOT_LO_ALM_Alarm_State; \
	VARIABLE func6_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func6_TOT_LO_ALM_Subcode; \
	VARIABLE func6_TOT_LO_ALM_Value; \
	MENU func6_TOT_LO_ALM_page; \
	COMMAND func6_TOT_LO_ALM_read; \
	COLLECTION func6_TOT_LO_LO_ALM; \
	VARIABLE func6_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func6_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func6_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func6_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func6_TOT_LO_LO_ALM_Value; \
	MENU func6_TOT_LO_LO_ALM_page; \
	COMMAND func6_TOT_LO_LO_ALM_read; \
	COLLECTION func6_TOT_VIEW_2; \
	MENU func6_TOT_VIEW_2_page; \
	COLLECTION func6_TOT_VIEW_3; \
	MENU func6_TOT_VIEW_3_page

#define USE_FUNC6_TOT_OPTIONAL_A \
	USE_FUNC6_TOT_OPTIONAL_BOTH; \
	VARIABLE func6_TOT_CHANNEL; \
	MENU func6_TOT_CHANNEL_page; \
	COMMAND func6_TOT_CHANNEL_read; \
	COMMAND func6_TOT_CHANNEL_write; \
	VARIABLE func6_TOT_SET_TOT; \
	MENU func6_TOT_SET_TOT_page; \
	COMMAND func6_TOT_SET_TOT_read; \
	COMMAND func6_TOT_SET_TOT_write; \
	VARIABLE func6_TOT_MODE_TOT; \
	MENU func6_TOT_MODE_TOT_page; \
	COMMAND func6_TOT_MODE_TOT_read; \
	COMMAND func6_TOT_MODE_TOT_write; \
	VARIABLE func6_TOT_FAIL_TOT; \
	MENU func6_TOT_FAIL_TOT_page; \
	COMMAND func6_TOT_FAIL_TOT_read; \
	COMMAND func6_TOT_FAIL_TOT_write; \
	VARIABLE func6_TOT_PRESET_TOT; \
	MENU func6_TOT_PRESET_TOT_page; \
	COMMAND func6_TOT_PRESET_TOT_read; \
	COMMAND func6_TOT_PRESET_TOT_write; \
	COLLECTION func6_TOT_VIEW_1; \
	MENU func6_TOT_VIEW_1_page; \
	MENU func6_TOT_Simple_Dialog_Optional_A

#define USE_FUNC6_TOT_OPTIONAL_B \
	USE_FUNC6_TOT_OPTIONAL_BOTH; \
	MENU func6_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC6_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func6_TOT_)
#define USE_FUNC6_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func6_TOT_)
#define USE_FUNC6_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func6_TOT_)
#define USE_FUNC6_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func6_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC7_TOT_MANDATORY_BOTH \
	BLOCK func7_TOT_block; \
	COLLECTION func7_TOT_BLOCK_OBJECT; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func7_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func7_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func7_TOT_BLOCK_OBJECT_page; \
	COMMAND func7_TOT_BLOCK_OBJECT_read; \
	VARIABLE func7_TOT_ST_REV; \
	MENU func7_TOT_ST_REV_page; \
	COMMAND func7_TOT_ST_REV_read; \
	VARIABLE func7_TOT_TAG_DESC; \
	MENU func7_TOT_TAG_DESC_page; \
	COMMAND func7_TOT_TAG_DESC_read; \
	COMMAND func7_TOT_TAG_DESC_write; \
	VARIABLE func7_TOT_STRATEGY; \
	MENU func7_TOT_STRATEGY_page; \
	COMMAND func7_TOT_STRATEGY_read; \
	COMMAND func7_TOT_STRATEGY_write; \
	VARIABLE func7_TOT_ALERT_KEY; \
	MENU func7_TOT_ALERT_KEY_page; \
	COMMAND func7_TOT_ALERT_KEY_read; \
	COMMAND func7_TOT_ALERT_KEY_write; \
	VARIABLE func7_TOT_TARGET_MODE; \
	MENU func7_TOT_TARGET_MODE_page; \
	COMMAND func7_TOT_TARGET_MODE_read; \
	COMMAND func7_TOT_TARGET_MODE_write; \
	COLLECTION func7_TOT_MODE_BLK; \
	VARIABLE func7_TOT_MODE_BLK_Actual; \
	VARIABLE func7_TOT_MODE_BLK_Permitted; \
	VARIABLE func7_TOT_MODE_BLK_Normal; \
	MENU func7_TOT_MODE_BLK_page; \
	COMMAND func7_TOT_MODE_BLK_read; \
	COLLECTION func7_TOT_ALARM_SUM; \
	VARIABLE func7_TOT_ALARM_SUM_Current; \
	VARIABLE func7_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func7_TOT_ALARM_SUM_Unreported; \
	VARIABLE func7_TOT_ALARM_SUM_Disabled; \
	MENU func7_TOT_ALARM_SUM_page; \
	COMMAND func7_TOT_ALARM_SUM_read; \
	COLLECTION func7_TOT_BATCH; \
	VARIABLE func7_TOT_BATCH_Batch_ID; \
	VARIABLE func7_TOT_BATCH_Rup; \
	VARIABLE func7_TOT_BATCH_Operation; \
	VARIABLE func7_TOT_BATCH_Phase; \
	MENU func7_TOT_BATCH_page; \
	COMMAND func7_TOT_BATCH_read; \
	COMMAND func7_TOT_BATCH_write; \
	COLLECTION func7_TOT_TOTAL; \
	VARIABLE func7_TOT_TOTAL_Value; \
	VARIABLE func7_TOT_TOTAL_Status_Condensed; \
	VARIABLE func7_TOT_TOTAL_Status_Quality; \
	VARIABLE func7_TOT_TOTAL_Status_Limit; \
	MENU func7_TOT_TOTAL_page; \
	COMMAND func7_TOT_TOTAL_read; \
	COMMAND func7_TOT_TOTAL_write; \
	VARIABLE func7_TOT_UNIT_TOT; \
	MENU func7_TOT_UNIT_TOT_page; \
	COMMAND func7_TOT_UNIT_TOT_read; \
	COMMAND func7_TOT_UNIT_TOT_write; \
	VARIABLE func7_TOT_ALARM_HYS; \
	MENU func7_TOT_ALARM_HYS_page; \
	COMMAND func7_TOT_ALARM_HYS_read; \
	COMMAND func7_TOT_ALARM_HYS_write; \
	VARIABLE func7_TOT_HI_HI_LIM; \
	MENU func7_TOT_HI_HI_LIM_page; \
	COMMAND func7_TOT_HI_HI_LIM_read; \
	COMMAND func7_TOT_HI_HI_LIM_write; \
	VARIABLE func7_TOT_HI_LIM; \
	MENU func7_TOT_HI_LIM_page; \
	COMMAND func7_TOT_HI_LIM_read; \
	COMMAND func7_TOT_HI_LIM_write; \
	VARIABLE func7_TOT_LO_LIM; \
	MENU func7_TOT_LO_LIM_page; \
	COMMAND func7_TOT_LO_LIM_read; \
	COMMAND func7_TOT_LO_LIM_write; \
	VARIABLE func7_TOT_LO_LO_LIM; \
	MENU func7_TOT_LO_LO_LIM_page; \
	COMMAND func7_TOT_LO_LO_LIM_read; \
	COMMAND func7_TOT_LO_LO_LIM_write; \
	UNIT func7_TOT_unit_1; \
	MENU func7_TOT_Display; \
	MENU func7_TOT_Display_out; \
	MENU func7_TOT_Tab_s_tot_limits

#define USE_FUNC7_TOT_MANDATORY_A \
	USE_FUNC7_TOT_MANDATORY_BOTH; \
	MENU func7_TOT_Simple_Dialog_Mandatory_A; \
	MENU func7_TOT_Tab_s_mandatory_A; \
	MENU func7_TOT_Tab_m_mandatory_A

#define USE_FUNC7_TOT_MANDATORY_B \
	USE_FUNC7_TOT_MANDATORY_BOTH; \
	VARIABLE func7_TOT_CHANNEL; \
	MENU func7_TOT_CHANNEL_page; \
	COMMAND func7_TOT_CHANNEL_read; \
	COMMAND func7_TOT_CHANNEL_write; \
	VARIABLE func7_TOT_SET_TOT; \
	MENU func7_TOT_SET_TOT_page; \
	COMMAND func7_TOT_SET_TOT_read; \
	COMMAND func7_TOT_SET_TOT_write; \
	VARIABLE func7_TOT_MODE_TOT; \
	MENU func7_TOT_MODE_TOT_page; \
	COMMAND func7_TOT_MODE_TOT_read; \
	COMMAND func7_TOT_MODE_TOT_write; \
	VARIABLE func7_TOT_FAIL_TOT; \
	MENU func7_TOT_FAIL_TOT_page; \
	COMMAND func7_TOT_FAIL_TOT_read; \
	COMMAND func7_TOT_FAIL_TOT_write; \
	VARIABLE func7_TOT_PRESET_TOT; \
	MENU func7_TOT_PRESET_TOT_page; \
	COMMAND func7_TOT_PRESET_TOT_read; \
	COMMAND func7_TOT_PRESET_TOT_write; \
	COLLECTION func7_TOT_VIEW_1; \
	MENU func7_TOT_VIEW_1_page; \
	MENU func7_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func7_TOT_unit_2; \
	MENU func7_TOT_Reset; \
	MENU func7_TOT_Reset_page; \
	METHOD func7_TOT_Reset_totalizer; \
	METHOD func7_TOT_Preset_totalizer; \
	MENU func7_TOT_Tab_s_mandatory_B; \
	MENU func7_TOT_Tab_m_mandatory_B

#define USE_FUNC7_TOT_OPTIONAL_BOTH \
	COLLECTION func7_TOT_HI_HI_ALM; \
	VARIABLE func7_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func7_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func7_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func7_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func7_TOT_HI_HI_ALM_Value; \
	MENU func7_TOT_HI_HI_ALM_page; \
	COMMAND func7_TOT_HI_HI_ALM_read; \
	COLLECTION func7_TOT_HI_ALM; \
	VARIABLE func7_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func7_TOT_HI_ALM_Alarm_State; \
	VARIABLE func7_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func7_TOT_HI_ALM_Subcode; \
	VARIABLE func7_TOT_HI_ALM_Value; \
	MENU func7_TOT_HI_ALM_page; \
	COMMAND func7_TOT_HI_ALM_read; \
	COLLECTION func7_TOT_LO_ALM; \
	VARIABLE func7_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func7_TOT_LO_ALM_Alarm_State; \
	VARIABLE func7_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func7_TOT_LO_ALM_Subcode; \
	VARIABLE func7_TOT_LO_ALM_Value; \
	MENU func7_TOT_LO_ALM_page; \
	COMMAND func7_TOT_LO_ALM_read; \
	COLLECTION func7_TOT_LO_LO_ALM; \
	VARIABLE func7_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func7_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func7_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func7_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func7_TOT_LO_LO_ALM_Value; \
	MENU func7_TOT_LO_LO_ALM_page; \
	COMMAND func7_TOT_LO_LO_ALM_read; \
	COLLECTION func7_TOT_VIEW_2; \
	MENU func7_TOT_VIEW_2_page; \
	COLLECTION func7_TOT_VIEW_3; \
	MENU func7_TOT_VIEW_3_page

#define USE_FUNC7_TOT_OPTIONAL_A \
	USE_FUNC7_TOT_OPTIONAL_BOTH; \
	VARIABLE func7_TOT_CHANNEL; \
	MENU func7_TOT_CHANNEL_page; \
	COMMAND func7_TOT_CHANNEL_read; \
	COMMAND func7_TOT_CHANNEL_write; \
	VARIABLE func7_TOT_SET_TOT; \
	MENU func7_TOT_SET_TOT_page; \
	COMMAND func7_TOT_SET_TOT_read; \
	COMMAND func7_TOT_SET_TOT_write; \
	VARIABLE func7_TOT_MODE_TOT; \
	MENU func7_TOT_MODE_TOT_page; \
	COMMAND func7_TOT_MODE_TOT_read; \
	COMMAND func7_TOT_MODE_TOT_write; \
	VARIABLE func7_TOT_FAIL_TOT; \
	MENU func7_TOT_FAIL_TOT_page; \
	COMMAND func7_TOT_FAIL_TOT_read; \
	COMMAND func7_TOT_FAIL_TOT_write; \
	VARIABLE func7_TOT_PRESET_TOT; \
	MENU func7_TOT_PRESET_TOT_page; \
	COMMAND func7_TOT_PRESET_TOT_read; \
	COMMAND func7_TOT_PRESET_TOT_write; \
	COLLECTION func7_TOT_VIEW_1; \
	MENU func7_TOT_VIEW_1_page; \
	MENU func7_TOT_Simple_Dialog_Optional_A

#define USE_FUNC7_TOT_OPTIONAL_B \
	USE_FUNC7_TOT_OPTIONAL_BOTH; \
	MENU func7_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC7_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func7_TOT_)
#define USE_FUNC7_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func7_TOT_)
#define USE_FUNC7_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func7_TOT_)
#define USE_FUNC7_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func7_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC8_TOT_MANDATORY_BOTH \
	BLOCK func8_TOT_block; \
	COLLECTION func8_TOT_BLOCK_OBJECT; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func8_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func8_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func8_TOT_BLOCK_OBJECT_page; \
	COMMAND func8_TOT_BLOCK_OBJECT_read; \
	VARIABLE func8_TOT_ST_REV; \
	MENU func8_TOT_ST_REV_page; \
	COMMAND func8_TOT_ST_REV_read; \
	VARIABLE func8_TOT_TAG_DESC; \
	MENU func8_TOT_TAG_DESC_page; \
	COMMAND func8_TOT_TAG_DESC_read; \
	COMMAND func8_TOT_TAG_DESC_write; \
	VARIABLE func8_TOT_STRATEGY; \
	MENU func8_TOT_STRATEGY_page; \
	COMMAND func8_TOT_STRATEGY_read; \
	COMMAND func8_TOT_STRATEGY_write; \
	VARIABLE func8_TOT_ALERT_KEY; \
	MENU func8_TOT_ALERT_KEY_page; \
	COMMAND func8_TOT_ALERT_KEY_read; \
	COMMAND func8_TOT_ALERT_KEY_write; \
	VARIABLE func8_TOT_TARGET_MODE; \
	MENU func8_TOT_TARGET_MODE_page; \
	COMMAND func8_TOT_TARGET_MODE_read; \
	COMMAND func8_TOT_TARGET_MODE_write; \
	COLLECTION func8_TOT_MODE_BLK; \
	VARIABLE func8_TOT_MODE_BLK_Actual; \
	VARIABLE func8_TOT_MODE_BLK_Permitted; \
	VARIABLE func8_TOT_MODE_BLK_Normal; \
	MENU func8_TOT_MODE_BLK_page; \
	COMMAND func8_TOT_MODE_BLK_read; \
	COLLECTION func8_TOT_ALARM_SUM; \
	VARIABLE func8_TOT_ALARM_SUM_Current; \
	VARIABLE func8_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func8_TOT_ALARM_SUM_Unreported; \
	VARIABLE func8_TOT_ALARM_SUM_Disabled; \
	MENU func8_TOT_ALARM_SUM_page; \
	COMMAND func8_TOT_ALARM_SUM_read; \
	COLLECTION func8_TOT_BATCH; \
	VARIABLE func8_TOT_BATCH_Batch_ID; \
	VARIABLE func8_TOT_BATCH_Rup; \
	VARIABLE func8_TOT_BATCH_Operation; \
	VARIABLE func8_TOT_BATCH_Phase; \
	MENU func8_TOT_BATCH_page; \
	COMMAND func8_TOT_BATCH_read; \
	COMMAND func8_TOT_BATCH_write; \
	COLLECTION func8_TOT_TOTAL; \
	VARIABLE func8_TOT_TOTAL_Value; \
	VARIABLE func8_TOT_TOTAL_Status_Condensed; \
	VARIABLE func8_TOT_TOTAL_Status_Quality; \
	VARIABLE func8_TOT_TOTAL_Status_Limit; \
	MENU func8_TOT_TOTAL_page; \
	COMMAND func8_TOT_TOTAL_read; \
	COMMAND func8_TOT_TOTAL_write; \
	VARIABLE func8_TOT_UNIT_TOT; \
	MENU func8_TOT_UNIT_TOT_page; \
	COMMAND func8_TOT_UNIT_TOT_read; \
	COMMAND func8_TOT_UNIT_TOT_write; \
	VARIABLE func8_TOT_ALARM_HYS; \
	MENU func8_TOT_ALARM_HYS_page; \
	COMMAND func8_TOT_ALARM_HYS_read; \
	COMMAND func8_TOT_ALARM_HYS_write; \
	VARIABLE func8_TOT_HI_HI_LIM; \
	MENU func8_TOT_HI_HI_LIM_page; \
	COMMAND func8_TOT_HI_HI_LIM_read; \
	COMMAND func8_TOT_HI_HI_LIM_write; \
	VARIABLE func8_TOT_HI_LIM; \
	MENU func8_TOT_HI_LIM_page; \
	COMMAND func8_TOT_HI_LIM_read; \
	COMMAND func8_TOT_HI_LIM_write; \
	VARIABLE func8_TOT_LO_LIM; \
	MENU func8_TOT_LO_LIM_page; \
	COMMAND func8_TOT_LO_LIM_read; \
	COMMAND func8_TOT_LO_LIM_write; \
	VARIABLE func8_TOT_LO_LO_LIM; \
	MENU func8_TOT_LO_LO_LIM_page; \
	COMMAND func8_TOT_LO_LO_LIM_read; \
	COMMAND func8_TOT_LO_LO_LIM_write; \
	UNIT func8_TOT_unit_1; \
	MENU func8_TOT_Display; \
	MENU func8_TOT_Display_out; \
	MENU func8_TOT_Tab_s_tot_limits

#define USE_FUNC8_TOT_MANDATORY_A \
	USE_FUNC8_TOT_MANDATORY_BOTH; \
	MENU func8_TOT_Simple_Dialog_Mandatory_A; \
	MENU func8_TOT_Tab_s_mandatory_A; \
	MENU func8_TOT_Tab_m_mandatory_A

#define USE_FUNC8_TOT_MANDATORY_B \
	USE_FUNC8_TOT_MANDATORY_BOTH; \
	VARIABLE func8_TOT_CHANNEL; \
	MENU func8_TOT_CHANNEL_page; \
	COMMAND func8_TOT_CHANNEL_read; \
	COMMAND func8_TOT_CHANNEL_write; \
	VARIABLE func8_TOT_SET_TOT; \
	MENU func8_TOT_SET_TOT_page; \
	COMMAND func8_TOT_SET_TOT_read; \
	COMMAND func8_TOT_SET_TOT_write; \
	VARIABLE func8_TOT_MODE_TOT; \
	MENU func8_TOT_MODE_TOT_page; \
	COMMAND func8_TOT_MODE_TOT_read; \
	COMMAND func8_TOT_MODE_TOT_write; \
	VARIABLE func8_TOT_FAIL_TOT; \
	MENU func8_TOT_FAIL_TOT_page; \
	COMMAND func8_TOT_FAIL_TOT_read; \
	COMMAND func8_TOT_FAIL_TOT_write; \
	VARIABLE func8_TOT_PRESET_TOT; \
	MENU func8_TOT_PRESET_TOT_page; \
	COMMAND func8_TOT_PRESET_TOT_read; \
	COMMAND func8_TOT_PRESET_TOT_write; \
	COLLECTION func8_TOT_VIEW_1; \
	MENU func8_TOT_VIEW_1_page; \
	MENU func8_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func8_TOT_unit_2; \
	MENU func8_TOT_Reset; \
	MENU func8_TOT_Reset_page; \
	METHOD func8_TOT_Reset_totalizer; \
	METHOD func8_TOT_Preset_totalizer; \
	MENU func8_TOT_Tab_s_mandatory_B; \
	MENU func8_TOT_Tab_m_mandatory_B

#define USE_FUNC8_TOT_OPTIONAL_BOTH \
	COLLECTION func8_TOT_HI_HI_ALM; \
	VARIABLE func8_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func8_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func8_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func8_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func8_TOT_HI_HI_ALM_Value; \
	MENU func8_TOT_HI_HI_ALM_page; \
	COMMAND func8_TOT_HI_HI_ALM_read; \
	COLLECTION func8_TOT_HI_ALM; \
	VARIABLE func8_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func8_TOT_HI_ALM_Alarm_State; \
	VARIABLE func8_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func8_TOT_HI_ALM_Subcode; \
	VARIABLE func8_TOT_HI_ALM_Value; \
	MENU func8_TOT_HI_ALM_page; \
	COMMAND func8_TOT_HI_ALM_read; \
	COLLECTION func8_TOT_LO_ALM; \
	VARIABLE func8_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func8_TOT_LO_ALM_Alarm_State; \
	VARIABLE func8_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func8_TOT_LO_ALM_Subcode; \
	VARIABLE func8_TOT_LO_ALM_Value; \
	MENU func8_TOT_LO_ALM_page; \
	COMMAND func8_TOT_LO_ALM_read; \
	COLLECTION func8_TOT_LO_LO_ALM; \
	VARIABLE func8_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func8_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func8_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func8_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func8_TOT_LO_LO_ALM_Value; \
	MENU func8_TOT_LO_LO_ALM_page; \
	COMMAND func8_TOT_LO_LO_ALM_read; \
	COLLECTION func8_TOT_VIEW_2; \
	MENU func8_TOT_VIEW_2_page; \
	COLLECTION func8_TOT_VIEW_3; \
	MENU func8_TOT_VIEW_3_page

#define USE_FUNC8_TOT_OPTIONAL_A \
	USE_FUNC8_TOT_OPTIONAL_BOTH; \
	VARIABLE func8_TOT_CHANNEL; \
	MENU func8_TOT_CHANNEL_page; \
	COMMAND func8_TOT_CHANNEL_read; \
	COMMAND func8_TOT_CHANNEL_write; \
	VARIABLE func8_TOT_SET_TOT; \
	MENU func8_TOT_SET_TOT_page; \
	COMMAND func8_TOT_SET_TOT_read; \
	COMMAND func8_TOT_SET_TOT_write; \
	VARIABLE func8_TOT_MODE_TOT; \
	MENU func8_TOT_MODE_TOT_page; \
	COMMAND func8_TOT_MODE_TOT_read; \
	COMMAND func8_TOT_MODE_TOT_write; \
	VARIABLE func8_TOT_FAIL_TOT; \
	MENU func8_TOT_FAIL_TOT_page; \
	COMMAND func8_TOT_FAIL_TOT_read; \
	COMMAND func8_TOT_FAIL_TOT_write; \
	VARIABLE func8_TOT_PRESET_TOT; \
	MENU func8_TOT_PRESET_TOT_page; \
	COMMAND func8_TOT_PRESET_TOT_read; \
	COMMAND func8_TOT_PRESET_TOT_write; \
	COLLECTION func8_TOT_VIEW_1; \
	MENU func8_TOT_VIEW_1_page; \
	MENU func8_TOT_Simple_Dialog_Optional_A

#define USE_FUNC8_TOT_OPTIONAL_B \
	USE_FUNC8_TOT_OPTIONAL_BOTH; \
	MENU func8_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC8_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func8_TOT_)
#define USE_FUNC8_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func8_TOT_)
#define USE_FUNC8_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func8_TOT_)
#define USE_FUNC8_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func8_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC9_TOT_MANDATORY_BOTH \
	BLOCK func9_TOT_block; \
	COLLECTION func9_TOT_BLOCK_OBJECT; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func9_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func9_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func9_TOT_BLOCK_OBJECT_page; \
	COMMAND func9_TOT_BLOCK_OBJECT_read; \
	VARIABLE func9_TOT_ST_REV; \
	MENU func9_TOT_ST_REV_page; \
	COMMAND func9_TOT_ST_REV_read; \
	VARIABLE func9_TOT_TAG_DESC; \
	MENU func9_TOT_TAG_DESC_page; \
	COMMAND func9_TOT_TAG_DESC_read; \
	COMMAND func9_TOT_TAG_DESC_write; \
	VARIABLE func9_TOT_STRATEGY; \
	MENU func9_TOT_STRATEGY_page; \
	COMMAND func9_TOT_STRATEGY_read; \
	COMMAND func9_TOT_STRATEGY_write; \
	VARIABLE func9_TOT_ALERT_KEY; \
	MENU func9_TOT_ALERT_KEY_page; \
	COMMAND func9_TOT_ALERT_KEY_read; \
	COMMAND func9_TOT_ALERT_KEY_write; \
	VARIABLE func9_TOT_TARGET_MODE; \
	MENU func9_TOT_TARGET_MODE_page; \
	COMMAND func9_TOT_TARGET_MODE_read; \
	COMMAND func9_TOT_TARGET_MODE_write; \
	COLLECTION func9_TOT_MODE_BLK; \
	VARIABLE func9_TOT_MODE_BLK_Actual; \
	VARIABLE func9_TOT_MODE_BLK_Permitted; \
	VARIABLE func9_TOT_MODE_BLK_Normal; \
	MENU func9_TOT_MODE_BLK_page; \
	COMMAND func9_TOT_MODE_BLK_read; \
	COLLECTION func9_TOT_ALARM_SUM; \
	VARIABLE func9_TOT_ALARM_SUM_Current; \
	VARIABLE func9_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func9_TOT_ALARM_SUM_Unreported; \
	VARIABLE func9_TOT_ALARM_SUM_Disabled; \
	MENU func9_TOT_ALARM_SUM_page; \
	COMMAND func9_TOT_ALARM_SUM_read; \
	COLLECTION func9_TOT_BATCH; \
	VARIABLE func9_TOT_BATCH_Batch_ID; \
	VARIABLE func9_TOT_BATCH_Rup; \
	VARIABLE func9_TOT_BATCH_Operation; \
	VARIABLE func9_TOT_BATCH_Phase; \
	MENU func9_TOT_BATCH_page; \
	COMMAND func9_TOT_BATCH_read; \
	COMMAND func9_TOT_BATCH_write; \
	COLLECTION func9_TOT_TOTAL; \
	VARIABLE func9_TOT_TOTAL_Value; \
	VARIABLE func9_TOT_TOTAL_Status_Condensed; \
	VARIABLE func9_TOT_TOTAL_Status_Quality; \
	VARIABLE func9_TOT_TOTAL_Status_Limit; \
	MENU func9_TOT_TOTAL_page; \
	COMMAND func9_TOT_TOTAL_read; \
	COMMAND func9_TOT_TOTAL_write; \
	VARIABLE func9_TOT_UNIT_TOT; \
	MENU func9_TOT_UNIT_TOT_page; \
	COMMAND func9_TOT_UNIT_TOT_read; \
	COMMAND func9_TOT_UNIT_TOT_write; \
	VARIABLE func9_TOT_ALARM_HYS; \
	MENU func9_TOT_ALARM_HYS_page; \
	COMMAND func9_TOT_ALARM_HYS_read; \
	COMMAND func9_TOT_ALARM_HYS_write; \
	VARIABLE func9_TOT_HI_HI_LIM; \
	MENU func9_TOT_HI_HI_LIM_page; \
	COMMAND func9_TOT_HI_HI_LIM_read; \
	COMMAND func9_TOT_HI_HI_LIM_write; \
	VARIABLE func9_TOT_HI_LIM; \
	MENU func9_TOT_HI_LIM_page; \
	COMMAND func9_TOT_HI_LIM_read; \
	COMMAND func9_TOT_HI_LIM_write; \
	VARIABLE func9_TOT_LO_LIM; \
	MENU func9_TOT_LO_LIM_page; \
	COMMAND func9_TOT_LO_LIM_read; \
	COMMAND func9_TOT_LO_LIM_write; \
	VARIABLE func9_TOT_LO_LO_LIM; \
	MENU func9_TOT_LO_LO_LIM_page; \
	COMMAND func9_TOT_LO_LO_LIM_read; \
	COMMAND func9_TOT_LO_LO_LIM_write; \
	UNIT func9_TOT_unit_1; \
	MENU func9_TOT_Display; \
	MENU func9_TOT_Display_out; \
	MENU func9_TOT_Tab_s_tot_limits

#define USE_FUNC9_TOT_MANDATORY_A \
	USE_FUNC9_TOT_MANDATORY_BOTH; \
	MENU func9_TOT_Simple_Dialog_Mandatory_A; \
	MENU func9_TOT_Tab_s_mandatory_A; \
	MENU func9_TOT_Tab_m_mandatory_A

#define USE_FUNC9_TOT_MANDATORY_B \
	USE_FUNC9_TOT_MANDATORY_BOTH; \
	VARIABLE func9_TOT_CHANNEL; \
	MENU func9_TOT_CHANNEL_page; \
	COMMAND func9_TOT_CHANNEL_read; \
	COMMAND func9_TOT_CHANNEL_write; \
	VARIABLE func9_TOT_SET_TOT; \
	MENU func9_TOT_SET_TOT_page; \
	COMMAND func9_TOT_SET_TOT_read; \
	COMMAND func9_TOT_SET_TOT_write; \
	VARIABLE func9_TOT_MODE_TOT; \
	MENU func9_TOT_MODE_TOT_page; \
	COMMAND func9_TOT_MODE_TOT_read; \
	COMMAND func9_TOT_MODE_TOT_write; \
	VARIABLE func9_TOT_FAIL_TOT; \
	MENU func9_TOT_FAIL_TOT_page; \
	COMMAND func9_TOT_FAIL_TOT_read; \
	COMMAND func9_TOT_FAIL_TOT_write; \
	VARIABLE func9_TOT_PRESET_TOT; \
	MENU func9_TOT_PRESET_TOT_page; \
	COMMAND func9_TOT_PRESET_TOT_read; \
	COMMAND func9_TOT_PRESET_TOT_write; \
	COLLECTION func9_TOT_VIEW_1; \
	MENU func9_TOT_VIEW_1_page; \
	MENU func9_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func9_TOT_unit_2; \
	MENU func9_TOT_Reset; \
	MENU func9_TOT_Reset_page; \
	METHOD func9_TOT_Reset_totalizer; \
	METHOD func9_TOT_Preset_totalizer; \
	MENU func9_TOT_Tab_s_mandatory_B; \
	MENU func9_TOT_Tab_m_mandatory_B

#define USE_FUNC9_TOT_OPTIONAL_BOTH \
	COLLECTION func9_TOT_HI_HI_ALM; \
	VARIABLE func9_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func9_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func9_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func9_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func9_TOT_HI_HI_ALM_Value; \
	MENU func9_TOT_HI_HI_ALM_page; \
	COMMAND func9_TOT_HI_HI_ALM_read; \
	COLLECTION func9_TOT_HI_ALM; \
	VARIABLE func9_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func9_TOT_HI_ALM_Alarm_State; \
	VARIABLE func9_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func9_TOT_HI_ALM_Subcode; \
	VARIABLE func9_TOT_HI_ALM_Value; \
	MENU func9_TOT_HI_ALM_page; \
	COMMAND func9_TOT_HI_ALM_read; \
	COLLECTION func9_TOT_LO_ALM; \
	VARIABLE func9_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func9_TOT_LO_ALM_Alarm_State; \
	VARIABLE func9_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func9_TOT_LO_ALM_Subcode; \
	VARIABLE func9_TOT_LO_ALM_Value; \
	MENU func9_TOT_LO_ALM_page; \
	COMMAND func9_TOT_LO_ALM_read; \
	COLLECTION func9_TOT_LO_LO_ALM; \
	VARIABLE func9_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func9_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func9_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func9_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func9_TOT_LO_LO_ALM_Value; \
	MENU func9_TOT_LO_LO_ALM_page; \
	COMMAND func9_TOT_LO_LO_ALM_read; \
	COLLECTION func9_TOT_VIEW_2; \
	MENU func9_TOT_VIEW_2_page; \
	COLLECTION func9_TOT_VIEW_3; \
	MENU func9_TOT_VIEW_3_page

#define USE_FUNC9_TOT_OPTIONAL_A \
	USE_FUNC9_TOT_OPTIONAL_BOTH; \
	VARIABLE func9_TOT_CHANNEL; \
	MENU func9_TOT_CHANNEL_page; \
	COMMAND func9_TOT_CHANNEL_read; \
	COMMAND func9_TOT_CHANNEL_write; \
	VARIABLE func9_TOT_SET_TOT; \
	MENU func9_TOT_SET_TOT_page; \
	COMMAND func9_TOT_SET_TOT_read; \
	COMMAND func9_TOT_SET_TOT_write; \
	VARIABLE func9_TOT_MODE_TOT; \
	MENU func9_TOT_MODE_TOT_page; \
	COMMAND func9_TOT_MODE_TOT_read; \
	COMMAND func9_TOT_MODE_TOT_write; \
	VARIABLE func9_TOT_FAIL_TOT; \
	MENU func9_TOT_FAIL_TOT_page; \
	COMMAND func9_TOT_FAIL_TOT_read; \
	COMMAND func9_TOT_FAIL_TOT_write; \
	VARIABLE func9_TOT_PRESET_TOT; \
	MENU func9_TOT_PRESET_TOT_page; \
	COMMAND func9_TOT_PRESET_TOT_read; \
	COMMAND func9_TOT_PRESET_TOT_write; \
	COLLECTION func9_TOT_VIEW_1; \
	MENU func9_TOT_VIEW_1_page; \
	MENU func9_TOT_Simple_Dialog_Optional_A

#define USE_FUNC9_TOT_OPTIONAL_B \
	USE_FUNC9_TOT_OPTIONAL_BOTH; \
	MENU func9_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC9_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func9_TOT_)
#define USE_FUNC9_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func9_TOT_)
#define USE_FUNC9_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func9_TOT_)
#define USE_FUNC9_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func9_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC10_TOT_MANDATORY_BOTH \
	BLOCK func10_TOT_block; \
	COLLECTION func10_TOT_BLOCK_OBJECT; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func10_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func10_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func10_TOT_BLOCK_OBJECT_page; \
	COMMAND func10_TOT_BLOCK_OBJECT_read; \
	VARIABLE func10_TOT_ST_REV; \
	MENU func10_TOT_ST_REV_page; \
	COMMAND func10_TOT_ST_REV_read; \
	VARIABLE func10_TOT_TAG_DESC; \
	MENU func10_TOT_TAG_DESC_page; \
	COMMAND func10_TOT_TAG_DESC_read; \
	COMMAND func10_TOT_TAG_DESC_write; \
	VARIABLE func10_TOT_STRATEGY; \
	MENU func10_TOT_STRATEGY_page; \
	COMMAND func10_TOT_STRATEGY_read; \
	COMMAND func10_TOT_STRATEGY_write; \
	VARIABLE func10_TOT_ALERT_KEY; \
	MENU func10_TOT_ALERT_KEY_page; \
	COMMAND func10_TOT_ALERT_KEY_read; \
	COMMAND func10_TOT_ALERT_KEY_write; \
	VARIABLE func10_TOT_TARGET_MODE; \
	MENU func10_TOT_TARGET_MODE_page; \
	COMMAND func10_TOT_TARGET_MODE_read; \
	COMMAND func10_TOT_TARGET_MODE_write; \
	COLLECTION func10_TOT_MODE_BLK; \
	VARIABLE func10_TOT_MODE_BLK_Actual; \
	VARIABLE func10_TOT_MODE_BLK_Permitted; \
	VARIABLE func10_TOT_MODE_BLK_Normal; \
	MENU func10_TOT_MODE_BLK_page; \
	COMMAND func10_TOT_MODE_BLK_read; \
	COLLECTION func10_TOT_ALARM_SUM; \
	VARIABLE func10_TOT_ALARM_SUM_Current; \
	VARIABLE func10_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func10_TOT_ALARM_SUM_Unreported; \
	VARIABLE func10_TOT_ALARM_SUM_Disabled; \
	MENU func10_TOT_ALARM_SUM_page; \
	COMMAND func10_TOT_ALARM_SUM_read; \
	COLLECTION func10_TOT_BATCH; \
	VARIABLE func10_TOT_BATCH_Batch_ID; \
	VARIABLE func10_TOT_BATCH_Rup; \
	VARIABLE func10_TOT_BATCH_Operation; \
	VARIABLE func10_TOT_BATCH_Phase; \
	MENU func10_TOT_BATCH_page; \
	COMMAND func10_TOT_BATCH_read; \
	COMMAND func10_TOT_BATCH_write; \
	COLLECTION func10_TOT_TOTAL; \
	VARIABLE func10_TOT_TOTAL_Value; \
	VARIABLE func10_TOT_TOTAL_Status_Condensed; \
	VARIABLE func10_TOT_TOTAL_Status_Quality; \
	VARIABLE func10_TOT_TOTAL_Status_Limit; \
	MENU func10_TOT_TOTAL_page; \
	COMMAND func10_TOT_TOTAL_read; \
	COMMAND func10_TOT_TOTAL_write; \
	VARIABLE func10_TOT_UNIT_TOT; \
	MENU func10_TOT_UNIT_TOT_page; \
	COMMAND func10_TOT_UNIT_TOT_read; \
	COMMAND func10_TOT_UNIT_TOT_write; \
	VARIABLE func10_TOT_ALARM_HYS; \
	MENU func10_TOT_ALARM_HYS_page; \
	COMMAND func10_TOT_ALARM_HYS_read; \
	COMMAND func10_TOT_ALARM_HYS_write; \
	VARIABLE func10_TOT_HI_HI_LIM; \
	MENU func10_TOT_HI_HI_LIM_page; \
	COMMAND func10_TOT_HI_HI_LIM_read; \
	COMMAND func10_TOT_HI_HI_LIM_write; \
	VARIABLE func10_TOT_HI_LIM; \
	MENU func10_TOT_HI_LIM_page; \
	COMMAND func10_TOT_HI_LIM_read; \
	COMMAND func10_TOT_HI_LIM_write; \
	VARIABLE func10_TOT_LO_LIM; \
	MENU func10_TOT_LO_LIM_page; \
	COMMAND func10_TOT_LO_LIM_read; \
	COMMAND func10_TOT_LO_LIM_write; \
	VARIABLE func10_TOT_LO_LO_LIM; \
	MENU func10_TOT_LO_LO_LIM_page; \
	COMMAND func10_TOT_LO_LO_LIM_read; \
	COMMAND func10_TOT_LO_LO_LIM_write; \
	UNIT func10_TOT_unit_1; \
	MENU func10_TOT_Display; \
	MENU func10_TOT_Display_out; \
	MENU func10_TOT_Tab_s_tot_limits

#define USE_FUNC10_TOT_MANDATORY_A \
	USE_FUNC10_TOT_MANDATORY_BOTH; \
	MENU func10_TOT_Simple_Dialog_Mandatory_A; \
	MENU func10_TOT_Tab_s_mandatory_A; \
	MENU func10_TOT_Tab_m_mandatory_A

#define USE_FUNC10_TOT_MANDATORY_B \
	USE_FUNC10_TOT_MANDATORY_BOTH; \
	VARIABLE func10_TOT_CHANNEL; \
	MENU func10_TOT_CHANNEL_page; \
	COMMAND func10_TOT_CHANNEL_read; \
	COMMAND func10_TOT_CHANNEL_write; \
	VARIABLE func10_TOT_SET_TOT; \
	MENU func10_TOT_SET_TOT_page; \
	COMMAND func10_TOT_SET_TOT_read; \
	COMMAND func10_TOT_SET_TOT_write; \
	VARIABLE func10_TOT_MODE_TOT; \
	MENU func10_TOT_MODE_TOT_page; \
	COMMAND func10_TOT_MODE_TOT_read; \
	COMMAND func10_TOT_MODE_TOT_write; \
	VARIABLE func10_TOT_FAIL_TOT; \
	MENU func10_TOT_FAIL_TOT_page; \
	COMMAND func10_TOT_FAIL_TOT_read; \
	COMMAND func10_TOT_FAIL_TOT_write; \
	VARIABLE func10_TOT_PRESET_TOT; \
	MENU func10_TOT_PRESET_TOT_page; \
	COMMAND func10_TOT_PRESET_TOT_read; \
	COMMAND func10_TOT_PRESET_TOT_write; \
	COLLECTION func10_TOT_VIEW_1; \
	MENU func10_TOT_VIEW_1_page; \
	MENU func10_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func10_TOT_unit_2; \
	MENU func10_TOT_Reset; \
	MENU func10_TOT_Reset_page; \
	METHOD func10_TOT_Reset_totalizer; \
	METHOD func10_TOT_Preset_totalizer; \
	MENU func10_TOT_Tab_s_mandatory_B; \
	MENU func10_TOT_Tab_m_mandatory_B

#define USE_FUNC10_TOT_OPTIONAL_BOTH \
	COLLECTION func10_TOT_HI_HI_ALM; \
	VARIABLE func10_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func10_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func10_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func10_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func10_TOT_HI_HI_ALM_Value; \
	MENU func10_TOT_HI_HI_ALM_page; \
	COMMAND func10_TOT_HI_HI_ALM_read; \
	COLLECTION func10_TOT_HI_ALM; \
	VARIABLE func10_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func10_TOT_HI_ALM_Alarm_State; \
	VARIABLE func10_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func10_TOT_HI_ALM_Subcode; \
	VARIABLE func10_TOT_HI_ALM_Value; \
	MENU func10_TOT_HI_ALM_page; \
	COMMAND func10_TOT_HI_ALM_read; \
	COLLECTION func10_TOT_LO_ALM; \
	VARIABLE func10_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func10_TOT_LO_ALM_Alarm_State; \
	VARIABLE func10_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func10_TOT_LO_ALM_Subcode; \
	VARIABLE func10_TOT_LO_ALM_Value; \
	MENU func10_TOT_LO_ALM_page; \
	COMMAND func10_TOT_LO_ALM_read; \
	COLLECTION func10_TOT_LO_LO_ALM; \
	VARIABLE func10_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func10_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func10_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func10_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func10_TOT_LO_LO_ALM_Value; \
	MENU func10_TOT_LO_LO_ALM_page; \
	COMMAND func10_TOT_LO_LO_ALM_read; \
	COLLECTION func10_TOT_VIEW_2; \
	MENU func10_TOT_VIEW_2_page; \
	COLLECTION func10_TOT_VIEW_3; \
	MENU func10_TOT_VIEW_3_page

#define USE_FUNC10_TOT_OPTIONAL_A \
	USE_FUNC10_TOT_OPTIONAL_BOTH; \
	VARIABLE func10_TOT_CHANNEL; \
	MENU func10_TOT_CHANNEL_page; \
	COMMAND func10_TOT_CHANNEL_read; \
	COMMAND func10_TOT_CHANNEL_write; \
	VARIABLE func10_TOT_SET_TOT; \
	MENU func10_TOT_SET_TOT_page; \
	COMMAND func10_TOT_SET_TOT_read; \
	COMMAND func10_TOT_SET_TOT_write; \
	VARIABLE func10_TOT_MODE_TOT; \
	MENU func10_TOT_MODE_TOT_page; \
	COMMAND func10_TOT_MODE_TOT_read; \
	COMMAND func10_TOT_MODE_TOT_write; \
	VARIABLE func10_TOT_FAIL_TOT; \
	MENU func10_TOT_FAIL_TOT_page; \
	COMMAND func10_TOT_FAIL_TOT_read; \
	COMMAND func10_TOT_FAIL_TOT_write; \
	VARIABLE func10_TOT_PRESET_TOT; \
	MENU func10_TOT_PRESET_TOT_page; \
	COMMAND func10_TOT_PRESET_TOT_read; \
	COMMAND func10_TOT_PRESET_TOT_write; \
	COLLECTION func10_TOT_VIEW_1; \
	MENU func10_TOT_VIEW_1_page; \
	MENU func10_TOT_Simple_Dialog_Optional_A

#define USE_FUNC10_TOT_OPTIONAL_B \
	USE_FUNC10_TOT_OPTIONAL_BOTH; \
	MENU func10_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC10_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func10_TOT_)
#define USE_FUNC10_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func10_TOT_)
#define USE_FUNC10_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func10_TOT_)
#define USE_FUNC10_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func10_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC11_TOT_MANDATORY_BOTH \
	BLOCK func11_TOT_block; \
	COLLECTION func11_TOT_BLOCK_OBJECT; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func11_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func11_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func11_TOT_BLOCK_OBJECT_page; \
	COMMAND func11_TOT_BLOCK_OBJECT_read; \
	VARIABLE func11_TOT_ST_REV; \
	MENU func11_TOT_ST_REV_page; \
	COMMAND func11_TOT_ST_REV_read; \
	VARIABLE func11_TOT_TAG_DESC; \
	MENU func11_TOT_TAG_DESC_page; \
	COMMAND func11_TOT_TAG_DESC_read; \
	COMMAND func11_TOT_TAG_DESC_write; \
	VARIABLE func11_TOT_STRATEGY; \
	MENU func11_TOT_STRATEGY_page; \
	COMMAND func11_TOT_STRATEGY_read; \
	COMMAND func11_TOT_STRATEGY_write; \
	VARIABLE func11_TOT_ALERT_KEY; \
	MENU func11_TOT_ALERT_KEY_page; \
	COMMAND func11_TOT_ALERT_KEY_read; \
	COMMAND func11_TOT_ALERT_KEY_write; \
	VARIABLE func11_TOT_TARGET_MODE; \
	MENU func11_TOT_TARGET_MODE_page; \
	COMMAND func11_TOT_TARGET_MODE_read; \
	COMMAND func11_TOT_TARGET_MODE_write; \
	COLLECTION func11_TOT_MODE_BLK; \
	VARIABLE func11_TOT_MODE_BLK_Actual; \
	VARIABLE func11_TOT_MODE_BLK_Permitted; \
	VARIABLE func11_TOT_MODE_BLK_Normal; \
	MENU func11_TOT_MODE_BLK_page; \
	COMMAND func11_TOT_MODE_BLK_read; \
	COLLECTION func11_TOT_ALARM_SUM; \
	VARIABLE func11_TOT_ALARM_SUM_Current; \
	VARIABLE func11_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func11_TOT_ALARM_SUM_Unreported; \
	VARIABLE func11_TOT_ALARM_SUM_Disabled; \
	MENU func11_TOT_ALARM_SUM_page; \
	COMMAND func11_TOT_ALARM_SUM_read; \
	COLLECTION func11_TOT_BATCH; \
	VARIABLE func11_TOT_BATCH_Batch_ID; \
	VARIABLE func11_TOT_BATCH_Rup; \
	VARIABLE func11_TOT_BATCH_Operation; \
	VARIABLE func11_TOT_BATCH_Phase; \
	MENU func11_TOT_BATCH_page; \
	COMMAND func11_TOT_BATCH_read; \
	COMMAND func11_TOT_BATCH_write; \
	COLLECTION func11_TOT_TOTAL; \
	VARIABLE func11_TOT_TOTAL_Value; \
	VARIABLE func11_TOT_TOTAL_Status_Condensed; \
	VARIABLE func11_TOT_TOTAL_Status_Quality; \
	VARIABLE func11_TOT_TOTAL_Status_Limit; \
	MENU func11_TOT_TOTAL_page; \
	COMMAND func11_TOT_TOTAL_read; \
	COMMAND func11_TOT_TOTAL_write; \
	VARIABLE func11_TOT_UNIT_TOT; \
	MENU func11_TOT_UNIT_TOT_page; \
	COMMAND func11_TOT_UNIT_TOT_read; \
	COMMAND func11_TOT_UNIT_TOT_write; \
	VARIABLE func11_TOT_ALARM_HYS; \
	MENU func11_TOT_ALARM_HYS_page; \
	COMMAND func11_TOT_ALARM_HYS_read; \
	COMMAND func11_TOT_ALARM_HYS_write; \
	VARIABLE func11_TOT_HI_HI_LIM; \
	MENU func11_TOT_HI_HI_LIM_page; \
	COMMAND func11_TOT_HI_HI_LIM_read; \
	COMMAND func11_TOT_HI_HI_LIM_write; \
	VARIABLE func11_TOT_HI_LIM; \
	MENU func11_TOT_HI_LIM_page; \
	COMMAND func11_TOT_HI_LIM_read; \
	COMMAND func11_TOT_HI_LIM_write; \
	VARIABLE func11_TOT_LO_LIM; \
	MENU func11_TOT_LO_LIM_page; \
	COMMAND func11_TOT_LO_LIM_read; \
	COMMAND func11_TOT_LO_LIM_write; \
	VARIABLE func11_TOT_LO_LO_LIM; \
	MENU func11_TOT_LO_LO_LIM_page; \
	COMMAND func11_TOT_LO_LO_LIM_read; \
	COMMAND func11_TOT_LO_LO_LIM_write; \
	UNIT func11_TOT_unit_1; \
	MENU func11_TOT_Display; \
	MENU func11_TOT_Display_out; \
	MENU func11_TOT_Tab_s_tot_limits

#define USE_FUNC11_TOT_MANDATORY_A \
	USE_FUNC11_TOT_MANDATORY_BOTH; \
	MENU func11_TOT_Simple_Dialog_Mandatory_A; \
	MENU func11_TOT_Tab_s_mandatory_A; \
	MENU func11_TOT_Tab_m_mandatory_A

#define USE_FUNC11_TOT_MANDATORY_B \
	USE_FUNC11_TOT_MANDATORY_BOTH; \
	VARIABLE func11_TOT_CHANNEL; \
	MENU func11_TOT_CHANNEL_page; \
	COMMAND func11_TOT_CHANNEL_read; \
	COMMAND func11_TOT_CHANNEL_write; \
	VARIABLE func11_TOT_SET_TOT; \
	MENU func11_TOT_SET_TOT_page; \
	COMMAND func11_TOT_SET_TOT_read; \
	COMMAND func11_TOT_SET_TOT_write; \
	VARIABLE func11_TOT_MODE_TOT; \
	MENU func11_TOT_MODE_TOT_page; \
	COMMAND func11_TOT_MODE_TOT_read; \
	COMMAND func11_TOT_MODE_TOT_write; \
	VARIABLE func11_TOT_FAIL_TOT; \
	MENU func11_TOT_FAIL_TOT_page; \
	COMMAND func11_TOT_FAIL_TOT_read; \
	COMMAND func11_TOT_FAIL_TOT_write; \
	VARIABLE func11_TOT_PRESET_TOT; \
	MENU func11_TOT_PRESET_TOT_page; \
	COMMAND func11_TOT_PRESET_TOT_read; \
	COMMAND func11_TOT_PRESET_TOT_write; \
	COLLECTION func11_TOT_VIEW_1; \
	MENU func11_TOT_VIEW_1_page; \
	MENU func11_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func11_TOT_unit_2; \
	MENU func11_TOT_Reset; \
	MENU func11_TOT_Reset_page; \
	METHOD func11_TOT_Reset_totalizer; \
	METHOD func11_TOT_Preset_totalizer; \
	MENU func11_TOT_Tab_s_mandatory_B; \
	MENU func11_TOT_Tab_m_mandatory_B

#define USE_FUNC11_TOT_OPTIONAL_BOTH \
	COLLECTION func11_TOT_HI_HI_ALM; \
	VARIABLE func11_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func11_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func11_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func11_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func11_TOT_HI_HI_ALM_Value; \
	MENU func11_TOT_HI_HI_ALM_page; \
	COMMAND func11_TOT_HI_HI_ALM_read; \
	COLLECTION func11_TOT_HI_ALM; \
	VARIABLE func11_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func11_TOT_HI_ALM_Alarm_State; \
	VARIABLE func11_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func11_TOT_HI_ALM_Subcode; \
	VARIABLE func11_TOT_HI_ALM_Value; \
	MENU func11_TOT_HI_ALM_page; \
	COMMAND func11_TOT_HI_ALM_read; \
	COLLECTION func11_TOT_LO_ALM; \
	VARIABLE func11_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func11_TOT_LO_ALM_Alarm_State; \
	VARIABLE func11_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func11_TOT_LO_ALM_Subcode; \
	VARIABLE func11_TOT_LO_ALM_Value; \
	MENU func11_TOT_LO_ALM_page; \
	COMMAND func11_TOT_LO_ALM_read; \
	COLLECTION func11_TOT_LO_LO_ALM; \
	VARIABLE func11_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func11_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func11_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func11_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func11_TOT_LO_LO_ALM_Value; \
	MENU func11_TOT_LO_LO_ALM_page; \
	COMMAND func11_TOT_LO_LO_ALM_read; \
	COLLECTION func11_TOT_VIEW_2; \
	MENU func11_TOT_VIEW_2_page; \
	COLLECTION func11_TOT_VIEW_3; \
	MENU func11_TOT_VIEW_3_page

#define USE_FUNC11_TOT_OPTIONAL_A \
	USE_FUNC11_TOT_OPTIONAL_BOTH; \
	VARIABLE func11_TOT_CHANNEL; \
	MENU func11_TOT_CHANNEL_page; \
	COMMAND func11_TOT_CHANNEL_read; \
	COMMAND func11_TOT_CHANNEL_write; \
	VARIABLE func11_TOT_SET_TOT; \
	MENU func11_TOT_SET_TOT_page; \
	COMMAND func11_TOT_SET_TOT_read; \
	COMMAND func11_TOT_SET_TOT_write; \
	VARIABLE func11_TOT_MODE_TOT; \
	MENU func11_TOT_MODE_TOT_page; \
	COMMAND func11_TOT_MODE_TOT_read; \
	COMMAND func11_TOT_MODE_TOT_write; \
	VARIABLE func11_TOT_FAIL_TOT; \
	MENU func11_TOT_FAIL_TOT_page; \
	COMMAND func11_TOT_FAIL_TOT_read; \
	COMMAND func11_TOT_FAIL_TOT_write; \
	VARIABLE func11_TOT_PRESET_TOT; \
	MENU func11_TOT_PRESET_TOT_page; \
	COMMAND func11_TOT_PRESET_TOT_read; \
	COMMAND func11_TOT_PRESET_TOT_write; \
	COLLECTION func11_TOT_VIEW_1; \
	MENU func11_TOT_VIEW_1_page; \
	MENU func11_TOT_Simple_Dialog_Optional_A

#define USE_FUNC11_TOT_OPTIONAL_B \
	USE_FUNC11_TOT_OPTIONAL_BOTH; \
	MENU func11_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC11_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func11_TOT_)
#define USE_FUNC11_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func11_TOT_)
#define USE_FUNC11_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func11_TOT_)
#define USE_FUNC11_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func11_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC12_TOT_MANDATORY_BOTH \
	BLOCK func12_TOT_block; \
	COLLECTION func12_TOT_BLOCK_OBJECT; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func12_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func12_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func12_TOT_BLOCK_OBJECT_page; \
	COMMAND func12_TOT_BLOCK_OBJECT_read; \
	VARIABLE func12_TOT_ST_REV; \
	MENU func12_TOT_ST_REV_page; \
	COMMAND func12_TOT_ST_REV_read; \
	VARIABLE func12_TOT_TAG_DESC; \
	MENU func12_TOT_TAG_DESC_page; \
	COMMAND func12_TOT_TAG_DESC_read; \
	COMMAND func12_TOT_TAG_DESC_write; \
	VARIABLE func12_TOT_STRATEGY; \
	MENU func12_TOT_STRATEGY_page; \
	COMMAND func12_TOT_STRATEGY_read; \
	COMMAND func12_TOT_STRATEGY_write; \
	VARIABLE func12_TOT_ALERT_KEY; \
	MENU func12_TOT_ALERT_KEY_page; \
	COMMAND func12_TOT_ALERT_KEY_read; \
	COMMAND func12_TOT_ALERT_KEY_write; \
	VARIABLE func12_TOT_TARGET_MODE; \
	MENU func12_TOT_TARGET_MODE_page; \
	COMMAND func12_TOT_TARGET_MODE_read; \
	COMMAND func12_TOT_TARGET_MODE_write; \
	COLLECTION func12_TOT_MODE_BLK; \
	VARIABLE func12_TOT_MODE_BLK_Actual; \
	VARIABLE func12_TOT_MODE_BLK_Permitted; \
	VARIABLE func12_TOT_MODE_BLK_Normal; \
	MENU func12_TOT_MODE_BLK_page; \
	COMMAND func12_TOT_MODE_BLK_read; \
	COLLECTION func12_TOT_ALARM_SUM; \
	VARIABLE func12_TOT_ALARM_SUM_Current; \
	VARIABLE func12_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func12_TOT_ALARM_SUM_Unreported; \
	VARIABLE func12_TOT_ALARM_SUM_Disabled; \
	MENU func12_TOT_ALARM_SUM_page; \
	COMMAND func12_TOT_ALARM_SUM_read; \
	COLLECTION func12_TOT_BATCH; \
	VARIABLE func12_TOT_BATCH_Batch_ID; \
	VARIABLE func12_TOT_BATCH_Rup; \
	VARIABLE func12_TOT_BATCH_Operation; \
	VARIABLE func12_TOT_BATCH_Phase; \
	MENU func12_TOT_BATCH_page; \
	COMMAND func12_TOT_BATCH_read; \
	COMMAND func12_TOT_BATCH_write; \
	COLLECTION func12_TOT_TOTAL; \
	VARIABLE func12_TOT_TOTAL_Value; \
	VARIABLE func12_TOT_TOTAL_Status_Condensed; \
	VARIABLE func12_TOT_TOTAL_Status_Quality; \
	VARIABLE func12_TOT_TOTAL_Status_Limit; \
	MENU func12_TOT_TOTAL_page; \
	COMMAND func12_TOT_TOTAL_read; \
	COMMAND func12_TOT_TOTAL_write; \
	VARIABLE func12_TOT_UNIT_TOT; \
	MENU func12_TOT_UNIT_TOT_page; \
	COMMAND func12_TOT_UNIT_TOT_read; \
	COMMAND func12_TOT_UNIT_TOT_write; \
	VARIABLE func12_TOT_ALARM_HYS; \
	MENU func12_TOT_ALARM_HYS_page; \
	COMMAND func12_TOT_ALARM_HYS_read; \
	COMMAND func12_TOT_ALARM_HYS_write; \
	VARIABLE func12_TOT_HI_HI_LIM; \
	MENU func12_TOT_HI_HI_LIM_page; \
	COMMAND func12_TOT_HI_HI_LIM_read; \
	COMMAND func12_TOT_HI_HI_LIM_write; \
	VARIABLE func12_TOT_HI_LIM; \
	MENU func12_TOT_HI_LIM_page; \
	COMMAND func12_TOT_HI_LIM_read; \
	COMMAND func12_TOT_HI_LIM_write; \
	VARIABLE func12_TOT_LO_LIM; \
	MENU func12_TOT_LO_LIM_page; \
	COMMAND func12_TOT_LO_LIM_read; \
	COMMAND func12_TOT_LO_LIM_write; \
	VARIABLE func12_TOT_LO_LO_LIM; \
	MENU func12_TOT_LO_LO_LIM_page; \
	COMMAND func12_TOT_LO_LO_LIM_read; \
	COMMAND func12_TOT_LO_LO_LIM_write; \
	UNIT func12_TOT_unit_1; \
	MENU func12_TOT_Display; \
	MENU func12_TOT_Display_out; \
	MENU func12_TOT_Tab_s_tot_limits

#define USE_FUNC12_TOT_MANDATORY_A \
	USE_FUNC12_TOT_MANDATORY_BOTH; \
	MENU func12_TOT_Simple_Dialog_Mandatory_A; \
	MENU func12_TOT_Tab_s_mandatory_A; \
	MENU func12_TOT_Tab_m_mandatory_A

#define USE_FUNC12_TOT_MANDATORY_B \
	USE_FUNC12_TOT_MANDATORY_BOTH; \
	VARIABLE func12_TOT_CHANNEL; \
	MENU func12_TOT_CHANNEL_page; \
	COMMAND func12_TOT_CHANNEL_read; \
	COMMAND func12_TOT_CHANNEL_write; \
	VARIABLE func12_TOT_SET_TOT; \
	MENU func12_TOT_SET_TOT_page; \
	COMMAND func12_TOT_SET_TOT_read; \
	COMMAND func12_TOT_SET_TOT_write; \
	VARIABLE func12_TOT_MODE_TOT; \
	MENU func12_TOT_MODE_TOT_page; \
	COMMAND func12_TOT_MODE_TOT_read; \
	COMMAND func12_TOT_MODE_TOT_write; \
	VARIABLE func12_TOT_FAIL_TOT; \
	MENU func12_TOT_FAIL_TOT_page; \
	COMMAND func12_TOT_FAIL_TOT_read; \
	COMMAND func12_TOT_FAIL_TOT_write; \
	VARIABLE func12_TOT_PRESET_TOT; \
	MENU func12_TOT_PRESET_TOT_page; \
	COMMAND func12_TOT_PRESET_TOT_read; \
	COMMAND func12_TOT_PRESET_TOT_write; \
	COLLECTION func12_TOT_VIEW_1; \
	MENU func12_TOT_VIEW_1_page; \
	MENU func12_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func12_TOT_unit_2; \
	MENU func12_TOT_Reset; \
	MENU func12_TOT_Reset_page; \
	METHOD func12_TOT_Reset_totalizer; \
	METHOD func12_TOT_Preset_totalizer; \
	MENU func12_TOT_Tab_s_mandatory_B; \
	MENU func12_TOT_Tab_m_mandatory_B

#define USE_FUNC12_TOT_OPTIONAL_BOTH \
	COLLECTION func12_TOT_HI_HI_ALM; \
	VARIABLE func12_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func12_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func12_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func12_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func12_TOT_HI_HI_ALM_Value; \
	MENU func12_TOT_HI_HI_ALM_page; \
	COMMAND func12_TOT_HI_HI_ALM_read; \
	COLLECTION func12_TOT_HI_ALM; \
	VARIABLE func12_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func12_TOT_HI_ALM_Alarm_State; \
	VARIABLE func12_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func12_TOT_HI_ALM_Subcode; \
	VARIABLE func12_TOT_HI_ALM_Value; \
	MENU func12_TOT_HI_ALM_page; \
	COMMAND func12_TOT_HI_ALM_read; \
	COLLECTION func12_TOT_LO_ALM; \
	VARIABLE func12_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func12_TOT_LO_ALM_Alarm_State; \
	VARIABLE func12_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func12_TOT_LO_ALM_Subcode; \
	VARIABLE func12_TOT_LO_ALM_Value; \
	MENU func12_TOT_LO_ALM_page; \
	COMMAND func12_TOT_LO_ALM_read; \
	COLLECTION func12_TOT_LO_LO_ALM; \
	VARIABLE func12_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func12_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func12_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func12_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func12_TOT_LO_LO_ALM_Value; \
	MENU func12_TOT_LO_LO_ALM_page; \
	COMMAND func12_TOT_LO_LO_ALM_read; \
	COLLECTION func12_TOT_VIEW_2; \
	MENU func12_TOT_VIEW_2_page; \
	COLLECTION func12_TOT_VIEW_3; \
	MENU func12_TOT_VIEW_3_page

#define USE_FUNC12_TOT_OPTIONAL_A \
	USE_FUNC12_TOT_OPTIONAL_BOTH; \
	VARIABLE func12_TOT_CHANNEL; \
	MENU func12_TOT_CHANNEL_page; \
	COMMAND func12_TOT_CHANNEL_read; \
	COMMAND func12_TOT_CHANNEL_write; \
	VARIABLE func12_TOT_SET_TOT; \
	MENU func12_TOT_SET_TOT_page; \
	COMMAND func12_TOT_SET_TOT_read; \
	COMMAND func12_TOT_SET_TOT_write; \
	VARIABLE func12_TOT_MODE_TOT; \
	MENU func12_TOT_MODE_TOT_page; \
	COMMAND func12_TOT_MODE_TOT_read; \
	COMMAND func12_TOT_MODE_TOT_write; \
	VARIABLE func12_TOT_FAIL_TOT; \
	MENU func12_TOT_FAIL_TOT_page; \
	COMMAND func12_TOT_FAIL_TOT_read; \
	COMMAND func12_TOT_FAIL_TOT_write; \
	VARIABLE func12_TOT_PRESET_TOT; \
	MENU func12_TOT_PRESET_TOT_page; \
	COMMAND func12_TOT_PRESET_TOT_read; \
	COMMAND func12_TOT_PRESET_TOT_write; \
	COLLECTION func12_TOT_VIEW_1; \
	MENU func12_TOT_VIEW_1_page; \
	MENU func12_TOT_Simple_Dialog_Optional_A

#define USE_FUNC12_TOT_OPTIONAL_B \
	USE_FUNC12_TOT_OPTIONAL_BOTH; \
	MENU func12_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC12_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func12_TOT_)
#define USE_FUNC12_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func12_TOT_)
#define USE_FUNC12_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func12_TOT_)
#define USE_FUNC12_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func12_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC13_TOT_MANDATORY_BOTH \
	BLOCK func13_TOT_block; \
	COLLECTION func13_TOT_BLOCK_OBJECT; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func13_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func13_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func13_TOT_BLOCK_OBJECT_page; \
	COMMAND func13_TOT_BLOCK_OBJECT_read; \
	VARIABLE func13_TOT_ST_REV; \
	MENU func13_TOT_ST_REV_page; \
	COMMAND func13_TOT_ST_REV_read; \
	VARIABLE func13_TOT_TAG_DESC; \
	MENU func13_TOT_TAG_DESC_page; \
	COMMAND func13_TOT_TAG_DESC_read; \
	COMMAND func13_TOT_TAG_DESC_write; \
	VARIABLE func13_TOT_STRATEGY; \
	MENU func13_TOT_STRATEGY_page; \
	COMMAND func13_TOT_STRATEGY_read; \
	COMMAND func13_TOT_STRATEGY_write; \
	VARIABLE func13_TOT_ALERT_KEY; \
	MENU func13_TOT_ALERT_KEY_page; \
	COMMAND func13_TOT_ALERT_KEY_read; \
	COMMAND func13_TOT_ALERT_KEY_write; \
	VARIABLE func13_TOT_TARGET_MODE; \
	MENU func13_TOT_TARGET_MODE_page; \
	COMMAND func13_TOT_TARGET_MODE_read; \
	COMMAND func13_TOT_TARGET_MODE_write; \
	COLLECTION func13_TOT_MODE_BLK; \
	VARIABLE func13_TOT_MODE_BLK_Actual; \
	VARIABLE func13_TOT_MODE_BLK_Permitted; \
	VARIABLE func13_TOT_MODE_BLK_Normal; \
	MENU func13_TOT_MODE_BLK_page; \
	COMMAND func13_TOT_MODE_BLK_read; \
	COLLECTION func13_TOT_ALARM_SUM; \
	VARIABLE func13_TOT_ALARM_SUM_Current; \
	VARIABLE func13_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func13_TOT_ALARM_SUM_Unreported; \
	VARIABLE func13_TOT_ALARM_SUM_Disabled; \
	MENU func13_TOT_ALARM_SUM_page; \
	COMMAND func13_TOT_ALARM_SUM_read; \
	COLLECTION func13_TOT_BATCH; \
	VARIABLE func13_TOT_BATCH_Batch_ID; \
	VARIABLE func13_TOT_BATCH_Rup; \
	VARIABLE func13_TOT_BATCH_Operation; \
	VARIABLE func13_TOT_BATCH_Phase; \
	MENU func13_TOT_BATCH_page; \
	COMMAND func13_TOT_BATCH_read; \
	COMMAND func13_TOT_BATCH_write; \
	COLLECTION func13_TOT_TOTAL; \
	VARIABLE func13_TOT_TOTAL_Value; \
	VARIABLE func13_TOT_TOTAL_Status_Condensed; \
	VARIABLE func13_TOT_TOTAL_Status_Quality; \
	VARIABLE func13_TOT_TOTAL_Status_Limit; \
	MENU func13_TOT_TOTAL_page; \
	COMMAND func13_TOT_TOTAL_read; \
	COMMAND func13_TOT_TOTAL_write; \
	VARIABLE func13_TOT_UNIT_TOT; \
	MENU func13_TOT_UNIT_TOT_page; \
	COMMAND func13_TOT_UNIT_TOT_read; \
	COMMAND func13_TOT_UNIT_TOT_write; \
	VARIABLE func13_TOT_ALARM_HYS; \
	MENU func13_TOT_ALARM_HYS_page; \
	COMMAND func13_TOT_ALARM_HYS_read; \
	COMMAND func13_TOT_ALARM_HYS_write; \
	VARIABLE func13_TOT_HI_HI_LIM; \
	MENU func13_TOT_HI_HI_LIM_page; \
	COMMAND func13_TOT_HI_HI_LIM_read; \
	COMMAND func13_TOT_HI_HI_LIM_write; \
	VARIABLE func13_TOT_HI_LIM; \
	MENU func13_TOT_HI_LIM_page; \
	COMMAND func13_TOT_HI_LIM_read; \
	COMMAND func13_TOT_HI_LIM_write; \
	VARIABLE func13_TOT_LO_LIM; \
	MENU func13_TOT_LO_LIM_page; \
	COMMAND func13_TOT_LO_LIM_read; \
	COMMAND func13_TOT_LO_LIM_write; \
	VARIABLE func13_TOT_LO_LO_LIM; \
	MENU func13_TOT_LO_LO_LIM_page; \
	COMMAND func13_TOT_LO_LO_LIM_read; \
	COMMAND func13_TOT_LO_LO_LIM_write; \
	UNIT func13_TOT_unit_1; \
	MENU func13_TOT_Display; \
	MENU func13_TOT_Display_out; \
	MENU func13_TOT_Tab_s_tot_limits

#define USE_FUNC13_TOT_MANDATORY_A \
	USE_FUNC13_TOT_MANDATORY_BOTH; \
	MENU func13_TOT_Simple_Dialog_Mandatory_A; \
	MENU func13_TOT_Tab_s_mandatory_A; \
	MENU func13_TOT_Tab_m_mandatory_A

#define USE_FUNC13_TOT_MANDATORY_B \
	USE_FUNC13_TOT_MANDATORY_BOTH; \
	VARIABLE func13_TOT_CHANNEL; \
	MENU func13_TOT_CHANNEL_page; \
	COMMAND func13_TOT_CHANNEL_read; \
	COMMAND func13_TOT_CHANNEL_write; \
	VARIABLE func13_TOT_SET_TOT; \
	MENU func13_TOT_SET_TOT_page; \
	COMMAND func13_TOT_SET_TOT_read; \
	COMMAND func13_TOT_SET_TOT_write; \
	VARIABLE func13_TOT_MODE_TOT; \
	MENU func13_TOT_MODE_TOT_page; \
	COMMAND func13_TOT_MODE_TOT_read; \
	COMMAND func13_TOT_MODE_TOT_write; \
	VARIABLE func13_TOT_FAIL_TOT; \
	MENU func13_TOT_FAIL_TOT_page; \
	COMMAND func13_TOT_FAIL_TOT_read; \
	COMMAND func13_TOT_FAIL_TOT_write; \
	VARIABLE func13_TOT_PRESET_TOT; \
	MENU func13_TOT_PRESET_TOT_page; \
	COMMAND func13_TOT_PRESET_TOT_read; \
	COMMAND func13_TOT_PRESET_TOT_write; \
	COLLECTION func13_TOT_VIEW_1; \
	MENU func13_TOT_VIEW_1_page; \
	MENU func13_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func13_TOT_unit_2; \
	MENU func13_TOT_Reset; \
	MENU func13_TOT_Reset_page; \
	METHOD func13_TOT_Reset_totalizer; \
	METHOD func13_TOT_Preset_totalizer; \
	MENU func13_TOT_Tab_s_mandatory_B; \
	MENU func13_TOT_Tab_m_mandatory_B

#define USE_FUNC13_TOT_OPTIONAL_BOTH \
	COLLECTION func13_TOT_HI_HI_ALM; \
	VARIABLE func13_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func13_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func13_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func13_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func13_TOT_HI_HI_ALM_Value; \
	MENU func13_TOT_HI_HI_ALM_page; \
	COMMAND func13_TOT_HI_HI_ALM_read; \
	COLLECTION func13_TOT_HI_ALM; \
	VARIABLE func13_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func13_TOT_HI_ALM_Alarm_State; \
	VARIABLE func13_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func13_TOT_HI_ALM_Subcode; \
	VARIABLE func13_TOT_HI_ALM_Value; \
	MENU func13_TOT_HI_ALM_page; \
	COMMAND func13_TOT_HI_ALM_read; \
	COLLECTION func13_TOT_LO_ALM; \
	VARIABLE func13_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func13_TOT_LO_ALM_Alarm_State; \
	VARIABLE func13_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func13_TOT_LO_ALM_Subcode; \
	VARIABLE func13_TOT_LO_ALM_Value; \
	MENU func13_TOT_LO_ALM_page; \
	COMMAND func13_TOT_LO_ALM_read; \
	COLLECTION func13_TOT_LO_LO_ALM; \
	VARIABLE func13_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func13_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func13_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func13_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func13_TOT_LO_LO_ALM_Value; \
	MENU func13_TOT_LO_LO_ALM_page; \
	COMMAND func13_TOT_LO_LO_ALM_read; \
	COLLECTION func13_TOT_VIEW_2; \
	MENU func13_TOT_VIEW_2_page; \
	COLLECTION func13_TOT_VIEW_3; \
	MENU func13_TOT_VIEW_3_page

#define USE_FUNC13_TOT_OPTIONAL_A \
	USE_FUNC13_TOT_OPTIONAL_BOTH; \
	VARIABLE func13_TOT_CHANNEL; \
	MENU func13_TOT_CHANNEL_page; \
	COMMAND func13_TOT_CHANNEL_read; \
	COMMAND func13_TOT_CHANNEL_write; \
	VARIABLE func13_TOT_SET_TOT; \
	MENU func13_TOT_SET_TOT_page; \
	COMMAND func13_TOT_SET_TOT_read; \
	COMMAND func13_TOT_SET_TOT_write; \
	VARIABLE func13_TOT_MODE_TOT; \
	MENU func13_TOT_MODE_TOT_page; \
	COMMAND func13_TOT_MODE_TOT_read; \
	COMMAND func13_TOT_MODE_TOT_write; \
	VARIABLE func13_TOT_FAIL_TOT; \
	MENU func13_TOT_FAIL_TOT_page; \
	COMMAND func13_TOT_FAIL_TOT_read; \
	COMMAND func13_TOT_FAIL_TOT_write; \
	VARIABLE func13_TOT_PRESET_TOT; \
	MENU func13_TOT_PRESET_TOT_page; \
	COMMAND func13_TOT_PRESET_TOT_read; \
	COMMAND func13_TOT_PRESET_TOT_write; \
	COLLECTION func13_TOT_VIEW_1; \
	MENU func13_TOT_VIEW_1_page; \
	MENU func13_TOT_Simple_Dialog_Optional_A

#define USE_FUNC13_TOT_OPTIONAL_B \
	USE_FUNC13_TOT_OPTIONAL_BOTH; \
	MENU func13_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC13_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func13_TOT_)
#define USE_FUNC13_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func13_TOT_)
#define USE_FUNC13_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func13_TOT_)
#define USE_FUNC13_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func13_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC14_TOT_MANDATORY_BOTH \
	BLOCK func14_TOT_block; \
	COLLECTION func14_TOT_BLOCK_OBJECT; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func14_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func14_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func14_TOT_BLOCK_OBJECT_page; \
	COMMAND func14_TOT_BLOCK_OBJECT_read; \
	VARIABLE func14_TOT_ST_REV; \
	MENU func14_TOT_ST_REV_page; \
	COMMAND func14_TOT_ST_REV_read; \
	VARIABLE func14_TOT_TAG_DESC; \
	MENU func14_TOT_TAG_DESC_page; \
	COMMAND func14_TOT_TAG_DESC_read; \
	COMMAND func14_TOT_TAG_DESC_write; \
	VARIABLE func14_TOT_STRATEGY; \
	MENU func14_TOT_STRATEGY_page; \
	COMMAND func14_TOT_STRATEGY_read; \
	COMMAND func14_TOT_STRATEGY_write; \
	VARIABLE func14_TOT_ALERT_KEY; \
	MENU func14_TOT_ALERT_KEY_page; \
	COMMAND func14_TOT_ALERT_KEY_read; \
	COMMAND func14_TOT_ALERT_KEY_write; \
	VARIABLE func14_TOT_TARGET_MODE; \
	MENU func14_TOT_TARGET_MODE_page; \
	COMMAND func14_TOT_TARGET_MODE_read; \
	COMMAND func14_TOT_TARGET_MODE_write; \
	COLLECTION func14_TOT_MODE_BLK; \
	VARIABLE func14_TOT_MODE_BLK_Actual; \
	VARIABLE func14_TOT_MODE_BLK_Permitted; \
	VARIABLE func14_TOT_MODE_BLK_Normal; \
	MENU func14_TOT_MODE_BLK_page; \
	COMMAND func14_TOT_MODE_BLK_read; \
	COLLECTION func14_TOT_ALARM_SUM; \
	VARIABLE func14_TOT_ALARM_SUM_Current; \
	VARIABLE func14_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func14_TOT_ALARM_SUM_Unreported; \
	VARIABLE func14_TOT_ALARM_SUM_Disabled; \
	MENU func14_TOT_ALARM_SUM_page; \
	COMMAND func14_TOT_ALARM_SUM_read; \
	COLLECTION func14_TOT_BATCH; \
	VARIABLE func14_TOT_BATCH_Batch_ID; \
	VARIABLE func14_TOT_BATCH_Rup; \
	VARIABLE func14_TOT_BATCH_Operation; \
	VARIABLE func14_TOT_BATCH_Phase; \
	MENU func14_TOT_BATCH_page; \
	COMMAND func14_TOT_BATCH_read; \
	COMMAND func14_TOT_BATCH_write; \
	COLLECTION func14_TOT_TOTAL; \
	VARIABLE func14_TOT_TOTAL_Value; \
	VARIABLE func14_TOT_TOTAL_Status_Condensed; \
	VARIABLE func14_TOT_TOTAL_Status_Quality; \
	VARIABLE func14_TOT_TOTAL_Status_Limit; \
	MENU func14_TOT_TOTAL_page; \
	COMMAND func14_TOT_TOTAL_read; \
	COMMAND func14_TOT_TOTAL_write; \
	VARIABLE func14_TOT_UNIT_TOT; \
	MENU func14_TOT_UNIT_TOT_page; \
	COMMAND func14_TOT_UNIT_TOT_read; \
	COMMAND func14_TOT_UNIT_TOT_write; \
	VARIABLE func14_TOT_ALARM_HYS; \
	MENU func14_TOT_ALARM_HYS_page; \
	COMMAND func14_TOT_ALARM_HYS_read; \
	COMMAND func14_TOT_ALARM_HYS_write; \
	VARIABLE func14_TOT_HI_HI_LIM; \
	MENU func14_TOT_HI_HI_LIM_page; \
	COMMAND func14_TOT_HI_HI_LIM_read; \
	COMMAND func14_TOT_HI_HI_LIM_write; \
	VARIABLE func14_TOT_HI_LIM; \
	MENU func14_TOT_HI_LIM_page; \
	COMMAND func14_TOT_HI_LIM_read; \
	COMMAND func14_TOT_HI_LIM_write; \
	VARIABLE func14_TOT_LO_LIM; \
	MENU func14_TOT_LO_LIM_page; \
	COMMAND func14_TOT_LO_LIM_read; \
	COMMAND func14_TOT_LO_LIM_write; \
	VARIABLE func14_TOT_LO_LO_LIM; \
	MENU func14_TOT_LO_LO_LIM_page; \
	COMMAND func14_TOT_LO_LO_LIM_read; \
	COMMAND func14_TOT_LO_LO_LIM_write; \
	UNIT func14_TOT_unit_1; \
	MENU func14_TOT_Display; \
	MENU func14_TOT_Display_out; \
	MENU func14_TOT_Tab_s_tot_limits

#define USE_FUNC14_TOT_MANDATORY_A \
	USE_FUNC14_TOT_MANDATORY_BOTH; \
	MENU func14_TOT_Simple_Dialog_Mandatory_A; \
	MENU func14_TOT_Tab_s_mandatory_A; \
	MENU func14_TOT_Tab_m_mandatory_A

#define USE_FUNC14_TOT_MANDATORY_B \
	USE_FUNC14_TOT_MANDATORY_BOTH; \
	VARIABLE func14_TOT_CHANNEL; \
	MENU func14_TOT_CHANNEL_page; \
	COMMAND func14_TOT_CHANNEL_read; \
	COMMAND func14_TOT_CHANNEL_write; \
	VARIABLE func14_TOT_SET_TOT; \
	MENU func14_TOT_SET_TOT_page; \
	COMMAND func14_TOT_SET_TOT_read; \
	COMMAND func14_TOT_SET_TOT_write; \
	VARIABLE func14_TOT_MODE_TOT; \
	MENU func14_TOT_MODE_TOT_page; \
	COMMAND func14_TOT_MODE_TOT_read; \
	COMMAND func14_TOT_MODE_TOT_write; \
	VARIABLE func14_TOT_FAIL_TOT; \
	MENU func14_TOT_FAIL_TOT_page; \
	COMMAND func14_TOT_FAIL_TOT_read; \
	COMMAND func14_TOT_FAIL_TOT_write; \
	VARIABLE func14_TOT_PRESET_TOT; \
	MENU func14_TOT_PRESET_TOT_page; \
	COMMAND func14_TOT_PRESET_TOT_read; \
	COMMAND func14_TOT_PRESET_TOT_write; \
	COLLECTION func14_TOT_VIEW_1; \
	MENU func14_TOT_VIEW_1_page; \
	MENU func14_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func14_TOT_unit_2; \
	MENU func14_TOT_Reset; \
	MENU func14_TOT_Reset_page; \
	METHOD func14_TOT_Reset_totalizer; \
	METHOD func14_TOT_Preset_totalizer; \
	MENU func14_TOT_Tab_s_mandatory_B; \
	MENU func14_TOT_Tab_m_mandatory_B

#define USE_FUNC14_TOT_OPTIONAL_BOTH \
	COLLECTION func14_TOT_HI_HI_ALM; \
	VARIABLE func14_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func14_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func14_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func14_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func14_TOT_HI_HI_ALM_Value; \
	MENU func14_TOT_HI_HI_ALM_page; \
	COMMAND func14_TOT_HI_HI_ALM_read; \
	COLLECTION func14_TOT_HI_ALM; \
	VARIABLE func14_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func14_TOT_HI_ALM_Alarm_State; \
	VARIABLE func14_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func14_TOT_HI_ALM_Subcode; \
	VARIABLE func14_TOT_HI_ALM_Value; \
	MENU func14_TOT_HI_ALM_page; \
	COMMAND func14_TOT_HI_ALM_read; \
	COLLECTION func14_TOT_LO_ALM; \
	VARIABLE func14_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func14_TOT_LO_ALM_Alarm_State; \
	VARIABLE func14_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func14_TOT_LO_ALM_Subcode; \
	VARIABLE func14_TOT_LO_ALM_Value; \
	MENU func14_TOT_LO_ALM_page; \
	COMMAND func14_TOT_LO_ALM_read; \
	COLLECTION func14_TOT_LO_LO_ALM; \
	VARIABLE func14_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func14_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func14_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func14_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func14_TOT_LO_LO_ALM_Value; \
	MENU func14_TOT_LO_LO_ALM_page; \
	COMMAND func14_TOT_LO_LO_ALM_read; \
	COLLECTION func14_TOT_VIEW_2; \
	MENU func14_TOT_VIEW_2_page; \
	COLLECTION func14_TOT_VIEW_3; \
	MENU func14_TOT_VIEW_3_page

#define USE_FUNC14_TOT_OPTIONAL_A \
	USE_FUNC14_TOT_OPTIONAL_BOTH; \
	VARIABLE func14_TOT_CHANNEL; \
	MENU func14_TOT_CHANNEL_page; \
	COMMAND func14_TOT_CHANNEL_read; \
	COMMAND func14_TOT_CHANNEL_write; \
	VARIABLE func14_TOT_SET_TOT; \
	MENU func14_TOT_SET_TOT_page; \
	COMMAND func14_TOT_SET_TOT_read; \
	COMMAND func14_TOT_SET_TOT_write; \
	VARIABLE func14_TOT_MODE_TOT; \
	MENU func14_TOT_MODE_TOT_page; \
	COMMAND func14_TOT_MODE_TOT_read; \
	COMMAND func14_TOT_MODE_TOT_write; \
	VARIABLE func14_TOT_FAIL_TOT; \
	MENU func14_TOT_FAIL_TOT_page; \
	COMMAND func14_TOT_FAIL_TOT_read; \
	COMMAND func14_TOT_FAIL_TOT_write; \
	VARIABLE func14_TOT_PRESET_TOT; \
	MENU func14_TOT_PRESET_TOT_page; \
	COMMAND func14_TOT_PRESET_TOT_read; \
	COMMAND func14_TOT_PRESET_TOT_write; \
	COLLECTION func14_TOT_VIEW_1; \
	MENU func14_TOT_VIEW_1_page; \
	MENU func14_TOT_Simple_Dialog_Optional_A

#define USE_FUNC14_TOT_OPTIONAL_B \
	USE_FUNC14_TOT_OPTIONAL_BOTH; \
	MENU func14_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC14_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func14_TOT_)
#define USE_FUNC14_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func14_TOT_)
#define USE_FUNC14_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func14_TOT_)
#define USE_FUNC14_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func14_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC15_TOT_MANDATORY_BOTH \
	BLOCK func15_TOT_block; \
	COLLECTION func15_TOT_BLOCK_OBJECT; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Reserved; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Block_Object; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Class; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func15_TOT_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Profile; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func15_TOT_BLOCK_OBJECT_Number_of_Views; \
	MENU func15_TOT_BLOCK_OBJECT_page; \
	COMMAND func15_TOT_BLOCK_OBJECT_read; \
	VARIABLE func15_TOT_ST_REV; \
	MENU func15_TOT_ST_REV_page; \
	COMMAND func15_TOT_ST_REV_read; \
	VARIABLE func15_TOT_TAG_DESC; \
	MENU func15_TOT_TAG_DESC_page; \
	COMMAND func15_TOT_TAG_DESC_read; \
	COMMAND func15_TOT_TAG_DESC_write; \
	VARIABLE func15_TOT_STRATEGY; \
	MENU func15_TOT_STRATEGY_page; \
	COMMAND func15_TOT_STRATEGY_read; \
	COMMAND func15_TOT_STRATEGY_write; \
	VARIABLE func15_TOT_ALERT_KEY; \
	MENU func15_TOT_ALERT_KEY_page; \
	COMMAND func15_TOT_ALERT_KEY_read; \
	COMMAND func15_TOT_ALERT_KEY_write; \
	VARIABLE func15_TOT_TARGET_MODE; \
	MENU func15_TOT_TARGET_MODE_page; \
	COMMAND func15_TOT_TARGET_MODE_read; \
	COMMAND func15_TOT_TARGET_MODE_write; \
	COLLECTION func15_TOT_MODE_BLK; \
	VARIABLE func15_TOT_MODE_BLK_Actual; \
	VARIABLE func15_TOT_MODE_BLK_Permitted; \
	VARIABLE func15_TOT_MODE_BLK_Normal; \
	MENU func15_TOT_MODE_BLK_page; \
	COMMAND func15_TOT_MODE_BLK_read; \
	COLLECTION func15_TOT_ALARM_SUM; \
	VARIABLE func15_TOT_ALARM_SUM_Current; \
	VARIABLE func15_TOT_ALARM_SUM_Unacknowledged; \
	VARIABLE func15_TOT_ALARM_SUM_Unreported; \
	VARIABLE func15_TOT_ALARM_SUM_Disabled; \
	MENU func15_TOT_ALARM_SUM_page; \
	COMMAND func15_TOT_ALARM_SUM_read; \
	COLLECTION func15_TOT_BATCH; \
	VARIABLE func15_TOT_BATCH_Batch_ID; \
	VARIABLE func15_TOT_BATCH_Rup; \
	VARIABLE func15_TOT_BATCH_Operation; \
	VARIABLE func15_TOT_BATCH_Phase; \
	MENU func15_TOT_BATCH_page; \
	COMMAND func15_TOT_BATCH_read; \
	COMMAND func15_TOT_BATCH_write; \
	COLLECTION func15_TOT_TOTAL; \
	VARIABLE func15_TOT_TOTAL_Value; \
	VARIABLE func15_TOT_TOTAL_Status_Condensed; \
	VARIABLE func15_TOT_TOTAL_Status_Quality; \
	VARIABLE func15_TOT_TOTAL_Status_Limit; \
	MENU func15_TOT_TOTAL_page; \
	COMMAND func15_TOT_TOTAL_read; \
	COMMAND func15_TOT_TOTAL_write; \
	VARIABLE func15_TOT_UNIT_TOT; \
	MENU func15_TOT_UNIT_TOT_page; \
	COMMAND func15_TOT_UNIT_TOT_read; \
	COMMAND func15_TOT_UNIT_TOT_write; \
	VARIABLE func15_TOT_ALARM_HYS; \
	MENU func15_TOT_ALARM_HYS_page; \
	COMMAND func15_TOT_ALARM_HYS_read; \
	COMMAND func15_TOT_ALARM_HYS_write; \
	VARIABLE func15_TOT_HI_HI_LIM; \
	MENU func15_TOT_HI_HI_LIM_page; \
	COMMAND func15_TOT_HI_HI_LIM_read; \
	COMMAND func15_TOT_HI_HI_LIM_write; \
	VARIABLE func15_TOT_HI_LIM; \
	MENU func15_TOT_HI_LIM_page; \
	COMMAND func15_TOT_HI_LIM_read; \
	COMMAND func15_TOT_HI_LIM_write; \
	VARIABLE func15_TOT_LO_LIM; \
	MENU func15_TOT_LO_LIM_page; \
	COMMAND func15_TOT_LO_LIM_read; \
	COMMAND func15_TOT_LO_LIM_write; \
	VARIABLE func15_TOT_LO_LO_LIM; \
	MENU func15_TOT_LO_LO_LIM_page; \
	COMMAND func15_TOT_LO_LO_LIM_read; \
	COMMAND func15_TOT_LO_LO_LIM_write; \
	UNIT func15_TOT_unit_1; \
	MENU func15_TOT_Display; \
	MENU func15_TOT_Display_out; \
	MENU func15_TOT_Tab_s_tot_limits

#define USE_FUNC15_TOT_MANDATORY_A \
	USE_FUNC15_TOT_MANDATORY_BOTH; \
	MENU func15_TOT_Simple_Dialog_Mandatory_A; \
	MENU func15_TOT_Tab_s_mandatory_A; \
	MENU func15_TOT_Tab_m_mandatory_A

#define USE_FUNC15_TOT_MANDATORY_B \
	USE_FUNC15_TOT_MANDATORY_BOTH; \
	VARIABLE func15_TOT_CHANNEL; \
	MENU func15_TOT_CHANNEL_page; \
	COMMAND func15_TOT_CHANNEL_read; \
	COMMAND func15_TOT_CHANNEL_write; \
	VARIABLE func15_TOT_SET_TOT; \
	MENU func15_TOT_SET_TOT_page; \
	COMMAND func15_TOT_SET_TOT_read; \
	COMMAND func15_TOT_SET_TOT_write; \
	VARIABLE func15_TOT_MODE_TOT; \
	MENU func15_TOT_MODE_TOT_page; \
	COMMAND func15_TOT_MODE_TOT_read; \
	COMMAND func15_TOT_MODE_TOT_write; \
	VARIABLE func15_TOT_FAIL_TOT; \
	MENU func15_TOT_FAIL_TOT_page; \
	COMMAND func15_TOT_FAIL_TOT_read; \
	COMMAND func15_TOT_FAIL_TOT_write; \
	VARIABLE func15_TOT_PRESET_TOT; \
	MENU func15_TOT_PRESET_TOT_page; \
	COMMAND func15_TOT_PRESET_TOT_read; \
	COMMAND func15_TOT_PRESET_TOT_write; \
	COLLECTION func15_TOT_VIEW_1; \
	MENU func15_TOT_VIEW_1_page; \
	MENU func15_TOT_Simple_Dialog_Mandatory_B; \
	UNIT func15_TOT_unit_2; \
	MENU func15_TOT_Reset; \
	MENU func15_TOT_Reset_page; \
	METHOD func15_TOT_Reset_totalizer; \
	METHOD func15_TOT_Preset_totalizer; \
	MENU func15_TOT_Tab_s_mandatory_B; \
	MENU func15_TOT_Tab_m_mandatory_B

#define USE_FUNC15_TOT_OPTIONAL_BOTH \
	COLLECTION func15_TOT_HI_HI_ALM; \
	VARIABLE func15_TOT_HI_HI_ALM_Unacknowledged; \
	VARIABLE func15_TOT_HI_HI_ALM_Alarm_State; \
	VARIABLE func15_TOT_HI_HI_ALM_Time_Stamp; \
	VARIABLE func15_TOT_HI_HI_ALM_Subcode; \
	VARIABLE func15_TOT_HI_HI_ALM_Value; \
	MENU func15_TOT_HI_HI_ALM_page; \
	COMMAND func15_TOT_HI_HI_ALM_read; \
	COLLECTION func15_TOT_HI_ALM; \
	VARIABLE func15_TOT_HI_ALM_Unacknowledged; \
	VARIABLE func15_TOT_HI_ALM_Alarm_State; \
	VARIABLE func15_TOT_HI_ALM_Time_Stamp; \
	VARIABLE func15_TOT_HI_ALM_Subcode; \
	VARIABLE func15_TOT_HI_ALM_Value; \
	MENU func15_TOT_HI_ALM_page; \
	COMMAND func15_TOT_HI_ALM_read; \
	COLLECTION func15_TOT_LO_ALM; \
	VARIABLE func15_TOT_LO_ALM_Unacknowledged; \
	VARIABLE func15_TOT_LO_ALM_Alarm_State; \
	VARIABLE func15_TOT_LO_ALM_Time_Stamp; \
	VARIABLE func15_TOT_LO_ALM_Subcode; \
	VARIABLE func15_TOT_LO_ALM_Value; \
	MENU func15_TOT_LO_ALM_page; \
	COMMAND func15_TOT_LO_ALM_read; \
	COLLECTION func15_TOT_LO_LO_ALM; \
	VARIABLE func15_TOT_LO_LO_ALM_Unacknowledged; \
	VARIABLE func15_TOT_LO_LO_ALM_Alarm_State; \
	VARIABLE func15_TOT_LO_LO_ALM_Time_Stamp; \
	VARIABLE func15_TOT_LO_LO_ALM_Subcode; \
	VARIABLE func15_TOT_LO_LO_ALM_Value; \
	MENU func15_TOT_LO_LO_ALM_page; \
	COMMAND func15_TOT_LO_LO_ALM_read; \
	COLLECTION func15_TOT_VIEW_2; \
	MENU func15_TOT_VIEW_2_page; \
	COLLECTION func15_TOT_VIEW_3; \
	MENU func15_TOT_VIEW_3_page

#define USE_FUNC15_TOT_OPTIONAL_A \
	USE_FUNC15_TOT_OPTIONAL_BOTH; \
	VARIABLE func15_TOT_CHANNEL; \
	MENU func15_TOT_CHANNEL_page; \
	COMMAND func15_TOT_CHANNEL_read; \
	COMMAND func15_TOT_CHANNEL_write; \
	VARIABLE func15_TOT_SET_TOT; \
	MENU func15_TOT_SET_TOT_page; \
	COMMAND func15_TOT_SET_TOT_read; \
	COMMAND func15_TOT_SET_TOT_write; \
	VARIABLE func15_TOT_MODE_TOT; \
	MENU func15_TOT_MODE_TOT_page; \
	COMMAND func15_TOT_MODE_TOT_read; \
	COMMAND func15_TOT_MODE_TOT_write; \
	VARIABLE func15_TOT_FAIL_TOT; \
	MENU func15_TOT_FAIL_TOT_page; \
	COMMAND func15_TOT_FAIL_TOT_read; \
	COMMAND func15_TOT_FAIL_TOT_write; \
	VARIABLE func15_TOT_PRESET_TOT; \
	MENU func15_TOT_PRESET_TOT_page; \
	COMMAND func15_TOT_PRESET_TOT_read; \
	COMMAND func15_TOT_PRESET_TOT_write; \
	COLLECTION func15_TOT_VIEW_1; \
	MENU func15_TOT_VIEW_1_page; \
	MENU func15_TOT_Simple_Dialog_Optional_A

#define USE_FUNC15_TOT_OPTIONAL_B \
	USE_FUNC15_TOT_OPTIONAL_BOTH; \
	MENU func15_TOT_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC15_TOT_MANDATORY_A USE_FUNC_TOT_MANDATORY_A(func15_TOT_)
#define USE_FUNC15_TOT_MANDATORY_B USE_FUNC_TOT_MANDATORY_B(func15_TOT_)
#define USE_FUNC15_TOT_OPTIONAL_A  USE_FUNC_TOT_OPTIONAL_A(func15_TOT_)
#define USE_FUNC15_TOT_OPTIONAL_B  USE_FUNC_TOT_OPTIONAL_B(func15_TOT_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_FLOWCM_MANDATORY_BOTH \
	BLOCK trans1_FlowCM_block; \
	COLLECTION trans1_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans1_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans1_FlowCM_ST_REV; \
	MENU trans1_FlowCM_ST_REV_page; \
	COMMAND trans1_FlowCM_ST_REV_read; \
	VARIABLE trans1_FlowCM_TAG_DESC; \
	MENU trans1_FlowCM_TAG_DESC_page; \
	COMMAND trans1_FlowCM_TAG_DESC_read; \
	COMMAND trans1_FlowCM_TAG_DESC_write; \
	VARIABLE trans1_FlowCM_STRATEGY; \
	MENU trans1_FlowCM_STRATEGY_page; \
	COMMAND trans1_FlowCM_STRATEGY_read; \
	COMMAND trans1_FlowCM_STRATEGY_write; \
	VARIABLE trans1_FlowCM_ALERT_KEY; \
	MENU trans1_FlowCM_ALERT_KEY_page; \
	COMMAND trans1_FlowCM_ALERT_KEY_read; \
	COMMAND trans1_FlowCM_ALERT_KEY_write; \
	VARIABLE trans1_FlowCM_TARGET_MODE; \
	MENU trans1_FlowCM_TARGET_MODE_page; \
	COMMAND trans1_FlowCM_TARGET_MODE_read; \
	COMMAND trans1_FlowCM_TARGET_MODE_write; \
	COLLECTION trans1_FlowCM_MODE_BLK; \
	VARIABLE trans1_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans1_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans1_FlowCM_MODE_BLK_Normal; \
	MENU trans1_FlowCM_MODE_BLK_page; \
	COMMAND trans1_FlowCM_MODE_BLK_read; \
	COLLECTION trans1_FlowCM_ALARM_SUM; \
	VARIABLE trans1_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans1_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans1_FlowCM_ALARM_SUM_Disabled; \
	MENU trans1_FlowCM_ALARM_SUM_page; \
	COMMAND trans1_FlowCM_ALARM_SUM_read; \
	VARIABLE trans1_FlowCM_CALIBR_FACTOR; \
	MENU trans1_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans1_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans1_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans1_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans1_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans1_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans1_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans1_FlowCM_MEASUREMENT_MODE; \
	MENU trans1_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans1_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans1_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans1_FlowCM_FLOW_DIRECTION; \
	MENU trans1_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans1_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans1_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans1_FlowCM_NOMINAL_SIZE; \
	MENU trans1_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans1_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans1_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans1_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans1_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans1_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans1_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans1_FlowCM_MASS_FLOW; \
	VARIABLE trans1_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans1_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans1_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans1_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans1_FlowCM_MASS_FLOW_page; \
	COMMAND trans1_FlowCM_MASS_FLOW_read; \
	VARIABLE trans1_FlowCM_MASS_FLOW_UNITS; \
	MENU trans1_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans1_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans1_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans1_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans1_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans1_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans1_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans1_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans1_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans1_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans1_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans1_FlowCM_DENSITY; \
	VARIABLE trans1_FlowCM_DENSITY_Value; \
	VARIABLE trans1_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans1_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans1_FlowCM_DENSITY_Status_Limit; \
	MENU trans1_FlowCM_DENSITY_page; \
	COMMAND trans1_FlowCM_DENSITY_read; \
	VARIABLE trans1_FlowCM_DENSITY_UNITS; \
	MENU trans1_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans1_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans1_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans1_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans1_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans1_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans1_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans1_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans1_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans1_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans1_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans1_FlowCM_TEMPERATURE; \
	VARIABLE trans1_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans1_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans1_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans1_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans1_FlowCM_TEMPERATURE_page; \
	COMMAND trans1_FlowCM_TEMPERATURE_read; \
	VARIABLE trans1_FlowCM_TEMPERATURE_UNITS; \
	MENU trans1_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans1_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans1_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans1_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans1_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans1_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans1_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans1_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans1_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans1_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans1_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans1_FlowCM_unit_nominal_size; \
	UNIT trans1_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans1_FlowCM_unit_density; \
	UNIT trans1_FlowCM_unit_temperature

#define USE_TRANS1_FLOWCM_MANDATORY_A \
	USE_TRANS1_FLOWCM_MANDATORY_BOTH; \
	MENU trans1_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS1_FLOWCM_MANDATORY_B \
	USE_TRANS1_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans1_FlowCM_VIEW_1; \
	MENU trans1_FlowCM_VIEW_1_page; \
	MENU trans1_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS1_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans1_FlowCM_ZERO_POINT; \
	MENU trans1_FlowCM_ZERO_POINT_page; \
	COMMAND trans1_FlowCM_ZERO_POINT_read; \
	COMMAND trans1_FlowCM_ZERO_POINT_write; \
	VARIABLE trans1_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans1_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans1_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans1_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans1_FlowCM_ZERO_POINT_UNIT; \
	MENU trans1_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans1_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans1_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans1_FlowCM_VIEW_2; \
	MENU trans1_FlowCM_VIEW_2_page; \
	COLLECTION trans1_FlowCM_VIEW_3; \
	MENU trans1_FlowCM_VIEW_3_page; \
	UNIT trans1_FlowCM_unit_zero_point

#define USE_TRANS1_FLOWCM_OPTIONAL_A \
	USE_TRANS1_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans1_FlowCM_VIEW_1; \
	MENU trans1_FlowCM_VIEW_1_page; \
	MENU trans1_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS1_FLOWCM_OPTIONAL_B \
	USE_TRANS1_FLOWCM_OPTIONAL_BOTH; \
	MENU trans1_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_FLOWCM_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CALIBR_FACTOR; \
	MENU prefix ## CALIBR_FACTOR_page; \
	COMMAND prefix ## CALIBR_FACTOR_read; \
	COMMAND prefix ## CALIBR_FACTOR_write; \
	VARIABLE prefix ## LOW_FLOW_CUTOFF; \
	MENU prefix ## LOW_FLOW_CUTOFF_page; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_read; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_write; \
	VARIABLE prefix ## MEASUREMENT_MODE; \
	MENU prefix ## MEASUREMENT_MODE_page; \
	COMMAND prefix ## MEASUREMENT_MODE_read; \
	COMMAND prefix ## MEASUREMENT_MODE_write; \
	VARIABLE prefix ## FLOW_DIRECTION; \
	MENU prefix ## FLOW_DIRECTION_page; \
	COMMAND prefix ## FLOW_DIRECTION_read; \
	COMMAND prefix ## FLOW_DIRECTION_write; \
	VARIABLE prefix ## NOMINAL_SIZE; \
	MENU prefix ## NOMINAL_SIZE_page; \
	COMMAND prefix ## NOMINAL_SIZE_read; \
	COMMAND prefix ## NOMINAL_SIZE_write; \
	VARIABLE prefix ## NOMINAL_SIZE_UNITS; \
	MENU prefix ## NOMINAL_SIZE_UNITS_page; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_read; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_write; \
	COLLECTION prefix ## MASS_FLOW; \
	VARIABLE prefix ## MASS_FLOW_Value; \
	VARIABLE prefix ## MASS_FLOW_Status_Condensed; \
	VARIABLE prefix ## MASS_FLOW_Status_Quality; \
	VARIABLE prefix ## MASS_FLOW_Status_Limit; \
	MENU prefix ## MASS_FLOW_page; \
	COMMAND prefix ## MASS_FLOW_read; \
	VARIABLE prefix ## MASS_FLOW_UNITS; \
	MENU prefix ## MASS_FLOW_UNITS_page; \
	COMMAND prefix ## MASS_FLOW_UNITS_read; \
	COMMAND prefix ## MASS_FLOW_UNITS_write; \
	VARIABLE prefix ## MASS_FLOW_LO_LIMIT; \
	MENU prefix ## MASS_FLOW_LO_LIMIT_page; \
	COMMAND prefix ## MASS_FLOW_LO_LIMIT_read; \
	COMMAND prefix ## MASS_FLOW_LO_LIMIT_write; \
	VARIABLE prefix ## MASS_FLOW_HI_LIMIT; \
	MENU prefix ## MASS_FLOW_HI_LIMIT_page; \
	COMMAND prefix ## MASS_FLOW_HI_LIMIT_read; \
	COMMAND prefix ## MASS_FLOW_HI_LIMIT_write; \
	COLLECTION prefix ## DENSITY; \
	VARIABLE prefix ## DENSITY_Value; \
	VARIABLE prefix ## DENSITY_Status_Condensed; \
	VARIABLE prefix ## DENSITY_Status_Quality; \
	VARIABLE prefix ## DENSITY_Status_Limit; \
	MENU prefix ## DENSITY_page; \
	COMMAND prefix ## DENSITY_read; \
	VARIABLE prefix ## DENSITY_UNITS; \
	MENU prefix ## DENSITY_UNITS_page; \
	COMMAND prefix ## DENSITY_UNITS_read; \
	COMMAND prefix ## DENSITY_UNITS_write; \
	VARIABLE prefix ## DENSITY_LO_LIMIT; \
	MENU prefix ## DENSITY_LO_LIMIT_page; \
	COMMAND prefix ## DENSITY_LO_LIMIT_read; \
	COMMAND prefix ## DENSITY_LO_LIMIT_write; \
	VARIABLE prefix ## DENSITY_HI_LIMIT; \
	MENU prefix ## DENSITY_HI_LIMIT_page; \
	COMMAND prefix ## DENSITY_HI_LIMIT_read; \
	COMMAND prefix ## DENSITY_HI_LIMIT_write; \
	COLLECTION prefix ## TEMPERATURE; \
	VARIABLE prefix ## TEMPERATURE_Value; \
	VARIABLE prefix ## TEMPERATURE_Status_Condensed; \
	VARIABLE prefix ## TEMPERATURE_Status_Quality; \
	VARIABLE prefix ## TEMPERATURE_Status_Limit; \
	MENU prefix ## TEMPERATURE_page; \
	COMMAND prefix ## TEMPERATURE_read; \
	VARIABLE prefix ## TEMPERATURE_UNITS; \
	MENU prefix ## TEMPERATURE_UNITS_page; \
	COMMAND prefix ## TEMPERATURE_UNITS_read; \
	COMMAND prefix ## TEMPERATURE_UNITS_write; \
	VARIABLE prefix ## TEMPERATURE_LO_LIMIT; \
	MENU prefix ## TEMPERATURE_LO_LIMIT_page; \
	COMMAND prefix ## TEMPERATURE_LO_LIMIT_read; \
	COMMAND prefix ## TEMPERATURE_LO_LIMIT_write; \
	VARIABLE prefix ## TEMPERATURE_HI_LIMIT; \
	MENU prefix ## TEMPERATURE_HI_LIMIT_page; \
	COMMAND prefix ## TEMPERATURE_HI_LIMIT_read; \
	COMMAND prefix ## TEMPERATURE_HI_LIMIT_write; \
	UNIT prefix ## unit_nominal_size; \
	UNIT prefix ## unit_TB_MASS_FLOW_UNIT; \
	UNIT prefix ## unit_density; \
	UNIT prefix ## unit_temperature

#define USE_TRANS_FLOWCM_MANDATORY_A(prefix) \
	USE_TRANS_FLOWCM_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_FLOWCM_MANDATORY_B(prefix) \
	USE_TRANS_FLOWCM_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_FLOWCM_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ZERO_POINT; \
	MENU prefix ## ZERO_POINT_page; \
	COMMAND prefix ## ZERO_POINT_read; \
	COMMAND prefix ## ZERO_POINT_write; \
	VARIABLE prefix ## ZERO_POINT_ADJUST; \
	MENU prefix ## ZERO_POINT_ADJUST_page; \
	COMMAND prefix ## ZERO_POINT_ADJUST_read; \
	COMMAND prefix ## ZERO_POINT_ADJUST_write; \
	VARIABLE prefix ## ZERO_POINT_UNIT; \
	MENU prefix ## ZERO_POINT_UNIT_page; \
	COMMAND prefix ## ZERO_POINT_UNIT_read; \
	COMMAND prefix ## ZERO_POINT_UNIT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## unit_zero_point

#define USE_TRANS_FLOWCM_OPTIONAL_A(prefix) \
	USE_TRANS_FLOWCM_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_FLOWCM_OPTIONAL_B(prefix) \
	USE_TRANS_FLOWCM_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans1_FlowCM_)
#define USE_TRANS1_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans1_FlowCM_)
#define USE_TRANS1_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans1_FlowCM_)
#define USE_TRANS1_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans1_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_FLOWCM_MANDATORY_BOTH \
	BLOCK trans2_FlowCM_block; \
	COLLECTION trans2_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans2_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans2_FlowCM_ST_REV; \
	MENU trans2_FlowCM_ST_REV_page; \
	COMMAND trans2_FlowCM_ST_REV_read; \
	VARIABLE trans2_FlowCM_TAG_DESC; \
	MENU trans2_FlowCM_TAG_DESC_page; \
	COMMAND trans2_FlowCM_TAG_DESC_read; \
	COMMAND trans2_FlowCM_TAG_DESC_write; \
	VARIABLE trans2_FlowCM_STRATEGY; \
	MENU trans2_FlowCM_STRATEGY_page; \
	COMMAND trans2_FlowCM_STRATEGY_read; \
	COMMAND trans2_FlowCM_STRATEGY_write; \
	VARIABLE trans2_FlowCM_ALERT_KEY; \
	MENU trans2_FlowCM_ALERT_KEY_page; \
	COMMAND trans2_FlowCM_ALERT_KEY_read; \
	COMMAND trans2_FlowCM_ALERT_KEY_write; \
	VARIABLE trans2_FlowCM_TARGET_MODE; \
	MENU trans2_FlowCM_TARGET_MODE_page; \
	COMMAND trans2_FlowCM_TARGET_MODE_read; \
	COMMAND trans2_FlowCM_TARGET_MODE_write; \
	COLLECTION trans2_FlowCM_MODE_BLK; \
	VARIABLE trans2_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans2_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans2_FlowCM_MODE_BLK_Normal; \
	MENU trans2_FlowCM_MODE_BLK_page; \
	COMMAND trans2_FlowCM_MODE_BLK_read; \
	COLLECTION trans2_FlowCM_ALARM_SUM; \
	VARIABLE trans2_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans2_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans2_FlowCM_ALARM_SUM_Disabled; \
	MENU trans2_FlowCM_ALARM_SUM_page; \
	COMMAND trans2_FlowCM_ALARM_SUM_read; \
	VARIABLE trans2_FlowCM_CALIBR_FACTOR; \
	MENU trans2_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans2_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans2_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans2_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans2_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans2_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans2_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans2_FlowCM_MEASUREMENT_MODE; \
	MENU trans2_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans2_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans2_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans2_FlowCM_FLOW_DIRECTION; \
	MENU trans2_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans2_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans2_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans2_FlowCM_NOMINAL_SIZE; \
	MENU trans2_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans2_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans2_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans2_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans2_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans2_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans2_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans2_FlowCM_MASS_FLOW; \
	VARIABLE trans2_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans2_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans2_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans2_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans2_FlowCM_MASS_FLOW_page; \
	COMMAND trans2_FlowCM_MASS_FLOW_read; \
	VARIABLE trans2_FlowCM_MASS_FLOW_UNITS; \
	MENU trans2_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans2_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans2_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans2_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans2_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans2_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans2_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans2_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans2_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans2_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans2_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans2_FlowCM_DENSITY; \
	VARIABLE trans2_FlowCM_DENSITY_Value; \
	VARIABLE trans2_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans2_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans2_FlowCM_DENSITY_Status_Limit; \
	MENU trans2_FlowCM_DENSITY_page; \
	COMMAND trans2_FlowCM_DENSITY_read; \
	VARIABLE trans2_FlowCM_DENSITY_UNITS; \
	MENU trans2_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans2_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans2_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans2_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans2_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans2_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans2_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans2_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans2_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans2_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans2_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans2_FlowCM_TEMPERATURE; \
	VARIABLE trans2_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans2_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans2_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans2_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans2_FlowCM_TEMPERATURE_page; \
	COMMAND trans2_FlowCM_TEMPERATURE_read; \
	VARIABLE trans2_FlowCM_TEMPERATURE_UNITS; \
	MENU trans2_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans2_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans2_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans2_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans2_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans2_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans2_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans2_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans2_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans2_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans2_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans2_FlowCM_unit_nominal_size; \
	UNIT trans2_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans2_FlowCM_unit_density; \
	UNIT trans2_FlowCM_unit_temperature

#define USE_TRANS2_FLOWCM_MANDATORY_A \
	USE_TRANS2_FLOWCM_MANDATORY_BOTH; \
	MENU trans2_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS2_FLOWCM_MANDATORY_B \
	USE_TRANS2_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans2_FlowCM_VIEW_1; \
	MENU trans2_FlowCM_VIEW_1_page; \
	MENU trans2_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS2_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans2_FlowCM_ZERO_POINT; \
	MENU trans2_FlowCM_ZERO_POINT_page; \
	COMMAND trans2_FlowCM_ZERO_POINT_read; \
	COMMAND trans2_FlowCM_ZERO_POINT_write; \
	VARIABLE trans2_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans2_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans2_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans2_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans2_FlowCM_ZERO_POINT_UNIT; \
	MENU trans2_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans2_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans2_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans2_FlowCM_VIEW_2; \
	MENU trans2_FlowCM_VIEW_2_page; \
	COLLECTION trans2_FlowCM_VIEW_3; \
	MENU trans2_FlowCM_VIEW_3_page; \
	UNIT trans2_FlowCM_unit_zero_point

#define USE_TRANS2_FLOWCM_OPTIONAL_A \
	USE_TRANS2_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans2_FlowCM_VIEW_1; \
	MENU trans2_FlowCM_VIEW_1_page; \
	MENU trans2_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS2_FLOWCM_OPTIONAL_B \
	USE_TRANS2_FLOWCM_OPTIONAL_BOTH; \
	MENU trans2_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans2_FlowCM_)
#define USE_TRANS2_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans2_FlowCM_)
#define USE_TRANS2_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans2_FlowCM_)
#define USE_TRANS2_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans2_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_FLOWCM_MANDATORY_BOTH \
	BLOCK trans3_FlowCM_block; \
	COLLECTION trans3_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans3_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans3_FlowCM_ST_REV; \
	MENU trans3_FlowCM_ST_REV_page; \
	COMMAND trans3_FlowCM_ST_REV_read; \
	VARIABLE trans3_FlowCM_TAG_DESC; \
	MENU trans3_FlowCM_TAG_DESC_page; \
	COMMAND trans3_FlowCM_TAG_DESC_read; \
	COMMAND trans3_FlowCM_TAG_DESC_write; \
	VARIABLE trans3_FlowCM_STRATEGY; \
	MENU trans3_FlowCM_STRATEGY_page; \
	COMMAND trans3_FlowCM_STRATEGY_read; \
	COMMAND trans3_FlowCM_STRATEGY_write; \
	VARIABLE trans3_FlowCM_ALERT_KEY; \
	MENU trans3_FlowCM_ALERT_KEY_page; \
	COMMAND trans3_FlowCM_ALERT_KEY_read; \
	COMMAND trans3_FlowCM_ALERT_KEY_write; \
	VARIABLE trans3_FlowCM_TARGET_MODE; \
	MENU trans3_FlowCM_TARGET_MODE_page; \
	COMMAND trans3_FlowCM_TARGET_MODE_read; \
	COMMAND trans3_FlowCM_TARGET_MODE_write; \
	COLLECTION trans3_FlowCM_MODE_BLK; \
	VARIABLE trans3_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans3_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans3_FlowCM_MODE_BLK_Normal; \
	MENU trans3_FlowCM_MODE_BLK_page; \
	COMMAND trans3_FlowCM_MODE_BLK_read; \
	COLLECTION trans3_FlowCM_ALARM_SUM; \
	VARIABLE trans3_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans3_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans3_FlowCM_ALARM_SUM_Disabled; \
	MENU trans3_FlowCM_ALARM_SUM_page; \
	COMMAND trans3_FlowCM_ALARM_SUM_read; \
	VARIABLE trans3_FlowCM_CALIBR_FACTOR; \
	MENU trans3_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans3_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans3_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans3_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans3_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans3_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans3_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans3_FlowCM_MEASUREMENT_MODE; \
	MENU trans3_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans3_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans3_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans3_FlowCM_FLOW_DIRECTION; \
	MENU trans3_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans3_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans3_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans3_FlowCM_NOMINAL_SIZE; \
	MENU trans3_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans3_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans3_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans3_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans3_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans3_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans3_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans3_FlowCM_MASS_FLOW; \
	VARIABLE trans3_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans3_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans3_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans3_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans3_FlowCM_MASS_FLOW_page; \
	COMMAND trans3_FlowCM_MASS_FLOW_read; \
	VARIABLE trans3_FlowCM_MASS_FLOW_UNITS; \
	MENU trans3_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans3_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans3_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans3_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans3_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans3_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans3_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans3_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans3_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans3_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans3_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans3_FlowCM_DENSITY; \
	VARIABLE trans3_FlowCM_DENSITY_Value; \
	VARIABLE trans3_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans3_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans3_FlowCM_DENSITY_Status_Limit; \
	MENU trans3_FlowCM_DENSITY_page; \
	COMMAND trans3_FlowCM_DENSITY_read; \
	VARIABLE trans3_FlowCM_DENSITY_UNITS; \
	MENU trans3_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans3_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans3_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans3_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans3_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans3_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans3_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans3_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans3_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans3_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans3_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans3_FlowCM_TEMPERATURE; \
	VARIABLE trans3_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans3_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans3_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans3_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans3_FlowCM_TEMPERATURE_page; \
	COMMAND trans3_FlowCM_TEMPERATURE_read; \
	VARIABLE trans3_FlowCM_TEMPERATURE_UNITS; \
	MENU trans3_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans3_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans3_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans3_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans3_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans3_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans3_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans3_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans3_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans3_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans3_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans3_FlowCM_unit_nominal_size; \
	UNIT trans3_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans3_FlowCM_unit_density; \
	UNIT trans3_FlowCM_unit_temperature

#define USE_TRANS3_FLOWCM_MANDATORY_A \
	USE_TRANS3_FLOWCM_MANDATORY_BOTH; \
	MENU trans3_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS3_FLOWCM_MANDATORY_B \
	USE_TRANS3_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans3_FlowCM_VIEW_1; \
	MENU trans3_FlowCM_VIEW_1_page; \
	MENU trans3_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS3_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans3_FlowCM_ZERO_POINT; \
	MENU trans3_FlowCM_ZERO_POINT_page; \
	COMMAND trans3_FlowCM_ZERO_POINT_read; \
	COMMAND trans3_FlowCM_ZERO_POINT_write; \
	VARIABLE trans3_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans3_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans3_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans3_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans3_FlowCM_ZERO_POINT_UNIT; \
	MENU trans3_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans3_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans3_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans3_FlowCM_VIEW_2; \
	MENU trans3_FlowCM_VIEW_2_page; \
	COLLECTION trans3_FlowCM_VIEW_3; \
	MENU trans3_FlowCM_VIEW_3_page; \
	UNIT trans3_FlowCM_unit_zero_point

#define USE_TRANS3_FLOWCM_OPTIONAL_A \
	USE_TRANS3_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans3_FlowCM_VIEW_1; \
	MENU trans3_FlowCM_VIEW_1_page; \
	MENU trans3_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS3_FLOWCM_OPTIONAL_B \
	USE_TRANS3_FLOWCM_OPTIONAL_BOTH; \
	MENU trans3_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans3_FlowCM_)
#define USE_TRANS3_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans3_FlowCM_)
#define USE_TRANS3_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans3_FlowCM_)
#define USE_TRANS3_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans3_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_FLOWCM_MANDATORY_BOTH \
	BLOCK trans4_FlowCM_block; \
	COLLECTION trans4_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans4_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans4_FlowCM_ST_REV; \
	MENU trans4_FlowCM_ST_REV_page; \
	COMMAND trans4_FlowCM_ST_REV_read; \
	VARIABLE trans4_FlowCM_TAG_DESC; \
	MENU trans4_FlowCM_TAG_DESC_page; \
	COMMAND trans4_FlowCM_TAG_DESC_read; \
	COMMAND trans4_FlowCM_TAG_DESC_write; \
	VARIABLE trans4_FlowCM_STRATEGY; \
	MENU trans4_FlowCM_STRATEGY_page; \
	COMMAND trans4_FlowCM_STRATEGY_read; \
	COMMAND trans4_FlowCM_STRATEGY_write; \
	VARIABLE trans4_FlowCM_ALERT_KEY; \
	MENU trans4_FlowCM_ALERT_KEY_page; \
	COMMAND trans4_FlowCM_ALERT_KEY_read; \
	COMMAND trans4_FlowCM_ALERT_KEY_write; \
	VARIABLE trans4_FlowCM_TARGET_MODE; \
	MENU trans4_FlowCM_TARGET_MODE_page; \
	COMMAND trans4_FlowCM_TARGET_MODE_read; \
	COMMAND trans4_FlowCM_TARGET_MODE_write; \
	COLLECTION trans4_FlowCM_MODE_BLK; \
	VARIABLE trans4_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans4_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans4_FlowCM_MODE_BLK_Normal; \
	MENU trans4_FlowCM_MODE_BLK_page; \
	COMMAND trans4_FlowCM_MODE_BLK_read; \
	COLLECTION trans4_FlowCM_ALARM_SUM; \
	VARIABLE trans4_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans4_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans4_FlowCM_ALARM_SUM_Disabled; \
	MENU trans4_FlowCM_ALARM_SUM_page; \
	COMMAND trans4_FlowCM_ALARM_SUM_read; \
	VARIABLE trans4_FlowCM_CALIBR_FACTOR; \
	MENU trans4_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans4_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans4_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans4_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans4_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans4_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans4_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans4_FlowCM_MEASUREMENT_MODE; \
	MENU trans4_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans4_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans4_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans4_FlowCM_FLOW_DIRECTION; \
	MENU trans4_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans4_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans4_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans4_FlowCM_NOMINAL_SIZE; \
	MENU trans4_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans4_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans4_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans4_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans4_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans4_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans4_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans4_FlowCM_MASS_FLOW; \
	VARIABLE trans4_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans4_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans4_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans4_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans4_FlowCM_MASS_FLOW_page; \
	COMMAND trans4_FlowCM_MASS_FLOW_read; \
	VARIABLE trans4_FlowCM_MASS_FLOW_UNITS; \
	MENU trans4_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans4_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans4_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans4_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans4_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans4_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans4_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans4_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans4_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans4_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans4_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans4_FlowCM_DENSITY; \
	VARIABLE trans4_FlowCM_DENSITY_Value; \
	VARIABLE trans4_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans4_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans4_FlowCM_DENSITY_Status_Limit; \
	MENU trans4_FlowCM_DENSITY_page; \
	COMMAND trans4_FlowCM_DENSITY_read; \
	VARIABLE trans4_FlowCM_DENSITY_UNITS; \
	MENU trans4_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans4_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans4_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans4_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans4_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans4_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans4_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans4_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans4_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans4_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans4_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans4_FlowCM_TEMPERATURE; \
	VARIABLE trans4_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans4_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans4_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans4_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans4_FlowCM_TEMPERATURE_page; \
	COMMAND trans4_FlowCM_TEMPERATURE_read; \
	VARIABLE trans4_FlowCM_TEMPERATURE_UNITS; \
	MENU trans4_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans4_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans4_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans4_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans4_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans4_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans4_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans4_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans4_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans4_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans4_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans4_FlowCM_unit_nominal_size; \
	UNIT trans4_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans4_FlowCM_unit_density; \
	UNIT trans4_FlowCM_unit_temperature

#define USE_TRANS4_FLOWCM_MANDATORY_A \
	USE_TRANS4_FLOWCM_MANDATORY_BOTH; \
	MENU trans4_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS4_FLOWCM_MANDATORY_B \
	USE_TRANS4_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans4_FlowCM_VIEW_1; \
	MENU trans4_FlowCM_VIEW_1_page; \
	MENU trans4_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS4_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans4_FlowCM_ZERO_POINT; \
	MENU trans4_FlowCM_ZERO_POINT_page; \
	COMMAND trans4_FlowCM_ZERO_POINT_read; \
	COMMAND trans4_FlowCM_ZERO_POINT_write; \
	VARIABLE trans4_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans4_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans4_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans4_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans4_FlowCM_ZERO_POINT_UNIT; \
	MENU trans4_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans4_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans4_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans4_FlowCM_VIEW_2; \
	MENU trans4_FlowCM_VIEW_2_page; \
	COLLECTION trans4_FlowCM_VIEW_3; \
	MENU trans4_FlowCM_VIEW_3_page; \
	UNIT trans4_FlowCM_unit_zero_point

#define USE_TRANS4_FLOWCM_OPTIONAL_A \
	USE_TRANS4_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans4_FlowCM_VIEW_1; \
	MENU trans4_FlowCM_VIEW_1_page; \
	MENU trans4_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS4_FLOWCM_OPTIONAL_B \
	USE_TRANS4_FLOWCM_OPTIONAL_BOTH; \
	MENU trans4_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans4_FlowCM_)
#define USE_TRANS4_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans4_FlowCM_)
#define USE_TRANS4_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans4_FlowCM_)
#define USE_TRANS4_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans4_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_FLOWCM_MANDATORY_BOTH \
	BLOCK trans5_FlowCM_block; \
	COLLECTION trans5_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans5_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans5_FlowCM_ST_REV; \
	MENU trans5_FlowCM_ST_REV_page; \
	COMMAND trans5_FlowCM_ST_REV_read; \
	VARIABLE trans5_FlowCM_TAG_DESC; \
	MENU trans5_FlowCM_TAG_DESC_page; \
	COMMAND trans5_FlowCM_TAG_DESC_read; \
	COMMAND trans5_FlowCM_TAG_DESC_write; \
	VARIABLE trans5_FlowCM_STRATEGY; \
	MENU trans5_FlowCM_STRATEGY_page; \
	COMMAND trans5_FlowCM_STRATEGY_read; \
	COMMAND trans5_FlowCM_STRATEGY_write; \
	VARIABLE trans5_FlowCM_ALERT_KEY; \
	MENU trans5_FlowCM_ALERT_KEY_page; \
	COMMAND trans5_FlowCM_ALERT_KEY_read; \
	COMMAND trans5_FlowCM_ALERT_KEY_write; \
	VARIABLE trans5_FlowCM_TARGET_MODE; \
	MENU trans5_FlowCM_TARGET_MODE_page; \
	COMMAND trans5_FlowCM_TARGET_MODE_read; \
	COMMAND trans5_FlowCM_TARGET_MODE_write; \
	COLLECTION trans5_FlowCM_MODE_BLK; \
	VARIABLE trans5_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans5_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans5_FlowCM_MODE_BLK_Normal; \
	MENU trans5_FlowCM_MODE_BLK_page; \
	COMMAND trans5_FlowCM_MODE_BLK_read; \
	COLLECTION trans5_FlowCM_ALARM_SUM; \
	VARIABLE trans5_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans5_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans5_FlowCM_ALARM_SUM_Disabled; \
	MENU trans5_FlowCM_ALARM_SUM_page; \
	COMMAND trans5_FlowCM_ALARM_SUM_read; \
	VARIABLE trans5_FlowCM_CALIBR_FACTOR; \
	MENU trans5_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans5_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans5_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans5_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans5_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans5_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans5_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans5_FlowCM_MEASUREMENT_MODE; \
	MENU trans5_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans5_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans5_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans5_FlowCM_FLOW_DIRECTION; \
	MENU trans5_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans5_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans5_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans5_FlowCM_NOMINAL_SIZE; \
	MENU trans5_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans5_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans5_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans5_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans5_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans5_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans5_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans5_FlowCM_MASS_FLOW; \
	VARIABLE trans5_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans5_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans5_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans5_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans5_FlowCM_MASS_FLOW_page; \
	COMMAND trans5_FlowCM_MASS_FLOW_read; \
	VARIABLE trans5_FlowCM_MASS_FLOW_UNITS; \
	MENU trans5_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans5_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans5_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans5_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans5_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans5_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans5_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans5_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans5_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans5_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans5_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans5_FlowCM_DENSITY; \
	VARIABLE trans5_FlowCM_DENSITY_Value; \
	VARIABLE trans5_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans5_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans5_FlowCM_DENSITY_Status_Limit; \
	MENU trans5_FlowCM_DENSITY_page; \
	COMMAND trans5_FlowCM_DENSITY_read; \
	VARIABLE trans5_FlowCM_DENSITY_UNITS; \
	MENU trans5_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans5_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans5_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans5_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans5_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans5_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans5_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans5_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans5_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans5_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans5_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans5_FlowCM_TEMPERATURE; \
	VARIABLE trans5_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans5_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans5_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans5_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans5_FlowCM_TEMPERATURE_page; \
	COMMAND trans5_FlowCM_TEMPERATURE_read; \
	VARIABLE trans5_FlowCM_TEMPERATURE_UNITS; \
	MENU trans5_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans5_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans5_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans5_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans5_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans5_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans5_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans5_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans5_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans5_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans5_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans5_FlowCM_unit_nominal_size; \
	UNIT trans5_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans5_FlowCM_unit_density; \
	UNIT trans5_FlowCM_unit_temperature

#define USE_TRANS5_FLOWCM_MANDATORY_A \
	USE_TRANS5_FLOWCM_MANDATORY_BOTH; \
	MENU trans5_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS5_FLOWCM_MANDATORY_B \
	USE_TRANS5_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans5_FlowCM_VIEW_1; \
	MENU trans5_FlowCM_VIEW_1_page; \
	MENU trans5_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS5_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans5_FlowCM_ZERO_POINT; \
	MENU trans5_FlowCM_ZERO_POINT_page; \
	COMMAND trans5_FlowCM_ZERO_POINT_read; \
	COMMAND trans5_FlowCM_ZERO_POINT_write; \
	VARIABLE trans5_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans5_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans5_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans5_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans5_FlowCM_ZERO_POINT_UNIT; \
	MENU trans5_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans5_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans5_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans5_FlowCM_VIEW_2; \
	MENU trans5_FlowCM_VIEW_2_page; \
	COLLECTION trans5_FlowCM_VIEW_3; \
	MENU trans5_FlowCM_VIEW_3_page; \
	UNIT trans5_FlowCM_unit_zero_point

#define USE_TRANS5_FLOWCM_OPTIONAL_A \
	USE_TRANS5_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans5_FlowCM_VIEW_1; \
	MENU trans5_FlowCM_VIEW_1_page; \
	MENU trans5_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS5_FLOWCM_OPTIONAL_B \
	USE_TRANS5_FLOWCM_OPTIONAL_BOTH; \
	MENU trans5_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans5_FlowCM_)
#define USE_TRANS5_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans5_FlowCM_)
#define USE_TRANS5_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans5_FlowCM_)
#define USE_TRANS5_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans5_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_FLOWCM_MANDATORY_BOTH \
	BLOCK trans6_FlowCM_block; \
	COLLECTION trans6_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans6_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans6_FlowCM_ST_REV; \
	MENU trans6_FlowCM_ST_REV_page; \
	COMMAND trans6_FlowCM_ST_REV_read; \
	VARIABLE trans6_FlowCM_TAG_DESC; \
	MENU trans6_FlowCM_TAG_DESC_page; \
	COMMAND trans6_FlowCM_TAG_DESC_read; \
	COMMAND trans6_FlowCM_TAG_DESC_write; \
	VARIABLE trans6_FlowCM_STRATEGY; \
	MENU trans6_FlowCM_STRATEGY_page; \
	COMMAND trans6_FlowCM_STRATEGY_read; \
	COMMAND trans6_FlowCM_STRATEGY_write; \
	VARIABLE trans6_FlowCM_ALERT_KEY; \
	MENU trans6_FlowCM_ALERT_KEY_page; \
	COMMAND trans6_FlowCM_ALERT_KEY_read; \
	COMMAND trans6_FlowCM_ALERT_KEY_write; \
	VARIABLE trans6_FlowCM_TARGET_MODE; \
	MENU trans6_FlowCM_TARGET_MODE_page; \
	COMMAND trans6_FlowCM_TARGET_MODE_read; \
	COMMAND trans6_FlowCM_TARGET_MODE_write; \
	COLLECTION trans6_FlowCM_MODE_BLK; \
	VARIABLE trans6_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans6_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans6_FlowCM_MODE_BLK_Normal; \
	MENU trans6_FlowCM_MODE_BLK_page; \
	COMMAND trans6_FlowCM_MODE_BLK_read; \
	COLLECTION trans6_FlowCM_ALARM_SUM; \
	VARIABLE trans6_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans6_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans6_FlowCM_ALARM_SUM_Disabled; \
	MENU trans6_FlowCM_ALARM_SUM_page; \
	COMMAND trans6_FlowCM_ALARM_SUM_read; \
	VARIABLE trans6_FlowCM_CALIBR_FACTOR; \
	MENU trans6_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans6_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans6_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans6_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans6_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans6_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans6_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans6_FlowCM_MEASUREMENT_MODE; \
	MENU trans6_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans6_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans6_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans6_FlowCM_FLOW_DIRECTION; \
	MENU trans6_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans6_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans6_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans6_FlowCM_NOMINAL_SIZE; \
	MENU trans6_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans6_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans6_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans6_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans6_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans6_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans6_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans6_FlowCM_MASS_FLOW; \
	VARIABLE trans6_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans6_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans6_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans6_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans6_FlowCM_MASS_FLOW_page; \
	COMMAND trans6_FlowCM_MASS_FLOW_read; \
	VARIABLE trans6_FlowCM_MASS_FLOW_UNITS; \
	MENU trans6_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans6_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans6_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans6_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans6_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans6_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans6_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans6_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans6_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans6_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans6_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans6_FlowCM_DENSITY; \
	VARIABLE trans6_FlowCM_DENSITY_Value; \
	VARIABLE trans6_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans6_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans6_FlowCM_DENSITY_Status_Limit; \
	MENU trans6_FlowCM_DENSITY_page; \
	COMMAND trans6_FlowCM_DENSITY_read; \
	VARIABLE trans6_FlowCM_DENSITY_UNITS; \
	MENU trans6_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans6_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans6_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans6_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans6_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans6_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans6_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans6_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans6_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans6_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans6_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans6_FlowCM_TEMPERATURE; \
	VARIABLE trans6_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans6_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans6_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans6_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans6_FlowCM_TEMPERATURE_page; \
	COMMAND trans6_FlowCM_TEMPERATURE_read; \
	VARIABLE trans6_FlowCM_TEMPERATURE_UNITS; \
	MENU trans6_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans6_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans6_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans6_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans6_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans6_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans6_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans6_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans6_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans6_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans6_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans6_FlowCM_unit_nominal_size; \
	UNIT trans6_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans6_FlowCM_unit_density; \
	UNIT trans6_FlowCM_unit_temperature

#define USE_TRANS6_FLOWCM_MANDATORY_A \
	USE_TRANS6_FLOWCM_MANDATORY_BOTH; \
	MENU trans6_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS6_FLOWCM_MANDATORY_B \
	USE_TRANS6_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans6_FlowCM_VIEW_1; \
	MENU trans6_FlowCM_VIEW_1_page; \
	MENU trans6_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS6_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans6_FlowCM_ZERO_POINT; \
	MENU trans6_FlowCM_ZERO_POINT_page; \
	COMMAND trans6_FlowCM_ZERO_POINT_read; \
	COMMAND trans6_FlowCM_ZERO_POINT_write; \
	VARIABLE trans6_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans6_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans6_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans6_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans6_FlowCM_ZERO_POINT_UNIT; \
	MENU trans6_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans6_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans6_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans6_FlowCM_VIEW_2; \
	MENU trans6_FlowCM_VIEW_2_page; \
	COLLECTION trans6_FlowCM_VIEW_3; \
	MENU trans6_FlowCM_VIEW_3_page; \
	UNIT trans6_FlowCM_unit_zero_point

#define USE_TRANS6_FLOWCM_OPTIONAL_A \
	USE_TRANS6_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans6_FlowCM_VIEW_1; \
	MENU trans6_FlowCM_VIEW_1_page; \
	MENU trans6_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS6_FLOWCM_OPTIONAL_B \
	USE_TRANS6_FLOWCM_OPTIONAL_BOTH; \
	MENU trans6_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans6_FlowCM_)
#define USE_TRANS6_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans6_FlowCM_)
#define USE_TRANS6_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans6_FlowCM_)
#define USE_TRANS6_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans6_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_FLOWCM_MANDATORY_BOTH \
	BLOCK trans7_FlowCM_block; \
	COLLECTION trans7_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans7_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans7_FlowCM_ST_REV; \
	MENU trans7_FlowCM_ST_REV_page; \
	COMMAND trans7_FlowCM_ST_REV_read; \
	VARIABLE trans7_FlowCM_TAG_DESC; \
	MENU trans7_FlowCM_TAG_DESC_page; \
	COMMAND trans7_FlowCM_TAG_DESC_read; \
	COMMAND trans7_FlowCM_TAG_DESC_write; \
	VARIABLE trans7_FlowCM_STRATEGY; \
	MENU trans7_FlowCM_STRATEGY_page; \
	COMMAND trans7_FlowCM_STRATEGY_read; \
	COMMAND trans7_FlowCM_STRATEGY_write; \
	VARIABLE trans7_FlowCM_ALERT_KEY; \
	MENU trans7_FlowCM_ALERT_KEY_page; \
	COMMAND trans7_FlowCM_ALERT_KEY_read; \
	COMMAND trans7_FlowCM_ALERT_KEY_write; \
	VARIABLE trans7_FlowCM_TARGET_MODE; \
	MENU trans7_FlowCM_TARGET_MODE_page; \
	COMMAND trans7_FlowCM_TARGET_MODE_read; \
	COMMAND trans7_FlowCM_TARGET_MODE_write; \
	COLLECTION trans7_FlowCM_MODE_BLK; \
	VARIABLE trans7_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans7_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans7_FlowCM_MODE_BLK_Normal; \
	MENU trans7_FlowCM_MODE_BLK_page; \
	COMMAND trans7_FlowCM_MODE_BLK_read; \
	COLLECTION trans7_FlowCM_ALARM_SUM; \
	VARIABLE trans7_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans7_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans7_FlowCM_ALARM_SUM_Disabled; \
	MENU trans7_FlowCM_ALARM_SUM_page; \
	COMMAND trans7_FlowCM_ALARM_SUM_read; \
	VARIABLE trans7_FlowCM_CALIBR_FACTOR; \
	MENU trans7_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans7_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans7_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans7_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans7_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans7_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans7_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans7_FlowCM_MEASUREMENT_MODE; \
	MENU trans7_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans7_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans7_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans7_FlowCM_FLOW_DIRECTION; \
	MENU trans7_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans7_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans7_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans7_FlowCM_NOMINAL_SIZE; \
	MENU trans7_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans7_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans7_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans7_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans7_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans7_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans7_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans7_FlowCM_MASS_FLOW; \
	VARIABLE trans7_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans7_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans7_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans7_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans7_FlowCM_MASS_FLOW_page; \
	COMMAND trans7_FlowCM_MASS_FLOW_read; \
	VARIABLE trans7_FlowCM_MASS_FLOW_UNITS; \
	MENU trans7_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans7_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans7_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans7_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans7_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans7_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans7_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans7_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans7_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans7_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans7_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans7_FlowCM_DENSITY; \
	VARIABLE trans7_FlowCM_DENSITY_Value; \
	VARIABLE trans7_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans7_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans7_FlowCM_DENSITY_Status_Limit; \
	MENU trans7_FlowCM_DENSITY_page; \
	COMMAND trans7_FlowCM_DENSITY_read; \
	VARIABLE trans7_FlowCM_DENSITY_UNITS; \
	MENU trans7_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans7_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans7_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans7_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans7_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans7_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans7_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans7_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans7_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans7_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans7_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans7_FlowCM_TEMPERATURE; \
	VARIABLE trans7_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans7_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans7_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans7_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans7_FlowCM_TEMPERATURE_page; \
	COMMAND trans7_FlowCM_TEMPERATURE_read; \
	VARIABLE trans7_FlowCM_TEMPERATURE_UNITS; \
	MENU trans7_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans7_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans7_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans7_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans7_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans7_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans7_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans7_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans7_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans7_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans7_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans7_FlowCM_unit_nominal_size; \
	UNIT trans7_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans7_FlowCM_unit_density; \
	UNIT trans7_FlowCM_unit_temperature

#define USE_TRANS7_FLOWCM_MANDATORY_A \
	USE_TRANS7_FLOWCM_MANDATORY_BOTH; \
	MENU trans7_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS7_FLOWCM_MANDATORY_B \
	USE_TRANS7_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans7_FlowCM_VIEW_1; \
	MENU trans7_FlowCM_VIEW_1_page; \
	MENU trans7_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS7_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans7_FlowCM_ZERO_POINT; \
	MENU trans7_FlowCM_ZERO_POINT_page; \
	COMMAND trans7_FlowCM_ZERO_POINT_read; \
	COMMAND trans7_FlowCM_ZERO_POINT_write; \
	VARIABLE trans7_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans7_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans7_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans7_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans7_FlowCM_ZERO_POINT_UNIT; \
	MENU trans7_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans7_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans7_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans7_FlowCM_VIEW_2; \
	MENU trans7_FlowCM_VIEW_2_page; \
	COLLECTION trans7_FlowCM_VIEW_3; \
	MENU trans7_FlowCM_VIEW_3_page; \
	UNIT trans7_FlowCM_unit_zero_point

#define USE_TRANS7_FLOWCM_OPTIONAL_A \
	USE_TRANS7_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans7_FlowCM_VIEW_1; \
	MENU trans7_FlowCM_VIEW_1_page; \
	MENU trans7_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS7_FLOWCM_OPTIONAL_B \
	USE_TRANS7_FLOWCM_OPTIONAL_BOTH; \
	MENU trans7_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans7_FlowCM_)
#define USE_TRANS7_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans7_FlowCM_)
#define USE_TRANS7_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans7_FlowCM_)
#define USE_TRANS7_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans7_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_FLOWCM_MANDATORY_BOTH \
	BLOCK trans8_FlowCM_block; \
	COLLECTION trans8_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans8_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans8_FlowCM_ST_REV; \
	MENU trans8_FlowCM_ST_REV_page; \
	COMMAND trans8_FlowCM_ST_REV_read; \
	VARIABLE trans8_FlowCM_TAG_DESC; \
	MENU trans8_FlowCM_TAG_DESC_page; \
	COMMAND trans8_FlowCM_TAG_DESC_read; \
	COMMAND trans8_FlowCM_TAG_DESC_write; \
	VARIABLE trans8_FlowCM_STRATEGY; \
	MENU trans8_FlowCM_STRATEGY_page; \
	COMMAND trans8_FlowCM_STRATEGY_read; \
	COMMAND trans8_FlowCM_STRATEGY_write; \
	VARIABLE trans8_FlowCM_ALERT_KEY; \
	MENU trans8_FlowCM_ALERT_KEY_page; \
	COMMAND trans8_FlowCM_ALERT_KEY_read; \
	COMMAND trans8_FlowCM_ALERT_KEY_write; \
	VARIABLE trans8_FlowCM_TARGET_MODE; \
	MENU trans8_FlowCM_TARGET_MODE_page; \
	COMMAND trans8_FlowCM_TARGET_MODE_read; \
	COMMAND trans8_FlowCM_TARGET_MODE_write; \
	COLLECTION trans8_FlowCM_MODE_BLK; \
	VARIABLE trans8_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans8_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans8_FlowCM_MODE_BLK_Normal; \
	MENU trans8_FlowCM_MODE_BLK_page; \
	COMMAND trans8_FlowCM_MODE_BLK_read; \
	COLLECTION trans8_FlowCM_ALARM_SUM; \
	VARIABLE trans8_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans8_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans8_FlowCM_ALARM_SUM_Disabled; \
	MENU trans8_FlowCM_ALARM_SUM_page; \
	COMMAND trans8_FlowCM_ALARM_SUM_read; \
	VARIABLE trans8_FlowCM_CALIBR_FACTOR; \
	MENU trans8_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans8_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans8_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans8_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans8_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans8_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans8_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans8_FlowCM_MEASUREMENT_MODE; \
	MENU trans8_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans8_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans8_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans8_FlowCM_FLOW_DIRECTION; \
	MENU trans8_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans8_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans8_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans8_FlowCM_NOMINAL_SIZE; \
	MENU trans8_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans8_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans8_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans8_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans8_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans8_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans8_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans8_FlowCM_MASS_FLOW; \
	VARIABLE trans8_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans8_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans8_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans8_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans8_FlowCM_MASS_FLOW_page; \
	COMMAND trans8_FlowCM_MASS_FLOW_read; \
	VARIABLE trans8_FlowCM_MASS_FLOW_UNITS; \
	MENU trans8_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans8_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans8_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans8_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans8_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans8_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans8_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans8_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans8_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans8_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans8_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans8_FlowCM_DENSITY; \
	VARIABLE trans8_FlowCM_DENSITY_Value; \
	VARIABLE trans8_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans8_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans8_FlowCM_DENSITY_Status_Limit; \
	MENU trans8_FlowCM_DENSITY_page; \
	COMMAND trans8_FlowCM_DENSITY_read; \
	VARIABLE trans8_FlowCM_DENSITY_UNITS; \
	MENU trans8_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans8_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans8_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans8_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans8_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans8_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans8_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans8_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans8_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans8_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans8_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans8_FlowCM_TEMPERATURE; \
	VARIABLE trans8_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans8_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans8_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans8_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans8_FlowCM_TEMPERATURE_page; \
	COMMAND trans8_FlowCM_TEMPERATURE_read; \
	VARIABLE trans8_FlowCM_TEMPERATURE_UNITS; \
	MENU trans8_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans8_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans8_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans8_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans8_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans8_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans8_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans8_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans8_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans8_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans8_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans8_FlowCM_unit_nominal_size; \
	UNIT trans8_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans8_FlowCM_unit_density; \
	UNIT trans8_FlowCM_unit_temperature

#define USE_TRANS8_FLOWCM_MANDATORY_A \
	USE_TRANS8_FLOWCM_MANDATORY_BOTH; \
	MENU trans8_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS8_FLOWCM_MANDATORY_B \
	USE_TRANS8_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans8_FlowCM_VIEW_1; \
	MENU trans8_FlowCM_VIEW_1_page; \
	MENU trans8_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS8_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans8_FlowCM_ZERO_POINT; \
	MENU trans8_FlowCM_ZERO_POINT_page; \
	COMMAND trans8_FlowCM_ZERO_POINT_read; \
	COMMAND trans8_FlowCM_ZERO_POINT_write; \
	VARIABLE trans8_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans8_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans8_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans8_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans8_FlowCM_ZERO_POINT_UNIT; \
	MENU trans8_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans8_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans8_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans8_FlowCM_VIEW_2; \
	MENU trans8_FlowCM_VIEW_2_page; \
	COLLECTION trans8_FlowCM_VIEW_3; \
	MENU trans8_FlowCM_VIEW_3_page; \
	UNIT trans8_FlowCM_unit_zero_point

#define USE_TRANS8_FLOWCM_OPTIONAL_A \
	USE_TRANS8_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans8_FlowCM_VIEW_1; \
	MENU trans8_FlowCM_VIEW_1_page; \
	MENU trans8_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS8_FLOWCM_OPTIONAL_B \
	USE_TRANS8_FLOWCM_OPTIONAL_BOTH; \
	MENU trans8_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans8_FlowCM_)
#define USE_TRANS8_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans8_FlowCM_)
#define USE_TRANS8_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans8_FlowCM_)
#define USE_TRANS8_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans8_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_FLOWCM_MANDATORY_BOTH \
	BLOCK trans9_FlowCM_block; \
	COLLECTION trans9_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans9_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans9_FlowCM_ST_REV; \
	MENU trans9_FlowCM_ST_REV_page; \
	COMMAND trans9_FlowCM_ST_REV_read; \
	VARIABLE trans9_FlowCM_TAG_DESC; \
	MENU trans9_FlowCM_TAG_DESC_page; \
	COMMAND trans9_FlowCM_TAG_DESC_read; \
	COMMAND trans9_FlowCM_TAG_DESC_write; \
	VARIABLE trans9_FlowCM_STRATEGY; \
	MENU trans9_FlowCM_STRATEGY_page; \
	COMMAND trans9_FlowCM_STRATEGY_read; \
	COMMAND trans9_FlowCM_STRATEGY_write; \
	VARIABLE trans9_FlowCM_ALERT_KEY; \
	MENU trans9_FlowCM_ALERT_KEY_page; \
	COMMAND trans9_FlowCM_ALERT_KEY_read; \
	COMMAND trans9_FlowCM_ALERT_KEY_write; \
	VARIABLE trans9_FlowCM_TARGET_MODE; \
	MENU trans9_FlowCM_TARGET_MODE_page; \
	COMMAND trans9_FlowCM_TARGET_MODE_read; \
	COMMAND trans9_FlowCM_TARGET_MODE_write; \
	COLLECTION trans9_FlowCM_MODE_BLK; \
	VARIABLE trans9_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans9_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans9_FlowCM_MODE_BLK_Normal; \
	MENU trans9_FlowCM_MODE_BLK_page; \
	COMMAND trans9_FlowCM_MODE_BLK_read; \
	COLLECTION trans9_FlowCM_ALARM_SUM; \
	VARIABLE trans9_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans9_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans9_FlowCM_ALARM_SUM_Disabled; \
	MENU trans9_FlowCM_ALARM_SUM_page; \
	COMMAND trans9_FlowCM_ALARM_SUM_read; \
	VARIABLE trans9_FlowCM_CALIBR_FACTOR; \
	MENU trans9_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans9_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans9_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans9_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans9_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans9_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans9_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans9_FlowCM_MEASUREMENT_MODE; \
	MENU trans9_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans9_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans9_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans9_FlowCM_FLOW_DIRECTION; \
	MENU trans9_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans9_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans9_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans9_FlowCM_NOMINAL_SIZE; \
	MENU trans9_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans9_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans9_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans9_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans9_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans9_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans9_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans9_FlowCM_MASS_FLOW; \
	VARIABLE trans9_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans9_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans9_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans9_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans9_FlowCM_MASS_FLOW_page; \
	COMMAND trans9_FlowCM_MASS_FLOW_read; \
	VARIABLE trans9_FlowCM_MASS_FLOW_UNITS; \
	MENU trans9_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans9_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans9_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans9_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans9_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans9_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans9_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans9_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans9_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans9_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans9_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans9_FlowCM_DENSITY; \
	VARIABLE trans9_FlowCM_DENSITY_Value; \
	VARIABLE trans9_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans9_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans9_FlowCM_DENSITY_Status_Limit; \
	MENU trans9_FlowCM_DENSITY_page; \
	COMMAND trans9_FlowCM_DENSITY_read; \
	VARIABLE trans9_FlowCM_DENSITY_UNITS; \
	MENU trans9_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans9_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans9_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans9_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans9_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans9_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans9_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans9_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans9_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans9_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans9_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans9_FlowCM_TEMPERATURE; \
	VARIABLE trans9_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans9_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans9_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans9_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans9_FlowCM_TEMPERATURE_page; \
	COMMAND trans9_FlowCM_TEMPERATURE_read; \
	VARIABLE trans9_FlowCM_TEMPERATURE_UNITS; \
	MENU trans9_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans9_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans9_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans9_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans9_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans9_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans9_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans9_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans9_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans9_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans9_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans9_FlowCM_unit_nominal_size; \
	UNIT trans9_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans9_FlowCM_unit_density; \
	UNIT trans9_FlowCM_unit_temperature

#define USE_TRANS9_FLOWCM_MANDATORY_A \
	USE_TRANS9_FLOWCM_MANDATORY_BOTH; \
	MENU trans9_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS9_FLOWCM_MANDATORY_B \
	USE_TRANS9_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans9_FlowCM_VIEW_1; \
	MENU trans9_FlowCM_VIEW_1_page; \
	MENU trans9_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS9_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans9_FlowCM_ZERO_POINT; \
	MENU trans9_FlowCM_ZERO_POINT_page; \
	COMMAND trans9_FlowCM_ZERO_POINT_read; \
	COMMAND trans9_FlowCM_ZERO_POINT_write; \
	VARIABLE trans9_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans9_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans9_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans9_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans9_FlowCM_ZERO_POINT_UNIT; \
	MENU trans9_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans9_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans9_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans9_FlowCM_VIEW_2; \
	MENU trans9_FlowCM_VIEW_2_page; \
	COLLECTION trans9_FlowCM_VIEW_3; \
	MENU trans9_FlowCM_VIEW_3_page; \
	UNIT trans9_FlowCM_unit_zero_point

#define USE_TRANS9_FLOWCM_OPTIONAL_A \
	USE_TRANS9_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans9_FlowCM_VIEW_1; \
	MENU trans9_FlowCM_VIEW_1_page; \
	MENU trans9_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS9_FLOWCM_OPTIONAL_B \
	USE_TRANS9_FLOWCM_OPTIONAL_BOTH; \
	MENU trans9_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans9_FlowCM_)
#define USE_TRANS9_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans9_FlowCM_)
#define USE_TRANS9_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans9_FlowCM_)
#define USE_TRANS9_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans9_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_FLOWCM_MANDATORY_BOTH \
	BLOCK trans10_FlowCM_block; \
	COLLECTION trans10_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans10_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans10_FlowCM_ST_REV; \
	MENU trans10_FlowCM_ST_REV_page; \
	COMMAND trans10_FlowCM_ST_REV_read; \
	VARIABLE trans10_FlowCM_TAG_DESC; \
	MENU trans10_FlowCM_TAG_DESC_page; \
	COMMAND trans10_FlowCM_TAG_DESC_read; \
	COMMAND trans10_FlowCM_TAG_DESC_write; \
	VARIABLE trans10_FlowCM_STRATEGY; \
	MENU trans10_FlowCM_STRATEGY_page; \
	COMMAND trans10_FlowCM_STRATEGY_read; \
	COMMAND trans10_FlowCM_STRATEGY_write; \
	VARIABLE trans10_FlowCM_ALERT_KEY; \
	MENU trans10_FlowCM_ALERT_KEY_page; \
	COMMAND trans10_FlowCM_ALERT_KEY_read; \
	COMMAND trans10_FlowCM_ALERT_KEY_write; \
	VARIABLE trans10_FlowCM_TARGET_MODE; \
	MENU trans10_FlowCM_TARGET_MODE_page; \
	COMMAND trans10_FlowCM_TARGET_MODE_read; \
	COMMAND trans10_FlowCM_TARGET_MODE_write; \
	COLLECTION trans10_FlowCM_MODE_BLK; \
	VARIABLE trans10_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans10_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans10_FlowCM_MODE_BLK_Normal; \
	MENU trans10_FlowCM_MODE_BLK_page; \
	COMMAND trans10_FlowCM_MODE_BLK_read; \
	COLLECTION trans10_FlowCM_ALARM_SUM; \
	VARIABLE trans10_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans10_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans10_FlowCM_ALARM_SUM_Disabled; \
	MENU trans10_FlowCM_ALARM_SUM_page; \
	COMMAND trans10_FlowCM_ALARM_SUM_read; \
	VARIABLE trans10_FlowCM_CALIBR_FACTOR; \
	MENU trans10_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans10_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans10_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans10_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans10_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans10_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans10_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans10_FlowCM_MEASUREMENT_MODE; \
	MENU trans10_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans10_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans10_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans10_FlowCM_FLOW_DIRECTION; \
	MENU trans10_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans10_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans10_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans10_FlowCM_NOMINAL_SIZE; \
	MENU trans10_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans10_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans10_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans10_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans10_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans10_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans10_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans10_FlowCM_MASS_FLOW; \
	VARIABLE trans10_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans10_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans10_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans10_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans10_FlowCM_MASS_FLOW_page; \
	COMMAND trans10_FlowCM_MASS_FLOW_read; \
	VARIABLE trans10_FlowCM_MASS_FLOW_UNITS; \
	MENU trans10_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans10_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans10_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans10_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans10_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans10_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans10_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans10_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans10_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans10_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans10_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans10_FlowCM_DENSITY; \
	VARIABLE trans10_FlowCM_DENSITY_Value; \
	VARIABLE trans10_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans10_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans10_FlowCM_DENSITY_Status_Limit; \
	MENU trans10_FlowCM_DENSITY_page; \
	COMMAND trans10_FlowCM_DENSITY_read; \
	VARIABLE trans10_FlowCM_DENSITY_UNITS; \
	MENU trans10_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans10_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans10_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans10_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans10_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans10_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans10_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans10_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans10_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans10_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans10_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans10_FlowCM_TEMPERATURE; \
	VARIABLE trans10_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans10_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans10_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans10_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans10_FlowCM_TEMPERATURE_page; \
	COMMAND trans10_FlowCM_TEMPERATURE_read; \
	VARIABLE trans10_FlowCM_TEMPERATURE_UNITS; \
	MENU trans10_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans10_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans10_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans10_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans10_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans10_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans10_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans10_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans10_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans10_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans10_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans10_FlowCM_unit_nominal_size; \
	UNIT trans10_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans10_FlowCM_unit_density; \
	UNIT trans10_FlowCM_unit_temperature

#define USE_TRANS10_FLOWCM_MANDATORY_A \
	USE_TRANS10_FLOWCM_MANDATORY_BOTH; \
	MENU trans10_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS10_FLOWCM_MANDATORY_B \
	USE_TRANS10_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans10_FlowCM_VIEW_1; \
	MENU trans10_FlowCM_VIEW_1_page; \
	MENU trans10_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS10_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans10_FlowCM_ZERO_POINT; \
	MENU trans10_FlowCM_ZERO_POINT_page; \
	COMMAND trans10_FlowCM_ZERO_POINT_read; \
	COMMAND trans10_FlowCM_ZERO_POINT_write; \
	VARIABLE trans10_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans10_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans10_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans10_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans10_FlowCM_ZERO_POINT_UNIT; \
	MENU trans10_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans10_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans10_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans10_FlowCM_VIEW_2; \
	MENU trans10_FlowCM_VIEW_2_page; \
	COLLECTION trans10_FlowCM_VIEW_3; \
	MENU trans10_FlowCM_VIEW_3_page; \
	UNIT trans10_FlowCM_unit_zero_point

#define USE_TRANS10_FLOWCM_OPTIONAL_A \
	USE_TRANS10_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans10_FlowCM_VIEW_1; \
	MENU trans10_FlowCM_VIEW_1_page; \
	MENU trans10_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS10_FLOWCM_OPTIONAL_B \
	USE_TRANS10_FLOWCM_OPTIONAL_BOTH; \
	MENU trans10_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans10_FlowCM_)
#define USE_TRANS10_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans10_FlowCM_)
#define USE_TRANS10_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans10_FlowCM_)
#define USE_TRANS10_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans10_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_FLOWCM_MANDATORY_BOTH \
	BLOCK trans11_FlowCM_block; \
	COLLECTION trans11_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans11_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans11_FlowCM_ST_REV; \
	MENU trans11_FlowCM_ST_REV_page; \
	COMMAND trans11_FlowCM_ST_REV_read; \
	VARIABLE trans11_FlowCM_TAG_DESC; \
	MENU trans11_FlowCM_TAG_DESC_page; \
	COMMAND trans11_FlowCM_TAG_DESC_read; \
	COMMAND trans11_FlowCM_TAG_DESC_write; \
	VARIABLE trans11_FlowCM_STRATEGY; \
	MENU trans11_FlowCM_STRATEGY_page; \
	COMMAND trans11_FlowCM_STRATEGY_read; \
	COMMAND trans11_FlowCM_STRATEGY_write; \
	VARIABLE trans11_FlowCM_ALERT_KEY; \
	MENU trans11_FlowCM_ALERT_KEY_page; \
	COMMAND trans11_FlowCM_ALERT_KEY_read; \
	COMMAND trans11_FlowCM_ALERT_KEY_write; \
	VARIABLE trans11_FlowCM_TARGET_MODE; \
	MENU trans11_FlowCM_TARGET_MODE_page; \
	COMMAND trans11_FlowCM_TARGET_MODE_read; \
	COMMAND trans11_FlowCM_TARGET_MODE_write; \
	COLLECTION trans11_FlowCM_MODE_BLK; \
	VARIABLE trans11_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans11_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans11_FlowCM_MODE_BLK_Normal; \
	MENU trans11_FlowCM_MODE_BLK_page; \
	COMMAND trans11_FlowCM_MODE_BLK_read; \
	COLLECTION trans11_FlowCM_ALARM_SUM; \
	VARIABLE trans11_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans11_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans11_FlowCM_ALARM_SUM_Disabled; \
	MENU trans11_FlowCM_ALARM_SUM_page; \
	COMMAND trans11_FlowCM_ALARM_SUM_read; \
	VARIABLE trans11_FlowCM_CALIBR_FACTOR; \
	MENU trans11_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans11_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans11_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans11_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans11_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans11_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans11_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans11_FlowCM_MEASUREMENT_MODE; \
	MENU trans11_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans11_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans11_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans11_FlowCM_FLOW_DIRECTION; \
	MENU trans11_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans11_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans11_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans11_FlowCM_NOMINAL_SIZE; \
	MENU trans11_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans11_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans11_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans11_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans11_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans11_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans11_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans11_FlowCM_MASS_FLOW; \
	VARIABLE trans11_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans11_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans11_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans11_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans11_FlowCM_MASS_FLOW_page; \
	COMMAND trans11_FlowCM_MASS_FLOW_read; \
	VARIABLE trans11_FlowCM_MASS_FLOW_UNITS; \
	MENU trans11_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans11_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans11_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans11_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans11_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans11_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans11_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans11_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans11_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans11_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans11_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans11_FlowCM_DENSITY; \
	VARIABLE trans11_FlowCM_DENSITY_Value; \
	VARIABLE trans11_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans11_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans11_FlowCM_DENSITY_Status_Limit; \
	MENU trans11_FlowCM_DENSITY_page; \
	COMMAND trans11_FlowCM_DENSITY_read; \
	VARIABLE trans11_FlowCM_DENSITY_UNITS; \
	MENU trans11_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans11_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans11_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans11_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans11_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans11_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans11_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans11_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans11_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans11_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans11_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans11_FlowCM_TEMPERATURE; \
	VARIABLE trans11_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans11_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans11_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans11_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans11_FlowCM_TEMPERATURE_page; \
	COMMAND trans11_FlowCM_TEMPERATURE_read; \
	VARIABLE trans11_FlowCM_TEMPERATURE_UNITS; \
	MENU trans11_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans11_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans11_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans11_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans11_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans11_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans11_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans11_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans11_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans11_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans11_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans11_FlowCM_unit_nominal_size; \
	UNIT trans11_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans11_FlowCM_unit_density; \
	UNIT trans11_FlowCM_unit_temperature

#define USE_TRANS11_FLOWCM_MANDATORY_A \
	USE_TRANS11_FLOWCM_MANDATORY_BOTH; \
	MENU trans11_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS11_FLOWCM_MANDATORY_B \
	USE_TRANS11_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans11_FlowCM_VIEW_1; \
	MENU trans11_FlowCM_VIEW_1_page; \
	MENU trans11_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS11_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans11_FlowCM_ZERO_POINT; \
	MENU trans11_FlowCM_ZERO_POINT_page; \
	COMMAND trans11_FlowCM_ZERO_POINT_read; \
	COMMAND trans11_FlowCM_ZERO_POINT_write; \
	VARIABLE trans11_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans11_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans11_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans11_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans11_FlowCM_ZERO_POINT_UNIT; \
	MENU trans11_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans11_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans11_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans11_FlowCM_VIEW_2; \
	MENU trans11_FlowCM_VIEW_2_page; \
	COLLECTION trans11_FlowCM_VIEW_3; \
	MENU trans11_FlowCM_VIEW_3_page; \
	UNIT trans11_FlowCM_unit_zero_point

#define USE_TRANS11_FLOWCM_OPTIONAL_A \
	USE_TRANS11_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans11_FlowCM_VIEW_1; \
	MENU trans11_FlowCM_VIEW_1_page; \
	MENU trans11_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS11_FLOWCM_OPTIONAL_B \
	USE_TRANS11_FLOWCM_OPTIONAL_BOTH; \
	MENU trans11_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans11_FlowCM_)
#define USE_TRANS11_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans11_FlowCM_)
#define USE_TRANS11_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans11_FlowCM_)
#define USE_TRANS11_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans11_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_FLOWCM_MANDATORY_BOTH \
	BLOCK trans12_FlowCM_block; \
	COLLECTION trans12_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans12_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans12_FlowCM_ST_REV; \
	MENU trans12_FlowCM_ST_REV_page; \
	COMMAND trans12_FlowCM_ST_REV_read; \
	VARIABLE trans12_FlowCM_TAG_DESC; \
	MENU trans12_FlowCM_TAG_DESC_page; \
	COMMAND trans12_FlowCM_TAG_DESC_read; \
	COMMAND trans12_FlowCM_TAG_DESC_write; \
	VARIABLE trans12_FlowCM_STRATEGY; \
	MENU trans12_FlowCM_STRATEGY_page; \
	COMMAND trans12_FlowCM_STRATEGY_read; \
	COMMAND trans12_FlowCM_STRATEGY_write; \
	VARIABLE trans12_FlowCM_ALERT_KEY; \
	MENU trans12_FlowCM_ALERT_KEY_page; \
	COMMAND trans12_FlowCM_ALERT_KEY_read; \
	COMMAND trans12_FlowCM_ALERT_KEY_write; \
	VARIABLE trans12_FlowCM_TARGET_MODE; \
	MENU trans12_FlowCM_TARGET_MODE_page; \
	COMMAND trans12_FlowCM_TARGET_MODE_read; \
	COMMAND trans12_FlowCM_TARGET_MODE_write; \
	COLLECTION trans12_FlowCM_MODE_BLK; \
	VARIABLE trans12_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans12_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans12_FlowCM_MODE_BLK_Normal; \
	MENU trans12_FlowCM_MODE_BLK_page; \
	COMMAND trans12_FlowCM_MODE_BLK_read; \
	COLLECTION trans12_FlowCM_ALARM_SUM; \
	VARIABLE trans12_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans12_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans12_FlowCM_ALARM_SUM_Disabled; \
	MENU trans12_FlowCM_ALARM_SUM_page; \
	COMMAND trans12_FlowCM_ALARM_SUM_read; \
	VARIABLE trans12_FlowCM_CALIBR_FACTOR; \
	MENU trans12_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans12_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans12_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans12_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans12_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans12_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans12_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans12_FlowCM_MEASUREMENT_MODE; \
	MENU trans12_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans12_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans12_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans12_FlowCM_FLOW_DIRECTION; \
	MENU trans12_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans12_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans12_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans12_FlowCM_NOMINAL_SIZE; \
	MENU trans12_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans12_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans12_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans12_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans12_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans12_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans12_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans12_FlowCM_MASS_FLOW; \
	VARIABLE trans12_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans12_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans12_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans12_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans12_FlowCM_MASS_FLOW_page; \
	COMMAND trans12_FlowCM_MASS_FLOW_read; \
	VARIABLE trans12_FlowCM_MASS_FLOW_UNITS; \
	MENU trans12_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans12_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans12_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans12_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans12_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans12_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans12_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans12_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans12_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans12_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans12_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans12_FlowCM_DENSITY; \
	VARIABLE trans12_FlowCM_DENSITY_Value; \
	VARIABLE trans12_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans12_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans12_FlowCM_DENSITY_Status_Limit; \
	MENU trans12_FlowCM_DENSITY_page; \
	COMMAND trans12_FlowCM_DENSITY_read; \
	VARIABLE trans12_FlowCM_DENSITY_UNITS; \
	MENU trans12_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans12_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans12_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans12_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans12_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans12_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans12_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans12_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans12_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans12_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans12_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans12_FlowCM_TEMPERATURE; \
	VARIABLE trans12_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans12_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans12_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans12_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans12_FlowCM_TEMPERATURE_page; \
	COMMAND trans12_FlowCM_TEMPERATURE_read; \
	VARIABLE trans12_FlowCM_TEMPERATURE_UNITS; \
	MENU trans12_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans12_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans12_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans12_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans12_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans12_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans12_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans12_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans12_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans12_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans12_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans12_FlowCM_unit_nominal_size; \
	UNIT trans12_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans12_FlowCM_unit_density; \
	UNIT trans12_FlowCM_unit_temperature

#define USE_TRANS12_FLOWCM_MANDATORY_A \
	USE_TRANS12_FLOWCM_MANDATORY_BOTH; \
	MENU trans12_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS12_FLOWCM_MANDATORY_B \
	USE_TRANS12_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans12_FlowCM_VIEW_1; \
	MENU trans12_FlowCM_VIEW_1_page; \
	MENU trans12_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS12_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans12_FlowCM_ZERO_POINT; \
	MENU trans12_FlowCM_ZERO_POINT_page; \
	COMMAND trans12_FlowCM_ZERO_POINT_read; \
	COMMAND trans12_FlowCM_ZERO_POINT_write; \
	VARIABLE trans12_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans12_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans12_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans12_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans12_FlowCM_ZERO_POINT_UNIT; \
	MENU trans12_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans12_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans12_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans12_FlowCM_VIEW_2; \
	MENU trans12_FlowCM_VIEW_2_page; \
	COLLECTION trans12_FlowCM_VIEW_3; \
	MENU trans12_FlowCM_VIEW_3_page; \
	UNIT trans12_FlowCM_unit_zero_point

#define USE_TRANS12_FLOWCM_OPTIONAL_A \
	USE_TRANS12_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans12_FlowCM_VIEW_1; \
	MENU trans12_FlowCM_VIEW_1_page; \
	MENU trans12_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS12_FLOWCM_OPTIONAL_B \
	USE_TRANS12_FLOWCM_OPTIONAL_BOTH; \
	MENU trans12_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans12_FlowCM_)
#define USE_TRANS12_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans12_FlowCM_)
#define USE_TRANS12_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans12_FlowCM_)
#define USE_TRANS12_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans12_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_FLOWCM_MANDATORY_BOTH \
	BLOCK trans13_FlowCM_block; \
	COLLECTION trans13_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans13_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans13_FlowCM_ST_REV; \
	MENU trans13_FlowCM_ST_REV_page; \
	COMMAND trans13_FlowCM_ST_REV_read; \
	VARIABLE trans13_FlowCM_TAG_DESC; \
	MENU trans13_FlowCM_TAG_DESC_page; \
	COMMAND trans13_FlowCM_TAG_DESC_read; \
	COMMAND trans13_FlowCM_TAG_DESC_write; \
	VARIABLE trans13_FlowCM_STRATEGY; \
	MENU trans13_FlowCM_STRATEGY_page; \
	COMMAND trans13_FlowCM_STRATEGY_read; \
	COMMAND trans13_FlowCM_STRATEGY_write; \
	VARIABLE trans13_FlowCM_ALERT_KEY; \
	MENU trans13_FlowCM_ALERT_KEY_page; \
	COMMAND trans13_FlowCM_ALERT_KEY_read; \
	COMMAND trans13_FlowCM_ALERT_KEY_write; \
	VARIABLE trans13_FlowCM_TARGET_MODE; \
	MENU trans13_FlowCM_TARGET_MODE_page; \
	COMMAND trans13_FlowCM_TARGET_MODE_read; \
	COMMAND trans13_FlowCM_TARGET_MODE_write; \
	COLLECTION trans13_FlowCM_MODE_BLK; \
	VARIABLE trans13_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans13_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans13_FlowCM_MODE_BLK_Normal; \
	MENU trans13_FlowCM_MODE_BLK_page; \
	COMMAND trans13_FlowCM_MODE_BLK_read; \
	COLLECTION trans13_FlowCM_ALARM_SUM; \
	VARIABLE trans13_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans13_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans13_FlowCM_ALARM_SUM_Disabled; \
	MENU trans13_FlowCM_ALARM_SUM_page; \
	COMMAND trans13_FlowCM_ALARM_SUM_read; \
	VARIABLE trans13_FlowCM_CALIBR_FACTOR; \
	MENU trans13_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans13_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans13_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans13_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans13_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans13_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans13_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans13_FlowCM_MEASUREMENT_MODE; \
	MENU trans13_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans13_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans13_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans13_FlowCM_FLOW_DIRECTION; \
	MENU trans13_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans13_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans13_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans13_FlowCM_NOMINAL_SIZE; \
	MENU trans13_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans13_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans13_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans13_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans13_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans13_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans13_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans13_FlowCM_MASS_FLOW; \
	VARIABLE trans13_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans13_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans13_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans13_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans13_FlowCM_MASS_FLOW_page; \
	COMMAND trans13_FlowCM_MASS_FLOW_read; \
	VARIABLE trans13_FlowCM_MASS_FLOW_UNITS; \
	MENU trans13_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans13_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans13_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans13_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans13_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans13_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans13_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans13_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans13_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans13_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans13_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans13_FlowCM_DENSITY; \
	VARIABLE trans13_FlowCM_DENSITY_Value; \
	VARIABLE trans13_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans13_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans13_FlowCM_DENSITY_Status_Limit; \
	MENU trans13_FlowCM_DENSITY_page; \
	COMMAND trans13_FlowCM_DENSITY_read; \
	VARIABLE trans13_FlowCM_DENSITY_UNITS; \
	MENU trans13_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans13_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans13_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans13_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans13_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans13_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans13_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans13_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans13_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans13_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans13_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans13_FlowCM_TEMPERATURE; \
	VARIABLE trans13_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans13_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans13_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans13_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans13_FlowCM_TEMPERATURE_page; \
	COMMAND trans13_FlowCM_TEMPERATURE_read; \
	VARIABLE trans13_FlowCM_TEMPERATURE_UNITS; \
	MENU trans13_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans13_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans13_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans13_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans13_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans13_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans13_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans13_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans13_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans13_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans13_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans13_FlowCM_unit_nominal_size; \
	UNIT trans13_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans13_FlowCM_unit_density; \
	UNIT trans13_FlowCM_unit_temperature

#define USE_TRANS13_FLOWCM_MANDATORY_A \
	USE_TRANS13_FLOWCM_MANDATORY_BOTH; \
	MENU trans13_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS13_FLOWCM_MANDATORY_B \
	USE_TRANS13_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans13_FlowCM_VIEW_1; \
	MENU trans13_FlowCM_VIEW_1_page; \
	MENU trans13_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS13_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans13_FlowCM_ZERO_POINT; \
	MENU trans13_FlowCM_ZERO_POINT_page; \
	COMMAND trans13_FlowCM_ZERO_POINT_read; \
	COMMAND trans13_FlowCM_ZERO_POINT_write; \
	VARIABLE trans13_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans13_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans13_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans13_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans13_FlowCM_ZERO_POINT_UNIT; \
	MENU trans13_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans13_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans13_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans13_FlowCM_VIEW_2; \
	MENU trans13_FlowCM_VIEW_2_page; \
	COLLECTION trans13_FlowCM_VIEW_3; \
	MENU trans13_FlowCM_VIEW_3_page; \
	UNIT trans13_FlowCM_unit_zero_point

#define USE_TRANS13_FLOWCM_OPTIONAL_A \
	USE_TRANS13_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans13_FlowCM_VIEW_1; \
	MENU trans13_FlowCM_VIEW_1_page; \
	MENU trans13_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS13_FLOWCM_OPTIONAL_B \
	USE_TRANS13_FLOWCM_OPTIONAL_BOTH; \
	MENU trans13_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans13_FlowCM_)
#define USE_TRANS13_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans13_FlowCM_)
#define USE_TRANS13_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans13_FlowCM_)
#define USE_TRANS13_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans13_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_FLOWCM_MANDATORY_BOTH \
	BLOCK trans14_FlowCM_block; \
	COLLECTION trans14_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans14_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans14_FlowCM_ST_REV; \
	MENU trans14_FlowCM_ST_REV_page; \
	COMMAND trans14_FlowCM_ST_REV_read; \
	VARIABLE trans14_FlowCM_TAG_DESC; \
	MENU trans14_FlowCM_TAG_DESC_page; \
	COMMAND trans14_FlowCM_TAG_DESC_read; \
	COMMAND trans14_FlowCM_TAG_DESC_write; \
	VARIABLE trans14_FlowCM_STRATEGY; \
	MENU trans14_FlowCM_STRATEGY_page; \
	COMMAND trans14_FlowCM_STRATEGY_read; \
	COMMAND trans14_FlowCM_STRATEGY_write; \
	VARIABLE trans14_FlowCM_ALERT_KEY; \
	MENU trans14_FlowCM_ALERT_KEY_page; \
	COMMAND trans14_FlowCM_ALERT_KEY_read; \
	COMMAND trans14_FlowCM_ALERT_KEY_write; \
	VARIABLE trans14_FlowCM_TARGET_MODE; \
	MENU trans14_FlowCM_TARGET_MODE_page; \
	COMMAND trans14_FlowCM_TARGET_MODE_read; \
	COMMAND trans14_FlowCM_TARGET_MODE_write; \
	COLLECTION trans14_FlowCM_MODE_BLK; \
	VARIABLE trans14_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans14_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans14_FlowCM_MODE_BLK_Normal; \
	MENU trans14_FlowCM_MODE_BLK_page; \
	COMMAND trans14_FlowCM_MODE_BLK_read; \
	COLLECTION trans14_FlowCM_ALARM_SUM; \
	VARIABLE trans14_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans14_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans14_FlowCM_ALARM_SUM_Disabled; \
	MENU trans14_FlowCM_ALARM_SUM_page; \
	COMMAND trans14_FlowCM_ALARM_SUM_read; \
	VARIABLE trans14_FlowCM_CALIBR_FACTOR; \
	MENU trans14_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans14_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans14_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans14_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans14_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans14_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans14_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans14_FlowCM_MEASUREMENT_MODE; \
	MENU trans14_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans14_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans14_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans14_FlowCM_FLOW_DIRECTION; \
	MENU trans14_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans14_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans14_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans14_FlowCM_NOMINAL_SIZE; \
	MENU trans14_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans14_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans14_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans14_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans14_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans14_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans14_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans14_FlowCM_MASS_FLOW; \
	VARIABLE trans14_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans14_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans14_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans14_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans14_FlowCM_MASS_FLOW_page; \
	COMMAND trans14_FlowCM_MASS_FLOW_read; \
	VARIABLE trans14_FlowCM_MASS_FLOW_UNITS; \
	MENU trans14_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans14_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans14_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans14_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans14_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans14_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans14_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans14_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans14_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans14_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans14_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans14_FlowCM_DENSITY; \
	VARIABLE trans14_FlowCM_DENSITY_Value; \
	VARIABLE trans14_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans14_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans14_FlowCM_DENSITY_Status_Limit; \
	MENU trans14_FlowCM_DENSITY_page; \
	COMMAND trans14_FlowCM_DENSITY_read; \
	VARIABLE trans14_FlowCM_DENSITY_UNITS; \
	MENU trans14_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans14_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans14_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans14_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans14_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans14_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans14_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans14_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans14_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans14_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans14_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans14_FlowCM_TEMPERATURE; \
	VARIABLE trans14_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans14_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans14_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans14_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans14_FlowCM_TEMPERATURE_page; \
	COMMAND trans14_FlowCM_TEMPERATURE_read; \
	VARIABLE trans14_FlowCM_TEMPERATURE_UNITS; \
	MENU trans14_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans14_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans14_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans14_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans14_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans14_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans14_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans14_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans14_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans14_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans14_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans14_FlowCM_unit_nominal_size; \
	UNIT trans14_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans14_FlowCM_unit_density; \
	UNIT trans14_FlowCM_unit_temperature

#define USE_TRANS14_FLOWCM_MANDATORY_A \
	USE_TRANS14_FLOWCM_MANDATORY_BOTH; \
	MENU trans14_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS14_FLOWCM_MANDATORY_B \
	USE_TRANS14_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans14_FlowCM_VIEW_1; \
	MENU trans14_FlowCM_VIEW_1_page; \
	MENU trans14_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS14_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans14_FlowCM_ZERO_POINT; \
	MENU trans14_FlowCM_ZERO_POINT_page; \
	COMMAND trans14_FlowCM_ZERO_POINT_read; \
	COMMAND trans14_FlowCM_ZERO_POINT_write; \
	VARIABLE trans14_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans14_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans14_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans14_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans14_FlowCM_ZERO_POINT_UNIT; \
	MENU trans14_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans14_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans14_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans14_FlowCM_VIEW_2; \
	MENU trans14_FlowCM_VIEW_2_page; \
	COLLECTION trans14_FlowCM_VIEW_3; \
	MENU trans14_FlowCM_VIEW_3_page; \
	UNIT trans14_FlowCM_unit_zero_point

#define USE_TRANS14_FLOWCM_OPTIONAL_A \
	USE_TRANS14_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans14_FlowCM_VIEW_1; \
	MENU trans14_FlowCM_VIEW_1_page; \
	MENU trans14_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS14_FLOWCM_OPTIONAL_B \
	USE_TRANS14_FLOWCM_OPTIONAL_BOTH; \
	MENU trans14_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans14_FlowCM_)
#define USE_TRANS14_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans14_FlowCM_)
#define USE_TRANS14_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans14_FlowCM_)
#define USE_TRANS14_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans14_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_FLOWCM_MANDATORY_BOTH \
	BLOCK trans15_FlowCM_block; \
	COLLECTION trans15_FlowCM_BLOCK_OBJECT; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Class; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_FlowCM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_FlowCM_BLOCK_OBJECT_page; \
	COMMAND trans15_FlowCM_BLOCK_OBJECT_read; \
	VARIABLE trans15_FlowCM_ST_REV; \
	MENU trans15_FlowCM_ST_REV_page; \
	COMMAND trans15_FlowCM_ST_REV_read; \
	VARIABLE trans15_FlowCM_TAG_DESC; \
	MENU trans15_FlowCM_TAG_DESC_page; \
	COMMAND trans15_FlowCM_TAG_DESC_read; \
	COMMAND trans15_FlowCM_TAG_DESC_write; \
	VARIABLE trans15_FlowCM_STRATEGY; \
	MENU trans15_FlowCM_STRATEGY_page; \
	COMMAND trans15_FlowCM_STRATEGY_read; \
	COMMAND trans15_FlowCM_STRATEGY_write; \
	VARIABLE trans15_FlowCM_ALERT_KEY; \
	MENU trans15_FlowCM_ALERT_KEY_page; \
	COMMAND trans15_FlowCM_ALERT_KEY_read; \
	COMMAND trans15_FlowCM_ALERT_KEY_write; \
	VARIABLE trans15_FlowCM_TARGET_MODE; \
	MENU trans15_FlowCM_TARGET_MODE_page; \
	COMMAND trans15_FlowCM_TARGET_MODE_read; \
	COMMAND trans15_FlowCM_TARGET_MODE_write; \
	COLLECTION trans15_FlowCM_MODE_BLK; \
	VARIABLE trans15_FlowCM_MODE_BLK_Actual; \
	VARIABLE trans15_FlowCM_MODE_BLK_Permitted; \
	VARIABLE trans15_FlowCM_MODE_BLK_Normal; \
	MENU trans15_FlowCM_MODE_BLK_page; \
	COMMAND trans15_FlowCM_MODE_BLK_read; \
	COLLECTION trans15_FlowCM_ALARM_SUM; \
	VARIABLE trans15_FlowCM_ALARM_SUM_Current; \
	VARIABLE trans15_FlowCM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_FlowCM_ALARM_SUM_Unreported; \
	VARIABLE trans15_FlowCM_ALARM_SUM_Disabled; \
	MENU trans15_FlowCM_ALARM_SUM_page; \
	COMMAND trans15_FlowCM_ALARM_SUM_read; \
	VARIABLE trans15_FlowCM_CALIBR_FACTOR; \
	MENU trans15_FlowCM_CALIBR_FACTOR_page; \
	COMMAND trans15_FlowCM_CALIBR_FACTOR_read; \
	COMMAND trans15_FlowCM_CALIBR_FACTOR_write; \
	VARIABLE trans15_FlowCM_LOW_FLOW_CUTOFF; \
	MENU trans15_FlowCM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans15_FlowCM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans15_FlowCM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans15_FlowCM_MEASUREMENT_MODE; \
	MENU trans15_FlowCM_MEASUREMENT_MODE_page; \
	COMMAND trans15_FlowCM_MEASUREMENT_MODE_read; \
	COMMAND trans15_FlowCM_MEASUREMENT_MODE_write; \
	VARIABLE trans15_FlowCM_FLOW_DIRECTION; \
	MENU trans15_FlowCM_FLOW_DIRECTION_page; \
	COMMAND trans15_FlowCM_FLOW_DIRECTION_read; \
	COMMAND trans15_FlowCM_FLOW_DIRECTION_write; \
	VARIABLE trans15_FlowCM_NOMINAL_SIZE; \
	MENU trans15_FlowCM_NOMINAL_SIZE_page; \
	COMMAND trans15_FlowCM_NOMINAL_SIZE_read; \
	COMMAND trans15_FlowCM_NOMINAL_SIZE_write; \
	VARIABLE trans15_FlowCM_NOMINAL_SIZE_UNITS; \
	MENU trans15_FlowCM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans15_FlowCM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans15_FlowCM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans15_FlowCM_MASS_FLOW; \
	VARIABLE trans15_FlowCM_MASS_FLOW_Value; \
	VARIABLE trans15_FlowCM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans15_FlowCM_MASS_FLOW_Status_Quality; \
	VARIABLE trans15_FlowCM_MASS_FLOW_Status_Limit; \
	MENU trans15_FlowCM_MASS_FLOW_page; \
	COMMAND trans15_FlowCM_MASS_FLOW_read; \
	VARIABLE trans15_FlowCM_MASS_FLOW_UNITS; \
	MENU trans15_FlowCM_MASS_FLOW_UNITS_page; \
	COMMAND trans15_FlowCM_MASS_FLOW_UNITS_read; \
	COMMAND trans15_FlowCM_MASS_FLOW_UNITS_write; \
	VARIABLE trans15_FlowCM_MASS_FLOW_LO_LIMIT; \
	MENU trans15_FlowCM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans15_FlowCM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans15_FlowCM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans15_FlowCM_MASS_FLOW_HI_LIMIT; \
	MENU trans15_FlowCM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans15_FlowCM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans15_FlowCM_MASS_FLOW_HI_LIMIT_write; \
	COLLECTION trans15_FlowCM_DENSITY; \
	VARIABLE trans15_FlowCM_DENSITY_Value; \
	VARIABLE trans15_FlowCM_DENSITY_Status_Condensed; \
	VARIABLE trans15_FlowCM_DENSITY_Status_Quality; \
	VARIABLE trans15_FlowCM_DENSITY_Status_Limit; \
	MENU trans15_FlowCM_DENSITY_page; \
	COMMAND trans15_FlowCM_DENSITY_read; \
	VARIABLE trans15_FlowCM_DENSITY_UNITS; \
	MENU trans15_FlowCM_DENSITY_UNITS_page; \
	COMMAND trans15_FlowCM_DENSITY_UNITS_read; \
	COMMAND trans15_FlowCM_DENSITY_UNITS_write; \
	VARIABLE trans15_FlowCM_DENSITY_LO_LIMIT; \
	MENU trans15_FlowCM_DENSITY_LO_LIMIT_page; \
	COMMAND trans15_FlowCM_DENSITY_LO_LIMIT_read; \
	COMMAND trans15_FlowCM_DENSITY_LO_LIMIT_write; \
	VARIABLE trans15_FlowCM_DENSITY_HI_LIMIT; \
	MENU trans15_FlowCM_DENSITY_HI_LIMIT_page; \
	COMMAND trans15_FlowCM_DENSITY_HI_LIMIT_read; \
	COMMAND trans15_FlowCM_DENSITY_HI_LIMIT_write; \
	COLLECTION trans15_FlowCM_TEMPERATURE; \
	VARIABLE trans15_FlowCM_TEMPERATURE_Value; \
	VARIABLE trans15_FlowCM_TEMPERATURE_Status_Condensed; \
	VARIABLE trans15_FlowCM_TEMPERATURE_Status_Quality; \
	VARIABLE trans15_FlowCM_TEMPERATURE_Status_Limit; \
	MENU trans15_FlowCM_TEMPERATURE_page; \
	COMMAND trans15_FlowCM_TEMPERATURE_read; \
	VARIABLE trans15_FlowCM_TEMPERATURE_UNITS; \
	MENU trans15_FlowCM_TEMPERATURE_UNITS_page; \
	COMMAND trans15_FlowCM_TEMPERATURE_UNITS_read; \
	COMMAND trans15_FlowCM_TEMPERATURE_UNITS_write; \
	VARIABLE trans15_FlowCM_TEMPERATURE_LO_LIMIT; \
	MENU trans15_FlowCM_TEMPERATURE_LO_LIMIT_page; \
	COMMAND trans15_FlowCM_TEMPERATURE_LO_LIMIT_read; \
	COMMAND trans15_FlowCM_TEMPERATURE_LO_LIMIT_write; \
	VARIABLE trans15_FlowCM_TEMPERATURE_HI_LIMIT; \
	MENU trans15_FlowCM_TEMPERATURE_HI_LIMIT_page; \
	COMMAND trans15_FlowCM_TEMPERATURE_HI_LIMIT_read; \
	COMMAND trans15_FlowCM_TEMPERATURE_HI_LIMIT_write; \
	UNIT trans15_FlowCM_unit_nominal_size; \
	UNIT trans15_FlowCM_unit_TB_MASS_FLOW_UNIT; \
	UNIT trans15_FlowCM_unit_density; \
	UNIT trans15_FlowCM_unit_temperature

#define USE_TRANS15_FLOWCM_MANDATORY_A \
	USE_TRANS15_FLOWCM_MANDATORY_BOTH; \
	MENU trans15_FlowCM_Simple_Dialog_Mandatory_A

#define USE_TRANS15_FLOWCM_MANDATORY_B \
	USE_TRANS15_FLOWCM_MANDATORY_BOTH; \
	COLLECTION trans15_FlowCM_VIEW_1; \
	MENU trans15_FlowCM_VIEW_1_page; \
	MENU trans15_FlowCM_Simple_Dialog_Mandatory_B

#define USE_TRANS15_FLOWCM_OPTIONAL_BOTH \
	VARIABLE trans15_FlowCM_ZERO_POINT; \
	MENU trans15_FlowCM_ZERO_POINT_page; \
	COMMAND trans15_FlowCM_ZERO_POINT_read; \
	COMMAND trans15_FlowCM_ZERO_POINT_write; \
	VARIABLE trans15_FlowCM_ZERO_POINT_ADJUST; \
	MENU trans15_FlowCM_ZERO_POINT_ADJUST_page; \
	COMMAND trans15_FlowCM_ZERO_POINT_ADJUST_read; \
	COMMAND trans15_FlowCM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans15_FlowCM_ZERO_POINT_UNIT; \
	MENU trans15_FlowCM_ZERO_POINT_UNIT_page; \
	COMMAND trans15_FlowCM_ZERO_POINT_UNIT_read; \
	COMMAND trans15_FlowCM_ZERO_POINT_UNIT_write; \
	COLLECTION trans15_FlowCM_VIEW_2; \
	MENU trans15_FlowCM_VIEW_2_page; \
	COLLECTION trans15_FlowCM_VIEW_3; \
	MENU trans15_FlowCM_VIEW_3_page; \
	UNIT trans15_FlowCM_unit_zero_point

#define USE_TRANS15_FLOWCM_OPTIONAL_A \
	USE_TRANS15_FLOWCM_OPTIONAL_BOTH; \
	COLLECTION trans15_FlowCM_VIEW_1; \
	MENU trans15_FlowCM_VIEW_1_page; \
	MENU trans15_FlowCM_Simple_Dialog_Optional_A

#define USE_TRANS15_FLOWCM_OPTIONAL_B \
	USE_TRANS15_FLOWCM_OPTIONAL_BOTH; \
	MENU trans15_FlowCM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_FLOWCM_MANDATORY_A USE_TRANS_FLOWCM_MANDATORY_A(trans15_FlowCM_)
#define USE_TRANS15_FLOWCM_MANDATORY_B USE_TRANS_FLOWCM_MANDATORY_B(trans15_FlowCM_)
#define USE_TRANS15_FLOWCM_OPTIONAL_A  USE_TRANS_FLOWCM_OPTIONAL_A(trans15_FlowCM_)
#define USE_TRANS15_FLOWCM_OPTIONAL_B  USE_TRANS_FLOWCM_OPTIONAL_B(trans15_FlowCM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_FLOWE_MANDATORY_BOTH \
	BLOCK trans1_FlowE_block; \
	COLLECTION trans1_FlowE_BLOCK_OBJECT; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans1_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans1_FlowE_ST_REV; \
	MENU trans1_FlowE_ST_REV_page; \
	COMMAND trans1_FlowE_ST_REV_read; \
	VARIABLE trans1_FlowE_TAG_DESC; \
	MENU trans1_FlowE_TAG_DESC_page; \
	COMMAND trans1_FlowE_TAG_DESC_read; \
	COMMAND trans1_FlowE_TAG_DESC_write; \
	VARIABLE trans1_FlowE_STRATEGY; \
	MENU trans1_FlowE_STRATEGY_page; \
	COMMAND trans1_FlowE_STRATEGY_read; \
	COMMAND trans1_FlowE_STRATEGY_write; \
	VARIABLE trans1_FlowE_ALERT_KEY; \
	MENU trans1_FlowE_ALERT_KEY_page; \
	COMMAND trans1_FlowE_ALERT_KEY_read; \
	COMMAND trans1_FlowE_ALERT_KEY_write; \
	VARIABLE trans1_FlowE_TARGET_MODE; \
	MENU trans1_FlowE_TARGET_MODE_page; \
	COMMAND trans1_FlowE_TARGET_MODE_read; \
	COMMAND trans1_FlowE_TARGET_MODE_write; \
	COLLECTION trans1_FlowE_MODE_BLK; \
	VARIABLE trans1_FlowE_MODE_BLK_Actual; \
	VARIABLE trans1_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans1_FlowE_MODE_BLK_Normal; \
	MENU trans1_FlowE_MODE_BLK_page; \
	COMMAND trans1_FlowE_MODE_BLK_read; \
	COLLECTION trans1_FlowE_ALARM_SUM; \
	VARIABLE trans1_FlowE_ALARM_SUM_Current; \
	VARIABLE trans1_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans1_FlowE_ALARM_SUM_Disabled; \
	MENU trans1_FlowE_ALARM_SUM_page; \
	COMMAND trans1_FlowE_ALARM_SUM_read; \
	VARIABLE trans1_FlowE_CALIBR_FACTOR; \
	MENU trans1_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans1_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans1_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans1_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans1_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans1_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans1_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans1_FlowE_MEASUREMENT_MODE; \
	MENU trans1_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans1_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans1_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans1_FlowE_FLOW_DIRECTION; \
	MENU trans1_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans1_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans1_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans1_FlowE_NOMINAL_SIZE; \
	MENU trans1_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans1_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans1_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans1_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans1_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans1_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans1_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans1_FlowE_VOLUME_FLOW; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans1_FlowE_VOLUME_FLOW_page; \
	COMMAND trans1_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans1_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans1_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans1_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans1_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans1_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans1_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans1_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans1_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans1_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans1_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans1_FlowE_SAMPLING_FREQ; \
	VARIABLE trans1_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans1_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans1_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans1_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans1_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans1_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans1_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans1_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans1_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans1_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans1_FlowE_unit_nominal_size; \
	UNIT trans1_FlowE_unit_volume_flow; \
	UNIT trans1_FlowE_unit_sampling_freq

#define USE_TRANS1_FLOWE_MANDATORY_A \
	USE_TRANS1_FLOWE_MANDATORY_BOTH; \
	MENU trans1_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS1_FLOWE_MANDATORY_B \
	USE_TRANS1_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans1_FlowE_VIEW_1; \
	MENU trans1_FlowE_VIEW_1_page; \
	MENU trans1_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS1_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans1_FlowE_ZERO_POINT; \
	MENU trans1_FlowE_ZERO_POINT_page; \
	COMMAND trans1_FlowE_ZERO_POINT_read; \
	COMMAND trans1_FlowE_ZERO_POINT_write; \
	VARIABLE trans1_FlowE_ZERO_POINT_ADJUST; \
	MENU trans1_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans1_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans1_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans1_FlowE_ZERO_POINT_UNIT; \
	MENU trans1_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans1_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans1_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans1_FlowE_VIEW_2; \
	MENU trans1_FlowE_VIEW_2_page; \
	COLLECTION trans1_FlowE_VIEW_3; \
	MENU trans1_FlowE_VIEW_3_page; \
	UNIT trans1_FlowE_unit_zero_point

#define USE_TRANS1_FLOWE_OPTIONAL_A \
	USE_TRANS1_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans1_FlowE_VIEW_1; \
	MENU trans1_FlowE_VIEW_1_page; \
	MENU trans1_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS1_FLOWE_OPTIONAL_B \
	USE_TRANS1_FLOWE_OPTIONAL_BOTH; \
	MENU trans1_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_FLOWE_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CALIBR_FACTOR; \
	MENU prefix ## CALIBR_FACTOR_page; \
	COMMAND prefix ## CALIBR_FACTOR_read; \
	COMMAND prefix ## CALIBR_FACTOR_write; \
	VARIABLE prefix ## LOW_FLOW_CUTOFF; \
	MENU prefix ## LOW_FLOW_CUTOFF_page; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_read; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_write; \
	VARIABLE prefix ## MEASUREMENT_MODE; \
	MENU prefix ## MEASUREMENT_MODE_page; \
	COMMAND prefix ## MEASUREMENT_MODE_read; \
	COMMAND prefix ## MEASUREMENT_MODE_write; \
	VARIABLE prefix ## FLOW_DIRECTION; \
	MENU prefix ## FLOW_DIRECTION_page; \
	COMMAND prefix ## FLOW_DIRECTION_read; \
	COMMAND prefix ## FLOW_DIRECTION_write; \
	VARIABLE prefix ## NOMINAL_SIZE; \
	MENU prefix ## NOMINAL_SIZE_page; \
	COMMAND prefix ## NOMINAL_SIZE_read; \
	COMMAND prefix ## NOMINAL_SIZE_write; \
	VARIABLE prefix ## NOMINAL_SIZE_UNITS; \
	MENU prefix ## NOMINAL_SIZE_UNITS_page; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_read; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_write; \
	COLLECTION prefix ## VOLUME_FLOW; \
	VARIABLE prefix ## VOLUME_FLOW_Value; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Condensed; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Quality; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Limit; \
	MENU prefix ## VOLUME_FLOW_page; \
	COMMAND prefix ## VOLUME_FLOW_read; \
	VARIABLE prefix ## VOLUME_FLOW_UNITS; \
	MENU prefix ## VOLUME_FLOW_UNITS_page; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_read; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_write; \
	VARIABLE prefix ## VOLUME_FLOW_LO_LIMIT; \
	MENU prefix ## VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE prefix ## VOLUME_FLOW_HI_LIMIT; \
	MENU prefix ## VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION prefix ## SAMPLING_FREQ; \
	VARIABLE prefix ## SAMPLING_FREQ_Value; \
	VARIABLE prefix ## SAMPLING_FREQ_Status_Condensed; \
	VARIABLE prefix ## SAMPLING_FREQ_Status_Quality; \
	VARIABLE prefix ## SAMPLING_FREQ_Status_Limit; \
	MENU prefix ## SAMPLING_FREQ_page; \
	COMMAND prefix ## SAMPLING_FREQ_read; \
	VARIABLE prefix ## SAMPLING_FREQ_UNITS; \
	MENU prefix ## SAMPLING_FREQ_UNITS_page; \
	COMMAND prefix ## SAMPLING_FREQ_UNITS_read; \
	COMMAND prefix ## SAMPLING_FREQ_UNITS_write; \
	UNIT prefix ## unit_nominal_size; \
	UNIT prefix ## unit_volume_flow; \
	UNIT prefix ## unit_sampling_freq

#define USE_TRANS_FLOWE_MANDATORY_A(prefix) \
	USE_TRANS_FLOWE_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_FLOWE_MANDATORY_B(prefix) \
	USE_TRANS_FLOWE_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_FLOWE_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ZERO_POINT; \
	MENU prefix ## ZERO_POINT_page; \
	COMMAND prefix ## ZERO_POINT_read; \
	COMMAND prefix ## ZERO_POINT_write; \
	VARIABLE prefix ## ZERO_POINT_ADJUST; \
	MENU prefix ## ZERO_POINT_ADJUST_page; \
	COMMAND prefix ## ZERO_POINT_ADJUST_read; \
	COMMAND prefix ## ZERO_POINT_ADJUST_write; \
	VARIABLE prefix ## ZERO_POINT_UNIT; \
	MENU prefix ## ZERO_POINT_UNIT_page; \
	COMMAND prefix ## ZERO_POINT_UNIT_read; \
	COMMAND prefix ## ZERO_POINT_UNIT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## unit_zero_point

#define USE_TRANS_FLOWE_OPTIONAL_A(prefix) \
	USE_TRANS_FLOWE_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_FLOWE_OPTIONAL_B(prefix) \
	USE_TRANS_FLOWE_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans1_FlowE_)
#define USE_TRANS1_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans1_FlowE_)
#define USE_TRANS1_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans1_FlowE_)
#define USE_TRANS1_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans1_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_FLOWE_MANDATORY_BOTH \
	BLOCK trans2_FlowE_block; \
	COLLECTION trans2_FlowE_BLOCK_OBJECT; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans2_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans2_FlowE_ST_REV; \
	MENU trans2_FlowE_ST_REV_page; \
	COMMAND trans2_FlowE_ST_REV_read; \
	VARIABLE trans2_FlowE_TAG_DESC; \
	MENU trans2_FlowE_TAG_DESC_page; \
	COMMAND trans2_FlowE_TAG_DESC_read; \
	COMMAND trans2_FlowE_TAG_DESC_write; \
	VARIABLE trans2_FlowE_STRATEGY; \
	MENU trans2_FlowE_STRATEGY_page; \
	COMMAND trans2_FlowE_STRATEGY_read; \
	COMMAND trans2_FlowE_STRATEGY_write; \
	VARIABLE trans2_FlowE_ALERT_KEY; \
	MENU trans2_FlowE_ALERT_KEY_page; \
	COMMAND trans2_FlowE_ALERT_KEY_read; \
	COMMAND trans2_FlowE_ALERT_KEY_write; \
	VARIABLE trans2_FlowE_TARGET_MODE; \
	MENU trans2_FlowE_TARGET_MODE_page; \
	COMMAND trans2_FlowE_TARGET_MODE_read; \
	COMMAND trans2_FlowE_TARGET_MODE_write; \
	COLLECTION trans2_FlowE_MODE_BLK; \
	VARIABLE trans2_FlowE_MODE_BLK_Actual; \
	VARIABLE trans2_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans2_FlowE_MODE_BLK_Normal; \
	MENU trans2_FlowE_MODE_BLK_page; \
	COMMAND trans2_FlowE_MODE_BLK_read; \
	COLLECTION trans2_FlowE_ALARM_SUM; \
	VARIABLE trans2_FlowE_ALARM_SUM_Current; \
	VARIABLE trans2_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans2_FlowE_ALARM_SUM_Disabled; \
	MENU trans2_FlowE_ALARM_SUM_page; \
	COMMAND trans2_FlowE_ALARM_SUM_read; \
	VARIABLE trans2_FlowE_CALIBR_FACTOR; \
	MENU trans2_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans2_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans2_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans2_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans2_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans2_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans2_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans2_FlowE_MEASUREMENT_MODE; \
	MENU trans2_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans2_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans2_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans2_FlowE_FLOW_DIRECTION; \
	MENU trans2_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans2_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans2_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans2_FlowE_NOMINAL_SIZE; \
	MENU trans2_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans2_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans2_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans2_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans2_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans2_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans2_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans2_FlowE_VOLUME_FLOW; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans2_FlowE_VOLUME_FLOW_page; \
	COMMAND trans2_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans2_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans2_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans2_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans2_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans2_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans2_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans2_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans2_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans2_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans2_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans2_FlowE_SAMPLING_FREQ; \
	VARIABLE trans2_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans2_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans2_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans2_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans2_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans2_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans2_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans2_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans2_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans2_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans2_FlowE_unit_nominal_size; \
	UNIT trans2_FlowE_unit_volume_flow; \
	UNIT trans2_FlowE_unit_sampling_freq

#define USE_TRANS2_FLOWE_MANDATORY_A \
	USE_TRANS2_FLOWE_MANDATORY_BOTH; \
	MENU trans2_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS2_FLOWE_MANDATORY_B \
	USE_TRANS2_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans2_FlowE_VIEW_1; \
	MENU trans2_FlowE_VIEW_1_page; \
	MENU trans2_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS2_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans2_FlowE_ZERO_POINT; \
	MENU trans2_FlowE_ZERO_POINT_page; \
	COMMAND trans2_FlowE_ZERO_POINT_read; \
	COMMAND trans2_FlowE_ZERO_POINT_write; \
	VARIABLE trans2_FlowE_ZERO_POINT_ADJUST; \
	MENU trans2_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans2_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans2_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans2_FlowE_ZERO_POINT_UNIT; \
	MENU trans2_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans2_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans2_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans2_FlowE_VIEW_2; \
	MENU trans2_FlowE_VIEW_2_page; \
	COLLECTION trans2_FlowE_VIEW_3; \
	MENU trans2_FlowE_VIEW_3_page; \
	UNIT trans2_FlowE_unit_zero_point

#define USE_TRANS2_FLOWE_OPTIONAL_A \
	USE_TRANS2_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans2_FlowE_VIEW_1; \
	MENU trans2_FlowE_VIEW_1_page; \
	MENU trans2_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS2_FLOWE_OPTIONAL_B \
	USE_TRANS2_FLOWE_OPTIONAL_BOTH; \
	MENU trans2_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans2_FlowE_)
#define USE_TRANS2_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans2_FlowE_)
#define USE_TRANS2_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans2_FlowE_)
#define USE_TRANS2_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans2_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_FLOWE_MANDATORY_BOTH \
	BLOCK trans3_FlowE_block; \
	COLLECTION trans3_FlowE_BLOCK_OBJECT; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans3_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans3_FlowE_ST_REV; \
	MENU trans3_FlowE_ST_REV_page; \
	COMMAND trans3_FlowE_ST_REV_read; \
	VARIABLE trans3_FlowE_TAG_DESC; \
	MENU trans3_FlowE_TAG_DESC_page; \
	COMMAND trans3_FlowE_TAG_DESC_read; \
	COMMAND trans3_FlowE_TAG_DESC_write; \
	VARIABLE trans3_FlowE_STRATEGY; \
	MENU trans3_FlowE_STRATEGY_page; \
	COMMAND trans3_FlowE_STRATEGY_read; \
	COMMAND trans3_FlowE_STRATEGY_write; \
	VARIABLE trans3_FlowE_ALERT_KEY; \
	MENU trans3_FlowE_ALERT_KEY_page; \
	COMMAND trans3_FlowE_ALERT_KEY_read; \
	COMMAND trans3_FlowE_ALERT_KEY_write; \
	VARIABLE trans3_FlowE_TARGET_MODE; \
	MENU trans3_FlowE_TARGET_MODE_page; \
	COMMAND trans3_FlowE_TARGET_MODE_read; \
	COMMAND trans3_FlowE_TARGET_MODE_write; \
	COLLECTION trans3_FlowE_MODE_BLK; \
	VARIABLE trans3_FlowE_MODE_BLK_Actual; \
	VARIABLE trans3_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans3_FlowE_MODE_BLK_Normal; \
	MENU trans3_FlowE_MODE_BLK_page; \
	COMMAND trans3_FlowE_MODE_BLK_read; \
	COLLECTION trans3_FlowE_ALARM_SUM; \
	VARIABLE trans3_FlowE_ALARM_SUM_Current; \
	VARIABLE trans3_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans3_FlowE_ALARM_SUM_Disabled; \
	MENU trans3_FlowE_ALARM_SUM_page; \
	COMMAND trans3_FlowE_ALARM_SUM_read; \
	VARIABLE trans3_FlowE_CALIBR_FACTOR; \
	MENU trans3_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans3_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans3_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans3_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans3_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans3_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans3_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans3_FlowE_MEASUREMENT_MODE; \
	MENU trans3_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans3_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans3_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans3_FlowE_FLOW_DIRECTION; \
	MENU trans3_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans3_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans3_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans3_FlowE_NOMINAL_SIZE; \
	MENU trans3_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans3_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans3_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans3_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans3_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans3_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans3_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans3_FlowE_VOLUME_FLOW; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans3_FlowE_VOLUME_FLOW_page; \
	COMMAND trans3_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans3_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans3_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans3_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans3_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans3_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans3_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans3_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans3_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans3_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans3_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans3_FlowE_SAMPLING_FREQ; \
	VARIABLE trans3_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans3_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans3_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans3_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans3_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans3_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans3_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans3_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans3_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans3_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans3_FlowE_unit_nominal_size; \
	UNIT trans3_FlowE_unit_volume_flow; \
	UNIT trans3_FlowE_unit_sampling_freq

#define USE_TRANS3_FLOWE_MANDATORY_A \
	USE_TRANS3_FLOWE_MANDATORY_BOTH; \
	MENU trans3_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS3_FLOWE_MANDATORY_B \
	USE_TRANS3_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans3_FlowE_VIEW_1; \
	MENU trans3_FlowE_VIEW_1_page; \
	MENU trans3_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS3_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans3_FlowE_ZERO_POINT; \
	MENU trans3_FlowE_ZERO_POINT_page; \
	COMMAND trans3_FlowE_ZERO_POINT_read; \
	COMMAND trans3_FlowE_ZERO_POINT_write; \
	VARIABLE trans3_FlowE_ZERO_POINT_ADJUST; \
	MENU trans3_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans3_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans3_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans3_FlowE_ZERO_POINT_UNIT; \
	MENU trans3_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans3_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans3_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans3_FlowE_VIEW_2; \
	MENU trans3_FlowE_VIEW_2_page; \
	COLLECTION trans3_FlowE_VIEW_3; \
	MENU trans3_FlowE_VIEW_3_page; \
	UNIT trans3_FlowE_unit_zero_point

#define USE_TRANS3_FLOWE_OPTIONAL_A \
	USE_TRANS3_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans3_FlowE_VIEW_1; \
	MENU trans3_FlowE_VIEW_1_page; \
	MENU trans3_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS3_FLOWE_OPTIONAL_B \
	USE_TRANS3_FLOWE_OPTIONAL_BOTH; \
	MENU trans3_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans3_FlowE_)
#define USE_TRANS3_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans3_FlowE_)
#define USE_TRANS3_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans3_FlowE_)
#define USE_TRANS3_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans3_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_FLOWE_MANDATORY_BOTH \
	BLOCK trans4_FlowE_block; \
	COLLECTION trans4_FlowE_BLOCK_OBJECT; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans4_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans4_FlowE_ST_REV; \
	MENU trans4_FlowE_ST_REV_page; \
	COMMAND trans4_FlowE_ST_REV_read; \
	VARIABLE trans4_FlowE_TAG_DESC; \
	MENU trans4_FlowE_TAG_DESC_page; \
	COMMAND trans4_FlowE_TAG_DESC_read; \
	COMMAND trans4_FlowE_TAG_DESC_write; \
	VARIABLE trans4_FlowE_STRATEGY; \
	MENU trans4_FlowE_STRATEGY_page; \
	COMMAND trans4_FlowE_STRATEGY_read; \
	COMMAND trans4_FlowE_STRATEGY_write; \
	VARIABLE trans4_FlowE_ALERT_KEY; \
	MENU trans4_FlowE_ALERT_KEY_page; \
	COMMAND trans4_FlowE_ALERT_KEY_read; \
	COMMAND trans4_FlowE_ALERT_KEY_write; \
	VARIABLE trans4_FlowE_TARGET_MODE; \
	MENU trans4_FlowE_TARGET_MODE_page; \
	COMMAND trans4_FlowE_TARGET_MODE_read; \
	COMMAND trans4_FlowE_TARGET_MODE_write; \
	COLLECTION trans4_FlowE_MODE_BLK; \
	VARIABLE trans4_FlowE_MODE_BLK_Actual; \
	VARIABLE trans4_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans4_FlowE_MODE_BLK_Normal; \
	MENU trans4_FlowE_MODE_BLK_page; \
	COMMAND trans4_FlowE_MODE_BLK_read; \
	COLLECTION trans4_FlowE_ALARM_SUM; \
	VARIABLE trans4_FlowE_ALARM_SUM_Current; \
	VARIABLE trans4_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans4_FlowE_ALARM_SUM_Disabled; \
	MENU trans4_FlowE_ALARM_SUM_page; \
	COMMAND trans4_FlowE_ALARM_SUM_read; \
	VARIABLE trans4_FlowE_CALIBR_FACTOR; \
	MENU trans4_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans4_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans4_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans4_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans4_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans4_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans4_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans4_FlowE_MEASUREMENT_MODE; \
	MENU trans4_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans4_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans4_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans4_FlowE_FLOW_DIRECTION; \
	MENU trans4_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans4_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans4_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans4_FlowE_NOMINAL_SIZE; \
	MENU trans4_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans4_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans4_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans4_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans4_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans4_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans4_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans4_FlowE_VOLUME_FLOW; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans4_FlowE_VOLUME_FLOW_page; \
	COMMAND trans4_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans4_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans4_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans4_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans4_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans4_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans4_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans4_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans4_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans4_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans4_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans4_FlowE_SAMPLING_FREQ; \
	VARIABLE trans4_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans4_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans4_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans4_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans4_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans4_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans4_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans4_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans4_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans4_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans4_FlowE_unit_nominal_size; \
	UNIT trans4_FlowE_unit_volume_flow; \
	UNIT trans4_FlowE_unit_sampling_freq

#define USE_TRANS4_FLOWE_MANDATORY_A \
	USE_TRANS4_FLOWE_MANDATORY_BOTH; \
	MENU trans4_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS4_FLOWE_MANDATORY_B \
	USE_TRANS4_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans4_FlowE_VIEW_1; \
	MENU trans4_FlowE_VIEW_1_page; \
	MENU trans4_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS4_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans4_FlowE_ZERO_POINT; \
	MENU trans4_FlowE_ZERO_POINT_page; \
	COMMAND trans4_FlowE_ZERO_POINT_read; \
	COMMAND trans4_FlowE_ZERO_POINT_write; \
	VARIABLE trans4_FlowE_ZERO_POINT_ADJUST; \
	MENU trans4_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans4_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans4_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans4_FlowE_ZERO_POINT_UNIT; \
	MENU trans4_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans4_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans4_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans4_FlowE_VIEW_2; \
	MENU trans4_FlowE_VIEW_2_page; \
	COLLECTION trans4_FlowE_VIEW_3; \
	MENU trans4_FlowE_VIEW_3_page; \
	UNIT trans4_FlowE_unit_zero_point

#define USE_TRANS4_FLOWE_OPTIONAL_A \
	USE_TRANS4_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans4_FlowE_VIEW_1; \
	MENU trans4_FlowE_VIEW_1_page; \
	MENU trans4_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS4_FLOWE_OPTIONAL_B \
	USE_TRANS4_FLOWE_OPTIONAL_BOTH; \
	MENU trans4_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans4_FlowE_)
#define USE_TRANS4_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans4_FlowE_)
#define USE_TRANS4_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans4_FlowE_)
#define USE_TRANS4_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans4_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_FLOWE_MANDATORY_BOTH \
	BLOCK trans5_FlowE_block; \
	COLLECTION trans5_FlowE_BLOCK_OBJECT; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans5_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans5_FlowE_ST_REV; \
	MENU trans5_FlowE_ST_REV_page; \
	COMMAND trans5_FlowE_ST_REV_read; \
	VARIABLE trans5_FlowE_TAG_DESC; \
	MENU trans5_FlowE_TAG_DESC_page; \
	COMMAND trans5_FlowE_TAG_DESC_read; \
	COMMAND trans5_FlowE_TAG_DESC_write; \
	VARIABLE trans5_FlowE_STRATEGY; \
	MENU trans5_FlowE_STRATEGY_page; \
	COMMAND trans5_FlowE_STRATEGY_read; \
	COMMAND trans5_FlowE_STRATEGY_write; \
	VARIABLE trans5_FlowE_ALERT_KEY; \
	MENU trans5_FlowE_ALERT_KEY_page; \
	COMMAND trans5_FlowE_ALERT_KEY_read; \
	COMMAND trans5_FlowE_ALERT_KEY_write; \
	VARIABLE trans5_FlowE_TARGET_MODE; \
	MENU trans5_FlowE_TARGET_MODE_page; \
	COMMAND trans5_FlowE_TARGET_MODE_read; \
	COMMAND trans5_FlowE_TARGET_MODE_write; \
	COLLECTION trans5_FlowE_MODE_BLK; \
	VARIABLE trans5_FlowE_MODE_BLK_Actual; \
	VARIABLE trans5_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans5_FlowE_MODE_BLK_Normal; \
	MENU trans5_FlowE_MODE_BLK_page; \
	COMMAND trans5_FlowE_MODE_BLK_read; \
	COLLECTION trans5_FlowE_ALARM_SUM; \
	VARIABLE trans5_FlowE_ALARM_SUM_Current; \
	VARIABLE trans5_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans5_FlowE_ALARM_SUM_Disabled; \
	MENU trans5_FlowE_ALARM_SUM_page; \
	COMMAND trans5_FlowE_ALARM_SUM_read; \
	VARIABLE trans5_FlowE_CALIBR_FACTOR; \
	MENU trans5_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans5_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans5_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans5_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans5_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans5_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans5_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans5_FlowE_MEASUREMENT_MODE; \
	MENU trans5_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans5_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans5_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans5_FlowE_FLOW_DIRECTION; \
	MENU trans5_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans5_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans5_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans5_FlowE_NOMINAL_SIZE; \
	MENU trans5_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans5_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans5_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans5_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans5_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans5_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans5_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans5_FlowE_VOLUME_FLOW; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans5_FlowE_VOLUME_FLOW_page; \
	COMMAND trans5_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans5_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans5_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans5_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans5_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans5_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans5_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans5_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans5_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans5_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans5_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans5_FlowE_SAMPLING_FREQ; \
	VARIABLE trans5_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans5_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans5_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans5_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans5_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans5_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans5_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans5_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans5_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans5_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans5_FlowE_unit_nominal_size; \
	UNIT trans5_FlowE_unit_volume_flow; \
	UNIT trans5_FlowE_unit_sampling_freq

#define USE_TRANS5_FLOWE_MANDATORY_A \
	USE_TRANS5_FLOWE_MANDATORY_BOTH; \
	MENU trans5_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS5_FLOWE_MANDATORY_B \
	USE_TRANS5_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans5_FlowE_VIEW_1; \
	MENU trans5_FlowE_VIEW_1_page; \
	MENU trans5_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS5_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans5_FlowE_ZERO_POINT; \
	MENU trans5_FlowE_ZERO_POINT_page; \
	COMMAND trans5_FlowE_ZERO_POINT_read; \
	COMMAND trans5_FlowE_ZERO_POINT_write; \
	VARIABLE trans5_FlowE_ZERO_POINT_ADJUST; \
	MENU trans5_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans5_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans5_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans5_FlowE_ZERO_POINT_UNIT; \
	MENU trans5_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans5_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans5_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans5_FlowE_VIEW_2; \
	MENU trans5_FlowE_VIEW_2_page; \
	COLLECTION trans5_FlowE_VIEW_3; \
	MENU trans5_FlowE_VIEW_3_page; \
	UNIT trans5_FlowE_unit_zero_point

#define USE_TRANS5_FLOWE_OPTIONAL_A \
	USE_TRANS5_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans5_FlowE_VIEW_1; \
	MENU trans5_FlowE_VIEW_1_page; \
	MENU trans5_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS5_FLOWE_OPTIONAL_B \
	USE_TRANS5_FLOWE_OPTIONAL_BOTH; \
	MENU trans5_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans5_FlowE_)
#define USE_TRANS5_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans5_FlowE_)
#define USE_TRANS5_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans5_FlowE_)
#define USE_TRANS5_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans5_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_FLOWE_MANDATORY_BOTH \
	BLOCK trans6_FlowE_block; \
	COLLECTION trans6_FlowE_BLOCK_OBJECT; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans6_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans6_FlowE_ST_REV; \
	MENU trans6_FlowE_ST_REV_page; \
	COMMAND trans6_FlowE_ST_REV_read; \
	VARIABLE trans6_FlowE_TAG_DESC; \
	MENU trans6_FlowE_TAG_DESC_page; \
	COMMAND trans6_FlowE_TAG_DESC_read; \
	COMMAND trans6_FlowE_TAG_DESC_write; \
	VARIABLE trans6_FlowE_STRATEGY; \
	MENU trans6_FlowE_STRATEGY_page; \
	COMMAND trans6_FlowE_STRATEGY_read; \
	COMMAND trans6_FlowE_STRATEGY_write; \
	VARIABLE trans6_FlowE_ALERT_KEY; \
	MENU trans6_FlowE_ALERT_KEY_page; \
	COMMAND trans6_FlowE_ALERT_KEY_read; \
	COMMAND trans6_FlowE_ALERT_KEY_write; \
	VARIABLE trans6_FlowE_TARGET_MODE; \
	MENU trans6_FlowE_TARGET_MODE_page; \
	COMMAND trans6_FlowE_TARGET_MODE_read; \
	COMMAND trans6_FlowE_TARGET_MODE_write; \
	COLLECTION trans6_FlowE_MODE_BLK; \
	VARIABLE trans6_FlowE_MODE_BLK_Actual; \
	VARIABLE trans6_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans6_FlowE_MODE_BLK_Normal; \
	MENU trans6_FlowE_MODE_BLK_page; \
	COMMAND trans6_FlowE_MODE_BLK_read; \
	COLLECTION trans6_FlowE_ALARM_SUM; \
	VARIABLE trans6_FlowE_ALARM_SUM_Current; \
	VARIABLE trans6_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans6_FlowE_ALARM_SUM_Disabled; \
	MENU trans6_FlowE_ALARM_SUM_page; \
	COMMAND trans6_FlowE_ALARM_SUM_read; \
	VARIABLE trans6_FlowE_CALIBR_FACTOR; \
	MENU trans6_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans6_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans6_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans6_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans6_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans6_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans6_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans6_FlowE_MEASUREMENT_MODE; \
	MENU trans6_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans6_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans6_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans6_FlowE_FLOW_DIRECTION; \
	MENU trans6_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans6_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans6_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans6_FlowE_NOMINAL_SIZE; \
	MENU trans6_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans6_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans6_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans6_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans6_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans6_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans6_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans6_FlowE_VOLUME_FLOW; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans6_FlowE_VOLUME_FLOW_page; \
	COMMAND trans6_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans6_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans6_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans6_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans6_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans6_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans6_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans6_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans6_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans6_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans6_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans6_FlowE_SAMPLING_FREQ; \
	VARIABLE trans6_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans6_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans6_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans6_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans6_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans6_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans6_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans6_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans6_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans6_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans6_FlowE_unit_nominal_size; \
	UNIT trans6_FlowE_unit_volume_flow; \
	UNIT trans6_FlowE_unit_sampling_freq

#define USE_TRANS6_FLOWE_MANDATORY_A \
	USE_TRANS6_FLOWE_MANDATORY_BOTH; \
	MENU trans6_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS6_FLOWE_MANDATORY_B \
	USE_TRANS6_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans6_FlowE_VIEW_1; \
	MENU trans6_FlowE_VIEW_1_page; \
	MENU trans6_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS6_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans6_FlowE_ZERO_POINT; \
	MENU trans6_FlowE_ZERO_POINT_page; \
	COMMAND trans6_FlowE_ZERO_POINT_read; \
	COMMAND trans6_FlowE_ZERO_POINT_write; \
	VARIABLE trans6_FlowE_ZERO_POINT_ADJUST; \
	MENU trans6_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans6_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans6_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans6_FlowE_ZERO_POINT_UNIT; \
	MENU trans6_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans6_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans6_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans6_FlowE_VIEW_2; \
	MENU trans6_FlowE_VIEW_2_page; \
	COLLECTION trans6_FlowE_VIEW_3; \
	MENU trans6_FlowE_VIEW_3_page; \
	UNIT trans6_FlowE_unit_zero_point

#define USE_TRANS6_FLOWE_OPTIONAL_A \
	USE_TRANS6_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans6_FlowE_VIEW_1; \
	MENU trans6_FlowE_VIEW_1_page; \
	MENU trans6_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS6_FLOWE_OPTIONAL_B \
	USE_TRANS6_FLOWE_OPTIONAL_BOTH; \
	MENU trans6_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans6_FlowE_)
#define USE_TRANS6_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans6_FlowE_)
#define USE_TRANS6_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans6_FlowE_)
#define USE_TRANS6_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans6_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_FLOWE_MANDATORY_BOTH \
	BLOCK trans7_FlowE_block; \
	COLLECTION trans7_FlowE_BLOCK_OBJECT; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans7_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans7_FlowE_ST_REV; \
	MENU trans7_FlowE_ST_REV_page; \
	COMMAND trans7_FlowE_ST_REV_read; \
	VARIABLE trans7_FlowE_TAG_DESC; \
	MENU trans7_FlowE_TAG_DESC_page; \
	COMMAND trans7_FlowE_TAG_DESC_read; \
	COMMAND trans7_FlowE_TAG_DESC_write; \
	VARIABLE trans7_FlowE_STRATEGY; \
	MENU trans7_FlowE_STRATEGY_page; \
	COMMAND trans7_FlowE_STRATEGY_read; \
	COMMAND trans7_FlowE_STRATEGY_write; \
	VARIABLE trans7_FlowE_ALERT_KEY; \
	MENU trans7_FlowE_ALERT_KEY_page; \
	COMMAND trans7_FlowE_ALERT_KEY_read; \
	COMMAND trans7_FlowE_ALERT_KEY_write; \
	VARIABLE trans7_FlowE_TARGET_MODE; \
	MENU trans7_FlowE_TARGET_MODE_page; \
	COMMAND trans7_FlowE_TARGET_MODE_read; \
	COMMAND trans7_FlowE_TARGET_MODE_write; \
	COLLECTION trans7_FlowE_MODE_BLK; \
	VARIABLE trans7_FlowE_MODE_BLK_Actual; \
	VARIABLE trans7_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans7_FlowE_MODE_BLK_Normal; \
	MENU trans7_FlowE_MODE_BLK_page; \
	COMMAND trans7_FlowE_MODE_BLK_read; \
	COLLECTION trans7_FlowE_ALARM_SUM; \
	VARIABLE trans7_FlowE_ALARM_SUM_Current; \
	VARIABLE trans7_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans7_FlowE_ALARM_SUM_Disabled; \
	MENU trans7_FlowE_ALARM_SUM_page; \
	COMMAND trans7_FlowE_ALARM_SUM_read; \
	VARIABLE trans7_FlowE_CALIBR_FACTOR; \
	MENU trans7_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans7_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans7_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans7_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans7_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans7_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans7_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans7_FlowE_MEASUREMENT_MODE; \
	MENU trans7_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans7_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans7_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans7_FlowE_FLOW_DIRECTION; \
	MENU trans7_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans7_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans7_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans7_FlowE_NOMINAL_SIZE; \
	MENU trans7_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans7_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans7_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans7_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans7_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans7_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans7_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans7_FlowE_VOLUME_FLOW; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans7_FlowE_VOLUME_FLOW_page; \
	COMMAND trans7_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans7_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans7_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans7_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans7_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans7_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans7_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans7_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans7_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans7_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans7_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans7_FlowE_SAMPLING_FREQ; \
	VARIABLE trans7_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans7_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans7_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans7_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans7_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans7_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans7_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans7_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans7_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans7_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans7_FlowE_unit_nominal_size; \
	UNIT trans7_FlowE_unit_volume_flow; \
	UNIT trans7_FlowE_unit_sampling_freq

#define USE_TRANS7_FLOWE_MANDATORY_A \
	USE_TRANS7_FLOWE_MANDATORY_BOTH; \
	MENU trans7_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS7_FLOWE_MANDATORY_B \
	USE_TRANS7_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans7_FlowE_VIEW_1; \
	MENU trans7_FlowE_VIEW_1_page; \
	MENU trans7_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS7_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans7_FlowE_ZERO_POINT; \
	MENU trans7_FlowE_ZERO_POINT_page; \
	COMMAND trans7_FlowE_ZERO_POINT_read; \
	COMMAND trans7_FlowE_ZERO_POINT_write; \
	VARIABLE trans7_FlowE_ZERO_POINT_ADJUST; \
	MENU trans7_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans7_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans7_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans7_FlowE_ZERO_POINT_UNIT; \
	MENU trans7_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans7_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans7_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans7_FlowE_VIEW_2; \
	MENU trans7_FlowE_VIEW_2_page; \
	COLLECTION trans7_FlowE_VIEW_3; \
	MENU trans7_FlowE_VIEW_3_page; \
	UNIT trans7_FlowE_unit_zero_point

#define USE_TRANS7_FLOWE_OPTIONAL_A \
	USE_TRANS7_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans7_FlowE_VIEW_1; \
	MENU trans7_FlowE_VIEW_1_page; \
	MENU trans7_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS7_FLOWE_OPTIONAL_B \
	USE_TRANS7_FLOWE_OPTIONAL_BOTH; \
	MENU trans7_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans7_FlowE_)
#define USE_TRANS7_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans7_FlowE_)
#define USE_TRANS7_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans7_FlowE_)
#define USE_TRANS7_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans7_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_FLOWE_MANDATORY_BOTH \
	BLOCK trans8_FlowE_block; \
	COLLECTION trans8_FlowE_BLOCK_OBJECT; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans8_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans8_FlowE_ST_REV; \
	MENU trans8_FlowE_ST_REV_page; \
	COMMAND trans8_FlowE_ST_REV_read; \
	VARIABLE trans8_FlowE_TAG_DESC; \
	MENU trans8_FlowE_TAG_DESC_page; \
	COMMAND trans8_FlowE_TAG_DESC_read; \
	COMMAND trans8_FlowE_TAG_DESC_write; \
	VARIABLE trans8_FlowE_STRATEGY; \
	MENU trans8_FlowE_STRATEGY_page; \
	COMMAND trans8_FlowE_STRATEGY_read; \
	COMMAND trans8_FlowE_STRATEGY_write; \
	VARIABLE trans8_FlowE_ALERT_KEY; \
	MENU trans8_FlowE_ALERT_KEY_page; \
	COMMAND trans8_FlowE_ALERT_KEY_read; \
	COMMAND trans8_FlowE_ALERT_KEY_write; \
	VARIABLE trans8_FlowE_TARGET_MODE; \
	MENU trans8_FlowE_TARGET_MODE_page; \
	COMMAND trans8_FlowE_TARGET_MODE_read; \
	COMMAND trans8_FlowE_TARGET_MODE_write; \
	COLLECTION trans8_FlowE_MODE_BLK; \
	VARIABLE trans8_FlowE_MODE_BLK_Actual; \
	VARIABLE trans8_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans8_FlowE_MODE_BLK_Normal; \
	MENU trans8_FlowE_MODE_BLK_page; \
	COMMAND trans8_FlowE_MODE_BLK_read; \
	COLLECTION trans8_FlowE_ALARM_SUM; \
	VARIABLE trans8_FlowE_ALARM_SUM_Current; \
	VARIABLE trans8_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans8_FlowE_ALARM_SUM_Disabled; \
	MENU trans8_FlowE_ALARM_SUM_page; \
	COMMAND trans8_FlowE_ALARM_SUM_read; \
	VARIABLE trans8_FlowE_CALIBR_FACTOR; \
	MENU trans8_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans8_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans8_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans8_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans8_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans8_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans8_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans8_FlowE_MEASUREMENT_MODE; \
	MENU trans8_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans8_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans8_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans8_FlowE_FLOW_DIRECTION; \
	MENU trans8_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans8_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans8_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans8_FlowE_NOMINAL_SIZE; \
	MENU trans8_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans8_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans8_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans8_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans8_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans8_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans8_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans8_FlowE_VOLUME_FLOW; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans8_FlowE_VOLUME_FLOW_page; \
	COMMAND trans8_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans8_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans8_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans8_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans8_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans8_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans8_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans8_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans8_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans8_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans8_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans8_FlowE_SAMPLING_FREQ; \
	VARIABLE trans8_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans8_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans8_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans8_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans8_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans8_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans8_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans8_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans8_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans8_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans8_FlowE_unit_nominal_size; \
	UNIT trans8_FlowE_unit_volume_flow; \
	UNIT trans8_FlowE_unit_sampling_freq

#define USE_TRANS8_FLOWE_MANDATORY_A \
	USE_TRANS8_FLOWE_MANDATORY_BOTH; \
	MENU trans8_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS8_FLOWE_MANDATORY_B \
	USE_TRANS8_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans8_FlowE_VIEW_1; \
	MENU trans8_FlowE_VIEW_1_page; \
	MENU trans8_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS8_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans8_FlowE_ZERO_POINT; \
	MENU trans8_FlowE_ZERO_POINT_page; \
	COMMAND trans8_FlowE_ZERO_POINT_read; \
	COMMAND trans8_FlowE_ZERO_POINT_write; \
	VARIABLE trans8_FlowE_ZERO_POINT_ADJUST; \
	MENU trans8_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans8_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans8_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans8_FlowE_ZERO_POINT_UNIT; \
	MENU trans8_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans8_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans8_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans8_FlowE_VIEW_2; \
	MENU trans8_FlowE_VIEW_2_page; \
	COLLECTION trans8_FlowE_VIEW_3; \
	MENU trans8_FlowE_VIEW_3_page; \
	UNIT trans8_FlowE_unit_zero_point

#define USE_TRANS8_FLOWE_OPTIONAL_A \
	USE_TRANS8_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans8_FlowE_VIEW_1; \
	MENU trans8_FlowE_VIEW_1_page; \
	MENU trans8_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS8_FLOWE_OPTIONAL_B \
	USE_TRANS8_FLOWE_OPTIONAL_BOTH; \
	MENU trans8_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans8_FlowE_)
#define USE_TRANS8_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans8_FlowE_)
#define USE_TRANS8_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans8_FlowE_)
#define USE_TRANS8_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans8_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_FLOWE_MANDATORY_BOTH \
	BLOCK trans9_FlowE_block; \
	COLLECTION trans9_FlowE_BLOCK_OBJECT; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans9_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans9_FlowE_ST_REV; \
	MENU trans9_FlowE_ST_REV_page; \
	COMMAND trans9_FlowE_ST_REV_read; \
	VARIABLE trans9_FlowE_TAG_DESC; \
	MENU trans9_FlowE_TAG_DESC_page; \
	COMMAND trans9_FlowE_TAG_DESC_read; \
	COMMAND trans9_FlowE_TAG_DESC_write; \
	VARIABLE trans9_FlowE_STRATEGY; \
	MENU trans9_FlowE_STRATEGY_page; \
	COMMAND trans9_FlowE_STRATEGY_read; \
	COMMAND trans9_FlowE_STRATEGY_write; \
	VARIABLE trans9_FlowE_ALERT_KEY; \
	MENU trans9_FlowE_ALERT_KEY_page; \
	COMMAND trans9_FlowE_ALERT_KEY_read; \
	COMMAND trans9_FlowE_ALERT_KEY_write; \
	VARIABLE trans9_FlowE_TARGET_MODE; \
	MENU trans9_FlowE_TARGET_MODE_page; \
	COMMAND trans9_FlowE_TARGET_MODE_read; \
	COMMAND trans9_FlowE_TARGET_MODE_write; \
	COLLECTION trans9_FlowE_MODE_BLK; \
	VARIABLE trans9_FlowE_MODE_BLK_Actual; \
	VARIABLE trans9_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans9_FlowE_MODE_BLK_Normal; \
	MENU trans9_FlowE_MODE_BLK_page; \
	COMMAND trans9_FlowE_MODE_BLK_read; \
	COLLECTION trans9_FlowE_ALARM_SUM; \
	VARIABLE trans9_FlowE_ALARM_SUM_Current; \
	VARIABLE trans9_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans9_FlowE_ALARM_SUM_Disabled; \
	MENU trans9_FlowE_ALARM_SUM_page; \
	COMMAND trans9_FlowE_ALARM_SUM_read; \
	VARIABLE trans9_FlowE_CALIBR_FACTOR; \
	MENU trans9_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans9_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans9_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans9_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans9_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans9_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans9_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans9_FlowE_MEASUREMENT_MODE; \
	MENU trans9_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans9_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans9_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans9_FlowE_FLOW_DIRECTION; \
	MENU trans9_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans9_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans9_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans9_FlowE_NOMINAL_SIZE; \
	MENU trans9_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans9_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans9_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans9_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans9_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans9_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans9_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans9_FlowE_VOLUME_FLOW; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans9_FlowE_VOLUME_FLOW_page; \
	COMMAND trans9_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans9_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans9_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans9_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans9_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans9_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans9_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans9_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans9_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans9_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans9_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans9_FlowE_SAMPLING_FREQ; \
	VARIABLE trans9_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans9_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans9_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans9_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans9_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans9_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans9_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans9_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans9_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans9_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans9_FlowE_unit_nominal_size; \
	UNIT trans9_FlowE_unit_volume_flow; \
	UNIT trans9_FlowE_unit_sampling_freq

#define USE_TRANS9_FLOWE_MANDATORY_A \
	USE_TRANS9_FLOWE_MANDATORY_BOTH; \
	MENU trans9_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS9_FLOWE_MANDATORY_B \
	USE_TRANS9_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans9_FlowE_VIEW_1; \
	MENU trans9_FlowE_VIEW_1_page; \
	MENU trans9_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS9_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans9_FlowE_ZERO_POINT; \
	MENU trans9_FlowE_ZERO_POINT_page; \
	COMMAND trans9_FlowE_ZERO_POINT_read; \
	COMMAND trans9_FlowE_ZERO_POINT_write; \
	VARIABLE trans9_FlowE_ZERO_POINT_ADJUST; \
	MENU trans9_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans9_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans9_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans9_FlowE_ZERO_POINT_UNIT; \
	MENU trans9_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans9_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans9_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans9_FlowE_VIEW_2; \
	MENU trans9_FlowE_VIEW_2_page; \
	COLLECTION trans9_FlowE_VIEW_3; \
	MENU trans9_FlowE_VIEW_3_page; \
	UNIT trans9_FlowE_unit_zero_point

#define USE_TRANS9_FLOWE_OPTIONAL_A \
	USE_TRANS9_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans9_FlowE_VIEW_1; \
	MENU trans9_FlowE_VIEW_1_page; \
	MENU trans9_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS9_FLOWE_OPTIONAL_B \
	USE_TRANS9_FLOWE_OPTIONAL_BOTH; \
	MENU trans9_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans9_FlowE_)
#define USE_TRANS9_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans9_FlowE_)
#define USE_TRANS9_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans9_FlowE_)
#define USE_TRANS9_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans9_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_FLOWE_MANDATORY_BOTH \
	BLOCK trans10_FlowE_block; \
	COLLECTION trans10_FlowE_BLOCK_OBJECT; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans10_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans10_FlowE_ST_REV; \
	MENU trans10_FlowE_ST_REV_page; \
	COMMAND trans10_FlowE_ST_REV_read; \
	VARIABLE trans10_FlowE_TAG_DESC; \
	MENU trans10_FlowE_TAG_DESC_page; \
	COMMAND trans10_FlowE_TAG_DESC_read; \
	COMMAND trans10_FlowE_TAG_DESC_write; \
	VARIABLE trans10_FlowE_STRATEGY; \
	MENU trans10_FlowE_STRATEGY_page; \
	COMMAND trans10_FlowE_STRATEGY_read; \
	COMMAND trans10_FlowE_STRATEGY_write; \
	VARIABLE trans10_FlowE_ALERT_KEY; \
	MENU trans10_FlowE_ALERT_KEY_page; \
	COMMAND trans10_FlowE_ALERT_KEY_read; \
	COMMAND trans10_FlowE_ALERT_KEY_write; \
	VARIABLE trans10_FlowE_TARGET_MODE; \
	MENU trans10_FlowE_TARGET_MODE_page; \
	COMMAND trans10_FlowE_TARGET_MODE_read; \
	COMMAND trans10_FlowE_TARGET_MODE_write; \
	COLLECTION trans10_FlowE_MODE_BLK; \
	VARIABLE trans10_FlowE_MODE_BLK_Actual; \
	VARIABLE trans10_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans10_FlowE_MODE_BLK_Normal; \
	MENU trans10_FlowE_MODE_BLK_page; \
	COMMAND trans10_FlowE_MODE_BLK_read; \
	COLLECTION trans10_FlowE_ALARM_SUM; \
	VARIABLE trans10_FlowE_ALARM_SUM_Current; \
	VARIABLE trans10_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans10_FlowE_ALARM_SUM_Disabled; \
	MENU trans10_FlowE_ALARM_SUM_page; \
	COMMAND trans10_FlowE_ALARM_SUM_read; \
	VARIABLE trans10_FlowE_CALIBR_FACTOR; \
	MENU trans10_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans10_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans10_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans10_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans10_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans10_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans10_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans10_FlowE_MEASUREMENT_MODE; \
	MENU trans10_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans10_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans10_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans10_FlowE_FLOW_DIRECTION; \
	MENU trans10_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans10_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans10_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans10_FlowE_NOMINAL_SIZE; \
	MENU trans10_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans10_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans10_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans10_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans10_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans10_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans10_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans10_FlowE_VOLUME_FLOW; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans10_FlowE_VOLUME_FLOW_page; \
	COMMAND trans10_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans10_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans10_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans10_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans10_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans10_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans10_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans10_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans10_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans10_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans10_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans10_FlowE_SAMPLING_FREQ; \
	VARIABLE trans10_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans10_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans10_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans10_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans10_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans10_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans10_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans10_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans10_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans10_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans10_FlowE_unit_nominal_size; \
	UNIT trans10_FlowE_unit_volume_flow; \
	UNIT trans10_FlowE_unit_sampling_freq

#define USE_TRANS10_FLOWE_MANDATORY_A \
	USE_TRANS10_FLOWE_MANDATORY_BOTH; \
	MENU trans10_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS10_FLOWE_MANDATORY_B \
	USE_TRANS10_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans10_FlowE_VIEW_1; \
	MENU trans10_FlowE_VIEW_1_page; \
	MENU trans10_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS10_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans10_FlowE_ZERO_POINT; \
	MENU trans10_FlowE_ZERO_POINT_page; \
	COMMAND trans10_FlowE_ZERO_POINT_read; \
	COMMAND trans10_FlowE_ZERO_POINT_write; \
	VARIABLE trans10_FlowE_ZERO_POINT_ADJUST; \
	MENU trans10_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans10_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans10_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans10_FlowE_ZERO_POINT_UNIT; \
	MENU trans10_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans10_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans10_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans10_FlowE_VIEW_2; \
	MENU trans10_FlowE_VIEW_2_page; \
	COLLECTION trans10_FlowE_VIEW_3; \
	MENU trans10_FlowE_VIEW_3_page; \
	UNIT trans10_FlowE_unit_zero_point

#define USE_TRANS10_FLOWE_OPTIONAL_A \
	USE_TRANS10_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans10_FlowE_VIEW_1; \
	MENU trans10_FlowE_VIEW_1_page; \
	MENU trans10_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS10_FLOWE_OPTIONAL_B \
	USE_TRANS10_FLOWE_OPTIONAL_BOTH; \
	MENU trans10_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans10_FlowE_)
#define USE_TRANS10_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans10_FlowE_)
#define USE_TRANS10_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans10_FlowE_)
#define USE_TRANS10_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans10_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_FLOWE_MANDATORY_BOTH \
	BLOCK trans11_FlowE_block; \
	COLLECTION trans11_FlowE_BLOCK_OBJECT; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans11_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans11_FlowE_ST_REV; \
	MENU trans11_FlowE_ST_REV_page; \
	COMMAND trans11_FlowE_ST_REV_read; \
	VARIABLE trans11_FlowE_TAG_DESC; \
	MENU trans11_FlowE_TAG_DESC_page; \
	COMMAND trans11_FlowE_TAG_DESC_read; \
	COMMAND trans11_FlowE_TAG_DESC_write; \
	VARIABLE trans11_FlowE_STRATEGY; \
	MENU trans11_FlowE_STRATEGY_page; \
	COMMAND trans11_FlowE_STRATEGY_read; \
	COMMAND trans11_FlowE_STRATEGY_write; \
	VARIABLE trans11_FlowE_ALERT_KEY; \
	MENU trans11_FlowE_ALERT_KEY_page; \
	COMMAND trans11_FlowE_ALERT_KEY_read; \
	COMMAND trans11_FlowE_ALERT_KEY_write; \
	VARIABLE trans11_FlowE_TARGET_MODE; \
	MENU trans11_FlowE_TARGET_MODE_page; \
	COMMAND trans11_FlowE_TARGET_MODE_read; \
	COMMAND trans11_FlowE_TARGET_MODE_write; \
	COLLECTION trans11_FlowE_MODE_BLK; \
	VARIABLE trans11_FlowE_MODE_BLK_Actual; \
	VARIABLE trans11_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans11_FlowE_MODE_BLK_Normal; \
	MENU trans11_FlowE_MODE_BLK_page; \
	COMMAND trans11_FlowE_MODE_BLK_read; \
	COLLECTION trans11_FlowE_ALARM_SUM; \
	VARIABLE trans11_FlowE_ALARM_SUM_Current; \
	VARIABLE trans11_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans11_FlowE_ALARM_SUM_Disabled; \
	MENU trans11_FlowE_ALARM_SUM_page; \
	COMMAND trans11_FlowE_ALARM_SUM_read; \
	VARIABLE trans11_FlowE_CALIBR_FACTOR; \
	MENU trans11_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans11_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans11_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans11_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans11_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans11_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans11_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans11_FlowE_MEASUREMENT_MODE; \
	MENU trans11_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans11_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans11_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans11_FlowE_FLOW_DIRECTION; \
	MENU trans11_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans11_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans11_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans11_FlowE_NOMINAL_SIZE; \
	MENU trans11_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans11_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans11_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans11_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans11_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans11_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans11_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans11_FlowE_VOLUME_FLOW; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans11_FlowE_VOLUME_FLOW_page; \
	COMMAND trans11_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans11_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans11_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans11_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans11_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans11_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans11_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans11_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans11_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans11_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans11_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans11_FlowE_SAMPLING_FREQ; \
	VARIABLE trans11_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans11_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans11_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans11_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans11_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans11_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans11_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans11_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans11_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans11_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans11_FlowE_unit_nominal_size; \
	UNIT trans11_FlowE_unit_volume_flow; \
	UNIT trans11_FlowE_unit_sampling_freq

#define USE_TRANS11_FLOWE_MANDATORY_A \
	USE_TRANS11_FLOWE_MANDATORY_BOTH; \
	MENU trans11_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS11_FLOWE_MANDATORY_B \
	USE_TRANS11_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans11_FlowE_VIEW_1; \
	MENU trans11_FlowE_VIEW_1_page; \
	MENU trans11_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS11_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans11_FlowE_ZERO_POINT; \
	MENU trans11_FlowE_ZERO_POINT_page; \
	COMMAND trans11_FlowE_ZERO_POINT_read; \
	COMMAND trans11_FlowE_ZERO_POINT_write; \
	VARIABLE trans11_FlowE_ZERO_POINT_ADJUST; \
	MENU trans11_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans11_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans11_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans11_FlowE_ZERO_POINT_UNIT; \
	MENU trans11_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans11_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans11_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans11_FlowE_VIEW_2; \
	MENU trans11_FlowE_VIEW_2_page; \
	COLLECTION trans11_FlowE_VIEW_3; \
	MENU trans11_FlowE_VIEW_3_page; \
	UNIT trans11_FlowE_unit_zero_point

#define USE_TRANS11_FLOWE_OPTIONAL_A \
	USE_TRANS11_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans11_FlowE_VIEW_1; \
	MENU trans11_FlowE_VIEW_1_page; \
	MENU trans11_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS11_FLOWE_OPTIONAL_B \
	USE_TRANS11_FLOWE_OPTIONAL_BOTH; \
	MENU trans11_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans11_FlowE_)
#define USE_TRANS11_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans11_FlowE_)
#define USE_TRANS11_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans11_FlowE_)
#define USE_TRANS11_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans11_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_FLOWE_MANDATORY_BOTH \
	BLOCK trans12_FlowE_block; \
	COLLECTION trans12_FlowE_BLOCK_OBJECT; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans12_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans12_FlowE_ST_REV; \
	MENU trans12_FlowE_ST_REV_page; \
	COMMAND trans12_FlowE_ST_REV_read; \
	VARIABLE trans12_FlowE_TAG_DESC; \
	MENU trans12_FlowE_TAG_DESC_page; \
	COMMAND trans12_FlowE_TAG_DESC_read; \
	COMMAND trans12_FlowE_TAG_DESC_write; \
	VARIABLE trans12_FlowE_STRATEGY; \
	MENU trans12_FlowE_STRATEGY_page; \
	COMMAND trans12_FlowE_STRATEGY_read; \
	COMMAND trans12_FlowE_STRATEGY_write; \
	VARIABLE trans12_FlowE_ALERT_KEY; \
	MENU trans12_FlowE_ALERT_KEY_page; \
	COMMAND trans12_FlowE_ALERT_KEY_read; \
	COMMAND trans12_FlowE_ALERT_KEY_write; \
	VARIABLE trans12_FlowE_TARGET_MODE; \
	MENU trans12_FlowE_TARGET_MODE_page; \
	COMMAND trans12_FlowE_TARGET_MODE_read; \
	COMMAND trans12_FlowE_TARGET_MODE_write; \
	COLLECTION trans12_FlowE_MODE_BLK; \
	VARIABLE trans12_FlowE_MODE_BLK_Actual; \
	VARIABLE trans12_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans12_FlowE_MODE_BLK_Normal; \
	MENU trans12_FlowE_MODE_BLK_page; \
	COMMAND trans12_FlowE_MODE_BLK_read; \
	COLLECTION trans12_FlowE_ALARM_SUM; \
	VARIABLE trans12_FlowE_ALARM_SUM_Current; \
	VARIABLE trans12_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans12_FlowE_ALARM_SUM_Disabled; \
	MENU trans12_FlowE_ALARM_SUM_page; \
	COMMAND trans12_FlowE_ALARM_SUM_read; \
	VARIABLE trans12_FlowE_CALIBR_FACTOR; \
	MENU trans12_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans12_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans12_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans12_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans12_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans12_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans12_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans12_FlowE_MEASUREMENT_MODE; \
	MENU trans12_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans12_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans12_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans12_FlowE_FLOW_DIRECTION; \
	MENU trans12_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans12_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans12_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans12_FlowE_NOMINAL_SIZE; \
	MENU trans12_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans12_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans12_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans12_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans12_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans12_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans12_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans12_FlowE_VOLUME_FLOW; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans12_FlowE_VOLUME_FLOW_page; \
	COMMAND trans12_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans12_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans12_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans12_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans12_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans12_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans12_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans12_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans12_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans12_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans12_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans12_FlowE_SAMPLING_FREQ; \
	VARIABLE trans12_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans12_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans12_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans12_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans12_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans12_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans12_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans12_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans12_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans12_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans12_FlowE_unit_nominal_size; \
	UNIT trans12_FlowE_unit_volume_flow; \
	UNIT trans12_FlowE_unit_sampling_freq

#define USE_TRANS12_FLOWE_MANDATORY_A \
	USE_TRANS12_FLOWE_MANDATORY_BOTH; \
	MENU trans12_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS12_FLOWE_MANDATORY_B \
	USE_TRANS12_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans12_FlowE_VIEW_1; \
	MENU trans12_FlowE_VIEW_1_page; \
	MENU trans12_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS12_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans12_FlowE_ZERO_POINT; \
	MENU trans12_FlowE_ZERO_POINT_page; \
	COMMAND trans12_FlowE_ZERO_POINT_read; \
	COMMAND trans12_FlowE_ZERO_POINT_write; \
	VARIABLE trans12_FlowE_ZERO_POINT_ADJUST; \
	MENU trans12_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans12_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans12_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans12_FlowE_ZERO_POINT_UNIT; \
	MENU trans12_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans12_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans12_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans12_FlowE_VIEW_2; \
	MENU trans12_FlowE_VIEW_2_page; \
	COLLECTION trans12_FlowE_VIEW_3; \
	MENU trans12_FlowE_VIEW_3_page; \
	UNIT trans12_FlowE_unit_zero_point

#define USE_TRANS12_FLOWE_OPTIONAL_A \
	USE_TRANS12_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans12_FlowE_VIEW_1; \
	MENU trans12_FlowE_VIEW_1_page; \
	MENU trans12_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS12_FLOWE_OPTIONAL_B \
	USE_TRANS12_FLOWE_OPTIONAL_BOTH; \
	MENU trans12_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans12_FlowE_)
#define USE_TRANS12_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans12_FlowE_)
#define USE_TRANS12_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans12_FlowE_)
#define USE_TRANS12_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans12_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_FLOWE_MANDATORY_BOTH \
	BLOCK trans13_FlowE_block; \
	COLLECTION trans13_FlowE_BLOCK_OBJECT; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans13_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans13_FlowE_ST_REV; \
	MENU trans13_FlowE_ST_REV_page; \
	COMMAND trans13_FlowE_ST_REV_read; \
	VARIABLE trans13_FlowE_TAG_DESC; \
	MENU trans13_FlowE_TAG_DESC_page; \
	COMMAND trans13_FlowE_TAG_DESC_read; \
	COMMAND trans13_FlowE_TAG_DESC_write; \
	VARIABLE trans13_FlowE_STRATEGY; \
	MENU trans13_FlowE_STRATEGY_page; \
	COMMAND trans13_FlowE_STRATEGY_read; \
	COMMAND trans13_FlowE_STRATEGY_write; \
	VARIABLE trans13_FlowE_ALERT_KEY; \
	MENU trans13_FlowE_ALERT_KEY_page; \
	COMMAND trans13_FlowE_ALERT_KEY_read; \
	COMMAND trans13_FlowE_ALERT_KEY_write; \
	VARIABLE trans13_FlowE_TARGET_MODE; \
	MENU trans13_FlowE_TARGET_MODE_page; \
	COMMAND trans13_FlowE_TARGET_MODE_read; \
	COMMAND trans13_FlowE_TARGET_MODE_write; \
	COLLECTION trans13_FlowE_MODE_BLK; \
	VARIABLE trans13_FlowE_MODE_BLK_Actual; \
	VARIABLE trans13_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans13_FlowE_MODE_BLK_Normal; \
	MENU trans13_FlowE_MODE_BLK_page; \
	COMMAND trans13_FlowE_MODE_BLK_read; \
	COLLECTION trans13_FlowE_ALARM_SUM; \
	VARIABLE trans13_FlowE_ALARM_SUM_Current; \
	VARIABLE trans13_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans13_FlowE_ALARM_SUM_Disabled; \
	MENU trans13_FlowE_ALARM_SUM_page; \
	COMMAND trans13_FlowE_ALARM_SUM_read; \
	VARIABLE trans13_FlowE_CALIBR_FACTOR; \
	MENU trans13_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans13_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans13_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans13_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans13_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans13_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans13_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans13_FlowE_MEASUREMENT_MODE; \
	MENU trans13_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans13_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans13_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans13_FlowE_FLOW_DIRECTION; \
	MENU trans13_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans13_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans13_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans13_FlowE_NOMINAL_SIZE; \
	MENU trans13_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans13_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans13_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans13_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans13_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans13_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans13_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans13_FlowE_VOLUME_FLOW; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans13_FlowE_VOLUME_FLOW_page; \
	COMMAND trans13_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans13_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans13_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans13_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans13_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans13_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans13_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans13_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans13_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans13_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans13_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans13_FlowE_SAMPLING_FREQ; \
	VARIABLE trans13_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans13_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans13_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans13_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans13_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans13_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans13_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans13_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans13_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans13_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans13_FlowE_unit_nominal_size; \
	UNIT trans13_FlowE_unit_volume_flow; \
	UNIT trans13_FlowE_unit_sampling_freq

#define USE_TRANS13_FLOWE_MANDATORY_A \
	USE_TRANS13_FLOWE_MANDATORY_BOTH; \
	MENU trans13_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS13_FLOWE_MANDATORY_B \
	USE_TRANS13_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans13_FlowE_VIEW_1; \
	MENU trans13_FlowE_VIEW_1_page; \
	MENU trans13_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS13_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans13_FlowE_ZERO_POINT; \
	MENU trans13_FlowE_ZERO_POINT_page; \
	COMMAND trans13_FlowE_ZERO_POINT_read; \
	COMMAND trans13_FlowE_ZERO_POINT_write; \
	VARIABLE trans13_FlowE_ZERO_POINT_ADJUST; \
	MENU trans13_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans13_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans13_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans13_FlowE_ZERO_POINT_UNIT; \
	MENU trans13_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans13_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans13_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans13_FlowE_VIEW_2; \
	MENU trans13_FlowE_VIEW_2_page; \
	COLLECTION trans13_FlowE_VIEW_3; \
	MENU trans13_FlowE_VIEW_3_page; \
	UNIT trans13_FlowE_unit_zero_point

#define USE_TRANS13_FLOWE_OPTIONAL_A \
	USE_TRANS13_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans13_FlowE_VIEW_1; \
	MENU trans13_FlowE_VIEW_1_page; \
	MENU trans13_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS13_FLOWE_OPTIONAL_B \
	USE_TRANS13_FLOWE_OPTIONAL_BOTH; \
	MENU trans13_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans13_FlowE_)
#define USE_TRANS13_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans13_FlowE_)
#define USE_TRANS13_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans13_FlowE_)
#define USE_TRANS13_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans13_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_FLOWE_MANDATORY_BOTH \
	BLOCK trans14_FlowE_block; \
	COLLECTION trans14_FlowE_BLOCK_OBJECT; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans14_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans14_FlowE_ST_REV; \
	MENU trans14_FlowE_ST_REV_page; \
	COMMAND trans14_FlowE_ST_REV_read; \
	VARIABLE trans14_FlowE_TAG_DESC; \
	MENU trans14_FlowE_TAG_DESC_page; \
	COMMAND trans14_FlowE_TAG_DESC_read; \
	COMMAND trans14_FlowE_TAG_DESC_write; \
	VARIABLE trans14_FlowE_STRATEGY; \
	MENU trans14_FlowE_STRATEGY_page; \
	COMMAND trans14_FlowE_STRATEGY_read; \
	COMMAND trans14_FlowE_STRATEGY_write; \
	VARIABLE trans14_FlowE_ALERT_KEY; \
	MENU trans14_FlowE_ALERT_KEY_page; \
	COMMAND trans14_FlowE_ALERT_KEY_read; \
	COMMAND trans14_FlowE_ALERT_KEY_write; \
	VARIABLE trans14_FlowE_TARGET_MODE; \
	MENU trans14_FlowE_TARGET_MODE_page; \
	COMMAND trans14_FlowE_TARGET_MODE_read; \
	COMMAND trans14_FlowE_TARGET_MODE_write; \
	COLLECTION trans14_FlowE_MODE_BLK; \
	VARIABLE trans14_FlowE_MODE_BLK_Actual; \
	VARIABLE trans14_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans14_FlowE_MODE_BLK_Normal; \
	MENU trans14_FlowE_MODE_BLK_page; \
	COMMAND trans14_FlowE_MODE_BLK_read; \
	COLLECTION trans14_FlowE_ALARM_SUM; \
	VARIABLE trans14_FlowE_ALARM_SUM_Current; \
	VARIABLE trans14_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans14_FlowE_ALARM_SUM_Disabled; \
	MENU trans14_FlowE_ALARM_SUM_page; \
	COMMAND trans14_FlowE_ALARM_SUM_read; \
	VARIABLE trans14_FlowE_CALIBR_FACTOR; \
	MENU trans14_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans14_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans14_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans14_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans14_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans14_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans14_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans14_FlowE_MEASUREMENT_MODE; \
	MENU trans14_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans14_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans14_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans14_FlowE_FLOW_DIRECTION; \
	MENU trans14_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans14_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans14_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans14_FlowE_NOMINAL_SIZE; \
	MENU trans14_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans14_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans14_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans14_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans14_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans14_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans14_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans14_FlowE_VOLUME_FLOW; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans14_FlowE_VOLUME_FLOW_page; \
	COMMAND trans14_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans14_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans14_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans14_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans14_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans14_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans14_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans14_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans14_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans14_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans14_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans14_FlowE_SAMPLING_FREQ; \
	VARIABLE trans14_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans14_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans14_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans14_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans14_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans14_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans14_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans14_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans14_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans14_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans14_FlowE_unit_nominal_size; \
	UNIT trans14_FlowE_unit_volume_flow; \
	UNIT trans14_FlowE_unit_sampling_freq

#define USE_TRANS14_FLOWE_MANDATORY_A \
	USE_TRANS14_FLOWE_MANDATORY_BOTH; \
	MENU trans14_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS14_FLOWE_MANDATORY_B \
	USE_TRANS14_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans14_FlowE_VIEW_1; \
	MENU trans14_FlowE_VIEW_1_page; \
	MENU trans14_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS14_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans14_FlowE_ZERO_POINT; \
	MENU trans14_FlowE_ZERO_POINT_page; \
	COMMAND trans14_FlowE_ZERO_POINT_read; \
	COMMAND trans14_FlowE_ZERO_POINT_write; \
	VARIABLE trans14_FlowE_ZERO_POINT_ADJUST; \
	MENU trans14_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans14_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans14_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans14_FlowE_ZERO_POINT_UNIT; \
	MENU trans14_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans14_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans14_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans14_FlowE_VIEW_2; \
	MENU trans14_FlowE_VIEW_2_page; \
	COLLECTION trans14_FlowE_VIEW_3; \
	MENU trans14_FlowE_VIEW_3_page; \
	UNIT trans14_FlowE_unit_zero_point

#define USE_TRANS14_FLOWE_OPTIONAL_A \
	USE_TRANS14_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans14_FlowE_VIEW_1; \
	MENU trans14_FlowE_VIEW_1_page; \
	MENU trans14_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS14_FLOWE_OPTIONAL_B \
	USE_TRANS14_FLOWE_OPTIONAL_BOTH; \
	MENU trans14_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans14_FlowE_)
#define USE_TRANS14_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans14_FlowE_)
#define USE_TRANS14_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans14_FlowE_)
#define USE_TRANS14_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans14_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_FLOWE_MANDATORY_BOTH \
	BLOCK trans15_FlowE_block; \
	COLLECTION trans15_FlowE_BLOCK_OBJECT; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Class; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_FlowE_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_FlowE_BLOCK_OBJECT_page; \
	COMMAND trans15_FlowE_BLOCK_OBJECT_read; \
	VARIABLE trans15_FlowE_ST_REV; \
	MENU trans15_FlowE_ST_REV_page; \
	COMMAND trans15_FlowE_ST_REV_read; \
	VARIABLE trans15_FlowE_TAG_DESC; \
	MENU trans15_FlowE_TAG_DESC_page; \
	COMMAND trans15_FlowE_TAG_DESC_read; \
	COMMAND trans15_FlowE_TAG_DESC_write; \
	VARIABLE trans15_FlowE_STRATEGY; \
	MENU trans15_FlowE_STRATEGY_page; \
	COMMAND trans15_FlowE_STRATEGY_read; \
	COMMAND trans15_FlowE_STRATEGY_write; \
	VARIABLE trans15_FlowE_ALERT_KEY; \
	MENU trans15_FlowE_ALERT_KEY_page; \
	COMMAND trans15_FlowE_ALERT_KEY_read; \
	COMMAND trans15_FlowE_ALERT_KEY_write; \
	VARIABLE trans15_FlowE_TARGET_MODE; \
	MENU trans15_FlowE_TARGET_MODE_page; \
	COMMAND trans15_FlowE_TARGET_MODE_read; \
	COMMAND trans15_FlowE_TARGET_MODE_write; \
	COLLECTION trans15_FlowE_MODE_BLK; \
	VARIABLE trans15_FlowE_MODE_BLK_Actual; \
	VARIABLE trans15_FlowE_MODE_BLK_Permitted; \
	VARIABLE trans15_FlowE_MODE_BLK_Normal; \
	MENU trans15_FlowE_MODE_BLK_page; \
	COMMAND trans15_FlowE_MODE_BLK_read; \
	COLLECTION trans15_FlowE_ALARM_SUM; \
	VARIABLE trans15_FlowE_ALARM_SUM_Current; \
	VARIABLE trans15_FlowE_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_FlowE_ALARM_SUM_Unreported; \
	VARIABLE trans15_FlowE_ALARM_SUM_Disabled; \
	MENU trans15_FlowE_ALARM_SUM_page; \
	COMMAND trans15_FlowE_ALARM_SUM_read; \
	VARIABLE trans15_FlowE_CALIBR_FACTOR; \
	MENU trans15_FlowE_CALIBR_FACTOR_page; \
	COMMAND trans15_FlowE_CALIBR_FACTOR_read; \
	COMMAND trans15_FlowE_CALIBR_FACTOR_write; \
	VARIABLE trans15_FlowE_LOW_FLOW_CUTOFF; \
	MENU trans15_FlowE_LOW_FLOW_CUTOFF_page; \
	COMMAND trans15_FlowE_LOW_FLOW_CUTOFF_read; \
	COMMAND trans15_FlowE_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans15_FlowE_MEASUREMENT_MODE; \
	MENU trans15_FlowE_MEASUREMENT_MODE_page; \
	COMMAND trans15_FlowE_MEASUREMENT_MODE_read; \
	COMMAND trans15_FlowE_MEASUREMENT_MODE_write; \
	VARIABLE trans15_FlowE_FLOW_DIRECTION; \
	MENU trans15_FlowE_FLOW_DIRECTION_page; \
	COMMAND trans15_FlowE_FLOW_DIRECTION_read; \
	COMMAND trans15_FlowE_FLOW_DIRECTION_write; \
	VARIABLE trans15_FlowE_NOMINAL_SIZE; \
	MENU trans15_FlowE_NOMINAL_SIZE_page; \
	COMMAND trans15_FlowE_NOMINAL_SIZE_read; \
	COMMAND trans15_FlowE_NOMINAL_SIZE_write; \
	VARIABLE trans15_FlowE_NOMINAL_SIZE_UNITS; \
	MENU trans15_FlowE_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans15_FlowE_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans15_FlowE_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans15_FlowE_VOLUME_FLOW; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_Value; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_Status_Limit; \
	MENU trans15_FlowE_VOLUME_FLOW_page; \
	COMMAND trans15_FlowE_VOLUME_FLOW_read; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_UNITS; \
	MENU trans15_FlowE_VOLUME_FLOW_UNITS_page; \
	COMMAND trans15_FlowE_VOLUME_FLOW_UNITS_read; \
	COMMAND trans15_FlowE_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_LO_LIMIT; \
	MENU trans15_FlowE_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans15_FlowE_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans15_FlowE_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans15_FlowE_VOLUME_FLOW_HI_LIMIT; \
	MENU trans15_FlowE_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans15_FlowE_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans15_FlowE_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans15_FlowE_SAMPLING_FREQ; \
	VARIABLE trans15_FlowE_SAMPLING_FREQ_Value; \
	VARIABLE trans15_FlowE_SAMPLING_FREQ_Status_Condensed; \
	VARIABLE trans15_FlowE_SAMPLING_FREQ_Status_Quality; \
	VARIABLE trans15_FlowE_SAMPLING_FREQ_Status_Limit; \
	MENU trans15_FlowE_SAMPLING_FREQ_page; \
	COMMAND trans15_FlowE_SAMPLING_FREQ_read; \
	VARIABLE trans15_FlowE_SAMPLING_FREQ_UNITS; \
	MENU trans15_FlowE_SAMPLING_FREQ_UNITS_page; \
	COMMAND trans15_FlowE_SAMPLING_FREQ_UNITS_read; \
	COMMAND trans15_FlowE_SAMPLING_FREQ_UNITS_write; \
	UNIT trans15_FlowE_unit_nominal_size; \
	UNIT trans15_FlowE_unit_volume_flow; \
	UNIT trans15_FlowE_unit_sampling_freq

#define USE_TRANS15_FLOWE_MANDATORY_A \
	USE_TRANS15_FLOWE_MANDATORY_BOTH; \
	MENU trans15_FlowE_Simple_Dialog_Mandatory_A

#define USE_TRANS15_FLOWE_MANDATORY_B \
	USE_TRANS15_FLOWE_MANDATORY_BOTH; \
	COLLECTION trans15_FlowE_VIEW_1; \
	MENU trans15_FlowE_VIEW_1_page; \
	MENU trans15_FlowE_Simple_Dialog_Mandatory_B

#define USE_TRANS15_FLOWE_OPTIONAL_BOTH \
	VARIABLE trans15_FlowE_ZERO_POINT; \
	MENU trans15_FlowE_ZERO_POINT_page; \
	COMMAND trans15_FlowE_ZERO_POINT_read; \
	COMMAND trans15_FlowE_ZERO_POINT_write; \
	VARIABLE trans15_FlowE_ZERO_POINT_ADJUST; \
	MENU trans15_FlowE_ZERO_POINT_ADJUST_page; \
	COMMAND trans15_FlowE_ZERO_POINT_ADJUST_read; \
	COMMAND trans15_FlowE_ZERO_POINT_ADJUST_write; \
	VARIABLE trans15_FlowE_ZERO_POINT_UNIT; \
	MENU trans15_FlowE_ZERO_POINT_UNIT_page; \
	COMMAND trans15_FlowE_ZERO_POINT_UNIT_read; \
	COMMAND trans15_FlowE_ZERO_POINT_UNIT_write; \
	COLLECTION trans15_FlowE_VIEW_2; \
	MENU trans15_FlowE_VIEW_2_page; \
	COLLECTION trans15_FlowE_VIEW_3; \
	MENU trans15_FlowE_VIEW_3_page; \
	UNIT trans15_FlowE_unit_zero_point

#define USE_TRANS15_FLOWE_OPTIONAL_A \
	USE_TRANS15_FLOWE_OPTIONAL_BOTH; \
	COLLECTION trans15_FlowE_VIEW_1; \
	MENU trans15_FlowE_VIEW_1_page; \
	MENU trans15_FlowE_Simple_Dialog_Optional_A

#define USE_TRANS15_FLOWE_OPTIONAL_B \
	USE_TRANS15_FLOWE_OPTIONAL_BOTH; \
	MENU trans15_FlowE_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_FLOWE_MANDATORY_A USE_TRANS_FLOWE_MANDATORY_A(trans15_FlowE_)
#define USE_TRANS15_FLOWE_MANDATORY_B USE_TRANS_FLOWE_MANDATORY_B(trans15_FlowE_)
#define USE_TRANS15_FLOWE_OPTIONAL_A  USE_TRANS_FLOWE_OPTIONAL_A(trans15_FlowE_)
#define USE_TRANS15_FLOWE_OPTIONAL_B  USE_TRANS_FLOWE_OPTIONAL_B(trans15_FlowE_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_FLOWTM_MANDATORY_BOTH \
	BLOCK trans1_FlowTM_block; \
	COLLECTION trans1_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans1_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans1_FlowTM_ST_REV; \
	MENU trans1_FlowTM_ST_REV_page; \
	COMMAND trans1_FlowTM_ST_REV_read; \
	VARIABLE trans1_FlowTM_TAG_DESC; \
	MENU trans1_FlowTM_TAG_DESC_page; \
	COMMAND trans1_FlowTM_TAG_DESC_read; \
	COMMAND trans1_FlowTM_TAG_DESC_write; \
	VARIABLE trans1_FlowTM_STRATEGY; \
	MENU trans1_FlowTM_STRATEGY_page; \
	COMMAND trans1_FlowTM_STRATEGY_read; \
	COMMAND trans1_FlowTM_STRATEGY_write; \
	VARIABLE trans1_FlowTM_ALERT_KEY; \
	MENU trans1_FlowTM_ALERT_KEY_page; \
	COMMAND trans1_FlowTM_ALERT_KEY_read; \
	COMMAND trans1_FlowTM_ALERT_KEY_write; \
	VARIABLE trans1_FlowTM_TARGET_MODE; \
	MENU trans1_FlowTM_TARGET_MODE_page; \
	COMMAND trans1_FlowTM_TARGET_MODE_read; \
	COMMAND trans1_FlowTM_TARGET_MODE_write; \
	COLLECTION trans1_FlowTM_MODE_BLK; \
	VARIABLE trans1_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans1_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans1_FlowTM_MODE_BLK_Normal; \
	MENU trans1_FlowTM_MODE_BLK_page; \
	COMMAND trans1_FlowTM_MODE_BLK_read; \
	COLLECTION trans1_FlowTM_ALARM_SUM; \
	VARIABLE trans1_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans1_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans1_FlowTM_ALARM_SUM_Disabled; \
	MENU trans1_FlowTM_ALARM_SUM_page; \
	COMMAND trans1_FlowTM_ALARM_SUM_read; \
	VARIABLE trans1_FlowTM_CALIBR_FACTOR; \
	MENU trans1_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans1_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans1_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans1_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans1_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans1_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans1_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans1_FlowTM_NOMINAL_SIZE; \
	MENU trans1_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans1_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans1_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans1_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans1_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans1_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans1_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans1_FlowTM_MASS_FLOW; \
	VARIABLE trans1_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans1_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans1_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans1_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans1_FlowTM_MASS_FLOW_page; \
	COMMAND trans1_FlowTM_MASS_FLOW_read; \
	VARIABLE trans1_FlowTM_MASS_FLOW_UNITS; \
	MENU trans1_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans1_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans1_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans1_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans1_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans1_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans1_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans1_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans1_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans1_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans1_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans1_FlowTM_unit_nominal_size; \
	UNIT trans1_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS1_FLOWTM_MANDATORY_A \
	USE_TRANS1_FLOWTM_MANDATORY_BOTH; \
	MENU trans1_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS1_FLOWTM_MANDATORY_B \
	USE_TRANS1_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans1_FlowTM_VIEW_1; \
	MENU trans1_FlowTM_VIEW_1_page; \
	MENU trans1_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS1_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans1_FlowTM_ZERO_POINT; \
	MENU trans1_FlowTM_ZERO_POINT_page; \
	COMMAND trans1_FlowTM_ZERO_POINT_read; \
	COMMAND trans1_FlowTM_ZERO_POINT_write; \
	VARIABLE trans1_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans1_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans1_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans1_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans1_FlowTM_ZERO_POINT_UNIT; \
	MENU trans1_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans1_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans1_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans1_FlowTM_VIEW_2; \
	MENU trans1_FlowTM_VIEW_2_page; \
	COLLECTION trans1_FlowTM_VIEW_3; \
	MENU trans1_FlowTM_VIEW_3_page; \
	UNIT trans1_FlowTM_unit_zero_point

#define USE_TRANS1_FLOWTM_OPTIONAL_A \
	USE_TRANS1_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans1_FlowTM_VIEW_1; \
	MENU trans1_FlowTM_VIEW_1_page; \
	MENU trans1_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS1_FLOWTM_OPTIONAL_B \
	USE_TRANS1_FLOWTM_OPTIONAL_BOTH; \
	MENU trans1_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_FLOWTM_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CALIBR_FACTOR; \
	MENU prefix ## CALIBR_FACTOR_page; \
	COMMAND prefix ## CALIBR_FACTOR_read; \
	COMMAND prefix ## CALIBR_FACTOR_write; \
	VARIABLE prefix ## LOW_FLOW_CUTOFF; \
	MENU prefix ## LOW_FLOW_CUTOFF_page; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_read; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_write; \
	VARIABLE prefix ## NOMINAL_SIZE; \
	MENU prefix ## NOMINAL_SIZE_page; \
	COMMAND prefix ## NOMINAL_SIZE_read; \
	COMMAND prefix ## NOMINAL_SIZE_write; \
	VARIABLE prefix ## NOMINAL_SIZE_UNITS; \
	MENU prefix ## NOMINAL_SIZE_UNITS_page; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_read; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_write; \
	COLLECTION prefix ## MASS_FLOW; \
	VARIABLE prefix ## MASS_FLOW_Value; \
	VARIABLE prefix ## MASS_FLOW_Status_Condensed; \
	VARIABLE prefix ## MASS_FLOW_Status_Quality; \
	VARIABLE prefix ## MASS_FLOW_Status_Limit; \
	MENU prefix ## MASS_FLOW_page; \
	COMMAND prefix ## MASS_FLOW_read; \
	VARIABLE prefix ## MASS_FLOW_UNITS; \
	MENU prefix ## MASS_FLOW_UNITS_page; \
	COMMAND prefix ## MASS_FLOW_UNITS_read; \
	COMMAND prefix ## MASS_FLOW_UNITS_write; \
	VARIABLE prefix ## MASS_FLOW_LO_LIMIT; \
	MENU prefix ## MASS_FLOW_LO_LIMIT_page; \
	COMMAND prefix ## MASS_FLOW_LO_LIMIT_read; \
	COMMAND prefix ## MASS_FLOW_LO_LIMIT_write; \
	VARIABLE prefix ## MASS_FLOW_HI_LIMIT; \
	MENU prefix ## MASS_FLOW_HI_LIMIT_page; \
	COMMAND prefix ## MASS_FLOW_HI_LIMIT_read; \
	COMMAND prefix ## MASS_FLOW_HI_LIMIT_write; \
	UNIT prefix ## unit_nominal_size; \
	UNIT prefix ## unit_TB_MASS_FLOW_UNIT

#define USE_TRANS_FLOWTM_MANDATORY_A(prefix) \
	USE_TRANS_FLOWTM_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_FLOWTM_MANDATORY_B(prefix) \
	USE_TRANS_FLOWTM_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_FLOWTM_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ZERO_POINT; \
	MENU prefix ## ZERO_POINT_page; \
	COMMAND prefix ## ZERO_POINT_read; \
	COMMAND prefix ## ZERO_POINT_write; \
	VARIABLE prefix ## ZERO_POINT_ADJUST; \
	MENU prefix ## ZERO_POINT_ADJUST_page; \
	COMMAND prefix ## ZERO_POINT_ADJUST_read; \
	COMMAND prefix ## ZERO_POINT_ADJUST_write; \
	VARIABLE prefix ## ZERO_POINT_UNIT; \
	MENU prefix ## ZERO_POINT_UNIT_page; \
	COMMAND prefix ## ZERO_POINT_UNIT_read; \
	COMMAND prefix ## ZERO_POINT_UNIT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## unit_zero_point

#define USE_TRANS_FLOWTM_OPTIONAL_A(prefix) \
	USE_TRANS_FLOWTM_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_FLOWTM_OPTIONAL_B(prefix) \
	USE_TRANS_FLOWTM_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans1_FlowTM_)
#define USE_TRANS1_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans1_FlowTM_)
#define USE_TRANS1_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans1_FlowTM_)
#define USE_TRANS1_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans1_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_FLOWTM_MANDATORY_BOTH \
	BLOCK trans2_FlowTM_block; \
	COLLECTION trans2_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans2_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans2_FlowTM_ST_REV; \
	MENU trans2_FlowTM_ST_REV_page; \
	COMMAND trans2_FlowTM_ST_REV_read; \
	VARIABLE trans2_FlowTM_TAG_DESC; \
	MENU trans2_FlowTM_TAG_DESC_page; \
	COMMAND trans2_FlowTM_TAG_DESC_read; \
	COMMAND trans2_FlowTM_TAG_DESC_write; \
	VARIABLE trans2_FlowTM_STRATEGY; \
	MENU trans2_FlowTM_STRATEGY_page; \
	COMMAND trans2_FlowTM_STRATEGY_read; \
	COMMAND trans2_FlowTM_STRATEGY_write; \
	VARIABLE trans2_FlowTM_ALERT_KEY; \
	MENU trans2_FlowTM_ALERT_KEY_page; \
	COMMAND trans2_FlowTM_ALERT_KEY_read; \
	COMMAND trans2_FlowTM_ALERT_KEY_write; \
	VARIABLE trans2_FlowTM_TARGET_MODE; \
	MENU trans2_FlowTM_TARGET_MODE_page; \
	COMMAND trans2_FlowTM_TARGET_MODE_read; \
	COMMAND trans2_FlowTM_TARGET_MODE_write; \
	COLLECTION trans2_FlowTM_MODE_BLK; \
	VARIABLE trans2_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans2_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans2_FlowTM_MODE_BLK_Normal; \
	MENU trans2_FlowTM_MODE_BLK_page; \
	COMMAND trans2_FlowTM_MODE_BLK_read; \
	COLLECTION trans2_FlowTM_ALARM_SUM; \
	VARIABLE trans2_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans2_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans2_FlowTM_ALARM_SUM_Disabled; \
	MENU trans2_FlowTM_ALARM_SUM_page; \
	COMMAND trans2_FlowTM_ALARM_SUM_read; \
	VARIABLE trans2_FlowTM_CALIBR_FACTOR; \
	MENU trans2_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans2_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans2_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans2_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans2_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans2_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans2_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans2_FlowTM_NOMINAL_SIZE; \
	MENU trans2_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans2_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans2_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans2_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans2_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans2_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans2_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans2_FlowTM_MASS_FLOW; \
	VARIABLE trans2_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans2_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans2_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans2_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans2_FlowTM_MASS_FLOW_page; \
	COMMAND trans2_FlowTM_MASS_FLOW_read; \
	VARIABLE trans2_FlowTM_MASS_FLOW_UNITS; \
	MENU trans2_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans2_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans2_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans2_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans2_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans2_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans2_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans2_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans2_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans2_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans2_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans2_FlowTM_unit_nominal_size; \
	UNIT trans2_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS2_FLOWTM_MANDATORY_A \
	USE_TRANS2_FLOWTM_MANDATORY_BOTH; \
	MENU trans2_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS2_FLOWTM_MANDATORY_B \
	USE_TRANS2_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans2_FlowTM_VIEW_1; \
	MENU trans2_FlowTM_VIEW_1_page; \
	MENU trans2_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS2_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans2_FlowTM_ZERO_POINT; \
	MENU trans2_FlowTM_ZERO_POINT_page; \
	COMMAND trans2_FlowTM_ZERO_POINT_read; \
	COMMAND trans2_FlowTM_ZERO_POINT_write; \
	VARIABLE trans2_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans2_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans2_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans2_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans2_FlowTM_ZERO_POINT_UNIT; \
	MENU trans2_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans2_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans2_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans2_FlowTM_VIEW_2; \
	MENU trans2_FlowTM_VIEW_2_page; \
	COLLECTION trans2_FlowTM_VIEW_3; \
	MENU trans2_FlowTM_VIEW_3_page; \
	UNIT trans2_FlowTM_unit_zero_point

#define USE_TRANS2_FLOWTM_OPTIONAL_A \
	USE_TRANS2_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans2_FlowTM_VIEW_1; \
	MENU trans2_FlowTM_VIEW_1_page; \
	MENU trans2_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS2_FLOWTM_OPTIONAL_B \
	USE_TRANS2_FLOWTM_OPTIONAL_BOTH; \
	MENU trans2_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans2_FlowTM_)
#define USE_TRANS2_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans2_FlowTM_)
#define USE_TRANS2_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans2_FlowTM_)
#define USE_TRANS2_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans2_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_FLOWTM_MANDATORY_BOTH \
	BLOCK trans3_FlowTM_block; \
	COLLECTION trans3_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans3_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans3_FlowTM_ST_REV; \
	MENU trans3_FlowTM_ST_REV_page; \
	COMMAND trans3_FlowTM_ST_REV_read; \
	VARIABLE trans3_FlowTM_TAG_DESC; \
	MENU trans3_FlowTM_TAG_DESC_page; \
	COMMAND trans3_FlowTM_TAG_DESC_read; \
	COMMAND trans3_FlowTM_TAG_DESC_write; \
	VARIABLE trans3_FlowTM_STRATEGY; \
	MENU trans3_FlowTM_STRATEGY_page; \
	COMMAND trans3_FlowTM_STRATEGY_read; \
	COMMAND trans3_FlowTM_STRATEGY_write; \
	VARIABLE trans3_FlowTM_ALERT_KEY; \
	MENU trans3_FlowTM_ALERT_KEY_page; \
	COMMAND trans3_FlowTM_ALERT_KEY_read; \
	COMMAND trans3_FlowTM_ALERT_KEY_write; \
	VARIABLE trans3_FlowTM_TARGET_MODE; \
	MENU trans3_FlowTM_TARGET_MODE_page; \
	COMMAND trans3_FlowTM_TARGET_MODE_read; \
	COMMAND trans3_FlowTM_TARGET_MODE_write; \
	COLLECTION trans3_FlowTM_MODE_BLK; \
	VARIABLE trans3_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans3_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans3_FlowTM_MODE_BLK_Normal; \
	MENU trans3_FlowTM_MODE_BLK_page; \
	COMMAND trans3_FlowTM_MODE_BLK_read; \
	COLLECTION trans3_FlowTM_ALARM_SUM; \
	VARIABLE trans3_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans3_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans3_FlowTM_ALARM_SUM_Disabled; \
	MENU trans3_FlowTM_ALARM_SUM_page; \
	COMMAND trans3_FlowTM_ALARM_SUM_read; \
	VARIABLE trans3_FlowTM_CALIBR_FACTOR; \
	MENU trans3_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans3_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans3_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans3_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans3_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans3_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans3_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans3_FlowTM_NOMINAL_SIZE; \
	MENU trans3_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans3_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans3_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans3_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans3_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans3_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans3_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans3_FlowTM_MASS_FLOW; \
	VARIABLE trans3_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans3_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans3_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans3_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans3_FlowTM_MASS_FLOW_page; \
	COMMAND trans3_FlowTM_MASS_FLOW_read; \
	VARIABLE trans3_FlowTM_MASS_FLOW_UNITS; \
	MENU trans3_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans3_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans3_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans3_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans3_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans3_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans3_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans3_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans3_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans3_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans3_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans3_FlowTM_unit_nominal_size; \
	UNIT trans3_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS3_FLOWTM_MANDATORY_A \
	USE_TRANS3_FLOWTM_MANDATORY_BOTH; \
	MENU trans3_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS3_FLOWTM_MANDATORY_B \
	USE_TRANS3_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans3_FlowTM_VIEW_1; \
	MENU trans3_FlowTM_VIEW_1_page; \
	MENU trans3_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS3_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans3_FlowTM_ZERO_POINT; \
	MENU trans3_FlowTM_ZERO_POINT_page; \
	COMMAND trans3_FlowTM_ZERO_POINT_read; \
	COMMAND trans3_FlowTM_ZERO_POINT_write; \
	VARIABLE trans3_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans3_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans3_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans3_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans3_FlowTM_ZERO_POINT_UNIT; \
	MENU trans3_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans3_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans3_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans3_FlowTM_VIEW_2; \
	MENU trans3_FlowTM_VIEW_2_page; \
	COLLECTION trans3_FlowTM_VIEW_3; \
	MENU trans3_FlowTM_VIEW_3_page; \
	UNIT trans3_FlowTM_unit_zero_point

#define USE_TRANS3_FLOWTM_OPTIONAL_A \
	USE_TRANS3_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans3_FlowTM_VIEW_1; \
	MENU trans3_FlowTM_VIEW_1_page; \
	MENU trans3_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS3_FLOWTM_OPTIONAL_B \
	USE_TRANS3_FLOWTM_OPTIONAL_BOTH; \
	MENU trans3_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans3_FlowTM_)
#define USE_TRANS3_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans3_FlowTM_)
#define USE_TRANS3_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans3_FlowTM_)
#define USE_TRANS3_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans3_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_FLOWTM_MANDATORY_BOTH \
	BLOCK trans4_FlowTM_block; \
	COLLECTION trans4_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans4_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans4_FlowTM_ST_REV; \
	MENU trans4_FlowTM_ST_REV_page; \
	COMMAND trans4_FlowTM_ST_REV_read; \
	VARIABLE trans4_FlowTM_TAG_DESC; \
	MENU trans4_FlowTM_TAG_DESC_page; \
	COMMAND trans4_FlowTM_TAG_DESC_read; \
	COMMAND trans4_FlowTM_TAG_DESC_write; \
	VARIABLE trans4_FlowTM_STRATEGY; \
	MENU trans4_FlowTM_STRATEGY_page; \
	COMMAND trans4_FlowTM_STRATEGY_read; \
	COMMAND trans4_FlowTM_STRATEGY_write; \
	VARIABLE trans4_FlowTM_ALERT_KEY; \
	MENU trans4_FlowTM_ALERT_KEY_page; \
	COMMAND trans4_FlowTM_ALERT_KEY_read; \
	COMMAND trans4_FlowTM_ALERT_KEY_write; \
	VARIABLE trans4_FlowTM_TARGET_MODE; \
	MENU trans4_FlowTM_TARGET_MODE_page; \
	COMMAND trans4_FlowTM_TARGET_MODE_read; \
	COMMAND trans4_FlowTM_TARGET_MODE_write; \
	COLLECTION trans4_FlowTM_MODE_BLK; \
	VARIABLE trans4_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans4_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans4_FlowTM_MODE_BLK_Normal; \
	MENU trans4_FlowTM_MODE_BLK_page; \
	COMMAND trans4_FlowTM_MODE_BLK_read; \
	COLLECTION trans4_FlowTM_ALARM_SUM; \
	VARIABLE trans4_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans4_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans4_FlowTM_ALARM_SUM_Disabled; \
	MENU trans4_FlowTM_ALARM_SUM_page; \
	COMMAND trans4_FlowTM_ALARM_SUM_read; \
	VARIABLE trans4_FlowTM_CALIBR_FACTOR; \
	MENU trans4_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans4_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans4_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans4_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans4_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans4_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans4_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans4_FlowTM_NOMINAL_SIZE; \
	MENU trans4_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans4_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans4_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans4_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans4_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans4_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans4_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans4_FlowTM_MASS_FLOW; \
	VARIABLE trans4_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans4_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans4_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans4_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans4_FlowTM_MASS_FLOW_page; \
	COMMAND trans4_FlowTM_MASS_FLOW_read; \
	VARIABLE trans4_FlowTM_MASS_FLOW_UNITS; \
	MENU trans4_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans4_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans4_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans4_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans4_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans4_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans4_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans4_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans4_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans4_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans4_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans4_FlowTM_unit_nominal_size; \
	UNIT trans4_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS4_FLOWTM_MANDATORY_A \
	USE_TRANS4_FLOWTM_MANDATORY_BOTH; \
	MENU trans4_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS4_FLOWTM_MANDATORY_B \
	USE_TRANS4_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans4_FlowTM_VIEW_1; \
	MENU trans4_FlowTM_VIEW_1_page; \
	MENU trans4_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS4_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans4_FlowTM_ZERO_POINT; \
	MENU trans4_FlowTM_ZERO_POINT_page; \
	COMMAND trans4_FlowTM_ZERO_POINT_read; \
	COMMAND trans4_FlowTM_ZERO_POINT_write; \
	VARIABLE trans4_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans4_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans4_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans4_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans4_FlowTM_ZERO_POINT_UNIT; \
	MENU trans4_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans4_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans4_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans4_FlowTM_VIEW_2; \
	MENU trans4_FlowTM_VIEW_2_page; \
	COLLECTION trans4_FlowTM_VIEW_3; \
	MENU trans4_FlowTM_VIEW_3_page; \
	UNIT trans4_FlowTM_unit_zero_point

#define USE_TRANS4_FLOWTM_OPTIONAL_A \
	USE_TRANS4_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans4_FlowTM_VIEW_1; \
	MENU trans4_FlowTM_VIEW_1_page; \
	MENU trans4_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS4_FLOWTM_OPTIONAL_B \
	USE_TRANS4_FLOWTM_OPTIONAL_BOTH; \
	MENU trans4_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans4_FlowTM_)
#define USE_TRANS4_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans4_FlowTM_)
#define USE_TRANS4_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans4_FlowTM_)
#define USE_TRANS4_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans4_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_FLOWTM_MANDATORY_BOTH \
	BLOCK trans5_FlowTM_block; \
	COLLECTION trans5_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans5_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans5_FlowTM_ST_REV; \
	MENU trans5_FlowTM_ST_REV_page; \
	COMMAND trans5_FlowTM_ST_REV_read; \
	VARIABLE trans5_FlowTM_TAG_DESC; \
	MENU trans5_FlowTM_TAG_DESC_page; \
	COMMAND trans5_FlowTM_TAG_DESC_read; \
	COMMAND trans5_FlowTM_TAG_DESC_write; \
	VARIABLE trans5_FlowTM_STRATEGY; \
	MENU trans5_FlowTM_STRATEGY_page; \
	COMMAND trans5_FlowTM_STRATEGY_read; \
	COMMAND trans5_FlowTM_STRATEGY_write; \
	VARIABLE trans5_FlowTM_ALERT_KEY; \
	MENU trans5_FlowTM_ALERT_KEY_page; \
	COMMAND trans5_FlowTM_ALERT_KEY_read; \
	COMMAND trans5_FlowTM_ALERT_KEY_write; \
	VARIABLE trans5_FlowTM_TARGET_MODE; \
	MENU trans5_FlowTM_TARGET_MODE_page; \
	COMMAND trans5_FlowTM_TARGET_MODE_read; \
	COMMAND trans5_FlowTM_TARGET_MODE_write; \
	COLLECTION trans5_FlowTM_MODE_BLK; \
	VARIABLE trans5_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans5_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans5_FlowTM_MODE_BLK_Normal; \
	MENU trans5_FlowTM_MODE_BLK_page; \
	COMMAND trans5_FlowTM_MODE_BLK_read; \
	COLLECTION trans5_FlowTM_ALARM_SUM; \
	VARIABLE trans5_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans5_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans5_FlowTM_ALARM_SUM_Disabled; \
	MENU trans5_FlowTM_ALARM_SUM_page; \
	COMMAND trans5_FlowTM_ALARM_SUM_read; \
	VARIABLE trans5_FlowTM_CALIBR_FACTOR; \
	MENU trans5_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans5_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans5_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans5_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans5_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans5_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans5_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans5_FlowTM_NOMINAL_SIZE; \
	MENU trans5_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans5_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans5_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans5_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans5_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans5_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans5_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans5_FlowTM_MASS_FLOW; \
	VARIABLE trans5_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans5_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans5_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans5_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans5_FlowTM_MASS_FLOW_page; \
	COMMAND trans5_FlowTM_MASS_FLOW_read; \
	VARIABLE trans5_FlowTM_MASS_FLOW_UNITS; \
	MENU trans5_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans5_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans5_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans5_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans5_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans5_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans5_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans5_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans5_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans5_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans5_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans5_FlowTM_unit_nominal_size; \
	UNIT trans5_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS5_FLOWTM_MANDATORY_A \
	USE_TRANS5_FLOWTM_MANDATORY_BOTH; \
	MENU trans5_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS5_FLOWTM_MANDATORY_B \
	USE_TRANS5_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans5_FlowTM_VIEW_1; \
	MENU trans5_FlowTM_VIEW_1_page; \
	MENU trans5_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS5_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans5_FlowTM_ZERO_POINT; \
	MENU trans5_FlowTM_ZERO_POINT_page; \
	COMMAND trans5_FlowTM_ZERO_POINT_read; \
	COMMAND trans5_FlowTM_ZERO_POINT_write; \
	VARIABLE trans5_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans5_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans5_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans5_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans5_FlowTM_ZERO_POINT_UNIT; \
	MENU trans5_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans5_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans5_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans5_FlowTM_VIEW_2; \
	MENU trans5_FlowTM_VIEW_2_page; \
	COLLECTION trans5_FlowTM_VIEW_3; \
	MENU trans5_FlowTM_VIEW_3_page; \
	UNIT trans5_FlowTM_unit_zero_point

#define USE_TRANS5_FLOWTM_OPTIONAL_A \
	USE_TRANS5_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans5_FlowTM_VIEW_1; \
	MENU trans5_FlowTM_VIEW_1_page; \
	MENU trans5_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS5_FLOWTM_OPTIONAL_B \
	USE_TRANS5_FLOWTM_OPTIONAL_BOTH; \
	MENU trans5_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans5_FlowTM_)
#define USE_TRANS5_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans5_FlowTM_)
#define USE_TRANS5_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans5_FlowTM_)
#define USE_TRANS5_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans5_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_FLOWTM_MANDATORY_BOTH \
	BLOCK trans6_FlowTM_block; \
	COLLECTION trans6_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans6_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans6_FlowTM_ST_REV; \
	MENU trans6_FlowTM_ST_REV_page; \
	COMMAND trans6_FlowTM_ST_REV_read; \
	VARIABLE trans6_FlowTM_TAG_DESC; \
	MENU trans6_FlowTM_TAG_DESC_page; \
	COMMAND trans6_FlowTM_TAG_DESC_read; \
	COMMAND trans6_FlowTM_TAG_DESC_write; \
	VARIABLE trans6_FlowTM_STRATEGY; \
	MENU trans6_FlowTM_STRATEGY_page; \
	COMMAND trans6_FlowTM_STRATEGY_read; \
	COMMAND trans6_FlowTM_STRATEGY_write; \
	VARIABLE trans6_FlowTM_ALERT_KEY; \
	MENU trans6_FlowTM_ALERT_KEY_page; \
	COMMAND trans6_FlowTM_ALERT_KEY_read; \
	COMMAND trans6_FlowTM_ALERT_KEY_write; \
	VARIABLE trans6_FlowTM_TARGET_MODE; \
	MENU trans6_FlowTM_TARGET_MODE_page; \
	COMMAND trans6_FlowTM_TARGET_MODE_read; \
	COMMAND trans6_FlowTM_TARGET_MODE_write; \
	COLLECTION trans6_FlowTM_MODE_BLK; \
	VARIABLE trans6_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans6_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans6_FlowTM_MODE_BLK_Normal; \
	MENU trans6_FlowTM_MODE_BLK_page; \
	COMMAND trans6_FlowTM_MODE_BLK_read; \
	COLLECTION trans6_FlowTM_ALARM_SUM; \
	VARIABLE trans6_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans6_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans6_FlowTM_ALARM_SUM_Disabled; \
	MENU trans6_FlowTM_ALARM_SUM_page; \
	COMMAND trans6_FlowTM_ALARM_SUM_read; \
	VARIABLE trans6_FlowTM_CALIBR_FACTOR; \
	MENU trans6_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans6_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans6_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans6_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans6_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans6_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans6_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans6_FlowTM_NOMINAL_SIZE; \
	MENU trans6_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans6_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans6_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans6_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans6_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans6_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans6_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans6_FlowTM_MASS_FLOW; \
	VARIABLE trans6_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans6_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans6_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans6_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans6_FlowTM_MASS_FLOW_page; \
	COMMAND trans6_FlowTM_MASS_FLOW_read; \
	VARIABLE trans6_FlowTM_MASS_FLOW_UNITS; \
	MENU trans6_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans6_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans6_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans6_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans6_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans6_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans6_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans6_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans6_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans6_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans6_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans6_FlowTM_unit_nominal_size; \
	UNIT trans6_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS6_FLOWTM_MANDATORY_A \
	USE_TRANS6_FLOWTM_MANDATORY_BOTH; \
	MENU trans6_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS6_FLOWTM_MANDATORY_B \
	USE_TRANS6_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans6_FlowTM_VIEW_1; \
	MENU trans6_FlowTM_VIEW_1_page; \
	MENU trans6_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS6_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans6_FlowTM_ZERO_POINT; \
	MENU trans6_FlowTM_ZERO_POINT_page; \
	COMMAND trans6_FlowTM_ZERO_POINT_read; \
	COMMAND trans6_FlowTM_ZERO_POINT_write; \
	VARIABLE trans6_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans6_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans6_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans6_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans6_FlowTM_ZERO_POINT_UNIT; \
	MENU trans6_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans6_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans6_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans6_FlowTM_VIEW_2; \
	MENU trans6_FlowTM_VIEW_2_page; \
	COLLECTION trans6_FlowTM_VIEW_3; \
	MENU trans6_FlowTM_VIEW_3_page; \
	UNIT trans6_FlowTM_unit_zero_point

#define USE_TRANS6_FLOWTM_OPTIONAL_A \
	USE_TRANS6_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans6_FlowTM_VIEW_1; \
	MENU trans6_FlowTM_VIEW_1_page; \
	MENU trans6_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS6_FLOWTM_OPTIONAL_B \
	USE_TRANS6_FLOWTM_OPTIONAL_BOTH; \
	MENU trans6_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans6_FlowTM_)
#define USE_TRANS6_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans6_FlowTM_)
#define USE_TRANS6_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans6_FlowTM_)
#define USE_TRANS6_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans6_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_FLOWTM_MANDATORY_BOTH \
	BLOCK trans7_FlowTM_block; \
	COLLECTION trans7_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans7_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans7_FlowTM_ST_REV; \
	MENU trans7_FlowTM_ST_REV_page; \
	COMMAND trans7_FlowTM_ST_REV_read; \
	VARIABLE trans7_FlowTM_TAG_DESC; \
	MENU trans7_FlowTM_TAG_DESC_page; \
	COMMAND trans7_FlowTM_TAG_DESC_read; \
	COMMAND trans7_FlowTM_TAG_DESC_write; \
	VARIABLE trans7_FlowTM_STRATEGY; \
	MENU trans7_FlowTM_STRATEGY_page; \
	COMMAND trans7_FlowTM_STRATEGY_read; \
	COMMAND trans7_FlowTM_STRATEGY_write; \
	VARIABLE trans7_FlowTM_ALERT_KEY; \
	MENU trans7_FlowTM_ALERT_KEY_page; \
	COMMAND trans7_FlowTM_ALERT_KEY_read; \
	COMMAND trans7_FlowTM_ALERT_KEY_write; \
	VARIABLE trans7_FlowTM_TARGET_MODE; \
	MENU trans7_FlowTM_TARGET_MODE_page; \
	COMMAND trans7_FlowTM_TARGET_MODE_read; \
	COMMAND trans7_FlowTM_TARGET_MODE_write; \
	COLLECTION trans7_FlowTM_MODE_BLK; \
	VARIABLE trans7_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans7_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans7_FlowTM_MODE_BLK_Normal; \
	MENU trans7_FlowTM_MODE_BLK_page; \
	COMMAND trans7_FlowTM_MODE_BLK_read; \
	COLLECTION trans7_FlowTM_ALARM_SUM; \
	VARIABLE trans7_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans7_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans7_FlowTM_ALARM_SUM_Disabled; \
	MENU trans7_FlowTM_ALARM_SUM_page; \
	COMMAND trans7_FlowTM_ALARM_SUM_read; \
	VARIABLE trans7_FlowTM_CALIBR_FACTOR; \
	MENU trans7_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans7_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans7_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans7_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans7_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans7_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans7_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans7_FlowTM_NOMINAL_SIZE; \
	MENU trans7_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans7_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans7_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans7_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans7_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans7_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans7_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans7_FlowTM_MASS_FLOW; \
	VARIABLE trans7_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans7_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans7_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans7_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans7_FlowTM_MASS_FLOW_page; \
	COMMAND trans7_FlowTM_MASS_FLOW_read; \
	VARIABLE trans7_FlowTM_MASS_FLOW_UNITS; \
	MENU trans7_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans7_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans7_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans7_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans7_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans7_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans7_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans7_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans7_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans7_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans7_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans7_FlowTM_unit_nominal_size; \
	UNIT trans7_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS7_FLOWTM_MANDATORY_A \
	USE_TRANS7_FLOWTM_MANDATORY_BOTH; \
	MENU trans7_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS7_FLOWTM_MANDATORY_B \
	USE_TRANS7_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans7_FlowTM_VIEW_1; \
	MENU trans7_FlowTM_VIEW_1_page; \
	MENU trans7_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS7_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans7_FlowTM_ZERO_POINT; \
	MENU trans7_FlowTM_ZERO_POINT_page; \
	COMMAND trans7_FlowTM_ZERO_POINT_read; \
	COMMAND trans7_FlowTM_ZERO_POINT_write; \
	VARIABLE trans7_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans7_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans7_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans7_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans7_FlowTM_ZERO_POINT_UNIT; \
	MENU trans7_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans7_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans7_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans7_FlowTM_VIEW_2; \
	MENU trans7_FlowTM_VIEW_2_page; \
	COLLECTION trans7_FlowTM_VIEW_3; \
	MENU trans7_FlowTM_VIEW_3_page; \
	UNIT trans7_FlowTM_unit_zero_point

#define USE_TRANS7_FLOWTM_OPTIONAL_A \
	USE_TRANS7_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans7_FlowTM_VIEW_1; \
	MENU trans7_FlowTM_VIEW_1_page; \
	MENU trans7_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS7_FLOWTM_OPTIONAL_B \
	USE_TRANS7_FLOWTM_OPTIONAL_BOTH; \
	MENU trans7_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans7_FlowTM_)
#define USE_TRANS7_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans7_FlowTM_)
#define USE_TRANS7_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans7_FlowTM_)
#define USE_TRANS7_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans7_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_FLOWTM_MANDATORY_BOTH \
	BLOCK trans8_FlowTM_block; \
	COLLECTION trans8_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans8_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans8_FlowTM_ST_REV; \
	MENU trans8_FlowTM_ST_REV_page; \
	COMMAND trans8_FlowTM_ST_REV_read; \
	VARIABLE trans8_FlowTM_TAG_DESC; \
	MENU trans8_FlowTM_TAG_DESC_page; \
	COMMAND trans8_FlowTM_TAG_DESC_read; \
	COMMAND trans8_FlowTM_TAG_DESC_write; \
	VARIABLE trans8_FlowTM_STRATEGY; \
	MENU trans8_FlowTM_STRATEGY_page; \
	COMMAND trans8_FlowTM_STRATEGY_read; \
	COMMAND trans8_FlowTM_STRATEGY_write; \
	VARIABLE trans8_FlowTM_ALERT_KEY; \
	MENU trans8_FlowTM_ALERT_KEY_page; \
	COMMAND trans8_FlowTM_ALERT_KEY_read; \
	COMMAND trans8_FlowTM_ALERT_KEY_write; \
	VARIABLE trans8_FlowTM_TARGET_MODE; \
	MENU trans8_FlowTM_TARGET_MODE_page; \
	COMMAND trans8_FlowTM_TARGET_MODE_read; \
	COMMAND trans8_FlowTM_TARGET_MODE_write; \
	COLLECTION trans8_FlowTM_MODE_BLK; \
	VARIABLE trans8_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans8_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans8_FlowTM_MODE_BLK_Normal; \
	MENU trans8_FlowTM_MODE_BLK_page; \
	COMMAND trans8_FlowTM_MODE_BLK_read; \
	COLLECTION trans8_FlowTM_ALARM_SUM; \
	VARIABLE trans8_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans8_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans8_FlowTM_ALARM_SUM_Disabled; \
	MENU trans8_FlowTM_ALARM_SUM_page; \
	COMMAND trans8_FlowTM_ALARM_SUM_read; \
	VARIABLE trans8_FlowTM_CALIBR_FACTOR; \
	MENU trans8_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans8_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans8_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans8_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans8_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans8_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans8_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans8_FlowTM_NOMINAL_SIZE; \
	MENU trans8_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans8_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans8_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans8_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans8_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans8_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans8_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans8_FlowTM_MASS_FLOW; \
	VARIABLE trans8_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans8_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans8_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans8_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans8_FlowTM_MASS_FLOW_page; \
	COMMAND trans8_FlowTM_MASS_FLOW_read; \
	VARIABLE trans8_FlowTM_MASS_FLOW_UNITS; \
	MENU trans8_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans8_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans8_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans8_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans8_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans8_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans8_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans8_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans8_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans8_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans8_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans8_FlowTM_unit_nominal_size; \
	UNIT trans8_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS8_FLOWTM_MANDATORY_A \
	USE_TRANS8_FLOWTM_MANDATORY_BOTH; \
	MENU trans8_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS8_FLOWTM_MANDATORY_B \
	USE_TRANS8_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans8_FlowTM_VIEW_1; \
	MENU trans8_FlowTM_VIEW_1_page; \
	MENU trans8_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS8_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans8_FlowTM_ZERO_POINT; \
	MENU trans8_FlowTM_ZERO_POINT_page; \
	COMMAND trans8_FlowTM_ZERO_POINT_read; \
	COMMAND trans8_FlowTM_ZERO_POINT_write; \
	VARIABLE trans8_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans8_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans8_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans8_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans8_FlowTM_ZERO_POINT_UNIT; \
	MENU trans8_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans8_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans8_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans8_FlowTM_VIEW_2; \
	MENU trans8_FlowTM_VIEW_2_page; \
	COLLECTION trans8_FlowTM_VIEW_3; \
	MENU trans8_FlowTM_VIEW_3_page; \
	UNIT trans8_FlowTM_unit_zero_point

#define USE_TRANS8_FLOWTM_OPTIONAL_A \
	USE_TRANS8_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans8_FlowTM_VIEW_1; \
	MENU trans8_FlowTM_VIEW_1_page; \
	MENU trans8_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS8_FLOWTM_OPTIONAL_B \
	USE_TRANS8_FLOWTM_OPTIONAL_BOTH; \
	MENU trans8_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans8_FlowTM_)
#define USE_TRANS8_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans8_FlowTM_)
#define USE_TRANS8_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans8_FlowTM_)
#define USE_TRANS8_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans8_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_FLOWTM_MANDATORY_BOTH \
	BLOCK trans9_FlowTM_block; \
	COLLECTION trans9_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans9_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans9_FlowTM_ST_REV; \
	MENU trans9_FlowTM_ST_REV_page; \
	COMMAND trans9_FlowTM_ST_REV_read; \
	VARIABLE trans9_FlowTM_TAG_DESC; \
	MENU trans9_FlowTM_TAG_DESC_page; \
	COMMAND trans9_FlowTM_TAG_DESC_read; \
	COMMAND trans9_FlowTM_TAG_DESC_write; \
	VARIABLE trans9_FlowTM_STRATEGY; \
	MENU trans9_FlowTM_STRATEGY_page; \
	COMMAND trans9_FlowTM_STRATEGY_read; \
	COMMAND trans9_FlowTM_STRATEGY_write; \
	VARIABLE trans9_FlowTM_ALERT_KEY; \
	MENU trans9_FlowTM_ALERT_KEY_page; \
	COMMAND trans9_FlowTM_ALERT_KEY_read; \
	COMMAND trans9_FlowTM_ALERT_KEY_write; \
	VARIABLE trans9_FlowTM_TARGET_MODE; \
	MENU trans9_FlowTM_TARGET_MODE_page; \
	COMMAND trans9_FlowTM_TARGET_MODE_read; \
	COMMAND trans9_FlowTM_TARGET_MODE_write; \
	COLLECTION trans9_FlowTM_MODE_BLK; \
	VARIABLE trans9_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans9_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans9_FlowTM_MODE_BLK_Normal; \
	MENU trans9_FlowTM_MODE_BLK_page; \
	COMMAND trans9_FlowTM_MODE_BLK_read; \
	COLLECTION trans9_FlowTM_ALARM_SUM; \
	VARIABLE trans9_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans9_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans9_FlowTM_ALARM_SUM_Disabled; \
	MENU trans9_FlowTM_ALARM_SUM_page; \
	COMMAND trans9_FlowTM_ALARM_SUM_read; \
	VARIABLE trans9_FlowTM_CALIBR_FACTOR; \
	MENU trans9_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans9_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans9_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans9_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans9_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans9_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans9_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans9_FlowTM_NOMINAL_SIZE; \
	MENU trans9_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans9_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans9_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans9_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans9_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans9_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans9_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans9_FlowTM_MASS_FLOW; \
	VARIABLE trans9_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans9_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans9_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans9_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans9_FlowTM_MASS_FLOW_page; \
	COMMAND trans9_FlowTM_MASS_FLOW_read; \
	VARIABLE trans9_FlowTM_MASS_FLOW_UNITS; \
	MENU trans9_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans9_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans9_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans9_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans9_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans9_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans9_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans9_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans9_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans9_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans9_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans9_FlowTM_unit_nominal_size; \
	UNIT trans9_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS9_FLOWTM_MANDATORY_A \
	USE_TRANS9_FLOWTM_MANDATORY_BOTH; \
	MENU trans9_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS9_FLOWTM_MANDATORY_B \
	USE_TRANS9_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans9_FlowTM_VIEW_1; \
	MENU trans9_FlowTM_VIEW_1_page; \
	MENU trans9_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS9_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans9_FlowTM_ZERO_POINT; \
	MENU trans9_FlowTM_ZERO_POINT_page; \
	COMMAND trans9_FlowTM_ZERO_POINT_read; \
	COMMAND trans9_FlowTM_ZERO_POINT_write; \
	VARIABLE trans9_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans9_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans9_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans9_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans9_FlowTM_ZERO_POINT_UNIT; \
	MENU trans9_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans9_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans9_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans9_FlowTM_VIEW_2; \
	MENU trans9_FlowTM_VIEW_2_page; \
	COLLECTION trans9_FlowTM_VIEW_3; \
	MENU trans9_FlowTM_VIEW_3_page; \
	UNIT trans9_FlowTM_unit_zero_point

#define USE_TRANS9_FLOWTM_OPTIONAL_A \
	USE_TRANS9_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans9_FlowTM_VIEW_1; \
	MENU trans9_FlowTM_VIEW_1_page; \
	MENU trans9_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS9_FLOWTM_OPTIONAL_B \
	USE_TRANS9_FLOWTM_OPTIONAL_BOTH; \
	MENU trans9_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans9_FlowTM_)
#define USE_TRANS9_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans9_FlowTM_)
#define USE_TRANS9_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans9_FlowTM_)
#define USE_TRANS9_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans9_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_FLOWTM_MANDATORY_BOTH \
	BLOCK trans10_FlowTM_block; \
	COLLECTION trans10_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans10_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans10_FlowTM_ST_REV; \
	MENU trans10_FlowTM_ST_REV_page; \
	COMMAND trans10_FlowTM_ST_REV_read; \
	VARIABLE trans10_FlowTM_TAG_DESC; \
	MENU trans10_FlowTM_TAG_DESC_page; \
	COMMAND trans10_FlowTM_TAG_DESC_read; \
	COMMAND trans10_FlowTM_TAG_DESC_write; \
	VARIABLE trans10_FlowTM_STRATEGY; \
	MENU trans10_FlowTM_STRATEGY_page; \
	COMMAND trans10_FlowTM_STRATEGY_read; \
	COMMAND trans10_FlowTM_STRATEGY_write; \
	VARIABLE trans10_FlowTM_ALERT_KEY; \
	MENU trans10_FlowTM_ALERT_KEY_page; \
	COMMAND trans10_FlowTM_ALERT_KEY_read; \
	COMMAND trans10_FlowTM_ALERT_KEY_write; \
	VARIABLE trans10_FlowTM_TARGET_MODE; \
	MENU trans10_FlowTM_TARGET_MODE_page; \
	COMMAND trans10_FlowTM_TARGET_MODE_read; \
	COMMAND trans10_FlowTM_TARGET_MODE_write; \
	COLLECTION trans10_FlowTM_MODE_BLK; \
	VARIABLE trans10_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans10_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans10_FlowTM_MODE_BLK_Normal; \
	MENU trans10_FlowTM_MODE_BLK_page; \
	COMMAND trans10_FlowTM_MODE_BLK_read; \
	COLLECTION trans10_FlowTM_ALARM_SUM; \
	VARIABLE trans10_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans10_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans10_FlowTM_ALARM_SUM_Disabled; \
	MENU trans10_FlowTM_ALARM_SUM_page; \
	COMMAND trans10_FlowTM_ALARM_SUM_read; \
	VARIABLE trans10_FlowTM_CALIBR_FACTOR; \
	MENU trans10_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans10_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans10_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans10_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans10_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans10_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans10_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans10_FlowTM_NOMINAL_SIZE; \
	MENU trans10_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans10_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans10_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans10_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans10_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans10_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans10_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans10_FlowTM_MASS_FLOW; \
	VARIABLE trans10_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans10_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans10_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans10_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans10_FlowTM_MASS_FLOW_page; \
	COMMAND trans10_FlowTM_MASS_FLOW_read; \
	VARIABLE trans10_FlowTM_MASS_FLOW_UNITS; \
	MENU trans10_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans10_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans10_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans10_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans10_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans10_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans10_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans10_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans10_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans10_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans10_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans10_FlowTM_unit_nominal_size; \
	UNIT trans10_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS10_FLOWTM_MANDATORY_A \
	USE_TRANS10_FLOWTM_MANDATORY_BOTH; \
	MENU trans10_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS10_FLOWTM_MANDATORY_B \
	USE_TRANS10_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans10_FlowTM_VIEW_1; \
	MENU trans10_FlowTM_VIEW_1_page; \
	MENU trans10_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS10_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans10_FlowTM_ZERO_POINT; \
	MENU trans10_FlowTM_ZERO_POINT_page; \
	COMMAND trans10_FlowTM_ZERO_POINT_read; \
	COMMAND trans10_FlowTM_ZERO_POINT_write; \
	VARIABLE trans10_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans10_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans10_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans10_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans10_FlowTM_ZERO_POINT_UNIT; \
	MENU trans10_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans10_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans10_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans10_FlowTM_VIEW_2; \
	MENU trans10_FlowTM_VIEW_2_page; \
	COLLECTION trans10_FlowTM_VIEW_3; \
	MENU trans10_FlowTM_VIEW_3_page; \
	UNIT trans10_FlowTM_unit_zero_point

#define USE_TRANS10_FLOWTM_OPTIONAL_A \
	USE_TRANS10_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans10_FlowTM_VIEW_1; \
	MENU trans10_FlowTM_VIEW_1_page; \
	MENU trans10_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS10_FLOWTM_OPTIONAL_B \
	USE_TRANS10_FLOWTM_OPTIONAL_BOTH; \
	MENU trans10_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans10_FlowTM_)
#define USE_TRANS10_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans10_FlowTM_)
#define USE_TRANS10_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans10_FlowTM_)
#define USE_TRANS10_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans10_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_FLOWTM_MANDATORY_BOTH \
	BLOCK trans11_FlowTM_block; \
	COLLECTION trans11_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans11_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans11_FlowTM_ST_REV; \
	MENU trans11_FlowTM_ST_REV_page; \
	COMMAND trans11_FlowTM_ST_REV_read; \
	VARIABLE trans11_FlowTM_TAG_DESC; \
	MENU trans11_FlowTM_TAG_DESC_page; \
	COMMAND trans11_FlowTM_TAG_DESC_read; \
	COMMAND trans11_FlowTM_TAG_DESC_write; \
	VARIABLE trans11_FlowTM_STRATEGY; \
	MENU trans11_FlowTM_STRATEGY_page; \
	COMMAND trans11_FlowTM_STRATEGY_read; \
	COMMAND trans11_FlowTM_STRATEGY_write; \
	VARIABLE trans11_FlowTM_ALERT_KEY; \
	MENU trans11_FlowTM_ALERT_KEY_page; \
	COMMAND trans11_FlowTM_ALERT_KEY_read; \
	COMMAND trans11_FlowTM_ALERT_KEY_write; \
	VARIABLE trans11_FlowTM_TARGET_MODE; \
	MENU trans11_FlowTM_TARGET_MODE_page; \
	COMMAND trans11_FlowTM_TARGET_MODE_read; \
	COMMAND trans11_FlowTM_TARGET_MODE_write; \
	COLLECTION trans11_FlowTM_MODE_BLK; \
	VARIABLE trans11_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans11_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans11_FlowTM_MODE_BLK_Normal; \
	MENU trans11_FlowTM_MODE_BLK_page; \
	COMMAND trans11_FlowTM_MODE_BLK_read; \
	COLLECTION trans11_FlowTM_ALARM_SUM; \
	VARIABLE trans11_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans11_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans11_FlowTM_ALARM_SUM_Disabled; \
	MENU trans11_FlowTM_ALARM_SUM_page; \
	COMMAND trans11_FlowTM_ALARM_SUM_read; \
	VARIABLE trans11_FlowTM_CALIBR_FACTOR; \
	MENU trans11_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans11_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans11_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans11_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans11_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans11_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans11_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans11_FlowTM_NOMINAL_SIZE; \
	MENU trans11_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans11_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans11_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans11_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans11_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans11_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans11_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans11_FlowTM_MASS_FLOW; \
	VARIABLE trans11_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans11_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans11_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans11_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans11_FlowTM_MASS_FLOW_page; \
	COMMAND trans11_FlowTM_MASS_FLOW_read; \
	VARIABLE trans11_FlowTM_MASS_FLOW_UNITS; \
	MENU trans11_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans11_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans11_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans11_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans11_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans11_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans11_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans11_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans11_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans11_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans11_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans11_FlowTM_unit_nominal_size; \
	UNIT trans11_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS11_FLOWTM_MANDATORY_A \
	USE_TRANS11_FLOWTM_MANDATORY_BOTH; \
	MENU trans11_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS11_FLOWTM_MANDATORY_B \
	USE_TRANS11_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans11_FlowTM_VIEW_1; \
	MENU trans11_FlowTM_VIEW_1_page; \
	MENU trans11_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS11_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans11_FlowTM_ZERO_POINT; \
	MENU trans11_FlowTM_ZERO_POINT_page; \
	COMMAND trans11_FlowTM_ZERO_POINT_read; \
	COMMAND trans11_FlowTM_ZERO_POINT_write; \
	VARIABLE trans11_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans11_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans11_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans11_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans11_FlowTM_ZERO_POINT_UNIT; \
	MENU trans11_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans11_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans11_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans11_FlowTM_VIEW_2; \
	MENU trans11_FlowTM_VIEW_2_page; \
	COLLECTION trans11_FlowTM_VIEW_3; \
	MENU trans11_FlowTM_VIEW_3_page; \
	UNIT trans11_FlowTM_unit_zero_point

#define USE_TRANS11_FLOWTM_OPTIONAL_A \
	USE_TRANS11_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans11_FlowTM_VIEW_1; \
	MENU trans11_FlowTM_VIEW_1_page; \
	MENU trans11_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS11_FLOWTM_OPTIONAL_B \
	USE_TRANS11_FLOWTM_OPTIONAL_BOTH; \
	MENU trans11_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans11_FlowTM_)
#define USE_TRANS11_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans11_FlowTM_)
#define USE_TRANS11_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans11_FlowTM_)
#define USE_TRANS11_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans11_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_FLOWTM_MANDATORY_BOTH \
	BLOCK trans12_FlowTM_block; \
	COLLECTION trans12_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans12_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans12_FlowTM_ST_REV; \
	MENU trans12_FlowTM_ST_REV_page; \
	COMMAND trans12_FlowTM_ST_REV_read; \
	VARIABLE trans12_FlowTM_TAG_DESC; \
	MENU trans12_FlowTM_TAG_DESC_page; \
	COMMAND trans12_FlowTM_TAG_DESC_read; \
	COMMAND trans12_FlowTM_TAG_DESC_write; \
	VARIABLE trans12_FlowTM_STRATEGY; \
	MENU trans12_FlowTM_STRATEGY_page; \
	COMMAND trans12_FlowTM_STRATEGY_read; \
	COMMAND trans12_FlowTM_STRATEGY_write; \
	VARIABLE trans12_FlowTM_ALERT_KEY; \
	MENU trans12_FlowTM_ALERT_KEY_page; \
	COMMAND trans12_FlowTM_ALERT_KEY_read; \
	COMMAND trans12_FlowTM_ALERT_KEY_write; \
	VARIABLE trans12_FlowTM_TARGET_MODE; \
	MENU trans12_FlowTM_TARGET_MODE_page; \
	COMMAND trans12_FlowTM_TARGET_MODE_read; \
	COMMAND trans12_FlowTM_TARGET_MODE_write; \
	COLLECTION trans12_FlowTM_MODE_BLK; \
	VARIABLE trans12_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans12_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans12_FlowTM_MODE_BLK_Normal; \
	MENU trans12_FlowTM_MODE_BLK_page; \
	COMMAND trans12_FlowTM_MODE_BLK_read; \
	COLLECTION trans12_FlowTM_ALARM_SUM; \
	VARIABLE trans12_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans12_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans12_FlowTM_ALARM_SUM_Disabled; \
	MENU trans12_FlowTM_ALARM_SUM_page; \
	COMMAND trans12_FlowTM_ALARM_SUM_read; \
	VARIABLE trans12_FlowTM_CALIBR_FACTOR; \
	MENU trans12_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans12_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans12_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans12_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans12_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans12_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans12_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans12_FlowTM_NOMINAL_SIZE; \
	MENU trans12_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans12_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans12_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans12_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans12_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans12_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans12_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans12_FlowTM_MASS_FLOW; \
	VARIABLE trans12_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans12_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans12_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans12_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans12_FlowTM_MASS_FLOW_page; \
	COMMAND trans12_FlowTM_MASS_FLOW_read; \
	VARIABLE trans12_FlowTM_MASS_FLOW_UNITS; \
	MENU trans12_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans12_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans12_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans12_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans12_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans12_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans12_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans12_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans12_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans12_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans12_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans12_FlowTM_unit_nominal_size; \
	UNIT trans12_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS12_FLOWTM_MANDATORY_A \
	USE_TRANS12_FLOWTM_MANDATORY_BOTH; \
	MENU trans12_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS12_FLOWTM_MANDATORY_B \
	USE_TRANS12_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans12_FlowTM_VIEW_1; \
	MENU trans12_FlowTM_VIEW_1_page; \
	MENU trans12_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS12_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans12_FlowTM_ZERO_POINT; \
	MENU trans12_FlowTM_ZERO_POINT_page; \
	COMMAND trans12_FlowTM_ZERO_POINT_read; \
	COMMAND trans12_FlowTM_ZERO_POINT_write; \
	VARIABLE trans12_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans12_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans12_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans12_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans12_FlowTM_ZERO_POINT_UNIT; \
	MENU trans12_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans12_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans12_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans12_FlowTM_VIEW_2; \
	MENU trans12_FlowTM_VIEW_2_page; \
	COLLECTION trans12_FlowTM_VIEW_3; \
	MENU trans12_FlowTM_VIEW_3_page; \
	UNIT trans12_FlowTM_unit_zero_point

#define USE_TRANS12_FLOWTM_OPTIONAL_A \
	USE_TRANS12_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans12_FlowTM_VIEW_1; \
	MENU trans12_FlowTM_VIEW_1_page; \
	MENU trans12_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS12_FLOWTM_OPTIONAL_B \
	USE_TRANS12_FLOWTM_OPTIONAL_BOTH; \
	MENU trans12_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans12_FlowTM_)
#define USE_TRANS12_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans12_FlowTM_)
#define USE_TRANS12_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans12_FlowTM_)
#define USE_TRANS12_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans12_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_FLOWTM_MANDATORY_BOTH \
	BLOCK trans13_FlowTM_block; \
	COLLECTION trans13_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans13_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans13_FlowTM_ST_REV; \
	MENU trans13_FlowTM_ST_REV_page; \
	COMMAND trans13_FlowTM_ST_REV_read; \
	VARIABLE trans13_FlowTM_TAG_DESC; \
	MENU trans13_FlowTM_TAG_DESC_page; \
	COMMAND trans13_FlowTM_TAG_DESC_read; \
	COMMAND trans13_FlowTM_TAG_DESC_write; \
	VARIABLE trans13_FlowTM_STRATEGY; \
	MENU trans13_FlowTM_STRATEGY_page; \
	COMMAND trans13_FlowTM_STRATEGY_read; \
	COMMAND trans13_FlowTM_STRATEGY_write; \
	VARIABLE trans13_FlowTM_ALERT_KEY; \
	MENU trans13_FlowTM_ALERT_KEY_page; \
	COMMAND trans13_FlowTM_ALERT_KEY_read; \
	COMMAND trans13_FlowTM_ALERT_KEY_write; \
	VARIABLE trans13_FlowTM_TARGET_MODE; \
	MENU trans13_FlowTM_TARGET_MODE_page; \
	COMMAND trans13_FlowTM_TARGET_MODE_read; \
	COMMAND trans13_FlowTM_TARGET_MODE_write; \
	COLLECTION trans13_FlowTM_MODE_BLK; \
	VARIABLE trans13_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans13_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans13_FlowTM_MODE_BLK_Normal; \
	MENU trans13_FlowTM_MODE_BLK_page; \
	COMMAND trans13_FlowTM_MODE_BLK_read; \
	COLLECTION trans13_FlowTM_ALARM_SUM; \
	VARIABLE trans13_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans13_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans13_FlowTM_ALARM_SUM_Disabled; \
	MENU trans13_FlowTM_ALARM_SUM_page; \
	COMMAND trans13_FlowTM_ALARM_SUM_read; \
	VARIABLE trans13_FlowTM_CALIBR_FACTOR; \
	MENU trans13_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans13_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans13_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans13_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans13_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans13_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans13_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans13_FlowTM_NOMINAL_SIZE; \
	MENU trans13_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans13_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans13_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans13_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans13_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans13_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans13_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans13_FlowTM_MASS_FLOW; \
	VARIABLE trans13_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans13_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans13_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans13_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans13_FlowTM_MASS_FLOW_page; \
	COMMAND trans13_FlowTM_MASS_FLOW_read; \
	VARIABLE trans13_FlowTM_MASS_FLOW_UNITS; \
	MENU trans13_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans13_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans13_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans13_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans13_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans13_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans13_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans13_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans13_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans13_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans13_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans13_FlowTM_unit_nominal_size; \
	UNIT trans13_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS13_FLOWTM_MANDATORY_A \
	USE_TRANS13_FLOWTM_MANDATORY_BOTH; \
	MENU trans13_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS13_FLOWTM_MANDATORY_B \
	USE_TRANS13_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans13_FlowTM_VIEW_1; \
	MENU trans13_FlowTM_VIEW_1_page; \
	MENU trans13_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS13_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans13_FlowTM_ZERO_POINT; \
	MENU trans13_FlowTM_ZERO_POINT_page; \
	COMMAND trans13_FlowTM_ZERO_POINT_read; \
	COMMAND trans13_FlowTM_ZERO_POINT_write; \
	VARIABLE trans13_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans13_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans13_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans13_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans13_FlowTM_ZERO_POINT_UNIT; \
	MENU trans13_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans13_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans13_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans13_FlowTM_VIEW_2; \
	MENU trans13_FlowTM_VIEW_2_page; \
	COLLECTION trans13_FlowTM_VIEW_3; \
	MENU trans13_FlowTM_VIEW_3_page; \
	UNIT trans13_FlowTM_unit_zero_point

#define USE_TRANS13_FLOWTM_OPTIONAL_A \
	USE_TRANS13_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans13_FlowTM_VIEW_1; \
	MENU trans13_FlowTM_VIEW_1_page; \
	MENU trans13_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS13_FLOWTM_OPTIONAL_B \
	USE_TRANS13_FLOWTM_OPTIONAL_BOTH; \
	MENU trans13_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans13_FlowTM_)
#define USE_TRANS13_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans13_FlowTM_)
#define USE_TRANS13_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans13_FlowTM_)
#define USE_TRANS13_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans13_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_FLOWTM_MANDATORY_BOTH \
	BLOCK trans14_FlowTM_block; \
	COLLECTION trans14_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans14_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans14_FlowTM_ST_REV; \
	MENU trans14_FlowTM_ST_REV_page; \
	COMMAND trans14_FlowTM_ST_REV_read; \
	VARIABLE trans14_FlowTM_TAG_DESC; \
	MENU trans14_FlowTM_TAG_DESC_page; \
	COMMAND trans14_FlowTM_TAG_DESC_read; \
	COMMAND trans14_FlowTM_TAG_DESC_write; \
	VARIABLE trans14_FlowTM_STRATEGY; \
	MENU trans14_FlowTM_STRATEGY_page; \
	COMMAND trans14_FlowTM_STRATEGY_read; \
	COMMAND trans14_FlowTM_STRATEGY_write; \
	VARIABLE trans14_FlowTM_ALERT_KEY; \
	MENU trans14_FlowTM_ALERT_KEY_page; \
	COMMAND trans14_FlowTM_ALERT_KEY_read; \
	COMMAND trans14_FlowTM_ALERT_KEY_write; \
	VARIABLE trans14_FlowTM_TARGET_MODE; \
	MENU trans14_FlowTM_TARGET_MODE_page; \
	COMMAND trans14_FlowTM_TARGET_MODE_read; \
	COMMAND trans14_FlowTM_TARGET_MODE_write; \
	COLLECTION trans14_FlowTM_MODE_BLK; \
	VARIABLE trans14_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans14_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans14_FlowTM_MODE_BLK_Normal; \
	MENU trans14_FlowTM_MODE_BLK_page; \
	COMMAND trans14_FlowTM_MODE_BLK_read; \
	COLLECTION trans14_FlowTM_ALARM_SUM; \
	VARIABLE trans14_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans14_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans14_FlowTM_ALARM_SUM_Disabled; \
	MENU trans14_FlowTM_ALARM_SUM_page; \
	COMMAND trans14_FlowTM_ALARM_SUM_read; \
	VARIABLE trans14_FlowTM_CALIBR_FACTOR; \
	MENU trans14_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans14_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans14_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans14_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans14_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans14_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans14_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans14_FlowTM_NOMINAL_SIZE; \
	MENU trans14_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans14_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans14_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans14_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans14_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans14_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans14_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans14_FlowTM_MASS_FLOW; \
	VARIABLE trans14_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans14_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans14_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans14_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans14_FlowTM_MASS_FLOW_page; \
	COMMAND trans14_FlowTM_MASS_FLOW_read; \
	VARIABLE trans14_FlowTM_MASS_FLOW_UNITS; \
	MENU trans14_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans14_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans14_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans14_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans14_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans14_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans14_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans14_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans14_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans14_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans14_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans14_FlowTM_unit_nominal_size; \
	UNIT trans14_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS14_FLOWTM_MANDATORY_A \
	USE_TRANS14_FLOWTM_MANDATORY_BOTH; \
	MENU trans14_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS14_FLOWTM_MANDATORY_B \
	USE_TRANS14_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans14_FlowTM_VIEW_1; \
	MENU trans14_FlowTM_VIEW_1_page; \
	MENU trans14_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS14_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans14_FlowTM_ZERO_POINT; \
	MENU trans14_FlowTM_ZERO_POINT_page; \
	COMMAND trans14_FlowTM_ZERO_POINT_read; \
	COMMAND trans14_FlowTM_ZERO_POINT_write; \
	VARIABLE trans14_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans14_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans14_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans14_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans14_FlowTM_ZERO_POINT_UNIT; \
	MENU trans14_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans14_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans14_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans14_FlowTM_VIEW_2; \
	MENU trans14_FlowTM_VIEW_2_page; \
	COLLECTION trans14_FlowTM_VIEW_3; \
	MENU trans14_FlowTM_VIEW_3_page; \
	UNIT trans14_FlowTM_unit_zero_point

#define USE_TRANS14_FLOWTM_OPTIONAL_A \
	USE_TRANS14_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans14_FlowTM_VIEW_1; \
	MENU trans14_FlowTM_VIEW_1_page; \
	MENU trans14_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS14_FLOWTM_OPTIONAL_B \
	USE_TRANS14_FLOWTM_OPTIONAL_BOTH; \
	MENU trans14_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans14_FlowTM_)
#define USE_TRANS14_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans14_FlowTM_)
#define USE_TRANS14_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans14_FlowTM_)
#define USE_TRANS14_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans14_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_FLOWTM_MANDATORY_BOTH \
	BLOCK trans15_FlowTM_block; \
	COLLECTION trans15_FlowTM_BLOCK_OBJECT; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Class; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_FlowTM_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_FlowTM_BLOCK_OBJECT_page; \
	COMMAND trans15_FlowTM_BLOCK_OBJECT_read; \
	VARIABLE trans15_FlowTM_ST_REV; \
	MENU trans15_FlowTM_ST_REV_page; \
	COMMAND trans15_FlowTM_ST_REV_read; \
	VARIABLE trans15_FlowTM_TAG_DESC; \
	MENU trans15_FlowTM_TAG_DESC_page; \
	COMMAND trans15_FlowTM_TAG_DESC_read; \
	COMMAND trans15_FlowTM_TAG_DESC_write; \
	VARIABLE trans15_FlowTM_STRATEGY; \
	MENU trans15_FlowTM_STRATEGY_page; \
	COMMAND trans15_FlowTM_STRATEGY_read; \
	COMMAND trans15_FlowTM_STRATEGY_write; \
	VARIABLE trans15_FlowTM_ALERT_KEY; \
	MENU trans15_FlowTM_ALERT_KEY_page; \
	COMMAND trans15_FlowTM_ALERT_KEY_read; \
	COMMAND trans15_FlowTM_ALERT_KEY_write; \
	VARIABLE trans15_FlowTM_TARGET_MODE; \
	MENU trans15_FlowTM_TARGET_MODE_page; \
	COMMAND trans15_FlowTM_TARGET_MODE_read; \
	COMMAND trans15_FlowTM_TARGET_MODE_write; \
	COLLECTION trans15_FlowTM_MODE_BLK; \
	VARIABLE trans15_FlowTM_MODE_BLK_Actual; \
	VARIABLE trans15_FlowTM_MODE_BLK_Permitted; \
	VARIABLE trans15_FlowTM_MODE_BLK_Normal; \
	MENU trans15_FlowTM_MODE_BLK_page; \
	COMMAND trans15_FlowTM_MODE_BLK_read; \
	COLLECTION trans15_FlowTM_ALARM_SUM; \
	VARIABLE trans15_FlowTM_ALARM_SUM_Current; \
	VARIABLE trans15_FlowTM_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_FlowTM_ALARM_SUM_Unreported; \
	VARIABLE trans15_FlowTM_ALARM_SUM_Disabled; \
	MENU trans15_FlowTM_ALARM_SUM_page; \
	COMMAND trans15_FlowTM_ALARM_SUM_read; \
	VARIABLE trans15_FlowTM_CALIBR_FACTOR; \
	MENU trans15_FlowTM_CALIBR_FACTOR_page; \
	COMMAND trans15_FlowTM_CALIBR_FACTOR_read; \
	COMMAND trans15_FlowTM_CALIBR_FACTOR_write; \
	VARIABLE trans15_FlowTM_LOW_FLOW_CUTOFF; \
	MENU trans15_FlowTM_LOW_FLOW_CUTOFF_page; \
	COMMAND trans15_FlowTM_LOW_FLOW_CUTOFF_read; \
	COMMAND trans15_FlowTM_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans15_FlowTM_NOMINAL_SIZE; \
	MENU trans15_FlowTM_NOMINAL_SIZE_page; \
	COMMAND trans15_FlowTM_NOMINAL_SIZE_read; \
	COMMAND trans15_FlowTM_NOMINAL_SIZE_write; \
	VARIABLE trans15_FlowTM_NOMINAL_SIZE_UNITS; \
	MENU trans15_FlowTM_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans15_FlowTM_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans15_FlowTM_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans15_FlowTM_MASS_FLOW; \
	VARIABLE trans15_FlowTM_MASS_FLOW_Value; \
	VARIABLE trans15_FlowTM_MASS_FLOW_Status_Condensed; \
	VARIABLE trans15_FlowTM_MASS_FLOW_Status_Quality; \
	VARIABLE trans15_FlowTM_MASS_FLOW_Status_Limit; \
	MENU trans15_FlowTM_MASS_FLOW_page; \
	COMMAND trans15_FlowTM_MASS_FLOW_read; \
	VARIABLE trans15_FlowTM_MASS_FLOW_UNITS; \
	MENU trans15_FlowTM_MASS_FLOW_UNITS_page; \
	COMMAND trans15_FlowTM_MASS_FLOW_UNITS_read; \
	COMMAND trans15_FlowTM_MASS_FLOW_UNITS_write; \
	VARIABLE trans15_FlowTM_MASS_FLOW_LO_LIMIT; \
	MENU trans15_FlowTM_MASS_FLOW_LO_LIMIT_page; \
	COMMAND trans15_FlowTM_MASS_FLOW_LO_LIMIT_read; \
	COMMAND trans15_FlowTM_MASS_FLOW_LO_LIMIT_write; \
	VARIABLE trans15_FlowTM_MASS_FLOW_HI_LIMIT; \
	MENU trans15_FlowTM_MASS_FLOW_HI_LIMIT_page; \
	COMMAND trans15_FlowTM_MASS_FLOW_HI_LIMIT_read; \
	COMMAND trans15_FlowTM_MASS_FLOW_HI_LIMIT_write; \
	UNIT trans15_FlowTM_unit_nominal_size; \
	UNIT trans15_FlowTM_unit_TB_MASS_FLOW_UNIT

#define USE_TRANS15_FLOWTM_MANDATORY_A \
	USE_TRANS15_FLOWTM_MANDATORY_BOTH; \
	MENU trans15_FlowTM_Simple_Dialog_Mandatory_A

#define USE_TRANS15_FLOWTM_MANDATORY_B \
	USE_TRANS15_FLOWTM_MANDATORY_BOTH; \
	COLLECTION trans15_FlowTM_VIEW_1; \
	MENU trans15_FlowTM_VIEW_1_page; \
	MENU trans15_FlowTM_Simple_Dialog_Mandatory_B

#define USE_TRANS15_FLOWTM_OPTIONAL_BOTH \
	VARIABLE trans15_FlowTM_ZERO_POINT; \
	MENU trans15_FlowTM_ZERO_POINT_page; \
	COMMAND trans15_FlowTM_ZERO_POINT_read; \
	COMMAND trans15_FlowTM_ZERO_POINT_write; \
	VARIABLE trans15_FlowTM_ZERO_POINT_ADJUST; \
	MENU trans15_FlowTM_ZERO_POINT_ADJUST_page; \
	COMMAND trans15_FlowTM_ZERO_POINT_ADJUST_read; \
	COMMAND trans15_FlowTM_ZERO_POINT_ADJUST_write; \
	VARIABLE trans15_FlowTM_ZERO_POINT_UNIT; \
	MENU trans15_FlowTM_ZERO_POINT_UNIT_page; \
	COMMAND trans15_FlowTM_ZERO_POINT_UNIT_read; \
	COMMAND trans15_FlowTM_ZERO_POINT_UNIT_write; \
	COLLECTION trans15_FlowTM_VIEW_2; \
	MENU trans15_FlowTM_VIEW_2_page; \
	COLLECTION trans15_FlowTM_VIEW_3; \
	MENU trans15_FlowTM_VIEW_3_page; \
	UNIT trans15_FlowTM_unit_zero_point

#define USE_TRANS15_FLOWTM_OPTIONAL_A \
	USE_TRANS15_FLOWTM_OPTIONAL_BOTH; \
	COLLECTION trans15_FlowTM_VIEW_1; \
	MENU trans15_FlowTM_VIEW_1_page; \
	MENU trans15_FlowTM_Simple_Dialog_Optional_A

#define USE_TRANS15_FLOWTM_OPTIONAL_B \
	USE_TRANS15_FLOWTM_OPTIONAL_BOTH; \
	MENU trans15_FlowTM_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_FLOWTM_MANDATORY_A USE_TRANS_FLOWTM_MANDATORY_A(trans15_FlowTM_)
#define USE_TRANS15_FLOWTM_MANDATORY_B USE_TRANS_FLOWTM_MANDATORY_B(trans15_FlowTM_)
#define USE_TRANS15_FLOWTM_OPTIONAL_A  USE_TRANS_FLOWTM_OPTIONAL_A(trans15_FlowTM_)
#define USE_TRANS15_FLOWTM_OPTIONAL_B  USE_TRANS_FLOWTM_OPTIONAL_B(trans15_FlowTM_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_FLOWU_MANDATORY_BOTH \
	BLOCK trans1_FlowU_block; \
	COLLECTION trans1_FlowU_BLOCK_OBJECT; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans1_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans1_FlowU_ST_REV; \
	MENU trans1_FlowU_ST_REV_page; \
	COMMAND trans1_FlowU_ST_REV_read; \
	VARIABLE trans1_FlowU_TAG_DESC; \
	MENU trans1_FlowU_TAG_DESC_page; \
	COMMAND trans1_FlowU_TAG_DESC_read; \
	COMMAND trans1_FlowU_TAG_DESC_write; \
	VARIABLE trans1_FlowU_STRATEGY; \
	MENU trans1_FlowU_STRATEGY_page; \
	COMMAND trans1_FlowU_STRATEGY_read; \
	COMMAND trans1_FlowU_STRATEGY_write; \
	VARIABLE trans1_FlowU_ALERT_KEY; \
	MENU trans1_FlowU_ALERT_KEY_page; \
	COMMAND trans1_FlowU_ALERT_KEY_read; \
	COMMAND trans1_FlowU_ALERT_KEY_write; \
	VARIABLE trans1_FlowU_TARGET_MODE; \
	MENU trans1_FlowU_TARGET_MODE_page; \
	COMMAND trans1_FlowU_TARGET_MODE_read; \
	COMMAND trans1_FlowU_TARGET_MODE_write; \
	COLLECTION trans1_FlowU_MODE_BLK; \
	VARIABLE trans1_FlowU_MODE_BLK_Actual; \
	VARIABLE trans1_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans1_FlowU_MODE_BLK_Normal; \
	MENU trans1_FlowU_MODE_BLK_page; \
	COMMAND trans1_FlowU_MODE_BLK_read; \
	COLLECTION trans1_FlowU_ALARM_SUM; \
	VARIABLE trans1_FlowU_ALARM_SUM_Current; \
	VARIABLE trans1_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans1_FlowU_ALARM_SUM_Disabled; \
	MENU trans1_FlowU_ALARM_SUM_page; \
	COMMAND trans1_FlowU_ALARM_SUM_read; \
	VARIABLE trans1_FlowU_CALIBR_FACTOR; \
	MENU trans1_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans1_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans1_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans1_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans1_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans1_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans1_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans1_FlowU_MEASUREMENT_MODE; \
	MENU trans1_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans1_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans1_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans1_FlowU_FLOW_DIRECTION; \
	MENU trans1_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans1_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans1_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans1_FlowU_NOMINAL_SIZE; \
	MENU trans1_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans1_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans1_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans1_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans1_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans1_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans1_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans1_FlowU_VOLUME_FLOW; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans1_FlowU_VOLUME_FLOW_page; \
	COMMAND trans1_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans1_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans1_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans1_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans1_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans1_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans1_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans1_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans1_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans1_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans1_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans1_FlowU_SOUND_VELOCITY; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans1_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans1_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans1_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans1_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans1_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans1_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans1_FlowU_unit_nominal_size; \
	UNIT trans1_FlowU_unit_volume_flow; \
	UNIT trans1_FlowU_unit_sound_velocity

#define USE_TRANS1_FLOWU_MANDATORY_A \
	USE_TRANS1_FLOWU_MANDATORY_BOTH; \
	MENU trans1_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS1_FLOWU_MANDATORY_B \
	USE_TRANS1_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans1_FlowU_VIEW_1; \
	MENU trans1_FlowU_VIEW_1_page; \
	MENU trans1_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS1_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans1_FlowU_ZERO_POINT; \
	MENU trans1_FlowU_ZERO_POINT_page; \
	COMMAND trans1_FlowU_ZERO_POINT_read; \
	COMMAND trans1_FlowU_ZERO_POINT_write; \
	VARIABLE trans1_FlowU_ZERO_POINT_ADJUST; \
	MENU trans1_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans1_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans1_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans1_FlowU_ZERO_POINT_UNIT; \
	MENU trans1_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans1_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans1_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans1_FlowU_VIEW_2; \
	MENU trans1_FlowU_VIEW_2_page; \
	COLLECTION trans1_FlowU_VIEW_3; \
	MENU trans1_FlowU_VIEW_3_page; \
	UNIT trans1_FlowU_unit_zero_point

#define USE_TRANS1_FLOWU_OPTIONAL_A \
	USE_TRANS1_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans1_FlowU_VIEW_1; \
	MENU trans1_FlowU_VIEW_1_page; \
	MENU trans1_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS1_FLOWU_OPTIONAL_B \
	USE_TRANS1_FLOWU_OPTIONAL_BOTH; \
	MENU trans1_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_FLOWU_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CALIBR_FACTOR; \
	MENU prefix ## CALIBR_FACTOR_page; \
	COMMAND prefix ## CALIBR_FACTOR_read; \
	COMMAND prefix ## CALIBR_FACTOR_write; \
	VARIABLE prefix ## LOW_FLOW_CUTOFF; \
	MENU prefix ## LOW_FLOW_CUTOFF_page; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_read; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_write; \
	VARIABLE prefix ## MEASUREMENT_MODE; \
	MENU prefix ## MEASUREMENT_MODE_page; \
	COMMAND prefix ## MEASUREMENT_MODE_read; \
	COMMAND prefix ## MEASUREMENT_MODE_write; \
	VARIABLE prefix ## FLOW_DIRECTION; \
	MENU prefix ## FLOW_DIRECTION_page; \
	COMMAND prefix ## FLOW_DIRECTION_read; \
	COMMAND prefix ## FLOW_DIRECTION_write; \
	VARIABLE prefix ## NOMINAL_SIZE; \
	MENU prefix ## NOMINAL_SIZE_page; \
	COMMAND prefix ## NOMINAL_SIZE_read; \
	COMMAND prefix ## NOMINAL_SIZE_write; \
	VARIABLE prefix ## NOMINAL_SIZE_UNITS; \
	MENU prefix ## NOMINAL_SIZE_UNITS_page; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_read; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_write; \
	COLLECTION prefix ## VOLUME_FLOW; \
	VARIABLE prefix ## VOLUME_FLOW_Value; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Condensed; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Quality; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Limit; \
	MENU prefix ## VOLUME_FLOW_page; \
	COMMAND prefix ## VOLUME_FLOW_read; \
	VARIABLE prefix ## VOLUME_FLOW_UNITS; \
	MENU prefix ## VOLUME_FLOW_UNITS_page; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_read; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_write; \
	VARIABLE prefix ## VOLUME_FLOW_LO_LIMIT; \
	MENU prefix ## VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE prefix ## VOLUME_FLOW_HI_LIMIT; \
	MENU prefix ## VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION prefix ## SOUND_VELOCITY; \
	VARIABLE prefix ## SOUND_VELOCITY_Value; \
	VARIABLE prefix ## SOUND_VELOCITY_Status_Condensed; \
	VARIABLE prefix ## SOUND_VELOCITY_Status_Quality; \
	VARIABLE prefix ## SOUND_VELOCITY_Status_Limit; \
	MENU prefix ## SOUND_VELOCITY_page; \
	COMMAND prefix ## SOUND_VELOCITY_read; \
	VARIABLE prefix ## SOUND_VELOCITY_UNITS; \
	MENU prefix ## SOUND_VELOCITY_UNITS_page; \
	COMMAND prefix ## SOUND_VELOCITY_UNITS_read; \
	COMMAND prefix ## SOUND_VELOCITY_UNITS_write; \
	VARIABLE prefix ## SOUND_VELOCITY_LO_LIMIT; \
	MENU prefix ## SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND prefix ## SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND prefix ## SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE prefix ## SOUND_VELOCITY_HI_LIMIT; \
	MENU prefix ## SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND prefix ## SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND prefix ## SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT prefix ## unit_nominal_size; \
	UNIT prefix ## unit_volume_flow; \
	UNIT prefix ## unit_sound_velocity

#define USE_TRANS_FLOWU_MANDATORY_A(prefix) \
	USE_TRANS_FLOWU_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_FLOWU_MANDATORY_B(prefix) \
	USE_TRANS_FLOWU_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_FLOWU_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ZERO_POINT; \
	MENU prefix ## ZERO_POINT_page; \
	COMMAND prefix ## ZERO_POINT_read; \
	COMMAND prefix ## ZERO_POINT_write; \
	VARIABLE prefix ## ZERO_POINT_ADJUST; \
	MENU prefix ## ZERO_POINT_ADJUST_page; \
	COMMAND prefix ## ZERO_POINT_ADJUST_read; \
	COMMAND prefix ## ZERO_POINT_ADJUST_write; \
	VARIABLE prefix ## ZERO_POINT_UNIT; \
	MENU prefix ## ZERO_POINT_UNIT_page; \
	COMMAND prefix ## ZERO_POINT_UNIT_read; \
	COMMAND prefix ## ZERO_POINT_UNIT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## unit_zero_point

#define USE_TRANS_FLOWU_OPTIONAL_A(prefix) \
	USE_TRANS_FLOWU_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_FLOWU_OPTIONAL_B(prefix) \
	USE_TRANS_FLOWU_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans1_FlowU_)
#define USE_TRANS1_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans1_FlowU_)
#define USE_TRANS1_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans1_FlowU_)
#define USE_TRANS1_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans1_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_FLOWU_MANDATORY_BOTH \
	BLOCK trans2_FlowU_block; \
	COLLECTION trans2_FlowU_BLOCK_OBJECT; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans2_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans2_FlowU_ST_REV; \
	MENU trans2_FlowU_ST_REV_page; \
	COMMAND trans2_FlowU_ST_REV_read; \
	VARIABLE trans2_FlowU_TAG_DESC; \
	MENU trans2_FlowU_TAG_DESC_page; \
	COMMAND trans2_FlowU_TAG_DESC_read; \
	COMMAND trans2_FlowU_TAG_DESC_write; \
	VARIABLE trans2_FlowU_STRATEGY; \
	MENU trans2_FlowU_STRATEGY_page; \
	COMMAND trans2_FlowU_STRATEGY_read; \
	COMMAND trans2_FlowU_STRATEGY_write; \
	VARIABLE trans2_FlowU_ALERT_KEY; \
	MENU trans2_FlowU_ALERT_KEY_page; \
	COMMAND trans2_FlowU_ALERT_KEY_read; \
	COMMAND trans2_FlowU_ALERT_KEY_write; \
	VARIABLE trans2_FlowU_TARGET_MODE; \
	MENU trans2_FlowU_TARGET_MODE_page; \
	COMMAND trans2_FlowU_TARGET_MODE_read; \
	COMMAND trans2_FlowU_TARGET_MODE_write; \
	COLLECTION trans2_FlowU_MODE_BLK; \
	VARIABLE trans2_FlowU_MODE_BLK_Actual; \
	VARIABLE trans2_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans2_FlowU_MODE_BLK_Normal; \
	MENU trans2_FlowU_MODE_BLK_page; \
	COMMAND trans2_FlowU_MODE_BLK_read; \
	COLLECTION trans2_FlowU_ALARM_SUM; \
	VARIABLE trans2_FlowU_ALARM_SUM_Current; \
	VARIABLE trans2_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans2_FlowU_ALARM_SUM_Disabled; \
	MENU trans2_FlowU_ALARM_SUM_page; \
	COMMAND trans2_FlowU_ALARM_SUM_read; \
	VARIABLE trans2_FlowU_CALIBR_FACTOR; \
	MENU trans2_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans2_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans2_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans2_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans2_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans2_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans2_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans2_FlowU_MEASUREMENT_MODE; \
	MENU trans2_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans2_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans2_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans2_FlowU_FLOW_DIRECTION; \
	MENU trans2_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans2_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans2_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans2_FlowU_NOMINAL_SIZE; \
	MENU trans2_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans2_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans2_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans2_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans2_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans2_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans2_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans2_FlowU_VOLUME_FLOW; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans2_FlowU_VOLUME_FLOW_page; \
	COMMAND trans2_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans2_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans2_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans2_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans2_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans2_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans2_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans2_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans2_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans2_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans2_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans2_FlowU_SOUND_VELOCITY; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans2_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans2_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans2_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans2_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans2_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans2_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans2_FlowU_unit_nominal_size; \
	UNIT trans2_FlowU_unit_volume_flow; \
	UNIT trans2_FlowU_unit_sound_velocity

#define USE_TRANS2_FLOWU_MANDATORY_A \
	USE_TRANS2_FLOWU_MANDATORY_BOTH; \
	MENU trans2_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS2_FLOWU_MANDATORY_B \
	USE_TRANS2_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans2_FlowU_VIEW_1; \
	MENU trans2_FlowU_VIEW_1_page; \
	MENU trans2_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS2_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans2_FlowU_ZERO_POINT; \
	MENU trans2_FlowU_ZERO_POINT_page; \
	COMMAND trans2_FlowU_ZERO_POINT_read; \
	COMMAND trans2_FlowU_ZERO_POINT_write; \
	VARIABLE trans2_FlowU_ZERO_POINT_ADJUST; \
	MENU trans2_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans2_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans2_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans2_FlowU_ZERO_POINT_UNIT; \
	MENU trans2_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans2_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans2_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans2_FlowU_VIEW_2; \
	MENU trans2_FlowU_VIEW_2_page; \
	COLLECTION trans2_FlowU_VIEW_3; \
	MENU trans2_FlowU_VIEW_3_page; \
	UNIT trans2_FlowU_unit_zero_point

#define USE_TRANS2_FLOWU_OPTIONAL_A \
	USE_TRANS2_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans2_FlowU_VIEW_1; \
	MENU trans2_FlowU_VIEW_1_page; \
	MENU trans2_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS2_FLOWU_OPTIONAL_B \
	USE_TRANS2_FLOWU_OPTIONAL_BOTH; \
	MENU trans2_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans2_FlowU_)
#define USE_TRANS2_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans2_FlowU_)
#define USE_TRANS2_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans2_FlowU_)
#define USE_TRANS2_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans2_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_FLOWU_MANDATORY_BOTH \
	BLOCK trans3_FlowU_block; \
	COLLECTION trans3_FlowU_BLOCK_OBJECT; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans3_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans3_FlowU_ST_REV; \
	MENU trans3_FlowU_ST_REV_page; \
	COMMAND trans3_FlowU_ST_REV_read; \
	VARIABLE trans3_FlowU_TAG_DESC; \
	MENU trans3_FlowU_TAG_DESC_page; \
	COMMAND trans3_FlowU_TAG_DESC_read; \
	COMMAND trans3_FlowU_TAG_DESC_write; \
	VARIABLE trans3_FlowU_STRATEGY; \
	MENU trans3_FlowU_STRATEGY_page; \
	COMMAND trans3_FlowU_STRATEGY_read; \
	COMMAND trans3_FlowU_STRATEGY_write; \
	VARIABLE trans3_FlowU_ALERT_KEY; \
	MENU trans3_FlowU_ALERT_KEY_page; \
	COMMAND trans3_FlowU_ALERT_KEY_read; \
	COMMAND trans3_FlowU_ALERT_KEY_write; \
	VARIABLE trans3_FlowU_TARGET_MODE; \
	MENU trans3_FlowU_TARGET_MODE_page; \
	COMMAND trans3_FlowU_TARGET_MODE_read; \
	COMMAND trans3_FlowU_TARGET_MODE_write; \
	COLLECTION trans3_FlowU_MODE_BLK; \
	VARIABLE trans3_FlowU_MODE_BLK_Actual; \
	VARIABLE trans3_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans3_FlowU_MODE_BLK_Normal; \
	MENU trans3_FlowU_MODE_BLK_page; \
	COMMAND trans3_FlowU_MODE_BLK_read; \
	COLLECTION trans3_FlowU_ALARM_SUM; \
	VARIABLE trans3_FlowU_ALARM_SUM_Current; \
	VARIABLE trans3_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans3_FlowU_ALARM_SUM_Disabled; \
	MENU trans3_FlowU_ALARM_SUM_page; \
	COMMAND trans3_FlowU_ALARM_SUM_read; \
	VARIABLE trans3_FlowU_CALIBR_FACTOR; \
	MENU trans3_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans3_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans3_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans3_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans3_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans3_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans3_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans3_FlowU_MEASUREMENT_MODE; \
	MENU trans3_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans3_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans3_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans3_FlowU_FLOW_DIRECTION; \
	MENU trans3_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans3_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans3_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans3_FlowU_NOMINAL_SIZE; \
	MENU trans3_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans3_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans3_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans3_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans3_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans3_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans3_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans3_FlowU_VOLUME_FLOW; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans3_FlowU_VOLUME_FLOW_page; \
	COMMAND trans3_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans3_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans3_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans3_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans3_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans3_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans3_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans3_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans3_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans3_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans3_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans3_FlowU_SOUND_VELOCITY; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans3_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans3_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans3_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans3_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans3_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans3_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans3_FlowU_unit_nominal_size; \
	UNIT trans3_FlowU_unit_volume_flow; \
	UNIT trans3_FlowU_unit_sound_velocity

#define USE_TRANS3_FLOWU_MANDATORY_A \
	USE_TRANS3_FLOWU_MANDATORY_BOTH; \
	MENU trans3_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS3_FLOWU_MANDATORY_B \
	USE_TRANS3_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans3_FlowU_VIEW_1; \
	MENU trans3_FlowU_VIEW_1_page; \
	MENU trans3_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS3_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans3_FlowU_ZERO_POINT; \
	MENU trans3_FlowU_ZERO_POINT_page; \
	COMMAND trans3_FlowU_ZERO_POINT_read; \
	COMMAND trans3_FlowU_ZERO_POINT_write; \
	VARIABLE trans3_FlowU_ZERO_POINT_ADJUST; \
	MENU trans3_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans3_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans3_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans3_FlowU_ZERO_POINT_UNIT; \
	MENU trans3_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans3_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans3_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans3_FlowU_VIEW_2; \
	MENU trans3_FlowU_VIEW_2_page; \
	COLLECTION trans3_FlowU_VIEW_3; \
	MENU trans3_FlowU_VIEW_3_page; \
	UNIT trans3_FlowU_unit_zero_point

#define USE_TRANS3_FLOWU_OPTIONAL_A \
	USE_TRANS3_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans3_FlowU_VIEW_1; \
	MENU trans3_FlowU_VIEW_1_page; \
	MENU trans3_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS3_FLOWU_OPTIONAL_B \
	USE_TRANS3_FLOWU_OPTIONAL_BOTH; \
	MENU trans3_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans3_FlowU_)
#define USE_TRANS3_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans3_FlowU_)
#define USE_TRANS3_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans3_FlowU_)
#define USE_TRANS3_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans3_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_FLOWU_MANDATORY_BOTH \
	BLOCK trans4_FlowU_block; \
	COLLECTION trans4_FlowU_BLOCK_OBJECT; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans4_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans4_FlowU_ST_REV; \
	MENU trans4_FlowU_ST_REV_page; \
	COMMAND trans4_FlowU_ST_REV_read; \
	VARIABLE trans4_FlowU_TAG_DESC; \
	MENU trans4_FlowU_TAG_DESC_page; \
	COMMAND trans4_FlowU_TAG_DESC_read; \
	COMMAND trans4_FlowU_TAG_DESC_write; \
	VARIABLE trans4_FlowU_STRATEGY; \
	MENU trans4_FlowU_STRATEGY_page; \
	COMMAND trans4_FlowU_STRATEGY_read; \
	COMMAND trans4_FlowU_STRATEGY_write; \
	VARIABLE trans4_FlowU_ALERT_KEY; \
	MENU trans4_FlowU_ALERT_KEY_page; \
	COMMAND trans4_FlowU_ALERT_KEY_read; \
	COMMAND trans4_FlowU_ALERT_KEY_write; \
	VARIABLE trans4_FlowU_TARGET_MODE; \
	MENU trans4_FlowU_TARGET_MODE_page; \
	COMMAND trans4_FlowU_TARGET_MODE_read; \
	COMMAND trans4_FlowU_TARGET_MODE_write; \
	COLLECTION trans4_FlowU_MODE_BLK; \
	VARIABLE trans4_FlowU_MODE_BLK_Actual; \
	VARIABLE trans4_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans4_FlowU_MODE_BLK_Normal; \
	MENU trans4_FlowU_MODE_BLK_page; \
	COMMAND trans4_FlowU_MODE_BLK_read; \
	COLLECTION trans4_FlowU_ALARM_SUM; \
	VARIABLE trans4_FlowU_ALARM_SUM_Current; \
	VARIABLE trans4_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans4_FlowU_ALARM_SUM_Disabled; \
	MENU trans4_FlowU_ALARM_SUM_page; \
	COMMAND trans4_FlowU_ALARM_SUM_read; \
	VARIABLE trans4_FlowU_CALIBR_FACTOR; \
	MENU trans4_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans4_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans4_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans4_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans4_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans4_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans4_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans4_FlowU_MEASUREMENT_MODE; \
	MENU trans4_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans4_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans4_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans4_FlowU_FLOW_DIRECTION; \
	MENU trans4_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans4_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans4_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans4_FlowU_NOMINAL_SIZE; \
	MENU trans4_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans4_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans4_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans4_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans4_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans4_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans4_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans4_FlowU_VOLUME_FLOW; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans4_FlowU_VOLUME_FLOW_page; \
	COMMAND trans4_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans4_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans4_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans4_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans4_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans4_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans4_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans4_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans4_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans4_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans4_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans4_FlowU_SOUND_VELOCITY; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans4_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans4_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans4_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans4_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans4_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans4_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans4_FlowU_unit_nominal_size; \
	UNIT trans4_FlowU_unit_volume_flow; \
	UNIT trans4_FlowU_unit_sound_velocity

#define USE_TRANS4_FLOWU_MANDATORY_A \
	USE_TRANS4_FLOWU_MANDATORY_BOTH; \
	MENU trans4_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS4_FLOWU_MANDATORY_B \
	USE_TRANS4_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans4_FlowU_VIEW_1; \
	MENU trans4_FlowU_VIEW_1_page; \
	MENU trans4_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS4_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans4_FlowU_ZERO_POINT; \
	MENU trans4_FlowU_ZERO_POINT_page; \
	COMMAND trans4_FlowU_ZERO_POINT_read; \
	COMMAND trans4_FlowU_ZERO_POINT_write; \
	VARIABLE trans4_FlowU_ZERO_POINT_ADJUST; \
	MENU trans4_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans4_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans4_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans4_FlowU_ZERO_POINT_UNIT; \
	MENU trans4_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans4_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans4_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans4_FlowU_VIEW_2; \
	MENU trans4_FlowU_VIEW_2_page; \
	COLLECTION trans4_FlowU_VIEW_3; \
	MENU trans4_FlowU_VIEW_3_page; \
	UNIT trans4_FlowU_unit_zero_point

#define USE_TRANS4_FLOWU_OPTIONAL_A \
	USE_TRANS4_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans4_FlowU_VIEW_1; \
	MENU trans4_FlowU_VIEW_1_page; \
	MENU trans4_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS4_FLOWU_OPTIONAL_B \
	USE_TRANS4_FLOWU_OPTIONAL_BOTH; \
	MENU trans4_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans4_FlowU_)
#define USE_TRANS4_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans4_FlowU_)
#define USE_TRANS4_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans4_FlowU_)
#define USE_TRANS4_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans4_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_FLOWU_MANDATORY_BOTH \
	BLOCK trans5_FlowU_block; \
	COLLECTION trans5_FlowU_BLOCK_OBJECT; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans5_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans5_FlowU_ST_REV; \
	MENU trans5_FlowU_ST_REV_page; \
	COMMAND trans5_FlowU_ST_REV_read; \
	VARIABLE trans5_FlowU_TAG_DESC; \
	MENU trans5_FlowU_TAG_DESC_page; \
	COMMAND trans5_FlowU_TAG_DESC_read; \
	COMMAND trans5_FlowU_TAG_DESC_write; \
	VARIABLE trans5_FlowU_STRATEGY; \
	MENU trans5_FlowU_STRATEGY_page; \
	COMMAND trans5_FlowU_STRATEGY_read; \
	COMMAND trans5_FlowU_STRATEGY_write; \
	VARIABLE trans5_FlowU_ALERT_KEY; \
	MENU trans5_FlowU_ALERT_KEY_page; \
	COMMAND trans5_FlowU_ALERT_KEY_read; \
	COMMAND trans5_FlowU_ALERT_KEY_write; \
	VARIABLE trans5_FlowU_TARGET_MODE; \
	MENU trans5_FlowU_TARGET_MODE_page; \
	COMMAND trans5_FlowU_TARGET_MODE_read; \
	COMMAND trans5_FlowU_TARGET_MODE_write; \
	COLLECTION trans5_FlowU_MODE_BLK; \
	VARIABLE trans5_FlowU_MODE_BLK_Actual; \
	VARIABLE trans5_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans5_FlowU_MODE_BLK_Normal; \
	MENU trans5_FlowU_MODE_BLK_page; \
	COMMAND trans5_FlowU_MODE_BLK_read; \
	COLLECTION trans5_FlowU_ALARM_SUM; \
	VARIABLE trans5_FlowU_ALARM_SUM_Current; \
	VARIABLE trans5_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans5_FlowU_ALARM_SUM_Disabled; \
	MENU trans5_FlowU_ALARM_SUM_page; \
	COMMAND trans5_FlowU_ALARM_SUM_read; \
	VARIABLE trans5_FlowU_CALIBR_FACTOR; \
	MENU trans5_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans5_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans5_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans5_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans5_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans5_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans5_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans5_FlowU_MEASUREMENT_MODE; \
	MENU trans5_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans5_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans5_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans5_FlowU_FLOW_DIRECTION; \
	MENU trans5_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans5_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans5_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans5_FlowU_NOMINAL_SIZE; \
	MENU trans5_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans5_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans5_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans5_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans5_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans5_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans5_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans5_FlowU_VOLUME_FLOW; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans5_FlowU_VOLUME_FLOW_page; \
	COMMAND trans5_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans5_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans5_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans5_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans5_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans5_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans5_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans5_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans5_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans5_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans5_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans5_FlowU_SOUND_VELOCITY; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans5_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans5_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans5_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans5_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans5_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans5_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans5_FlowU_unit_nominal_size; \
	UNIT trans5_FlowU_unit_volume_flow; \
	UNIT trans5_FlowU_unit_sound_velocity

#define USE_TRANS5_FLOWU_MANDATORY_A \
	USE_TRANS5_FLOWU_MANDATORY_BOTH; \
	MENU trans5_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS5_FLOWU_MANDATORY_B \
	USE_TRANS5_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans5_FlowU_VIEW_1; \
	MENU trans5_FlowU_VIEW_1_page; \
	MENU trans5_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS5_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans5_FlowU_ZERO_POINT; \
	MENU trans5_FlowU_ZERO_POINT_page; \
	COMMAND trans5_FlowU_ZERO_POINT_read; \
	COMMAND trans5_FlowU_ZERO_POINT_write; \
	VARIABLE trans5_FlowU_ZERO_POINT_ADJUST; \
	MENU trans5_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans5_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans5_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans5_FlowU_ZERO_POINT_UNIT; \
	MENU trans5_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans5_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans5_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans5_FlowU_VIEW_2; \
	MENU trans5_FlowU_VIEW_2_page; \
	COLLECTION trans5_FlowU_VIEW_3; \
	MENU trans5_FlowU_VIEW_3_page; \
	UNIT trans5_FlowU_unit_zero_point

#define USE_TRANS5_FLOWU_OPTIONAL_A \
	USE_TRANS5_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans5_FlowU_VIEW_1; \
	MENU trans5_FlowU_VIEW_1_page; \
	MENU trans5_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS5_FLOWU_OPTIONAL_B \
	USE_TRANS5_FLOWU_OPTIONAL_BOTH; \
	MENU trans5_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans5_FlowU_)
#define USE_TRANS5_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans5_FlowU_)
#define USE_TRANS5_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans5_FlowU_)
#define USE_TRANS5_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans5_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_FLOWU_MANDATORY_BOTH \
	BLOCK trans6_FlowU_block; \
	COLLECTION trans6_FlowU_BLOCK_OBJECT; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans6_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans6_FlowU_ST_REV; \
	MENU trans6_FlowU_ST_REV_page; \
	COMMAND trans6_FlowU_ST_REV_read; \
	VARIABLE trans6_FlowU_TAG_DESC; \
	MENU trans6_FlowU_TAG_DESC_page; \
	COMMAND trans6_FlowU_TAG_DESC_read; \
	COMMAND trans6_FlowU_TAG_DESC_write; \
	VARIABLE trans6_FlowU_STRATEGY; \
	MENU trans6_FlowU_STRATEGY_page; \
	COMMAND trans6_FlowU_STRATEGY_read; \
	COMMAND trans6_FlowU_STRATEGY_write; \
	VARIABLE trans6_FlowU_ALERT_KEY; \
	MENU trans6_FlowU_ALERT_KEY_page; \
	COMMAND trans6_FlowU_ALERT_KEY_read; \
	COMMAND trans6_FlowU_ALERT_KEY_write; \
	VARIABLE trans6_FlowU_TARGET_MODE; \
	MENU trans6_FlowU_TARGET_MODE_page; \
	COMMAND trans6_FlowU_TARGET_MODE_read; \
	COMMAND trans6_FlowU_TARGET_MODE_write; \
	COLLECTION trans6_FlowU_MODE_BLK; \
	VARIABLE trans6_FlowU_MODE_BLK_Actual; \
	VARIABLE trans6_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans6_FlowU_MODE_BLK_Normal; \
	MENU trans6_FlowU_MODE_BLK_page; \
	COMMAND trans6_FlowU_MODE_BLK_read; \
	COLLECTION trans6_FlowU_ALARM_SUM; \
	VARIABLE trans6_FlowU_ALARM_SUM_Current; \
	VARIABLE trans6_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans6_FlowU_ALARM_SUM_Disabled; \
	MENU trans6_FlowU_ALARM_SUM_page; \
	COMMAND trans6_FlowU_ALARM_SUM_read; \
	VARIABLE trans6_FlowU_CALIBR_FACTOR; \
	MENU trans6_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans6_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans6_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans6_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans6_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans6_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans6_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans6_FlowU_MEASUREMENT_MODE; \
	MENU trans6_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans6_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans6_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans6_FlowU_FLOW_DIRECTION; \
	MENU trans6_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans6_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans6_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans6_FlowU_NOMINAL_SIZE; \
	MENU trans6_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans6_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans6_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans6_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans6_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans6_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans6_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans6_FlowU_VOLUME_FLOW; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans6_FlowU_VOLUME_FLOW_page; \
	COMMAND trans6_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans6_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans6_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans6_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans6_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans6_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans6_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans6_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans6_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans6_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans6_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans6_FlowU_SOUND_VELOCITY; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans6_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans6_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans6_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans6_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans6_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans6_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans6_FlowU_unit_nominal_size; \
	UNIT trans6_FlowU_unit_volume_flow; \
	UNIT trans6_FlowU_unit_sound_velocity

#define USE_TRANS6_FLOWU_MANDATORY_A \
	USE_TRANS6_FLOWU_MANDATORY_BOTH; \
	MENU trans6_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS6_FLOWU_MANDATORY_B \
	USE_TRANS6_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans6_FlowU_VIEW_1; \
	MENU trans6_FlowU_VIEW_1_page; \
	MENU trans6_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS6_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans6_FlowU_ZERO_POINT; \
	MENU trans6_FlowU_ZERO_POINT_page; \
	COMMAND trans6_FlowU_ZERO_POINT_read; \
	COMMAND trans6_FlowU_ZERO_POINT_write; \
	VARIABLE trans6_FlowU_ZERO_POINT_ADJUST; \
	MENU trans6_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans6_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans6_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans6_FlowU_ZERO_POINT_UNIT; \
	MENU trans6_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans6_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans6_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans6_FlowU_VIEW_2; \
	MENU trans6_FlowU_VIEW_2_page; \
	COLLECTION trans6_FlowU_VIEW_3; \
	MENU trans6_FlowU_VIEW_3_page; \
	UNIT trans6_FlowU_unit_zero_point

#define USE_TRANS6_FLOWU_OPTIONAL_A \
	USE_TRANS6_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans6_FlowU_VIEW_1; \
	MENU trans6_FlowU_VIEW_1_page; \
	MENU trans6_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS6_FLOWU_OPTIONAL_B \
	USE_TRANS6_FLOWU_OPTIONAL_BOTH; \
	MENU trans6_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans6_FlowU_)
#define USE_TRANS6_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans6_FlowU_)
#define USE_TRANS6_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans6_FlowU_)
#define USE_TRANS6_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans6_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_FLOWU_MANDATORY_BOTH \
	BLOCK trans7_FlowU_block; \
	COLLECTION trans7_FlowU_BLOCK_OBJECT; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans7_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans7_FlowU_ST_REV; \
	MENU trans7_FlowU_ST_REV_page; \
	COMMAND trans7_FlowU_ST_REV_read; \
	VARIABLE trans7_FlowU_TAG_DESC; \
	MENU trans7_FlowU_TAG_DESC_page; \
	COMMAND trans7_FlowU_TAG_DESC_read; \
	COMMAND trans7_FlowU_TAG_DESC_write; \
	VARIABLE trans7_FlowU_STRATEGY; \
	MENU trans7_FlowU_STRATEGY_page; \
	COMMAND trans7_FlowU_STRATEGY_read; \
	COMMAND trans7_FlowU_STRATEGY_write; \
	VARIABLE trans7_FlowU_ALERT_KEY; \
	MENU trans7_FlowU_ALERT_KEY_page; \
	COMMAND trans7_FlowU_ALERT_KEY_read; \
	COMMAND trans7_FlowU_ALERT_KEY_write; \
	VARIABLE trans7_FlowU_TARGET_MODE; \
	MENU trans7_FlowU_TARGET_MODE_page; \
	COMMAND trans7_FlowU_TARGET_MODE_read; \
	COMMAND trans7_FlowU_TARGET_MODE_write; \
	COLLECTION trans7_FlowU_MODE_BLK; \
	VARIABLE trans7_FlowU_MODE_BLK_Actual; \
	VARIABLE trans7_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans7_FlowU_MODE_BLK_Normal; \
	MENU trans7_FlowU_MODE_BLK_page; \
	COMMAND trans7_FlowU_MODE_BLK_read; \
	COLLECTION trans7_FlowU_ALARM_SUM; \
	VARIABLE trans7_FlowU_ALARM_SUM_Current; \
	VARIABLE trans7_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans7_FlowU_ALARM_SUM_Disabled; \
	MENU trans7_FlowU_ALARM_SUM_page; \
	COMMAND trans7_FlowU_ALARM_SUM_read; \
	VARIABLE trans7_FlowU_CALIBR_FACTOR; \
	MENU trans7_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans7_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans7_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans7_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans7_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans7_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans7_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans7_FlowU_MEASUREMENT_MODE; \
	MENU trans7_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans7_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans7_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans7_FlowU_FLOW_DIRECTION; \
	MENU trans7_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans7_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans7_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans7_FlowU_NOMINAL_SIZE; \
	MENU trans7_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans7_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans7_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans7_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans7_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans7_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans7_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans7_FlowU_VOLUME_FLOW; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans7_FlowU_VOLUME_FLOW_page; \
	COMMAND trans7_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans7_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans7_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans7_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans7_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans7_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans7_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans7_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans7_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans7_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans7_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans7_FlowU_SOUND_VELOCITY; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans7_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans7_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans7_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans7_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans7_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans7_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans7_FlowU_unit_nominal_size; \
	UNIT trans7_FlowU_unit_volume_flow; \
	UNIT trans7_FlowU_unit_sound_velocity

#define USE_TRANS7_FLOWU_MANDATORY_A \
	USE_TRANS7_FLOWU_MANDATORY_BOTH; \
	MENU trans7_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS7_FLOWU_MANDATORY_B \
	USE_TRANS7_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans7_FlowU_VIEW_1; \
	MENU trans7_FlowU_VIEW_1_page; \
	MENU trans7_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS7_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans7_FlowU_ZERO_POINT; \
	MENU trans7_FlowU_ZERO_POINT_page; \
	COMMAND trans7_FlowU_ZERO_POINT_read; \
	COMMAND trans7_FlowU_ZERO_POINT_write; \
	VARIABLE trans7_FlowU_ZERO_POINT_ADJUST; \
	MENU trans7_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans7_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans7_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans7_FlowU_ZERO_POINT_UNIT; \
	MENU trans7_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans7_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans7_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans7_FlowU_VIEW_2; \
	MENU trans7_FlowU_VIEW_2_page; \
	COLLECTION trans7_FlowU_VIEW_3; \
	MENU trans7_FlowU_VIEW_3_page; \
	UNIT trans7_FlowU_unit_zero_point

#define USE_TRANS7_FLOWU_OPTIONAL_A \
	USE_TRANS7_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans7_FlowU_VIEW_1; \
	MENU trans7_FlowU_VIEW_1_page; \
	MENU trans7_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS7_FLOWU_OPTIONAL_B \
	USE_TRANS7_FLOWU_OPTIONAL_BOTH; \
	MENU trans7_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans7_FlowU_)
#define USE_TRANS7_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans7_FlowU_)
#define USE_TRANS7_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans7_FlowU_)
#define USE_TRANS7_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans7_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_FLOWU_MANDATORY_BOTH \
	BLOCK trans8_FlowU_block; \
	COLLECTION trans8_FlowU_BLOCK_OBJECT; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans8_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans8_FlowU_ST_REV; \
	MENU trans8_FlowU_ST_REV_page; \
	COMMAND trans8_FlowU_ST_REV_read; \
	VARIABLE trans8_FlowU_TAG_DESC; \
	MENU trans8_FlowU_TAG_DESC_page; \
	COMMAND trans8_FlowU_TAG_DESC_read; \
	COMMAND trans8_FlowU_TAG_DESC_write; \
	VARIABLE trans8_FlowU_STRATEGY; \
	MENU trans8_FlowU_STRATEGY_page; \
	COMMAND trans8_FlowU_STRATEGY_read; \
	COMMAND trans8_FlowU_STRATEGY_write; \
	VARIABLE trans8_FlowU_ALERT_KEY; \
	MENU trans8_FlowU_ALERT_KEY_page; \
	COMMAND trans8_FlowU_ALERT_KEY_read; \
	COMMAND trans8_FlowU_ALERT_KEY_write; \
	VARIABLE trans8_FlowU_TARGET_MODE; \
	MENU trans8_FlowU_TARGET_MODE_page; \
	COMMAND trans8_FlowU_TARGET_MODE_read; \
	COMMAND trans8_FlowU_TARGET_MODE_write; \
	COLLECTION trans8_FlowU_MODE_BLK; \
	VARIABLE trans8_FlowU_MODE_BLK_Actual; \
	VARIABLE trans8_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans8_FlowU_MODE_BLK_Normal; \
	MENU trans8_FlowU_MODE_BLK_page; \
	COMMAND trans8_FlowU_MODE_BLK_read; \
	COLLECTION trans8_FlowU_ALARM_SUM; \
	VARIABLE trans8_FlowU_ALARM_SUM_Current; \
	VARIABLE trans8_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans8_FlowU_ALARM_SUM_Disabled; \
	MENU trans8_FlowU_ALARM_SUM_page; \
	COMMAND trans8_FlowU_ALARM_SUM_read; \
	VARIABLE trans8_FlowU_CALIBR_FACTOR; \
	MENU trans8_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans8_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans8_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans8_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans8_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans8_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans8_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans8_FlowU_MEASUREMENT_MODE; \
	MENU trans8_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans8_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans8_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans8_FlowU_FLOW_DIRECTION; \
	MENU trans8_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans8_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans8_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans8_FlowU_NOMINAL_SIZE; \
	MENU trans8_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans8_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans8_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans8_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans8_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans8_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans8_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans8_FlowU_VOLUME_FLOW; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans8_FlowU_VOLUME_FLOW_page; \
	COMMAND trans8_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans8_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans8_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans8_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans8_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans8_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans8_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans8_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans8_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans8_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans8_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans8_FlowU_SOUND_VELOCITY; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans8_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans8_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans8_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans8_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans8_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans8_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans8_FlowU_unit_nominal_size; \
	UNIT trans8_FlowU_unit_volume_flow; \
	UNIT trans8_FlowU_unit_sound_velocity

#define USE_TRANS8_FLOWU_MANDATORY_A \
	USE_TRANS8_FLOWU_MANDATORY_BOTH; \
	MENU trans8_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS8_FLOWU_MANDATORY_B \
	USE_TRANS8_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans8_FlowU_VIEW_1; \
	MENU trans8_FlowU_VIEW_1_page; \
	MENU trans8_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS8_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans8_FlowU_ZERO_POINT; \
	MENU trans8_FlowU_ZERO_POINT_page; \
	COMMAND trans8_FlowU_ZERO_POINT_read; \
	COMMAND trans8_FlowU_ZERO_POINT_write; \
	VARIABLE trans8_FlowU_ZERO_POINT_ADJUST; \
	MENU trans8_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans8_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans8_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans8_FlowU_ZERO_POINT_UNIT; \
	MENU trans8_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans8_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans8_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans8_FlowU_VIEW_2; \
	MENU trans8_FlowU_VIEW_2_page; \
	COLLECTION trans8_FlowU_VIEW_3; \
	MENU trans8_FlowU_VIEW_3_page; \
	UNIT trans8_FlowU_unit_zero_point

#define USE_TRANS8_FLOWU_OPTIONAL_A \
	USE_TRANS8_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans8_FlowU_VIEW_1; \
	MENU trans8_FlowU_VIEW_1_page; \
	MENU trans8_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS8_FLOWU_OPTIONAL_B \
	USE_TRANS8_FLOWU_OPTIONAL_BOTH; \
	MENU trans8_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans8_FlowU_)
#define USE_TRANS8_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans8_FlowU_)
#define USE_TRANS8_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans8_FlowU_)
#define USE_TRANS8_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans8_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_FLOWU_MANDATORY_BOTH \
	BLOCK trans9_FlowU_block; \
	COLLECTION trans9_FlowU_BLOCK_OBJECT; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans9_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans9_FlowU_ST_REV; \
	MENU trans9_FlowU_ST_REV_page; \
	COMMAND trans9_FlowU_ST_REV_read; \
	VARIABLE trans9_FlowU_TAG_DESC; \
	MENU trans9_FlowU_TAG_DESC_page; \
	COMMAND trans9_FlowU_TAG_DESC_read; \
	COMMAND trans9_FlowU_TAG_DESC_write; \
	VARIABLE trans9_FlowU_STRATEGY; \
	MENU trans9_FlowU_STRATEGY_page; \
	COMMAND trans9_FlowU_STRATEGY_read; \
	COMMAND trans9_FlowU_STRATEGY_write; \
	VARIABLE trans9_FlowU_ALERT_KEY; \
	MENU trans9_FlowU_ALERT_KEY_page; \
	COMMAND trans9_FlowU_ALERT_KEY_read; \
	COMMAND trans9_FlowU_ALERT_KEY_write; \
	VARIABLE trans9_FlowU_TARGET_MODE; \
	MENU trans9_FlowU_TARGET_MODE_page; \
	COMMAND trans9_FlowU_TARGET_MODE_read; \
	COMMAND trans9_FlowU_TARGET_MODE_write; \
	COLLECTION trans9_FlowU_MODE_BLK; \
	VARIABLE trans9_FlowU_MODE_BLK_Actual; \
	VARIABLE trans9_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans9_FlowU_MODE_BLK_Normal; \
	MENU trans9_FlowU_MODE_BLK_page; \
	COMMAND trans9_FlowU_MODE_BLK_read; \
	COLLECTION trans9_FlowU_ALARM_SUM; \
	VARIABLE trans9_FlowU_ALARM_SUM_Current; \
	VARIABLE trans9_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans9_FlowU_ALARM_SUM_Disabled; \
	MENU trans9_FlowU_ALARM_SUM_page; \
	COMMAND trans9_FlowU_ALARM_SUM_read; \
	VARIABLE trans9_FlowU_CALIBR_FACTOR; \
	MENU trans9_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans9_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans9_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans9_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans9_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans9_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans9_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans9_FlowU_MEASUREMENT_MODE; \
	MENU trans9_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans9_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans9_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans9_FlowU_FLOW_DIRECTION; \
	MENU trans9_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans9_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans9_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans9_FlowU_NOMINAL_SIZE; \
	MENU trans9_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans9_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans9_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans9_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans9_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans9_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans9_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans9_FlowU_VOLUME_FLOW; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans9_FlowU_VOLUME_FLOW_page; \
	COMMAND trans9_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans9_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans9_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans9_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans9_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans9_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans9_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans9_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans9_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans9_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans9_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans9_FlowU_SOUND_VELOCITY; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans9_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans9_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans9_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans9_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans9_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans9_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans9_FlowU_unit_nominal_size; \
	UNIT trans9_FlowU_unit_volume_flow; \
	UNIT trans9_FlowU_unit_sound_velocity

#define USE_TRANS9_FLOWU_MANDATORY_A \
	USE_TRANS9_FLOWU_MANDATORY_BOTH; \
	MENU trans9_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS9_FLOWU_MANDATORY_B \
	USE_TRANS9_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans9_FlowU_VIEW_1; \
	MENU trans9_FlowU_VIEW_1_page; \
	MENU trans9_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS9_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans9_FlowU_ZERO_POINT; \
	MENU trans9_FlowU_ZERO_POINT_page; \
	COMMAND trans9_FlowU_ZERO_POINT_read; \
	COMMAND trans9_FlowU_ZERO_POINT_write; \
	VARIABLE trans9_FlowU_ZERO_POINT_ADJUST; \
	MENU trans9_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans9_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans9_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans9_FlowU_ZERO_POINT_UNIT; \
	MENU trans9_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans9_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans9_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans9_FlowU_VIEW_2; \
	MENU trans9_FlowU_VIEW_2_page; \
	COLLECTION trans9_FlowU_VIEW_3; \
	MENU trans9_FlowU_VIEW_3_page; \
	UNIT trans9_FlowU_unit_zero_point

#define USE_TRANS9_FLOWU_OPTIONAL_A \
	USE_TRANS9_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans9_FlowU_VIEW_1; \
	MENU trans9_FlowU_VIEW_1_page; \
	MENU trans9_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS9_FLOWU_OPTIONAL_B \
	USE_TRANS9_FLOWU_OPTIONAL_BOTH; \
	MENU trans9_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans9_FlowU_)
#define USE_TRANS9_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans9_FlowU_)
#define USE_TRANS9_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans9_FlowU_)
#define USE_TRANS9_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans9_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_FLOWU_MANDATORY_BOTH \
	BLOCK trans10_FlowU_block; \
	COLLECTION trans10_FlowU_BLOCK_OBJECT; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans10_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans10_FlowU_ST_REV; \
	MENU trans10_FlowU_ST_REV_page; \
	COMMAND trans10_FlowU_ST_REV_read; \
	VARIABLE trans10_FlowU_TAG_DESC; \
	MENU trans10_FlowU_TAG_DESC_page; \
	COMMAND trans10_FlowU_TAG_DESC_read; \
	COMMAND trans10_FlowU_TAG_DESC_write; \
	VARIABLE trans10_FlowU_STRATEGY; \
	MENU trans10_FlowU_STRATEGY_page; \
	COMMAND trans10_FlowU_STRATEGY_read; \
	COMMAND trans10_FlowU_STRATEGY_write; \
	VARIABLE trans10_FlowU_ALERT_KEY; \
	MENU trans10_FlowU_ALERT_KEY_page; \
	COMMAND trans10_FlowU_ALERT_KEY_read; \
	COMMAND trans10_FlowU_ALERT_KEY_write; \
	VARIABLE trans10_FlowU_TARGET_MODE; \
	MENU trans10_FlowU_TARGET_MODE_page; \
	COMMAND trans10_FlowU_TARGET_MODE_read; \
	COMMAND trans10_FlowU_TARGET_MODE_write; \
	COLLECTION trans10_FlowU_MODE_BLK; \
	VARIABLE trans10_FlowU_MODE_BLK_Actual; \
	VARIABLE trans10_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans10_FlowU_MODE_BLK_Normal; \
	MENU trans10_FlowU_MODE_BLK_page; \
	COMMAND trans10_FlowU_MODE_BLK_read; \
	COLLECTION trans10_FlowU_ALARM_SUM; \
	VARIABLE trans10_FlowU_ALARM_SUM_Current; \
	VARIABLE trans10_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans10_FlowU_ALARM_SUM_Disabled; \
	MENU trans10_FlowU_ALARM_SUM_page; \
	COMMAND trans10_FlowU_ALARM_SUM_read; \
	VARIABLE trans10_FlowU_CALIBR_FACTOR; \
	MENU trans10_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans10_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans10_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans10_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans10_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans10_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans10_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans10_FlowU_MEASUREMENT_MODE; \
	MENU trans10_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans10_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans10_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans10_FlowU_FLOW_DIRECTION; \
	MENU trans10_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans10_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans10_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans10_FlowU_NOMINAL_SIZE; \
	MENU trans10_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans10_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans10_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans10_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans10_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans10_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans10_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans10_FlowU_VOLUME_FLOW; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans10_FlowU_VOLUME_FLOW_page; \
	COMMAND trans10_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans10_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans10_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans10_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans10_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans10_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans10_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans10_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans10_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans10_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans10_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans10_FlowU_SOUND_VELOCITY; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans10_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans10_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans10_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans10_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans10_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans10_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans10_FlowU_unit_nominal_size; \
	UNIT trans10_FlowU_unit_volume_flow; \
	UNIT trans10_FlowU_unit_sound_velocity

#define USE_TRANS10_FLOWU_MANDATORY_A \
	USE_TRANS10_FLOWU_MANDATORY_BOTH; \
	MENU trans10_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS10_FLOWU_MANDATORY_B \
	USE_TRANS10_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans10_FlowU_VIEW_1; \
	MENU trans10_FlowU_VIEW_1_page; \
	MENU trans10_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS10_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans10_FlowU_ZERO_POINT; \
	MENU trans10_FlowU_ZERO_POINT_page; \
	COMMAND trans10_FlowU_ZERO_POINT_read; \
	COMMAND trans10_FlowU_ZERO_POINT_write; \
	VARIABLE trans10_FlowU_ZERO_POINT_ADJUST; \
	MENU trans10_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans10_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans10_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans10_FlowU_ZERO_POINT_UNIT; \
	MENU trans10_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans10_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans10_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans10_FlowU_VIEW_2; \
	MENU trans10_FlowU_VIEW_2_page; \
	COLLECTION trans10_FlowU_VIEW_3; \
	MENU trans10_FlowU_VIEW_3_page; \
	UNIT trans10_FlowU_unit_zero_point

#define USE_TRANS10_FLOWU_OPTIONAL_A \
	USE_TRANS10_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans10_FlowU_VIEW_1; \
	MENU trans10_FlowU_VIEW_1_page; \
	MENU trans10_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS10_FLOWU_OPTIONAL_B \
	USE_TRANS10_FLOWU_OPTIONAL_BOTH; \
	MENU trans10_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans10_FlowU_)
#define USE_TRANS10_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans10_FlowU_)
#define USE_TRANS10_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans10_FlowU_)
#define USE_TRANS10_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans10_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_FLOWU_MANDATORY_BOTH \
	BLOCK trans11_FlowU_block; \
	COLLECTION trans11_FlowU_BLOCK_OBJECT; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans11_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans11_FlowU_ST_REV; \
	MENU trans11_FlowU_ST_REV_page; \
	COMMAND trans11_FlowU_ST_REV_read; \
	VARIABLE trans11_FlowU_TAG_DESC; \
	MENU trans11_FlowU_TAG_DESC_page; \
	COMMAND trans11_FlowU_TAG_DESC_read; \
	COMMAND trans11_FlowU_TAG_DESC_write; \
	VARIABLE trans11_FlowU_STRATEGY; \
	MENU trans11_FlowU_STRATEGY_page; \
	COMMAND trans11_FlowU_STRATEGY_read; \
	COMMAND trans11_FlowU_STRATEGY_write; \
	VARIABLE trans11_FlowU_ALERT_KEY; \
	MENU trans11_FlowU_ALERT_KEY_page; \
	COMMAND trans11_FlowU_ALERT_KEY_read; \
	COMMAND trans11_FlowU_ALERT_KEY_write; \
	VARIABLE trans11_FlowU_TARGET_MODE; \
	MENU trans11_FlowU_TARGET_MODE_page; \
	COMMAND trans11_FlowU_TARGET_MODE_read; \
	COMMAND trans11_FlowU_TARGET_MODE_write; \
	COLLECTION trans11_FlowU_MODE_BLK; \
	VARIABLE trans11_FlowU_MODE_BLK_Actual; \
	VARIABLE trans11_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans11_FlowU_MODE_BLK_Normal; \
	MENU trans11_FlowU_MODE_BLK_page; \
	COMMAND trans11_FlowU_MODE_BLK_read; \
	COLLECTION trans11_FlowU_ALARM_SUM; \
	VARIABLE trans11_FlowU_ALARM_SUM_Current; \
	VARIABLE trans11_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans11_FlowU_ALARM_SUM_Disabled; \
	MENU trans11_FlowU_ALARM_SUM_page; \
	COMMAND trans11_FlowU_ALARM_SUM_read; \
	VARIABLE trans11_FlowU_CALIBR_FACTOR; \
	MENU trans11_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans11_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans11_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans11_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans11_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans11_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans11_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans11_FlowU_MEASUREMENT_MODE; \
	MENU trans11_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans11_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans11_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans11_FlowU_FLOW_DIRECTION; \
	MENU trans11_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans11_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans11_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans11_FlowU_NOMINAL_SIZE; \
	MENU trans11_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans11_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans11_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans11_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans11_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans11_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans11_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans11_FlowU_VOLUME_FLOW; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans11_FlowU_VOLUME_FLOW_page; \
	COMMAND trans11_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans11_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans11_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans11_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans11_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans11_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans11_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans11_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans11_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans11_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans11_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans11_FlowU_SOUND_VELOCITY; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans11_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans11_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans11_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans11_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans11_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans11_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans11_FlowU_unit_nominal_size; \
	UNIT trans11_FlowU_unit_volume_flow; \
	UNIT trans11_FlowU_unit_sound_velocity

#define USE_TRANS11_FLOWU_MANDATORY_A \
	USE_TRANS11_FLOWU_MANDATORY_BOTH; \
	MENU trans11_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS11_FLOWU_MANDATORY_B \
	USE_TRANS11_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans11_FlowU_VIEW_1; \
	MENU trans11_FlowU_VIEW_1_page; \
	MENU trans11_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS11_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans11_FlowU_ZERO_POINT; \
	MENU trans11_FlowU_ZERO_POINT_page; \
	COMMAND trans11_FlowU_ZERO_POINT_read; \
	COMMAND trans11_FlowU_ZERO_POINT_write; \
	VARIABLE trans11_FlowU_ZERO_POINT_ADJUST; \
	MENU trans11_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans11_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans11_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans11_FlowU_ZERO_POINT_UNIT; \
	MENU trans11_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans11_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans11_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans11_FlowU_VIEW_2; \
	MENU trans11_FlowU_VIEW_2_page; \
	COLLECTION trans11_FlowU_VIEW_3; \
	MENU trans11_FlowU_VIEW_3_page; \
	UNIT trans11_FlowU_unit_zero_point

#define USE_TRANS11_FLOWU_OPTIONAL_A \
	USE_TRANS11_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans11_FlowU_VIEW_1; \
	MENU trans11_FlowU_VIEW_1_page; \
	MENU trans11_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS11_FLOWU_OPTIONAL_B \
	USE_TRANS11_FLOWU_OPTIONAL_BOTH; \
	MENU trans11_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans11_FlowU_)
#define USE_TRANS11_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans11_FlowU_)
#define USE_TRANS11_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans11_FlowU_)
#define USE_TRANS11_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans11_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_FLOWU_MANDATORY_BOTH \
	BLOCK trans12_FlowU_block; \
	COLLECTION trans12_FlowU_BLOCK_OBJECT; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans12_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans12_FlowU_ST_REV; \
	MENU trans12_FlowU_ST_REV_page; \
	COMMAND trans12_FlowU_ST_REV_read; \
	VARIABLE trans12_FlowU_TAG_DESC; \
	MENU trans12_FlowU_TAG_DESC_page; \
	COMMAND trans12_FlowU_TAG_DESC_read; \
	COMMAND trans12_FlowU_TAG_DESC_write; \
	VARIABLE trans12_FlowU_STRATEGY; \
	MENU trans12_FlowU_STRATEGY_page; \
	COMMAND trans12_FlowU_STRATEGY_read; \
	COMMAND trans12_FlowU_STRATEGY_write; \
	VARIABLE trans12_FlowU_ALERT_KEY; \
	MENU trans12_FlowU_ALERT_KEY_page; \
	COMMAND trans12_FlowU_ALERT_KEY_read; \
	COMMAND trans12_FlowU_ALERT_KEY_write; \
	VARIABLE trans12_FlowU_TARGET_MODE; \
	MENU trans12_FlowU_TARGET_MODE_page; \
	COMMAND trans12_FlowU_TARGET_MODE_read; \
	COMMAND trans12_FlowU_TARGET_MODE_write; \
	COLLECTION trans12_FlowU_MODE_BLK; \
	VARIABLE trans12_FlowU_MODE_BLK_Actual; \
	VARIABLE trans12_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans12_FlowU_MODE_BLK_Normal; \
	MENU trans12_FlowU_MODE_BLK_page; \
	COMMAND trans12_FlowU_MODE_BLK_read; \
	COLLECTION trans12_FlowU_ALARM_SUM; \
	VARIABLE trans12_FlowU_ALARM_SUM_Current; \
	VARIABLE trans12_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans12_FlowU_ALARM_SUM_Disabled; \
	MENU trans12_FlowU_ALARM_SUM_page; \
	COMMAND trans12_FlowU_ALARM_SUM_read; \
	VARIABLE trans12_FlowU_CALIBR_FACTOR; \
	MENU trans12_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans12_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans12_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans12_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans12_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans12_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans12_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans12_FlowU_MEASUREMENT_MODE; \
	MENU trans12_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans12_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans12_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans12_FlowU_FLOW_DIRECTION; \
	MENU trans12_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans12_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans12_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans12_FlowU_NOMINAL_SIZE; \
	MENU trans12_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans12_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans12_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans12_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans12_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans12_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans12_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans12_FlowU_VOLUME_FLOW; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans12_FlowU_VOLUME_FLOW_page; \
	COMMAND trans12_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans12_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans12_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans12_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans12_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans12_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans12_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans12_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans12_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans12_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans12_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans12_FlowU_SOUND_VELOCITY; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans12_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans12_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans12_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans12_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans12_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans12_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans12_FlowU_unit_nominal_size; \
	UNIT trans12_FlowU_unit_volume_flow; \
	UNIT trans12_FlowU_unit_sound_velocity

#define USE_TRANS12_FLOWU_MANDATORY_A \
	USE_TRANS12_FLOWU_MANDATORY_BOTH; \
	MENU trans12_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS12_FLOWU_MANDATORY_B \
	USE_TRANS12_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans12_FlowU_VIEW_1; \
	MENU trans12_FlowU_VIEW_1_page; \
	MENU trans12_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS12_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans12_FlowU_ZERO_POINT; \
	MENU trans12_FlowU_ZERO_POINT_page; \
	COMMAND trans12_FlowU_ZERO_POINT_read; \
	COMMAND trans12_FlowU_ZERO_POINT_write; \
	VARIABLE trans12_FlowU_ZERO_POINT_ADJUST; \
	MENU trans12_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans12_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans12_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans12_FlowU_ZERO_POINT_UNIT; \
	MENU trans12_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans12_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans12_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans12_FlowU_VIEW_2; \
	MENU trans12_FlowU_VIEW_2_page; \
	COLLECTION trans12_FlowU_VIEW_3; \
	MENU trans12_FlowU_VIEW_3_page; \
	UNIT trans12_FlowU_unit_zero_point

#define USE_TRANS12_FLOWU_OPTIONAL_A \
	USE_TRANS12_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans12_FlowU_VIEW_1; \
	MENU trans12_FlowU_VIEW_1_page; \
	MENU trans12_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS12_FLOWU_OPTIONAL_B \
	USE_TRANS12_FLOWU_OPTIONAL_BOTH; \
	MENU trans12_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans12_FlowU_)
#define USE_TRANS12_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans12_FlowU_)
#define USE_TRANS12_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans12_FlowU_)
#define USE_TRANS12_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans12_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_FLOWU_MANDATORY_BOTH \
	BLOCK trans13_FlowU_block; \
	COLLECTION trans13_FlowU_BLOCK_OBJECT; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans13_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans13_FlowU_ST_REV; \
	MENU trans13_FlowU_ST_REV_page; \
	COMMAND trans13_FlowU_ST_REV_read; \
	VARIABLE trans13_FlowU_TAG_DESC; \
	MENU trans13_FlowU_TAG_DESC_page; \
	COMMAND trans13_FlowU_TAG_DESC_read; \
	COMMAND trans13_FlowU_TAG_DESC_write; \
	VARIABLE trans13_FlowU_STRATEGY; \
	MENU trans13_FlowU_STRATEGY_page; \
	COMMAND trans13_FlowU_STRATEGY_read; \
	COMMAND trans13_FlowU_STRATEGY_write; \
	VARIABLE trans13_FlowU_ALERT_KEY; \
	MENU trans13_FlowU_ALERT_KEY_page; \
	COMMAND trans13_FlowU_ALERT_KEY_read; \
	COMMAND trans13_FlowU_ALERT_KEY_write; \
	VARIABLE trans13_FlowU_TARGET_MODE; \
	MENU trans13_FlowU_TARGET_MODE_page; \
	COMMAND trans13_FlowU_TARGET_MODE_read; \
	COMMAND trans13_FlowU_TARGET_MODE_write; \
	COLLECTION trans13_FlowU_MODE_BLK; \
	VARIABLE trans13_FlowU_MODE_BLK_Actual; \
	VARIABLE trans13_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans13_FlowU_MODE_BLK_Normal; \
	MENU trans13_FlowU_MODE_BLK_page; \
	COMMAND trans13_FlowU_MODE_BLK_read; \
	COLLECTION trans13_FlowU_ALARM_SUM; \
	VARIABLE trans13_FlowU_ALARM_SUM_Current; \
	VARIABLE trans13_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans13_FlowU_ALARM_SUM_Disabled; \
	MENU trans13_FlowU_ALARM_SUM_page; \
	COMMAND trans13_FlowU_ALARM_SUM_read; \
	VARIABLE trans13_FlowU_CALIBR_FACTOR; \
	MENU trans13_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans13_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans13_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans13_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans13_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans13_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans13_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans13_FlowU_MEASUREMENT_MODE; \
	MENU trans13_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans13_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans13_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans13_FlowU_FLOW_DIRECTION; \
	MENU trans13_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans13_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans13_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans13_FlowU_NOMINAL_SIZE; \
	MENU trans13_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans13_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans13_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans13_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans13_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans13_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans13_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans13_FlowU_VOLUME_FLOW; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans13_FlowU_VOLUME_FLOW_page; \
	COMMAND trans13_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans13_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans13_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans13_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans13_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans13_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans13_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans13_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans13_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans13_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans13_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans13_FlowU_SOUND_VELOCITY; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans13_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans13_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans13_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans13_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans13_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans13_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans13_FlowU_unit_nominal_size; \
	UNIT trans13_FlowU_unit_volume_flow; \
	UNIT trans13_FlowU_unit_sound_velocity

#define USE_TRANS13_FLOWU_MANDATORY_A \
	USE_TRANS13_FLOWU_MANDATORY_BOTH; \
	MENU trans13_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS13_FLOWU_MANDATORY_B \
	USE_TRANS13_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans13_FlowU_VIEW_1; \
	MENU trans13_FlowU_VIEW_1_page; \
	MENU trans13_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS13_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans13_FlowU_ZERO_POINT; \
	MENU trans13_FlowU_ZERO_POINT_page; \
	COMMAND trans13_FlowU_ZERO_POINT_read; \
	COMMAND trans13_FlowU_ZERO_POINT_write; \
	VARIABLE trans13_FlowU_ZERO_POINT_ADJUST; \
	MENU trans13_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans13_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans13_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans13_FlowU_ZERO_POINT_UNIT; \
	MENU trans13_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans13_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans13_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans13_FlowU_VIEW_2; \
	MENU trans13_FlowU_VIEW_2_page; \
	COLLECTION trans13_FlowU_VIEW_3; \
	MENU trans13_FlowU_VIEW_3_page; \
	UNIT trans13_FlowU_unit_zero_point

#define USE_TRANS13_FLOWU_OPTIONAL_A \
	USE_TRANS13_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans13_FlowU_VIEW_1; \
	MENU trans13_FlowU_VIEW_1_page; \
	MENU trans13_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS13_FLOWU_OPTIONAL_B \
	USE_TRANS13_FLOWU_OPTIONAL_BOTH; \
	MENU trans13_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans13_FlowU_)
#define USE_TRANS13_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans13_FlowU_)
#define USE_TRANS13_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans13_FlowU_)
#define USE_TRANS13_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans13_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_FLOWU_MANDATORY_BOTH \
	BLOCK trans14_FlowU_block; \
	COLLECTION trans14_FlowU_BLOCK_OBJECT; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans14_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans14_FlowU_ST_REV; \
	MENU trans14_FlowU_ST_REV_page; \
	COMMAND trans14_FlowU_ST_REV_read; \
	VARIABLE trans14_FlowU_TAG_DESC; \
	MENU trans14_FlowU_TAG_DESC_page; \
	COMMAND trans14_FlowU_TAG_DESC_read; \
	COMMAND trans14_FlowU_TAG_DESC_write; \
	VARIABLE trans14_FlowU_STRATEGY; \
	MENU trans14_FlowU_STRATEGY_page; \
	COMMAND trans14_FlowU_STRATEGY_read; \
	COMMAND trans14_FlowU_STRATEGY_write; \
	VARIABLE trans14_FlowU_ALERT_KEY; \
	MENU trans14_FlowU_ALERT_KEY_page; \
	COMMAND trans14_FlowU_ALERT_KEY_read; \
	COMMAND trans14_FlowU_ALERT_KEY_write; \
	VARIABLE trans14_FlowU_TARGET_MODE; \
	MENU trans14_FlowU_TARGET_MODE_page; \
	COMMAND trans14_FlowU_TARGET_MODE_read; \
	COMMAND trans14_FlowU_TARGET_MODE_write; \
	COLLECTION trans14_FlowU_MODE_BLK; \
	VARIABLE trans14_FlowU_MODE_BLK_Actual; \
	VARIABLE trans14_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans14_FlowU_MODE_BLK_Normal; \
	MENU trans14_FlowU_MODE_BLK_page; \
	COMMAND trans14_FlowU_MODE_BLK_read; \
	COLLECTION trans14_FlowU_ALARM_SUM; \
	VARIABLE trans14_FlowU_ALARM_SUM_Current; \
	VARIABLE trans14_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans14_FlowU_ALARM_SUM_Disabled; \
	MENU trans14_FlowU_ALARM_SUM_page; \
	COMMAND trans14_FlowU_ALARM_SUM_read; \
	VARIABLE trans14_FlowU_CALIBR_FACTOR; \
	MENU trans14_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans14_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans14_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans14_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans14_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans14_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans14_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans14_FlowU_MEASUREMENT_MODE; \
	MENU trans14_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans14_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans14_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans14_FlowU_FLOW_DIRECTION; \
	MENU trans14_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans14_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans14_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans14_FlowU_NOMINAL_SIZE; \
	MENU trans14_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans14_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans14_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans14_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans14_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans14_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans14_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans14_FlowU_VOLUME_FLOW; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans14_FlowU_VOLUME_FLOW_page; \
	COMMAND trans14_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans14_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans14_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans14_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans14_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans14_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans14_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans14_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans14_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans14_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans14_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans14_FlowU_SOUND_VELOCITY; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans14_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans14_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans14_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans14_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans14_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans14_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans14_FlowU_unit_nominal_size; \
	UNIT trans14_FlowU_unit_volume_flow; \
	UNIT trans14_FlowU_unit_sound_velocity

#define USE_TRANS14_FLOWU_MANDATORY_A \
	USE_TRANS14_FLOWU_MANDATORY_BOTH; \
	MENU trans14_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS14_FLOWU_MANDATORY_B \
	USE_TRANS14_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans14_FlowU_VIEW_1; \
	MENU trans14_FlowU_VIEW_1_page; \
	MENU trans14_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS14_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans14_FlowU_ZERO_POINT; \
	MENU trans14_FlowU_ZERO_POINT_page; \
	COMMAND trans14_FlowU_ZERO_POINT_read; \
	COMMAND trans14_FlowU_ZERO_POINT_write; \
	VARIABLE trans14_FlowU_ZERO_POINT_ADJUST; \
	MENU trans14_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans14_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans14_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans14_FlowU_ZERO_POINT_UNIT; \
	MENU trans14_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans14_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans14_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans14_FlowU_VIEW_2; \
	MENU trans14_FlowU_VIEW_2_page; \
	COLLECTION trans14_FlowU_VIEW_3; \
	MENU trans14_FlowU_VIEW_3_page; \
	UNIT trans14_FlowU_unit_zero_point

#define USE_TRANS14_FLOWU_OPTIONAL_A \
	USE_TRANS14_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans14_FlowU_VIEW_1; \
	MENU trans14_FlowU_VIEW_1_page; \
	MENU trans14_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS14_FLOWU_OPTIONAL_B \
	USE_TRANS14_FLOWU_OPTIONAL_BOTH; \
	MENU trans14_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans14_FlowU_)
#define USE_TRANS14_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans14_FlowU_)
#define USE_TRANS14_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans14_FlowU_)
#define USE_TRANS14_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans14_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_FLOWU_MANDATORY_BOTH \
	BLOCK trans15_FlowU_block; \
	COLLECTION trans15_FlowU_BLOCK_OBJECT; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Class; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_FlowU_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_FlowU_BLOCK_OBJECT_page; \
	COMMAND trans15_FlowU_BLOCK_OBJECT_read; \
	VARIABLE trans15_FlowU_ST_REV; \
	MENU trans15_FlowU_ST_REV_page; \
	COMMAND trans15_FlowU_ST_REV_read; \
	VARIABLE trans15_FlowU_TAG_DESC; \
	MENU trans15_FlowU_TAG_DESC_page; \
	COMMAND trans15_FlowU_TAG_DESC_read; \
	COMMAND trans15_FlowU_TAG_DESC_write; \
	VARIABLE trans15_FlowU_STRATEGY; \
	MENU trans15_FlowU_STRATEGY_page; \
	COMMAND trans15_FlowU_STRATEGY_read; \
	COMMAND trans15_FlowU_STRATEGY_write; \
	VARIABLE trans15_FlowU_ALERT_KEY; \
	MENU trans15_FlowU_ALERT_KEY_page; \
	COMMAND trans15_FlowU_ALERT_KEY_read; \
	COMMAND trans15_FlowU_ALERT_KEY_write; \
	VARIABLE trans15_FlowU_TARGET_MODE; \
	MENU trans15_FlowU_TARGET_MODE_page; \
	COMMAND trans15_FlowU_TARGET_MODE_read; \
	COMMAND trans15_FlowU_TARGET_MODE_write; \
	COLLECTION trans15_FlowU_MODE_BLK; \
	VARIABLE trans15_FlowU_MODE_BLK_Actual; \
	VARIABLE trans15_FlowU_MODE_BLK_Permitted; \
	VARIABLE trans15_FlowU_MODE_BLK_Normal; \
	MENU trans15_FlowU_MODE_BLK_page; \
	COMMAND trans15_FlowU_MODE_BLK_read; \
	COLLECTION trans15_FlowU_ALARM_SUM; \
	VARIABLE trans15_FlowU_ALARM_SUM_Current; \
	VARIABLE trans15_FlowU_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_FlowU_ALARM_SUM_Unreported; \
	VARIABLE trans15_FlowU_ALARM_SUM_Disabled; \
	MENU trans15_FlowU_ALARM_SUM_page; \
	COMMAND trans15_FlowU_ALARM_SUM_read; \
	VARIABLE trans15_FlowU_CALIBR_FACTOR; \
	MENU trans15_FlowU_CALIBR_FACTOR_page; \
	COMMAND trans15_FlowU_CALIBR_FACTOR_read; \
	COMMAND trans15_FlowU_CALIBR_FACTOR_write; \
	VARIABLE trans15_FlowU_LOW_FLOW_CUTOFF; \
	MENU trans15_FlowU_LOW_FLOW_CUTOFF_page; \
	COMMAND trans15_FlowU_LOW_FLOW_CUTOFF_read; \
	COMMAND trans15_FlowU_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans15_FlowU_MEASUREMENT_MODE; \
	MENU trans15_FlowU_MEASUREMENT_MODE_page; \
	COMMAND trans15_FlowU_MEASUREMENT_MODE_read; \
	COMMAND trans15_FlowU_MEASUREMENT_MODE_write; \
	VARIABLE trans15_FlowU_FLOW_DIRECTION; \
	MENU trans15_FlowU_FLOW_DIRECTION_page; \
	COMMAND trans15_FlowU_FLOW_DIRECTION_read; \
	COMMAND trans15_FlowU_FLOW_DIRECTION_write; \
	VARIABLE trans15_FlowU_NOMINAL_SIZE; \
	MENU trans15_FlowU_NOMINAL_SIZE_page; \
	COMMAND trans15_FlowU_NOMINAL_SIZE_read; \
	COMMAND trans15_FlowU_NOMINAL_SIZE_write; \
	VARIABLE trans15_FlowU_NOMINAL_SIZE_UNITS; \
	MENU trans15_FlowU_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans15_FlowU_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans15_FlowU_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans15_FlowU_VOLUME_FLOW; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_Value; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_Status_Limit; \
	MENU trans15_FlowU_VOLUME_FLOW_page; \
	COMMAND trans15_FlowU_VOLUME_FLOW_read; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_UNITS; \
	MENU trans15_FlowU_VOLUME_FLOW_UNITS_page; \
	COMMAND trans15_FlowU_VOLUME_FLOW_UNITS_read; \
	COMMAND trans15_FlowU_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_LO_LIMIT; \
	MENU trans15_FlowU_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans15_FlowU_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans15_FlowU_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans15_FlowU_VOLUME_FLOW_HI_LIMIT; \
	MENU trans15_FlowU_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans15_FlowU_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans15_FlowU_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans15_FlowU_SOUND_VELOCITY; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_Value; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_Status_Condensed; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_Status_Quality; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_Status_Limit; \
	MENU trans15_FlowU_SOUND_VELOCITY_page; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_read; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_UNITS; \
	MENU trans15_FlowU_SOUND_VELOCITY_UNITS_page; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_UNITS_read; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_UNITS_write; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_LO_LIMIT; \
	MENU trans15_FlowU_SOUND_VELOCITY_LO_LIMIT_page; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_LO_LIMIT_read; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_LO_LIMIT_write; \
	VARIABLE trans15_FlowU_SOUND_VELOCITY_HI_LIMIT; \
	MENU trans15_FlowU_SOUND_VELOCITY_HI_LIMIT_page; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_HI_LIMIT_read; \
	COMMAND trans15_FlowU_SOUND_VELOCITY_HI_LIMIT_write; \
	UNIT trans15_FlowU_unit_nominal_size; \
	UNIT trans15_FlowU_unit_volume_flow; \
	UNIT trans15_FlowU_unit_sound_velocity

#define USE_TRANS15_FLOWU_MANDATORY_A \
	USE_TRANS15_FLOWU_MANDATORY_BOTH; \
	MENU trans15_FlowU_Simple_Dialog_Mandatory_A

#define USE_TRANS15_FLOWU_MANDATORY_B \
	USE_TRANS15_FLOWU_MANDATORY_BOTH; \
	COLLECTION trans15_FlowU_VIEW_1; \
	MENU trans15_FlowU_VIEW_1_page; \
	MENU trans15_FlowU_Simple_Dialog_Mandatory_B

#define USE_TRANS15_FLOWU_OPTIONAL_BOTH \
	VARIABLE trans15_FlowU_ZERO_POINT; \
	MENU trans15_FlowU_ZERO_POINT_page; \
	COMMAND trans15_FlowU_ZERO_POINT_read; \
	COMMAND trans15_FlowU_ZERO_POINT_write; \
	VARIABLE trans15_FlowU_ZERO_POINT_ADJUST; \
	MENU trans15_FlowU_ZERO_POINT_ADJUST_page; \
	COMMAND trans15_FlowU_ZERO_POINT_ADJUST_read; \
	COMMAND trans15_FlowU_ZERO_POINT_ADJUST_write; \
	VARIABLE trans15_FlowU_ZERO_POINT_UNIT; \
	MENU trans15_FlowU_ZERO_POINT_UNIT_page; \
	COMMAND trans15_FlowU_ZERO_POINT_UNIT_read; \
	COMMAND trans15_FlowU_ZERO_POINT_UNIT_write; \
	COLLECTION trans15_FlowU_VIEW_2; \
	MENU trans15_FlowU_VIEW_2_page; \
	COLLECTION trans15_FlowU_VIEW_3; \
	MENU trans15_FlowU_VIEW_3_page; \
	UNIT trans15_FlowU_unit_zero_point

#define USE_TRANS15_FLOWU_OPTIONAL_A \
	USE_TRANS15_FLOWU_OPTIONAL_BOTH; \
	COLLECTION trans15_FlowU_VIEW_1; \
	MENU trans15_FlowU_VIEW_1_page; \
	MENU trans15_FlowU_Simple_Dialog_Optional_A

#define USE_TRANS15_FLOWU_OPTIONAL_B \
	USE_TRANS15_FLOWU_OPTIONAL_BOTH; \
	MENU trans15_FlowU_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_FLOWU_MANDATORY_A USE_TRANS_FLOWU_MANDATORY_A(trans15_FlowU_)
#define USE_TRANS15_FLOWU_MANDATORY_B USE_TRANS_FLOWU_MANDATORY_B(trans15_FlowU_)
#define USE_TRANS15_FLOWU_OPTIONAL_A  USE_TRANS_FLOWU_OPTIONAL_A(trans15_FlowU_)
#define USE_TRANS15_FLOWU_OPTIONAL_B  USE_TRANS_FLOWU_OPTIONAL_B(trans15_FlowU_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_FLOWVA_MANDATORY_BOTH \
	BLOCK trans1_FlowVA_block; \
	COLLECTION trans1_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans1_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans1_FlowVA_ST_REV; \
	MENU trans1_FlowVA_ST_REV_page; \
	COMMAND trans1_FlowVA_ST_REV_read; \
	VARIABLE trans1_FlowVA_TAG_DESC; \
	MENU trans1_FlowVA_TAG_DESC_page; \
	COMMAND trans1_FlowVA_TAG_DESC_read; \
	COMMAND trans1_FlowVA_TAG_DESC_write; \
	VARIABLE trans1_FlowVA_STRATEGY; \
	MENU trans1_FlowVA_STRATEGY_page; \
	COMMAND trans1_FlowVA_STRATEGY_read; \
	COMMAND trans1_FlowVA_STRATEGY_write; \
	VARIABLE trans1_FlowVA_ALERT_KEY; \
	MENU trans1_FlowVA_ALERT_KEY_page; \
	COMMAND trans1_FlowVA_ALERT_KEY_read; \
	COMMAND trans1_FlowVA_ALERT_KEY_write; \
	VARIABLE trans1_FlowVA_TARGET_MODE; \
	MENU trans1_FlowVA_TARGET_MODE_page; \
	COMMAND trans1_FlowVA_TARGET_MODE_read; \
	COMMAND trans1_FlowVA_TARGET_MODE_write; \
	COLLECTION trans1_FlowVA_MODE_BLK; \
	VARIABLE trans1_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans1_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans1_FlowVA_MODE_BLK_Normal; \
	MENU trans1_FlowVA_MODE_BLK_page; \
	COMMAND trans1_FlowVA_MODE_BLK_read; \
	COLLECTION trans1_FlowVA_ALARM_SUM; \
	VARIABLE trans1_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans1_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans1_FlowVA_ALARM_SUM_Disabled; \
	MENU trans1_FlowVA_ALARM_SUM_page; \
	COMMAND trans1_FlowVA_ALARM_SUM_read; \
	VARIABLE trans1_FlowVA_CALIBR_FACTOR; \
	MENU trans1_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans1_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans1_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans1_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans1_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans1_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans1_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans1_FlowVA_NOMINAL_SIZE; \
	MENU trans1_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans1_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans1_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans1_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans1_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans1_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans1_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans1_FlowVA_VOLUME_FLOW; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans1_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans1_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans1_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans1_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans1_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans1_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans1_FlowVA_unit_nominal_size; \
	UNIT trans1_FlowVA_unit_volume_flow

#define USE_TRANS1_FLOWVA_MANDATORY_A \
	USE_TRANS1_FLOWVA_MANDATORY_BOTH; \
	MENU trans1_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS1_FLOWVA_MANDATORY_B \
	USE_TRANS1_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans1_FlowVA_VIEW_1; \
	MENU trans1_FlowVA_VIEW_1_page; \
	MENU trans1_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS1_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans1_FlowVA_ZERO_POINT; \
	MENU trans1_FlowVA_ZERO_POINT_page; \
	COMMAND trans1_FlowVA_ZERO_POINT_read; \
	COMMAND trans1_FlowVA_ZERO_POINT_write; \
	VARIABLE trans1_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans1_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans1_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans1_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans1_FlowVA_ZERO_POINT_UNIT; \
	MENU trans1_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans1_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans1_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans1_FlowVA_VIEW_2; \
	MENU trans1_FlowVA_VIEW_2_page; \
	COLLECTION trans1_FlowVA_VIEW_3; \
	MENU trans1_FlowVA_VIEW_3_page; \
	UNIT trans1_FlowVA_unit_zero_point

#define USE_TRANS1_FLOWVA_OPTIONAL_A \
	USE_TRANS1_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans1_FlowVA_VIEW_1; \
	MENU trans1_FlowVA_VIEW_1_page; \
	MENU trans1_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS1_FLOWVA_OPTIONAL_B \
	USE_TRANS1_FLOWVA_OPTIONAL_BOTH; \
	MENU trans1_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_FLOWVA_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CALIBR_FACTOR; \
	MENU prefix ## CALIBR_FACTOR_page; \
	COMMAND prefix ## CALIBR_FACTOR_read; \
	COMMAND prefix ## CALIBR_FACTOR_write; \
	VARIABLE prefix ## LOW_FLOW_CUTOFF; \
	MENU prefix ## LOW_FLOW_CUTOFF_page; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_read; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_write; \
	VARIABLE prefix ## NOMINAL_SIZE; \
	MENU prefix ## NOMINAL_SIZE_page; \
	COMMAND prefix ## NOMINAL_SIZE_read; \
	COMMAND prefix ## NOMINAL_SIZE_write; \
	VARIABLE prefix ## NOMINAL_SIZE_UNITS; \
	MENU prefix ## NOMINAL_SIZE_UNITS_page; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_read; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_write; \
	COLLECTION prefix ## VOLUME_FLOW; \
	VARIABLE prefix ## VOLUME_FLOW_Value; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Condensed; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Quality; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Limit; \
	MENU prefix ## VOLUME_FLOW_page; \
	COMMAND prefix ## VOLUME_FLOW_read; \
	VARIABLE prefix ## VOLUME_FLOW_UNITS; \
	MENU prefix ## VOLUME_FLOW_UNITS_page; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_read; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_write; \
	VARIABLE prefix ## VOLUME_FLOW_LO_LIMIT; \
	MENU prefix ## VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE prefix ## VOLUME_FLOW_HI_LIMIT; \
	MENU prefix ## VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_write; \
	UNIT prefix ## unit_nominal_size; \
	UNIT prefix ## unit_volume_flow

#define USE_TRANS_FLOWVA_MANDATORY_A(prefix) \
	USE_TRANS_FLOWVA_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_FLOWVA_MANDATORY_B(prefix) \
	USE_TRANS_FLOWVA_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_FLOWVA_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ZERO_POINT; \
	MENU prefix ## ZERO_POINT_page; \
	COMMAND prefix ## ZERO_POINT_read; \
	COMMAND prefix ## ZERO_POINT_write; \
	VARIABLE prefix ## ZERO_POINT_ADJUST; \
	MENU prefix ## ZERO_POINT_ADJUST_page; \
	COMMAND prefix ## ZERO_POINT_ADJUST_read; \
	COMMAND prefix ## ZERO_POINT_ADJUST_write; \
	VARIABLE prefix ## ZERO_POINT_UNIT; \
	MENU prefix ## ZERO_POINT_UNIT_page; \
	COMMAND prefix ## ZERO_POINT_UNIT_read; \
	COMMAND prefix ## ZERO_POINT_UNIT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## unit_zero_point

#define USE_TRANS_FLOWVA_OPTIONAL_A(prefix) \
	USE_TRANS_FLOWVA_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_FLOWVA_OPTIONAL_B(prefix) \
	USE_TRANS_FLOWVA_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans1_FlowVA_)
#define USE_TRANS1_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans1_FlowVA_)
#define USE_TRANS1_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans1_FlowVA_)
#define USE_TRANS1_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans1_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_FLOWVA_MANDATORY_BOTH \
	BLOCK trans2_FlowVA_block; \
	COLLECTION trans2_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans2_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans2_FlowVA_ST_REV; \
	MENU trans2_FlowVA_ST_REV_page; \
	COMMAND trans2_FlowVA_ST_REV_read; \
	VARIABLE trans2_FlowVA_TAG_DESC; \
	MENU trans2_FlowVA_TAG_DESC_page; \
	COMMAND trans2_FlowVA_TAG_DESC_read; \
	COMMAND trans2_FlowVA_TAG_DESC_write; \
	VARIABLE trans2_FlowVA_STRATEGY; \
	MENU trans2_FlowVA_STRATEGY_page; \
	COMMAND trans2_FlowVA_STRATEGY_read; \
	COMMAND trans2_FlowVA_STRATEGY_write; \
	VARIABLE trans2_FlowVA_ALERT_KEY; \
	MENU trans2_FlowVA_ALERT_KEY_page; \
	COMMAND trans2_FlowVA_ALERT_KEY_read; \
	COMMAND trans2_FlowVA_ALERT_KEY_write; \
	VARIABLE trans2_FlowVA_TARGET_MODE; \
	MENU trans2_FlowVA_TARGET_MODE_page; \
	COMMAND trans2_FlowVA_TARGET_MODE_read; \
	COMMAND trans2_FlowVA_TARGET_MODE_write; \
	COLLECTION trans2_FlowVA_MODE_BLK; \
	VARIABLE trans2_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans2_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans2_FlowVA_MODE_BLK_Normal; \
	MENU trans2_FlowVA_MODE_BLK_page; \
	COMMAND trans2_FlowVA_MODE_BLK_read; \
	COLLECTION trans2_FlowVA_ALARM_SUM; \
	VARIABLE trans2_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans2_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans2_FlowVA_ALARM_SUM_Disabled; \
	MENU trans2_FlowVA_ALARM_SUM_page; \
	COMMAND trans2_FlowVA_ALARM_SUM_read; \
	VARIABLE trans2_FlowVA_CALIBR_FACTOR; \
	MENU trans2_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans2_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans2_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans2_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans2_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans2_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans2_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans2_FlowVA_NOMINAL_SIZE; \
	MENU trans2_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans2_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans2_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans2_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans2_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans2_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans2_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans2_FlowVA_VOLUME_FLOW; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans2_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans2_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans2_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans2_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans2_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans2_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans2_FlowVA_unit_nominal_size; \
	UNIT trans2_FlowVA_unit_volume_flow

#define USE_TRANS2_FLOWVA_MANDATORY_A \
	USE_TRANS2_FLOWVA_MANDATORY_BOTH; \
	MENU trans2_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS2_FLOWVA_MANDATORY_B \
	USE_TRANS2_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans2_FlowVA_VIEW_1; \
	MENU trans2_FlowVA_VIEW_1_page; \
	MENU trans2_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS2_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans2_FlowVA_ZERO_POINT; \
	MENU trans2_FlowVA_ZERO_POINT_page; \
	COMMAND trans2_FlowVA_ZERO_POINT_read; \
	COMMAND trans2_FlowVA_ZERO_POINT_write; \
	VARIABLE trans2_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans2_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans2_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans2_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans2_FlowVA_ZERO_POINT_UNIT; \
	MENU trans2_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans2_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans2_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans2_FlowVA_VIEW_2; \
	MENU trans2_FlowVA_VIEW_2_page; \
	COLLECTION trans2_FlowVA_VIEW_3; \
	MENU trans2_FlowVA_VIEW_3_page; \
	UNIT trans2_FlowVA_unit_zero_point

#define USE_TRANS2_FLOWVA_OPTIONAL_A \
	USE_TRANS2_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans2_FlowVA_VIEW_1; \
	MENU trans2_FlowVA_VIEW_1_page; \
	MENU trans2_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS2_FLOWVA_OPTIONAL_B \
	USE_TRANS2_FLOWVA_OPTIONAL_BOTH; \
	MENU trans2_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans2_FlowVA_)
#define USE_TRANS2_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans2_FlowVA_)
#define USE_TRANS2_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans2_FlowVA_)
#define USE_TRANS2_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans2_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_FLOWVA_MANDATORY_BOTH \
	BLOCK trans3_FlowVA_block; \
	COLLECTION trans3_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans3_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans3_FlowVA_ST_REV; \
	MENU trans3_FlowVA_ST_REV_page; \
	COMMAND trans3_FlowVA_ST_REV_read; \
	VARIABLE trans3_FlowVA_TAG_DESC; \
	MENU trans3_FlowVA_TAG_DESC_page; \
	COMMAND trans3_FlowVA_TAG_DESC_read; \
	COMMAND trans3_FlowVA_TAG_DESC_write; \
	VARIABLE trans3_FlowVA_STRATEGY; \
	MENU trans3_FlowVA_STRATEGY_page; \
	COMMAND trans3_FlowVA_STRATEGY_read; \
	COMMAND trans3_FlowVA_STRATEGY_write; \
	VARIABLE trans3_FlowVA_ALERT_KEY; \
	MENU trans3_FlowVA_ALERT_KEY_page; \
	COMMAND trans3_FlowVA_ALERT_KEY_read; \
	COMMAND trans3_FlowVA_ALERT_KEY_write; \
	VARIABLE trans3_FlowVA_TARGET_MODE; \
	MENU trans3_FlowVA_TARGET_MODE_page; \
	COMMAND trans3_FlowVA_TARGET_MODE_read; \
	COMMAND trans3_FlowVA_TARGET_MODE_write; \
	COLLECTION trans3_FlowVA_MODE_BLK; \
	VARIABLE trans3_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans3_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans3_FlowVA_MODE_BLK_Normal; \
	MENU trans3_FlowVA_MODE_BLK_page; \
	COMMAND trans3_FlowVA_MODE_BLK_read; \
	COLLECTION trans3_FlowVA_ALARM_SUM; \
	VARIABLE trans3_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans3_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans3_FlowVA_ALARM_SUM_Disabled; \
	MENU trans3_FlowVA_ALARM_SUM_page; \
	COMMAND trans3_FlowVA_ALARM_SUM_read; \
	VARIABLE trans3_FlowVA_CALIBR_FACTOR; \
	MENU trans3_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans3_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans3_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans3_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans3_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans3_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans3_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans3_FlowVA_NOMINAL_SIZE; \
	MENU trans3_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans3_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans3_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans3_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans3_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans3_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans3_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans3_FlowVA_VOLUME_FLOW; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans3_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans3_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans3_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans3_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans3_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans3_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans3_FlowVA_unit_nominal_size; \
	UNIT trans3_FlowVA_unit_volume_flow

#define USE_TRANS3_FLOWVA_MANDATORY_A \
	USE_TRANS3_FLOWVA_MANDATORY_BOTH; \
	MENU trans3_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS3_FLOWVA_MANDATORY_B \
	USE_TRANS3_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans3_FlowVA_VIEW_1; \
	MENU trans3_FlowVA_VIEW_1_page; \
	MENU trans3_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS3_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans3_FlowVA_ZERO_POINT; \
	MENU trans3_FlowVA_ZERO_POINT_page; \
	COMMAND trans3_FlowVA_ZERO_POINT_read; \
	COMMAND trans3_FlowVA_ZERO_POINT_write; \
	VARIABLE trans3_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans3_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans3_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans3_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans3_FlowVA_ZERO_POINT_UNIT; \
	MENU trans3_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans3_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans3_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans3_FlowVA_VIEW_2; \
	MENU trans3_FlowVA_VIEW_2_page; \
	COLLECTION trans3_FlowVA_VIEW_3; \
	MENU trans3_FlowVA_VIEW_3_page; \
	UNIT trans3_FlowVA_unit_zero_point

#define USE_TRANS3_FLOWVA_OPTIONAL_A \
	USE_TRANS3_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans3_FlowVA_VIEW_1; \
	MENU trans3_FlowVA_VIEW_1_page; \
	MENU trans3_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS3_FLOWVA_OPTIONAL_B \
	USE_TRANS3_FLOWVA_OPTIONAL_BOTH; \
	MENU trans3_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans3_FlowVA_)
#define USE_TRANS3_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans3_FlowVA_)
#define USE_TRANS3_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans3_FlowVA_)
#define USE_TRANS3_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans3_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_FLOWVA_MANDATORY_BOTH \
	BLOCK trans4_FlowVA_block; \
	COLLECTION trans4_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans4_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans4_FlowVA_ST_REV; \
	MENU trans4_FlowVA_ST_REV_page; \
	COMMAND trans4_FlowVA_ST_REV_read; \
	VARIABLE trans4_FlowVA_TAG_DESC; \
	MENU trans4_FlowVA_TAG_DESC_page; \
	COMMAND trans4_FlowVA_TAG_DESC_read; \
	COMMAND trans4_FlowVA_TAG_DESC_write; \
	VARIABLE trans4_FlowVA_STRATEGY; \
	MENU trans4_FlowVA_STRATEGY_page; \
	COMMAND trans4_FlowVA_STRATEGY_read; \
	COMMAND trans4_FlowVA_STRATEGY_write; \
	VARIABLE trans4_FlowVA_ALERT_KEY; \
	MENU trans4_FlowVA_ALERT_KEY_page; \
	COMMAND trans4_FlowVA_ALERT_KEY_read; \
	COMMAND trans4_FlowVA_ALERT_KEY_write; \
	VARIABLE trans4_FlowVA_TARGET_MODE; \
	MENU trans4_FlowVA_TARGET_MODE_page; \
	COMMAND trans4_FlowVA_TARGET_MODE_read; \
	COMMAND trans4_FlowVA_TARGET_MODE_write; \
	COLLECTION trans4_FlowVA_MODE_BLK; \
	VARIABLE trans4_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans4_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans4_FlowVA_MODE_BLK_Normal; \
	MENU trans4_FlowVA_MODE_BLK_page; \
	COMMAND trans4_FlowVA_MODE_BLK_read; \
	COLLECTION trans4_FlowVA_ALARM_SUM; \
	VARIABLE trans4_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans4_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans4_FlowVA_ALARM_SUM_Disabled; \
	MENU trans4_FlowVA_ALARM_SUM_page; \
	COMMAND trans4_FlowVA_ALARM_SUM_read; \
	VARIABLE trans4_FlowVA_CALIBR_FACTOR; \
	MENU trans4_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans4_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans4_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans4_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans4_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans4_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans4_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans4_FlowVA_NOMINAL_SIZE; \
	MENU trans4_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans4_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans4_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans4_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans4_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans4_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans4_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans4_FlowVA_VOLUME_FLOW; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans4_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans4_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans4_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans4_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans4_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans4_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans4_FlowVA_unit_nominal_size; \
	UNIT trans4_FlowVA_unit_volume_flow

#define USE_TRANS4_FLOWVA_MANDATORY_A \
	USE_TRANS4_FLOWVA_MANDATORY_BOTH; \
	MENU trans4_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS4_FLOWVA_MANDATORY_B \
	USE_TRANS4_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans4_FlowVA_VIEW_1; \
	MENU trans4_FlowVA_VIEW_1_page; \
	MENU trans4_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS4_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans4_FlowVA_ZERO_POINT; \
	MENU trans4_FlowVA_ZERO_POINT_page; \
	COMMAND trans4_FlowVA_ZERO_POINT_read; \
	COMMAND trans4_FlowVA_ZERO_POINT_write; \
	VARIABLE trans4_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans4_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans4_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans4_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans4_FlowVA_ZERO_POINT_UNIT; \
	MENU trans4_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans4_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans4_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans4_FlowVA_VIEW_2; \
	MENU trans4_FlowVA_VIEW_2_page; \
	COLLECTION trans4_FlowVA_VIEW_3; \
	MENU trans4_FlowVA_VIEW_3_page; \
	UNIT trans4_FlowVA_unit_zero_point

#define USE_TRANS4_FLOWVA_OPTIONAL_A \
	USE_TRANS4_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans4_FlowVA_VIEW_1; \
	MENU trans4_FlowVA_VIEW_1_page; \
	MENU trans4_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS4_FLOWVA_OPTIONAL_B \
	USE_TRANS4_FLOWVA_OPTIONAL_BOTH; \
	MENU trans4_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans4_FlowVA_)
#define USE_TRANS4_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans4_FlowVA_)
#define USE_TRANS4_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans4_FlowVA_)
#define USE_TRANS4_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans4_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_FLOWVA_MANDATORY_BOTH \
	BLOCK trans5_FlowVA_block; \
	COLLECTION trans5_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans5_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans5_FlowVA_ST_REV; \
	MENU trans5_FlowVA_ST_REV_page; \
	COMMAND trans5_FlowVA_ST_REV_read; \
	VARIABLE trans5_FlowVA_TAG_DESC; \
	MENU trans5_FlowVA_TAG_DESC_page; \
	COMMAND trans5_FlowVA_TAG_DESC_read; \
	COMMAND trans5_FlowVA_TAG_DESC_write; \
	VARIABLE trans5_FlowVA_STRATEGY; \
	MENU trans5_FlowVA_STRATEGY_page; \
	COMMAND trans5_FlowVA_STRATEGY_read; \
	COMMAND trans5_FlowVA_STRATEGY_write; \
	VARIABLE trans5_FlowVA_ALERT_KEY; \
	MENU trans5_FlowVA_ALERT_KEY_page; \
	COMMAND trans5_FlowVA_ALERT_KEY_read; \
	COMMAND trans5_FlowVA_ALERT_KEY_write; \
	VARIABLE trans5_FlowVA_TARGET_MODE; \
	MENU trans5_FlowVA_TARGET_MODE_page; \
	COMMAND trans5_FlowVA_TARGET_MODE_read; \
	COMMAND trans5_FlowVA_TARGET_MODE_write; \
	COLLECTION trans5_FlowVA_MODE_BLK; \
	VARIABLE trans5_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans5_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans5_FlowVA_MODE_BLK_Normal; \
	MENU trans5_FlowVA_MODE_BLK_page; \
	COMMAND trans5_FlowVA_MODE_BLK_read; \
	COLLECTION trans5_FlowVA_ALARM_SUM; \
	VARIABLE trans5_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans5_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans5_FlowVA_ALARM_SUM_Disabled; \
	MENU trans5_FlowVA_ALARM_SUM_page; \
	COMMAND trans5_FlowVA_ALARM_SUM_read; \
	VARIABLE trans5_FlowVA_CALIBR_FACTOR; \
	MENU trans5_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans5_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans5_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans5_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans5_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans5_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans5_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans5_FlowVA_NOMINAL_SIZE; \
	MENU trans5_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans5_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans5_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans5_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans5_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans5_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans5_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans5_FlowVA_VOLUME_FLOW; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans5_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans5_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans5_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans5_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans5_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans5_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans5_FlowVA_unit_nominal_size; \
	UNIT trans5_FlowVA_unit_volume_flow

#define USE_TRANS5_FLOWVA_MANDATORY_A \
	USE_TRANS5_FLOWVA_MANDATORY_BOTH; \
	MENU trans5_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS5_FLOWVA_MANDATORY_B \
	USE_TRANS5_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans5_FlowVA_VIEW_1; \
	MENU trans5_FlowVA_VIEW_1_page; \
	MENU trans5_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS5_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans5_FlowVA_ZERO_POINT; \
	MENU trans5_FlowVA_ZERO_POINT_page; \
	COMMAND trans5_FlowVA_ZERO_POINT_read; \
	COMMAND trans5_FlowVA_ZERO_POINT_write; \
	VARIABLE trans5_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans5_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans5_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans5_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans5_FlowVA_ZERO_POINT_UNIT; \
	MENU trans5_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans5_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans5_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans5_FlowVA_VIEW_2; \
	MENU trans5_FlowVA_VIEW_2_page; \
	COLLECTION trans5_FlowVA_VIEW_3; \
	MENU trans5_FlowVA_VIEW_3_page; \
	UNIT trans5_FlowVA_unit_zero_point

#define USE_TRANS5_FLOWVA_OPTIONAL_A \
	USE_TRANS5_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans5_FlowVA_VIEW_1; \
	MENU trans5_FlowVA_VIEW_1_page; \
	MENU trans5_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS5_FLOWVA_OPTIONAL_B \
	USE_TRANS5_FLOWVA_OPTIONAL_BOTH; \
	MENU trans5_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans5_FlowVA_)
#define USE_TRANS5_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans5_FlowVA_)
#define USE_TRANS5_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans5_FlowVA_)
#define USE_TRANS5_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans5_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_FLOWVA_MANDATORY_BOTH \
	BLOCK trans6_FlowVA_block; \
	COLLECTION trans6_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans6_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans6_FlowVA_ST_REV; \
	MENU trans6_FlowVA_ST_REV_page; \
	COMMAND trans6_FlowVA_ST_REV_read; \
	VARIABLE trans6_FlowVA_TAG_DESC; \
	MENU trans6_FlowVA_TAG_DESC_page; \
	COMMAND trans6_FlowVA_TAG_DESC_read; \
	COMMAND trans6_FlowVA_TAG_DESC_write; \
	VARIABLE trans6_FlowVA_STRATEGY; \
	MENU trans6_FlowVA_STRATEGY_page; \
	COMMAND trans6_FlowVA_STRATEGY_read; \
	COMMAND trans6_FlowVA_STRATEGY_write; \
	VARIABLE trans6_FlowVA_ALERT_KEY; \
	MENU trans6_FlowVA_ALERT_KEY_page; \
	COMMAND trans6_FlowVA_ALERT_KEY_read; \
	COMMAND trans6_FlowVA_ALERT_KEY_write; \
	VARIABLE trans6_FlowVA_TARGET_MODE; \
	MENU trans6_FlowVA_TARGET_MODE_page; \
	COMMAND trans6_FlowVA_TARGET_MODE_read; \
	COMMAND trans6_FlowVA_TARGET_MODE_write; \
	COLLECTION trans6_FlowVA_MODE_BLK; \
	VARIABLE trans6_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans6_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans6_FlowVA_MODE_BLK_Normal; \
	MENU trans6_FlowVA_MODE_BLK_page; \
	COMMAND trans6_FlowVA_MODE_BLK_read; \
	COLLECTION trans6_FlowVA_ALARM_SUM; \
	VARIABLE trans6_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans6_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans6_FlowVA_ALARM_SUM_Disabled; \
	MENU trans6_FlowVA_ALARM_SUM_page; \
	COMMAND trans6_FlowVA_ALARM_SUM_read; \
	VARIABLE trans6_FlowVA_CALIBR_FACTOR; \
	MENU trans6_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans6_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans6_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans6_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans6_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans6_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans6_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans6_FlowVA_NOMINAL_SIZE; \
	MENU trans6_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans6_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans6_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans6_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans6_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans6_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans6_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans6_FlowVA_VOLUME_FLOW; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans6_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans6_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans6_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans6_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans6_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans6_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans6_FlowVA_unit_nominal_size; \
	UNIT trans6_FlowVA_unit_volume_flow

#define USE_TRANS6_FLOWVA_MANDATORY_A \
	USE_TRANS6_FLOWVA_MANDATORY_BOTH; \
	MENU trans6_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS6_FLOWVA_MANDATORY_B \
	USE_TRANS6_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans6_FlowVA_VIEW_1; \
	MENU trans6_FlowVA_VIEW_1_page; \
	MENU trans6_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS6_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans6_FlowVA_ZERO_POINT; \
	MENU trans6_FlowVA_ZERO_POINT_page; \
	COMMAND trans6_FlowVA_ZERO_POINT_read; \
	COMMAND trans6_FlowVA_ZERO_POINT_write; \
	VARIABLE trans6_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans6_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans6_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans6_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans6_FlowVA_ZERO_POINT_UNIT; \
	MENU trans6_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans6_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans6_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans6_FlowVA_VIEW_2; \
	MENU trans6_FlowVA_VIEW_2_page; \
	COLLECTION trans6_FlowVA_VIEW_3; \
	MENU trans6_FlowVA_VIEW_3_page; \
	UNIT trans6_FlowVA_unit_zero_point

#define USE_TRANS6_FLOWVA_OPTIONAL_A \
	USE_TRANS6_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans6_FlowVA_VIEW_1; \
	MENU trans6_FlowVA_VIEW_1_page; \
	MENU trans6_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS6_FLOWVA_OPTIONAL_B \
	USE_TRANS6_FLOWVA_OPTIONAL_BOTH; \
	MENU trans6_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans6_FlowVA_)
#define USE_TRANS6_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans6_FlowVA_)
#define USE_TRANS6_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans6_FlowVA_)
#define USE_TRANS6_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans6_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_FLOWVA_MANDATORY_BOTH \
	BLOCK trans7_FlowVA_block; \
	COLLECTION trans7_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans7_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans7_FlowVA_ST_REV; \
	MENU trans7_FlowVA_ST_REV_page; \
	COMMAND trans7_FlowVA_ST_REV_read; \
	VARIABLE trans7_FlowVA_TAG_DESC; \
	MENU trans7_FlowVA_TAG_DESC_page; \
	COMMAND trans7_FlowVA_TAG_DESC_read; \
	COMMAND trans7_FlowVA_TAG_DESC_write; \
	VARIABLE trans7_FlowVA_STRATEGY; \
	MENU trans7_FlowVA_STRATEGY_page; \
	COMMAND trans7_FlowVA_STRATEGY_read; \
	COMMAND trans7_FlowVA_STRATEGY_write; \
	VARIABLE trans7_FlowVA_ALERT_KEY; \
	MENU trans7_FlowVA_ALERT_KEY_page; \
	COMMAND trans7_FlowVA_ALERT_KEY_read; \
	COMMAND trans7_FlowVA_ALERT_KEY_write; \
	VARIABLE trans7_FlowVA_TARGET_MODE; \
	MENU trans7_FlowVA_TARGET_MODE_page; \
	COMMAND trans7_FlowVA_TARGET_MODE_read; \
	COMMAND trans7_FlowVA_TARGET_MODE_write; \
	COLLECTION trans7_FlowVA_MODE_BLK; \
	VARIABLE trans7_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans7_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans7_FlowVA_MODE_BLK_Normal; \
	MENU trans7_FlowVA_MODE_BLK_page; \
	COMMAND trans7_FlowVA_MODE_BLK_read; \
	COLLECTION trans7_FlowVA_ALARM_SUM; \
	VARIABLE trans7_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans7_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans7_FlowVA_ALARM_SUM_Disabled; \
	MENU trans7_FlowVA_ALARM_SUM_page; \
	COMMAND trans7_FlowVA_ALARM_SUM_read; \
	VARIABLE trans7_FlowVA_CALIBR_FACTOR; \
	MENU trans7_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans7_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans7_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans7_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans7_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans7_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans7_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans7_FlowVA_NOMINAL_SIZE; \
	MENU trans7_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans7_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans7_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans7_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans7_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans7_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans7_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans7_FlowVA_VOLUME_FLOW; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans7_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans7_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans7_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans7_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans7_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans7_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans7_FlowVA_unit_nominal_size; \
	UNIT trans7_FlowVA_unit_volume_flow

#define USE_TRANS7_FLOWVA_MANDATORY_A \
	USE_TRANS7_FLOWVA_MANDATORY_BOTH; \
	MENU trans7_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS7_FLOWVA_MANDATORY_B \
	USE_TRANS7_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans7_FlowVA_VIEW_1; \
	MENU trans7_FlowVA_VIEW_1_page; \
	MENU trans7_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS7_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans7_FlowVA_ZERO_POINT; \
	MENU trans7_FlowVA_ZERO_POINT_page; \
	COMMAND trans7_FlowVA_ZERO_POINT_read; \
	COMMAND trans7_FlowVA_ZERO_POINT_write; \
	VARIABLE trans7_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans7_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans7_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans7_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans7_FlowVA_ZERO_POINT_UNIT; \
	MENU trans7_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans7_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans7_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans7_FlowVA_VIEW_2; \
	MENU trans7_FlowVA_VIEW_2_page; \
	COLLECTION trans7_FlowVA_VIEW_3; \
	MENU trans7_FlowVA_VIEW_3_page; \
	UNIT trans7_FlowVA_unit_zero_point

#define USE_TRANS7_FLOWVA_OPTIONAL_A \
	USE_TRANS7_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans7_FlowVA_VIEW_1; \
	MENU trans7_FlowVA_VIEW_1_page; \
	MENU trans7_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS7_FLOWVA_OPTIONAL_B \
	USE_TRANS7_FLOWVA_OPTIONAL_BOTH; \
	MENU trans7_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans7_FlowVA_)
#define USE_TRANS7_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans7_FlowVA_)
#define USE_TRANS7_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans7_FlowVA_)
#define USE_TRANS7_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans7_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_FLOWVA_MANDATORY_BOTH \
	BLOCK trans8_FlowVA_block; \
	COLLECTION trans8_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans8_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans8_FlowVA_ST_REV; \
	MENU trans8_FlowVA_ST_REV_page; \
	COMMAND trans8_FlowVA_ST_REV_read; \
	VARIABLE trans8_FlowVA_TAG_DESC; \
	MENU trans8_FlowVA_TAG_DESC_page; \
	COMMAND trans8_FlowVA_TAG_DESC_read; \
	COMMAND trans8_FlowVA_TAG_DESC_write; \
	VARIABLE trans8_FlowVA_STRATEGY; \
	MENU trans8_FlowVA_STRATEGY_page; \
	COMMAND trans8_FlowVA_STRATEGY_read; \
	COMMAND trans8_FlowVA_STRATEGY_write; \
	VARIABLE trans8_FlowVA_ALERT_KEY; \
	MENU trans8_FlowVA_ALERT_KEY_page; \
	COMMAND trans8_FlowVA_ALERT_KEY_read; \
	COMMAND trans8_FlowVA_ALERT_KEY_write; \
	VARIABLE trans8_FlowVA_TARGET_MODE; \
	MENU trans8_FlowVA_TARGET_MODE_page; \
	COMMAND trans8_FlowVA_TARGET_MODE_read; \
	COMMAND trans8_FlowVA_TARGET_MODE_write; \
	COLLECTION trans8_FlowVA_MODE_BLK; \
	VARIABLE trans8_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans8_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans8_FlowVA_MODE_BLK_Normal; \
	MENU trans8_FlowVA_MODE_BLK_page; \
	COMMAND trans8_FlowVA_MODE_BLK_read; \
	COLLECTION trans8_FlowVA_ALARM_SUM; \
	VARIABLE trans8_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans8_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans8_FlowVA_ALARM_SUM_Disabled; \
	MENU trans8_FlowVA_ALARM_SUM_page; \
	COMMAND trans8_FlowVA_ALARM_SUM_read; \
	VARIABLE trans8_FlowVA_CALIBR_FACTOR; \
	MENU trans8_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans8_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans8_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans8_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans8_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans8_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans8_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans8_FlowVA_NOMINAL_SIZE; \
	MENU trans8_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans8_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans8_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans8_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans8_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans8_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans8_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans8_FlowVA_VOLUME_FLOW; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans8_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans8_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans8_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans8_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans8_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans8_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans8_FlowVA_unit_nominal_size; \
	UNIT trans8_FlowVA_unit_volume_flow

#define USE_TRANS8_FLOWVA_MANDATORY_A \
	USE_TRANS8_FLOWVA_MANDATORY_BOTH; \
	MENU trans8_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS8_FLOWVA_MANDATORY_B \
	USE_TRANS8_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans8_FlowVA_VIEW_1; \
	MENU trans8_FlowVA_VIEW_1_page; \
	MENU trans8_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS8_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans8_FlowVA_ZERO_POINT; \
	MENU trans8_FlowVA_ZERO_POINT_page; \
	COMMAND trans8_FlowVA_ZERO_POINT_read; \
	COMMAND trans8_FlowVA_ZERO_POINT_write; \
	VARIABLE trans8_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans8_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans8_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans8_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans8_FlowVA_ZERO_POINT_UNIT; \
	MENU trans8_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans8_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans8_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans8_FlowVA_VIEW_2; \
	MENU trans8_FlowVA_VIEW_2_page; \
	COLLECTION trans8_FlowVA_VIEW_3; \
	MENU trans8_FlowVA_VIEW_3_page; \
	UNIT trans8_FlowVA_unit_zero_point

#define USE_TRANS8_FLOWVA_OPTIONAL_A \
	USE_TRANS8_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans8_FlowVA_VIEW_1; \
	MENU trans8_FlowVA_VIEW_1_page; \
	MENU trans8_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS8_FLOWVA_OPTIONAL_B \
	USE_TRANS8_FLOWVA_OPTIONAL_BOTH; \
	MENU trans8_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans8_FlowVA_)
#define USE_TRANS8_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans8_FlowVA_)
#define USE_TRANS8_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans8_FlowVA_)
#define USE_TRANS8_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans8_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_FLOWVA_MANDATORY_BOTH \
	BLOCK trans9_FlowVA_block; \
	COLLECTION trans9_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans9_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans9_FlowVA_ST_REV; \
	MENU trans9_FlowVA_ST_REV_page; \
	COMMAND trans9_FlowVA_ST_REV_read; \
	VARIABLE trans9_FlowVA_TAG_DESC; \
	MENU trans9_FlowVA_TAG_DESC_page; \
	COMMAND trans9_FlowVA_TAG_DESC_read; \
	COMMAND trans9_FlowVA_TAG_DESC_write; \
	VARIABLE trans9_FlowVA_STRATEGY; \
	MENU trans9_FlowVA_STRATEGY_page; \
	COMMAND trans9_FlowVA_STRATEGY_read; \
	COMMAND trans9_FlowVA_STRATEGY_write; \
	VARIABLE trans9_FlowVA_ALERT_KEY; \
	MENU trans9_FlowVA_ALERT_KEY_page; \
	COMMAND trans9_FlowVA_ALERT_KEY_read; \
	COMMAND trans9_FlowVA_ALERT_KEY_write; \
	VARIABLE trans9_FlowVA_TARGET_MODE; \
	MENU trans9_FlowVA_TARGET_MODE_page; \
	COMMAND trans9_FlowVA_TARGET_MODE_read; \
	COMMAND trans9_FlowVA_TARGET_MODE_write; \
	COLLECTION trans9_FlowVA_MODE_BLK; \
	VARIABLE trans9_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans9_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans9_FlowVA_MODE_BLK_Normal; \
	MENU trans9_FlowVA_MODE_BLK_page; \
	COMMAND trans9_FlowVA_MODE_BLK_read; \
	COLLECTION trans9_FlowVA_ALARM_SUM; \
	VARIABLE trans9_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans9_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans9_FlowVA_ALARM_SUM_Disabled; \
	MENU trans9_FlowVA_ALARM_SUM_page; \
	COMMAND trans9_FlowVA_ALARM_SUM_read; \
	VARIABLE trans9_FlowVA_CALIBR_FACTOR; \
	MENU trans9_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans9_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans9_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans9_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans9_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans9_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans9_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans9_FlowVA_NOMINAL_SIZE; \
	MENU trans9_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans9_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans9_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans9_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans9_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans9_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans9_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans9_FlowVA_VOLUME_FLOW; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans9_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans9_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans9_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans9_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans9_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans9_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans9_FlowVA_unit_nominal_size; \
	UNIT trans9_FlowVA_unit_volume_flow

#define USE_TRANS9_FLOWVA_MANDATORY_A \
	USE_TRANS9_FLOWVA_MANDATORY_BOTH; \
	MENU trans9_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS9_FLOWVA_MANDATORY_B \
	USE_TRANS9_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans9_FlowVA_VIEW_1; \
	MENU trans9_FlowVA_VIEW_1_page; \
	MENU trans9_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS9_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans9_FlowVA_ZERO_POINT; \
	MENU trans9_FlowVA_ZERO_POINT_page; \
	COMMAND trans9_FlowVA_ZERO_POINT_read; \
	COMMAND trans9_FlowVA_ZERO_POINT_write; \
	VARIABLE trans9_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans9_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans9_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans9_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans9_FlowVA_ZERO_POINT_UNIT; \
	MENU trans9_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans9_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans9_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans9_FlowVA_VIEW_2; \
	MENU trans9_FlowVA_VIEW_2_page; \
	COLLECTION trans9_FlowVA_VIEW_3; \
	MENU trans9_FlowVA_VIEW_3_page; \
	UNIT trans9_FlowVA_unit_zero_point

#define USE_TRANS9_FLOWVA_OPTIONAL_A \
	USE_TRANS9_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans9_FlowVA_VIEW_1; \
	MENU trans9_FlowVA_VIEW_1_page; \
	MENU trans9_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS9_FLOWVA_OPTIONAL_B \
	USE_TRANS9_FLOWVA_OPTIONAL_BOTH; \
	MENU trans9_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans9_FlowVA_)
#define USE_TRANS9_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans9_FlowVA_)
#define USE_TRANS9_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans9_FlowVA_)
#define USE_TRANS9_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans9_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_FLOWVA_MANDATORY_BOTH \
	BLOCK trans10_FlowVA_block; \
	COLLECTION trans10_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans10_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans10_FlowVA_ST_REV; \
	MENU trans10_FlowVA_ST_REV_page; \
	COMMAND trans10_FlowVA_ST_REV_read; \
	VARIABLE trans10_FlowVA_TAG_DESC; \
	MENU trans10_FlowVA_TAG_DESC_page; \
	COMMAND trans10_FlowVA_TAG_DESC_read; \
	COMMAND trans10_FlowVA_TAG_DESC_write; \
	VARIABLE trans10_FlowVA_STRATEGY; \
	MENU trans10_FlowVA_STRATEGY_page; \
	COMMAND trans10_FlowVA_STRATEGY_read; \
	COMMAND trans10_FlowVA_STRATEGY_write; \
	VARIABLE trans10_FlowVA_ALERT_KEY; \
	MENU trans10_FlowVA_ALERT_KEY_page; \
	COMMAND trans10_FlowVA_ALERT_KEY_read; \
	COMMAND trans10_FlowVA_ALERT_KEY_write; \
	VARIABLE trans10_FlowVA_TARGET_MODE; \
	MENU trans10_FlowVA_TARGET_MODE_page; \
	COMMAND trans10_FlowVA_TARGET_MODE_read; \
	COMMAND trans10_FlowVA_TARGET_MODE_write; \
	COLLECTION trans10_FlowVA_MODE_BLK; \
	VARIABLE trans10_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans10_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans10_FlowVA_MODE_BLK_Normal; \
	MENU trans10_FlowVA_MODE_BLK_page; \
	COMMAND trans10_FlowVA_MODE_BLK_read; \
	COLLECTION trans10_FlowVA_ALARM_SUM; \
	VARIABLE trans10_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans10_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans10_FlowVA_ALARM_SUM_Disabled; \
	MENU trans10_FlowVA_ALARM_SUM_page; \
	COMMAND trans10_FlowVA_ALARM_SUM_read; \
	VARIABLE trans10_FlowVA_CALIBR_FACTOR; \
	MENU trans10_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans10_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans10_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans10_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans10_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans10_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans10_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans10_FlowVA_NOMINAL_SIZE; \
	MENU trans10_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans10_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans10_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans10_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans10_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans10_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans10_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans10_FlowVA_VOLUME_FLOW; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans10_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans10_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans10_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans10_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans10_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans10_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans10_FlowVA_unit_nominal_size; \
	UNIT trans10_FlowVA_unit_volume_flow

#define USE_TRANS10_FLOWVA_MANDATORY_A \
	USE_TRANS10_FLOWVA_MANDATORY_BOTH; \
	MENU trans10_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS10_FLOWVA_MANDATORY_B \
	USE_TRANS10_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans10_FlowVA_VIEW_1; \
	MENU trans10_FlowVA_VIEW_1_page; \
	MENU trans10_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS10_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans10_FlowVA_ZERO_POINT; \
	MENU trans10_FlowVA_ZERO_POINT_page; \
	COMMAND trans10_FlowVA_ZERO_POINT_read; \
	COMMAND trans10_FlowVA_ZERO_POINT_write; \
	VARIABLE trans10_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans10_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans10_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans10_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans10_FlowVA_ZERO_POINT_UNIT; \
	MENU trans10_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans10_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans10_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans10_FlowVA_VIEW_2; \
	MENU trans10_FlowVA_VIEW_2_page; \
	COLLECTION trans10_FlowVA_VIEW_3; \
	MENU trans10_FlowVA_VIEW_3_page; \
	UNIT trans10_FlowVA_unit_zero_point

#define USE_TRANS10_FLOWVA_OPTIONAL_A \
	USE_TRANS10_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans10_FlowVA_VIEW_1; \
	MENU trans10_FlowVA_VIEW_1_page; \
	MENU trans10_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS10_FLOWVA_OPTIONAL_B \
	USE_TRANS10_FLOWVA_OPTIONAL_BOTH; \
	MENU trans10_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans10_FlowVA_)
#define USE_TRANS10_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans10_FlowVA_)
#define USE_TRANS10_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans10_FlowVA_)
#define USE_TRANS10_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans10_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_FLOWVA_MANDATORY_BOTH \
	BLOCK trans11_FlowVA_block; \
	COLLECTION trans11_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans11_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans11_FlowVA_ST_REV; \
	MENU trans11_FlowVA_ST_REV_page; \
	COMMAND trans11_FlowVA_ST_REV_read; \
	VARIABLE trans11_FlowVA_TAG_DESC; \
	MENU trans11_FlowVA_TAG_DESC_page; \
	COMMAND trans11_FlowVA_TAG_DESC_read; \
	COMMAND trans11_FlowVA_TAG_DESC_write; \
	VARIABLE trans11_FlowVA_STRATEGY; \
	MENU trans11_FlowVA_STRATEGY_page; \
	COMMAND trans11_FlowVA_STRATEGY_read; \
	COMMAND trans11_FlowVA_STRATEGY_write; \
	VARIABLE trans11_FlowVA_ALERT_KEY; \
	MENU trans11_FlowVA_ALERT_KEY_page; \
	COMMAND trans11_FlowVA_ALERT_KEY_read; \
	COMMAND trans11_FlowVA_ALERT_KEY_write; \
	VARIABLE trans11_FlowVA_TARGET_MODE; \
	MENU trans11_FlowVA_TARGET_MODE_page; \
	COMMAND trans11_FlowVA_TARGET_MODE_read; \
	COMMAND trans11_FlowVA_TARGET_MODE_write; \
	COLLECTION trans11_FlowVA_MODE_BLK; \
	VARIABLE trans11_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans11_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans11_FlowVA_MODE_BLK_Normal; \
	MENU trans11_FlowVA_MODE_BLK_page; \
	COMMAND trans11_FlowVA_MODE_BLK_read; \
	COLLECTION trans11_FlowVA_ALARM_SUM; \
	VARIABLE trans11_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans11_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans11_FlowVA_ALARM_SUM_Disabled; \
	MENU trans11_FlowVA_ALARM_SUM_page; \
	COMMAND trans11_FlowVA_ALARM_SUM_read; \
	VARIABLE trans11_FlowVA_CALIBR_FACTOR; \
	MENU trans11_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans11_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans11_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans11_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans11_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans11_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans11_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans11_FlowVA_NOMINAL_SIZE; \
	MENU trans11_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans11_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans11_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans11_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans11_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans11_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans11_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans11_FlowVA_VOLUME_FLOW; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans11_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans11_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans11_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans11_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans11_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans11_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans11_FlowVA_unit_nominal_size; \
	UNIT trans11_FlowVA_unit_volume_flow

#define USE_TRANS11_FLOWVA_MANDATORY_A \
	USE_TRANS11_FLOWVA_MANDATORY_BOTH; \
	MENU trans11_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS11_FLOWVA_MANDATORY_B \
	USE_TRANS11_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans11_FlowVA_VIEW_1; \
	MENU trans11_FlowVA_VIEW_1_page; \
	MENU trans11_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS11_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans11_FlowVA_ZERO_POINT; \
	MENU trans11_FlowVA_ZERO_POINT_page; \
	COMMAND trans11_FlowVA_ZERO_POINT_read; \
	COMMAND trans11_FlowVA_ZERO_POINT_write; \
	VARIABLE trans11_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans11_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans11_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans11_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans11_FlowVA_ZERO_POINT_UNIT; \
	MENU trans11_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans11_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans11_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans11_FlowVA_VIEW_2; \
	MENU trans11_FlowVA_VIEW_2_page; \
	COLLECTION trans11_FlowVA_VIEW_3; \
	MENU trans11_FlowVA_VIEW_3_page; \
	UNIT trans11_FlowVA_unit_zero_point

#define USE_TRANS11_FLOWVA_OPTIONAL_A \
	USE_TRANS11_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans11_FlowVA_VIEW_1; \
	MENU trans11_FlowVA_VIEW_1_page; \
	MENU trans11_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS11_FLOWVA_OPTIONAL_B \
	USE_TRANS11_FLOWVA_OPTIONAL_BOTH; \
	MENU trans11_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans11_FlowVA_)
#define USE_TRANS11_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans11_FlowVA_)
#define USE_TRANS11_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans11_FlowVA_)
#define USE_TRANS11_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans11_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_FLOWVA_MANDATORY_BOTH \
	BLOCK trans12_FlowVA_block; \
	COLLECTION trans12_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans12_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans12_FlowVA_ST_REV; \
	MENU trans12_FlowVA_ST_REV_page; \
	COMMAND trans12_FlowVA_ST_REV_read; \
	VARIABLE trans12_FlowVA_TAG_DESC; \
	MENU trans12_FlowVA_TAG_DESC_page; \
	COMMAND trans12_FlowVA_TAG_DESC_read; \
	COMMAND trans12_FlowVA_TAG_DESC_write; \
	VARIABLE trans12_FlowVA_STRATEGY; \
	MENU trans12_FlowVA_STRATEGY_page; \
	COMMAND trans12_FlowVA_STRATEGY_read; \
	COMMAND trans12_FlowVA_STRATEGY_write; \
	VARIABLE trans12_FlowVA_ALERT_KEY; \
	MENU trans12_FlowVA_ALERT_KEY_page; \
	COMMAND trans12_FlowVA_ALERT_KEY_read; \
	COMMAND trans12_FlowVA_ALERT_KEY_write; \
	VARIABLE trans12_FlowVA_TARGET_MODE; \
	MENU trans12_FlowVA_TARGET_MODE_page; \
	COMMAND trans12_FlowVA_TARGET_MODE_read; \
	COMMAND trans12_FlowVA_TARGET_MODE_write; \
	COLLECTION trans12_FlowVA_MODE_BLK; \
	VARIABLE trans12_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans12_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans12_FlowVA_MODE_BLK_Normal; \
	MENU trans12_FlowVA_MODE_BLK_page; \
	COMMAND trans12_FlowVA_MODE_BLK_read; \
	COLLECTION trans12_FlowVA_ALARM_SUM; \
	VARIABLE trans12_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans12_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans12_FlowVA_ALARM_SUM_Disabled; \
	MENU trans12_FlowVA_ALARM_SUM_page; \
	COMMAND trans12_FlowVA_ALARM_SUM_read; \
	VARIABLE trans12_FlowVA_CALIBR_FACTOR; \
	MENU trans12_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans12_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans12_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans12_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans12_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans12_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans12_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans12_FlowVA_NOMINAL_SIZE; \
	MENU trans12_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans12_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans12_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans12_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans12_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans12_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans12_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans12_FlowVA_VOLUME_FLOW; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans12_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans12_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans12_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans12_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans12_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans12_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans12_FlowVA_unit_nominal_size; \
	UNIT trans12_FlowVA_unit_volume_flow

#define USE_TRANS12_FLOWVA_MANDATORY_A \
	USE_TRANS12_FLOWVA_MANDATORY_BOTH; \
	MENU trans12_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS12_FLOWVA_MANDATORY_B \
	USE_TRANS12_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans12_FlowVA_VIEW_1; \
	MENU trans12_FlowVA_VIEW_1_page; \
	MENU trans12_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS12_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans12_FlowVA_ZERO_POINT; \
	MENU trans12_FlowVA_ZERO_POINT_page; \
	COMMAND trans12_FlowVA_ZERO_POINT_read; \
	COMMAND trans12_FlowVA_ZERO_POINT_write; \
	VARIABLE trans12_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans12_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans12_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans12_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans12_FlowVA_ZERO_POINT_UNIT; \
	MENU trans12_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans12_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans12_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans12_FlowVA_VIEW_2; \
	MENU trans12_FlowVA_VIEW_2_page; \
	COLLECTION trans12_FlowVA_VIEW_3; \
	MENU trans12_FlowVA_VIEW_3_page; \
	UNIT trans12_FlowVA_unit_zero_point

#define USE_TRANS12_FLOWVA_OPTIONAL_A \
	USE_TRANS12_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans12_FlowVA_VIEW_1; \
	MENU trans12_FlowVA_VIEW_1_page; \
	MENU trans12_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS12_FLOWVA_OPTIONAL_B \
	USE_TRANS12_FLOWVA_OPTIONAL_BOTH; \
	MENU trans12_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans12_FlowVA_)
#define USE_TRANS12_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans12_FlowVA_)
#define USE_TRANS12_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans12_FlowVA_)
#define USE_TRANS12_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans12_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_FLOWVA_MANDATORY_BOTH \
	BLOCK trans13_FlowVA_block; \
	COLLECTION trans13_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans13_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans13_FlowVA_ST_REV; \
	MENU trans13_FlowVA_ST_REV_page; \
	COMMAND trans13_FlowVA_ST_REV_read; \
	VARIABLE trans13_FlowVA_TAG_DESC; \
	MENU trans13_FlowVA_TAG_DESC_page; \
	COMMAND trans13_FlowVA_TAG_DESC_read; \
	COMMAND trans13_FlowVA_TAG_DESC_write; \
	VARIABLE trans13_FlowVA_STRATEGY; \
	MENU trans13_FlowVA_STRATEGY_page; \
	COMMAND trans13_FlowVA_STRATEGY_read; \
	COMMAND trans13_FlowVA_STRATEGY_write; \
	VARIABLE trans13_FlowVA_ALERT_KEY; \
	MENU trans13_FlowVA_ALERT_KEY_page; \
	COMMAND trans13_FlowVA_ALERT_KEY_read; \
	COMMAND trans13_FlowVA_ALERT_KEY_write; \
	VARIABLE trans13_FlowVA_TARGET_MODE; \
	MENU trans13_FlowVA_TARGET_MODE_page; \
	COMMAND trans13_FlowVA_TARGET_MODE_read; \
	COMMAND trans13_FlowVA_TARGET_MODE_write; \
	COLLECTION trans13_FlowVA_MODE_BLK; \
	VARIABLE trans13_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans13_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans13_FlowVA_MODE_BLK_Normal; \
	MENU trans13_FlowVA_MODE_BLK_page; \
	COMMAND trans13_FlowVA_MODE_BLK_read; \
	COLLECTION trans13_FlowVA_ALARM_SUM; \
	VARIABLE trans13_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans13_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans13_FlowVA_ALARM_SUM_Disabled; \
	MENU trans13_FlowVA_ALARM_SUM_page; \
	COMMAND trans13_FlowVA_ALARM_SUM_read; \
	VARIABLE trans13_FlowVA_CALIBR_FACTOR; \
	MENU trans13_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans13_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans13_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans13_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans13_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans13_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans13_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans13_FlowVA_NOMINAL_SIZE; \
	MENU trans13_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans13_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans13_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans13_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans13_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans13_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans13_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans13_FlowVA_VOLUME_FLOW; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans13_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans13_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans13_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans13_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans13_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans13_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans13_FlowVA_unit_nominal_size; \
	UNIT trans13_FlowVA_unit_volume_flow

#define USE_TRANS13_FLOWVA_MANDATORY_A \
	USE_TRANS13_FLOWVA_MANDATORY_BOTH; \
	MENU trans13_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS13_FLOWVA_MANDATORY_B \
	USE_TRANS13_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans13_FlowVA_VIEW_1; \
	MENU trans13_FlowVA_VIEW_1_page; \
	MENU trans13_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS13_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans13_FlowVA_ZERO_POINT; \
	MENU trans13_FlowVA_ZERO_POINT_page; \
	COMMAND trans13_FlowVA_ZERO_POINT_read; \
	COMMAND trans13_FlowVA_ZERO_POINT_write; \
	VARIABLE trans13_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans13_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans13_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans13_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans13_FlowVA_ZERO_POINT_UNIT; \
	MENU trans13_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans13_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans13_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans13_FlowVA_VIEW_2; \
	MENU trans13_FlowVA_VIEW_2_page; \
	COLLECTION trans13_FlowVA_VIEW_3; \
	MENU trans13_FlowVA_VIEW_3_page; \
	UNIT trans13_FlowVA_unit_zero_point

#define USE_TRANS13_FLOWVA_OPTIONAL_A \
	USE_TRANS13_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans13_FlowVA_VIEW_1; \
	MENU trans13_FlowVA_VIEW_1_page; \
	MENU trans13_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS13_FLOWVA_OPTIONAL_B \
	USE_TRANS13_FLOWVA_OPTIONAL_BOTH; \
	MENU trans13_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans13_FlowVA_)
#define USE_TRANS13_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans13_FlowVA_)
#define USE_TRANS13_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans13_FlowVA_)
#define USE_TRANS13_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans13_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_FLOWVA_MANDATORY_BOTH \
	BLOCK trans14_FlowVA_block; \
	COLLECTION trans14_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans14_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans14_FlowVA_ST_REV; \
	MENU trans14_FlowVA_ST_REV_page; \
	COMMAND trans14_FlowVA_ST_REV_read; \
	VARIABLE trans14_FlowVA_TAG_DESC; \
	MENU trans14_FlowVA_TAG_DESC_page; \
	COMMAND trans14_FlowVA_TAG_DESC_read; \
	COMMAND trans14_FlowVA_TAG_DESC_write; \
	VARIABLE trans14_FlowVA_STRATEGY; \
	MENU trans14_FlowVA_STRATEGY_page; \
	COMMAND trans14_FlowVA_STRATEGY_read; \
	COMMAND trans14_FlowVA_STRATEGY_write; \
	VARIABLE trans14_FlowVA_ALERT_KEY; \
	MENU trans14_FlowVA_ALERT_KEY_page; \
	COMMAND trans14_FlowVA_ALERT_KEY_read; \
	COMMAND trans14_FlowVA_ALERT_KEY_write; \
	VARIABLE trans14_FlowVA_TARGET_MODE; \
	MENU trans14_FlowVA_TARGET_MODE_page; \
	COMMAND trans14_FlowVA_TARGET_MODE_read; \
	COMMAND trans14_FlowVA_TARGET_MODE_write; \
	COLLECTION trans14_FlowVA_MODE_BLK; \
	VARIABLE trans14_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans14_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans14_FlowVA_MODE_BLK_Normal; \
	MENU trans14_FlowVA_MODE_BLK_page; \
	COMMAND trans14_FlowVA_MODE_BLK_read; \
	COLLECTION trans14_FlowVA_ALARM_SUM; \
	VARIABLE trans14_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans14_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans14_FlowVA_ALARM_SUM_Disabled; \
	MENU trans14_FlowVA_ALARM_SUM_page; \
	COMMAND trans14_FlowVA_ALARM_SUM_read; \
	VARIABLE trans14_FlowVA_CALIBR_FACTOR; \
	MENU trans14_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans14_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans14_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans14_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans14_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans14_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans14_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans14_FlowVA_NOMINAL_SIZE; \
	MENU trans14_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans14_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans14_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans14_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans14_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans14_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans14_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans14_FlowVA_VOLUME_FLOW; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans14_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans14_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans14_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans14_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans14_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans14_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans14_FlowVA_unit_nominal_size; \
	UNIT trans14_FlowVA_unit_volume_flow

#define USE_TRANS14_FLOWVA_MANDATORY_A \
	USE_TRANS14_FLOWVA_MANDATORY_BOTH; \
	MENU trans14_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS14_FLOWVA_MANDATORY_B \
	USE_TRANS14_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans14_FlowVA_VIEW_1; \
	MENU trans14_FlowVA_VIEW_1_page; \
	MENU trans14_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS14_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans14_FlowVA_ZERO_POINT; \
	MENU trans14_FlowVA_ZERO_POINT_page; \
	COMMAND trans14_FlowVA_ZERO_POINT_read; \
	COMMAND trans14_FlowVA_ZERO_POINT_write; \
	VARIABLE trans14_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans14_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans14_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans14_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans14_FlowVA_ZERO_POINT_UNIT; \
	MENU trans14_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans14_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans14_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans14_FlowVA_VIEW_2; \
	MENU trans14_FlowVA_VIEW_2_page; \
	COLLECTION trans14_FlowVA_VIEW_3; \
	MENU trans14_FlowVA_VIEW_3_page; \
	UNIT trans14_FlowVA_unit_zero_point

#define USE_TRANS14_FLOWVA_OPTIONAL_A \
	USE_TRANS14_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans14_FlowVA_VIEW_1; \
	MENU trans14_FlowVA_VIEW_1_page; \
	MENU trans14_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS14_FLOWVA_OPTIONAL_B \
	USE_TRANS14_FLOWVA_OPTIONAL_BOTH; \
	MENU trans14_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans14_FlowVA_)
#define USE_TRANS14_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans14_FlowVA_)
#define USE_TRANS14_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans14_FlowVA_)
#define USE_TRANS14_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans14_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_FLOWVA_MANDATORY_BOTH \
	BLOCK trans15_FlowVA_block; \
	COLLECTION trans15_FlowVA_BLOCK_OBJECT; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Class; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_FlowVA_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_FlowVA_BLOCK_OBJECT_page; \
	COMMAND trans15_FlowVA_BLOCK_OBJECT_read; \
	VARIABLE trans15_FlowVA_ST_REV; \
	MENU trans15_FlowVA_ST_REV_page; \
	COMMAND trans15_FlowVA_ST_REV_read; \
	VARIABLE trans15_FlowVA_TAG_DESC; \
	MENU trans15_FlowVA_TAG_DESC_page; \
	COMMAND trans15_FlowVA_TAG_DESC_read; \
	COMMAND trans15_FlowVA_TAG_DESC_write; \
	VARIABLE trans15_FlowVA_STRATEGY; \
	MENU trans15_FlowVA_STRATEGY_page; \
	COMMAND trans15_FlowVA_STRATEGY_read; \
	COMMAND trans15_FlowVA_STRATEGY_write; \
	VARIABLE trans15_FlowVA_ALERT_KEY; \
	MENU trans15_FlowVA_ALERT_KEY_page; \
	COMMAND trans15_FlowVA_ALERT_KEY_read; \
	COMMAND trans15_FlowVA_ALERT_KEY_write; \
	VARIABLE trans15_FlowVA_TARGET_MODE; \
	MENU trans15_FlowVA_TARGET_MODE_page; \
	COMMAND trans15_FlowVA_TARGET_MODE_read; \
	COMMAND trans15_FlowVA_TARGET_MODE_write; \
	COLLECTION trans15_FlowVA_MODE_BLK; \
	VARIABLE trans15_FlowVA_MODE_BLK_Actual; \
	VARIABLE trans15_FlowVA_MODE_BLK_Permitted; \
	VARIABLE trans15_FlowVA_MODE_BLK_Normal; \
	MENU trans15_FlowVA_MODE_BLK_page; \
	COMMAND trans15_FlowVA_MODE_BLK_read; \
	COLLECTION trans15_FlowVA_ALARM_SUM; \
	VARIABLE trans15_FlowVA_ALARM_SUM_Current; \
	VARIABLE trans15_FlowVA_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_FlowVA_ALARM_SUM_Unreported; \
	VARIABLE trans15_FlowVA_ALARM_SUM_Disabled; \
	MENU trans15_FlowVA_ALARM_SUM_page; \
	COMMAND trans15_FlowVA_ALARM_SUM_read; \
	VARIABLE trans15_FlowVA_CALIBR_FACTOR; \
	MENU trans15_FlowVA_CALIBR_FACTOR_page; \
	COMMAND trans15_FlowVA_CALIBR_FACTOR_read; \
	COMMAND trans15_FlowVA_CALIBR_FACTOR_write; \
	VARIABLE trans15_FlowVA_LOW_FLOW_CUTOFF; \
	MENU trans15_FlowVA_LOW_FLOW_CUTOFF_page; \
	COMMAND trans15_FlowVA_LOW_FLOW_CUTOFF_read; \
	COMMAND trans15_FlowVA_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans15_FlowVA_NOMINAL_SIZE; \
	MENU trans15_FlowVA_NOMINAL_SIZE_page; \
	COMMAND trans15_FlowVA_NOMINAL_SIZE_read; \
	COMMAND trans15_FlowVA_NOMINAL_SIZE_write; \
	VARIABLE trans15_FlowVA_NOMINAL_SIZE_UNITS; \
	MENU trans15_FlowVA_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans15_FlowVA_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans15_FlowVA_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans15_FlowVA_VOLUME_FLOW; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_Value; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_Status_Limit; \
	MENU trans15_FlowVA_VOLUME_FLOW_page; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_read; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_UNITS; \
	MENU trans15_FlowVA_VOLUME_FLOW_UNITS_page; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_UNITS_read; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_LO_LIMIT; \
	MENU trans15_FlowVA_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans15_FlowVA_VOLUME_FLOW_HI_LIMIT; \
	MENU trans15_FlowVA_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans15_FlowVA_VOLUME_FLOW_HI_LIMIT_write; \
	UNIT trans15_FlowVA_unit_nominal_size; \
	UNIT trans15_FlowVA_unit_volume_flow

#define USE_TRANS15_FLOWVA_MANDATORY_A \
	USE_TRANS15_FLOWVA_MANDATORY_BOTH; \
	MENU trans15_FlowVA_Simple_Dialog_Mandatory_A

#define USE_TRANS15_FLOWVA_MANDATORY_B \
	USE_TRANS15_FLOWVA_MANDATORY_BOTH; \
	COLLECTION trans15_FlowVA_VIEW_1; \
	MENU trans15_FlowVA_VIEW_1_page; \
	MENU trans15_FlowVA_Simple_Dialog_Mandatory_B

#define USE_TRANS15_FLOWVA_OPTIONAL_BOTH \
	VARIABLE trans15_FlowVA_ZERO_POINT; \
	MENU trans15_FlowVA_ZERO_POINT_page; \
	COMMAND trans15_FlowVA_ZERO_POINT_read; \
	COMMAND trans15_FlowVA_ZERO_POINT_write; \
	VARIABLE trans15_FlowVA_ZERO_POINT_ADJUST; \
	MENU trans15_FlowVA_ZERO_POINT_ADJUST_page; \
	COMMAND trans15_FlowVA_ZERO_POINT_ADJUST_read; \
	COMMAND trans15_FlowVA_ZERO_POINT_ADJUST_write; \
	VARIABLE trans15_FlowVA_ZERO_POINT_UNIT; \
	MENU trans15_FlowVA_ZERO_POINT_UNIT_page; \
	COMMAND trans15_FlowVA_ZERO_POINT_UNIT_read; \
	COMMAND trans15_FlowVA_ZERO_POINT_UNIT_write; \
	COLLECTION trans15_FlowVA_VIEW_2; \
	MENU trans15_FlowVA_VIEW_2_page; \
	COLLECTION trans15_FlowVA_VIEW_3; \
	MENU trans15_FlowVA_VIEW_3_page; \
	UNIT trans15_FlowVA_unit_zero_point

#define USE_TRANS15_FLOWVA_OPTIONAL_A \
	USE_TRANS15_FLOWVA_OPTIONAL_BOTH; \
	COLLECTION trans15_FlowVA_VIEW_1; \
	MENU trans15_FlowVA_VIEW_1_page; \
	MENU trans15_FlowVA_Simple_Dialog_Optional_A

#define USE_TRANS15_FLOWVA_OPTIONAL_B \
	USE_TRANS15_FLOWVA_OPTIONAL_BOTH; \
	MENU trans15_FlowVA_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_FLOWVA_MANDATORY_A USE_TRANS_FLOWVA_MANDATORY_A(trans15_FlowVA_)
#define USE_TRANS15_FLOWVA_MANDATORY_B USE_TRANS_FLOWVA_MANDATORY_B(trans15_FlowVA_)
#define USE_TRANS15_FLOWVA_OPTIONAL_A  USE_TRANS_FLOWVA_OPTIONAL_A(trans15_FlowVA_)
#define USE_TRANS15_FLOWVA_OPTIONAL_B  USE_TRANS_FLOWVA_OPTIONAL_B(trans15_FlowVA_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_FLOWV_MANDATORY_BOTH \
	BLOCK trans1_FlowV_block; \
	COLLECTION trans1_FlowV_BLOCK_OBJECT; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans1_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans1_FlowV_ST_REV; \
	MENU trans1_FlowV_ST_REV_page; \
	COMMAND trans1_FlowV_ST_REV_read; \
	VARIABLE trans1_FlowV_TAG_DESC; \
	MENU trans1_FlowV_TAG_DESC_page; \
	COMMAND trans1_FlowV_TAG_DESC_read; \
	COMMAND trans1_FlowV_TAG_DESC_write; \
	VARIABLE trans1_FlowV_STRATEGY; \
	MENU trans1_FlowV_STRATEGY_page; \
	COMMAND trans1_FlowV_STRATEGY_read; \
	COMMAND trans1_FlowV_STRATEGY_write; \
	VARIABLE trans1_FlowV_ALERT_KEY; \
	MENU trans1_FlowV_ALERT_KEY_page; \
	COMMAND trans1_FlowV_ALERT_KEY_read; \
	COMMAND trans1_FlowV_ALERT_KEY_write; \
	VARIABLE trans1_FlowV_TARGET_MODE; \
	MENU trans1_FlowV_TARGET_MODE_page; \
	COMMAND trans1_FlowV_TARGET_MODE_read; \
	COMMAND trans1_FlowV_TARGET_MODE_write; \
	COLLECTION trans1_FlowV_MODE_BLK; \
	VARIABLE trans1_FlowV_MODE_BLK_Actual; \
	VARIABLE trans1_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans1_FlowV_MODE_BLK_Normal; \
	MENU trans1_FlowV_MODE_BLK_page; \
	COMMAND trans1_FlowV_MODE_BLK_read; \
	COLLECTION trans1_FlowV_ALARM_SUM; \
	VARIABLE trans1_FlowV_ALARM_SUM_Current; \
	VARIABLE trans1_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans1_FlowV_ALARM_SUM_Disabled; \
	MENU trans1_FlowV_ALARM_SUM_page; \
	COMMAND trans1_FlowV_ALARM_SUM_read; \
	VARIABLE trans1_FlowV_CALIBR_FACTOR; \
	MENU trans1_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans1_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans1_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans1_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans1_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans1_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans1_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans1_FlowV_NOMINAL_SIZE; \
	MENU trans1_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans1_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans1_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans1_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans1_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans1_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans1_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans1_FlowV_VOLUME_FLOW; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans1_FlowV_VOLUME_FLOW_page; \
	COMMAND trans1_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans1_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans1_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans1_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans1_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans1_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans1_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans1_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans1_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans1_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans1_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans1_FlowV_VORTEX_FREQ; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans1_FlowV_VORTEX_FREQ_page; \
	COMMAND trans1_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans1_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans1_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans1_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans1_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans1_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans1_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans1_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans1_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans1_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans1_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans1_FlowV_unit_nominal_size; \
	UNIT trans1_FlowV_unit_volume_flow; \
	UNIT trans1_FlowV_unit_vortex_frequency

#define USE_TRANS1_FLOWV_MANDATORY_A \
	USE_TRANS1_FLOWV_MANDATORY_BOTH; \
	MENU trans1_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS1_FLOWV_MANDATORY_B \
	USE_TRANS1_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans1_FlowV_VIEW_1; \
	MENU trans1_FlowV_VIEW_1_page; \
	MENU trans1_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS1_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans1_FlowV_VIEW_2; \
	MENU trans1_FlowV_VIEW_2_page; \
	COLLECTION trans1_FlowV_VIEW_3; \
	MENU trans1_FlowV_VIEW_3_page

#define USE_TRANS1_FLOWV_OPTIONAL_A \
	USE_TRANS1_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans1_FlowV_VIEW_1; \
	MENU trans1_FlowV_VIEW_1_page; \
	MENU trans1_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS1_FLOWV_OPTIONAL_B \
	USE_TRANS1_FLOWV_OPTIONAL_BOTH; \
	MENU trans1_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_FLOWV_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CALIBR_FACTOR; \
	MENU prefix ## CALIBR_FACTOR_page; \
	COMMAND prefix ## CALIBR_FACTOR_read; \
	COMMAND prefix ## CALIBR_FACTOR_write; \
	VARIABLE prefix ## LOW_FLOW_CUTOFF; \
	MENU prefix ## LOW_FLOW_CUTOFF_page; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_read; \
	COMMAND prefix ## LOW_FLOW_CUTOFF_write; \
	VARIABLE prefix ## NOMINAL_SIZE; \
	MENU prefix ## NOMINAL_SIZE_page; \
	COMMAND prefix ## NOMINAL_SIZE_read; \
	COMMAND prefix ## NOMINAL_SIZE_write; \
	VARIABLE prefix ## NOMINAL_SIZE_UNITS; \
	MENU prefix ## NOMINAL_SIZE_UNITS_page; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_read; \
	COMMAND prefix ## NOMINAL_SIZE_UNITS_write; \
	COLLECTION prefix ## VOLUME_FLOW; \
	VARIABLE prefix ## VOLUME_FLOW_Value; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Condensed; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Quality; \
	VARIABLE prefix ## VOLUME_FLOW_Status_Limit; \
	MENU prefix ## VOLUME_FLOW_page; \
	COMMAND prefix ## VOLUME_FLOW_read; \
	VARIABLE prefix ## VOLUME_FLOW_UNITS; \
	MENU prefix ## VOLUME_FLOW_UNITS_page; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_read; \
	COMMAND prefix ## VOLUME_FLOW_UNITS_write; \
	VARIABLE prefix ## VOLUME_FLOW_LO_LIMIT; \
	MENU prefix ## VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE prefix ## VOLUME_FLOW_HI_LIMIT; \
	MENU prefix ## VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND prefix ## VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION prefix ## VORTEX_FREQ; \
	VARIABLE prefix ## VORTEX_FREQ_Value; \
	VARIABLE prefix ## VORTEX_FREQ_Status_Condensed; \
	VARIABLE prefix ## VORTEX_FREQ_Status_Quality; \
	VARIABLE prefix ## VORTEX_FREQ_Status_Limit; \
	MENU prefix ## VORTEX_FREQ_page; \
	COMMAND prefix ## VORTEX_FREQ_read; \
	VARIABLE prefix ## VORTEX_FREQ_UNITS; \
	MENU prefix ## VORTEX_FREQ_UNITS_page; \
	COMMAND prefix ## VORTEX_FREQ_UNITS_read; \
	COMMAND prefix ## VORTEX_FREQ_UNITS_write; \
	VARIABLE prefix ## VORTEX_FREQ_LO_LIMIT; \
	MENU prefix ## VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND prefix ## VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND prefix ## VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE prefix ## VORTEX_FREQ_HI_LIMIT; \
	MENU prefix ## VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND prefix ## VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND prefix ## VORTEX_FREQ_HI_LIMIT_write; \
	UNIT prefix ## unit_nominal_size; \
	UNIT prefix ## unit_volume_flow; \
	UNIT prefix ## unit_vortex_frequency

#define USE_TRANS_FLOWV_MANDATORY_A(prefix) \
	USE_TRANS_FLOWV_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_FLOWV_MANDATORY_B(prefix) \
	USE_TRANS_FLOWV_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_FLOWV_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_FLOWV_OPTIONAL_A(prefix) \
	USE_TRANS_FLOWV_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_FLOWV_OPTIONAL_B(prefix) \
	USE_TRANS_FLOWV_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans1_FlowV_)
#define USE_TRANS1_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans1_FlowV_)
#define USE_TRANS1_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans1_FlowV_)
#define USE_TRANS1_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans1_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_FLOWV_MANDATORY_BOTH \
	BLOCK trans2_FlowV_block; \
	COLLECTION trans2_FlowV_BLOCK_OBJECT; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans2_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans2_FlowV_ST_REV; \
	MENU trans2_FlowV_ST_REV_page; \
	COMMAND trans2_FlowV_ST_REV_read; \
	VARIABLE trans2_FlowV_TAG_DESC; \
	MENU trans2_FlowV_TAG_DESC_page; \
	COMMAND trans2_FlowV_TAG_DESC_read; \
	COMMAND trans2_FlowV_TAG_DESC_write; \
	VARIABLE trans2_FlowV_STRATEGY; \
	MENU trans2_FlowV_STRATEGY_page; \
	COMMAND trans2_FlowV_STRATEGY_read; \
	COMMAND trans2_FlowV_STRATEGY_write; \
	VARIABLE trans2_FlowV_ALERT_KEY; \
	MENU trans2_FlowV_ALERT_KEY_page; \
	COMMAND trans2_FlowV_ALERT_KEY_read; \
	COMMAND trans2_FlowV_ALERT_KEY_write; \
	VARIABLE trans2_FlowV_TARGET_MODE; \
	MENU trans2_FlowV_TARGET_MODE_page; \
	COMMAND trans2_FlowV_TARGET_MODE_read; \
	COMMAND trans2_FlowV_TARGET_MODE_write; \
	COLLECTION trans2_FlowV_MODE_BLK; \
	VARIABLE trans2_FlowV_MODE_BLK_Actual; \
	VARIABLE trans2_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans2_FlowV_MODE_BLK_Normal; \
	MENU trans2_FlowV_MODE_BLK_page; \
	COMMAND trans2_FlowV_MODE_BLK_read; \
	COLLECTION trans2_FlowV_ALARM_SUM; \
	VARIABLE trans2_FlowV_ALARM_SUM_Current; \
	VARIABLE trans2_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans2_FlowV_ALARM_SUM_Disabled; \
	MENU trans2_FlowV_ALARM_SUM_page; \
	COMMAND trans2_FlowV_ALARM_SUM_read; \
	VARIABLE trans2_FlowV_CALIBR_FACTOR; \
	MENU trans2_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans2_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans2_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans2_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans2_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans2_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans2_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans2_FlowV_NOMINAL_SIZE; \
	MENU trans2_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans2_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans2_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans2_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans2_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans2_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans2_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans2_FlowV_VOLUME_FLOW; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans2_FlowV_VOLUME_FLOW_page; \
	COMMAND trans2_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans2_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans2_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans2_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans2_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans2_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans2_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans2_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans2_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans2_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans2_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans2_FlowV_VORTEX_FREQ; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans2_FlowV_VORTEX_FREQ_page; \
	COMMAND trans2_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans2_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans2_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans2_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans2_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans2_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans2_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans2_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans2_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans2_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans2_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans2_FlowV_unit_nominal_size; \
	UNIT trans2_FlowV_unit_volume_flow; \
	UNIT trans2_FlowV_unit_vortex_frequency

#define USE_TRANS2_FLOWV_MANDATORY_A \
	USE_TRANS2_FLOWV_MANDATORY_BOTH; \
	MENU trans2_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS2_FLOWV_MANDATORY_B \
	USE_TRANS2_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans2_FlowV_VIEW_1; \
	MENU trans2_FlowV_VIEW_1_page; \
	MENU trans2_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS2_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans2_FlowV_VIEW_2; \
	MENU trans2_FlowV_VIEW_2_page; \
	COLLECTION trans2_FlowV_VIEW_3; \
	MENU trans2_FlowV_VIEW_3_page

#define USE_TRANS2_FLOWV_OPTIONAL_A \
	USE_TRANS2_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans2_FlowV_VIEW_1; \
	MENU trans2_FlowV_VIEW_1_page; \
	MENU trans2_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS2_FLOWV_OPTIONAL_B \
	USE_TRANS2_FLOWV_OPTIONAL_BOTH; \
	MENU trans2_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans2_FlowV_)
#define USE_TRANS2_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans2_FlowV_)
#define USE_TRANS2_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans2_FlowV_)
#define USE_TRANS2_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans2_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_FLOWV_MANDATORY_BOTH \
	BLOCK trans3_FlowV_block; \
	COLLECTION trans3_FlowV_BLOCK_OBJECT; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans3_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans3_FlowV_ST_REV; \
	MENU trans3_FlowV_ST_REV_page; \
	COMMAND trans3_FlowV_ST_REV_read; \
	VARIABLE trans3_FlowV_TAG_DESC; \
	MENU trans3_FlowV_TAG_DESC_page; \
	COMMAND trans3_FlowV_TAG_DESC_read; \
	COMMAND trans3_FlowV_TAG_DESC_write; \
	VARIABLE trans3_FlowV_STRATEGY; \
	MENU trans3_FlowV_STRATEGY_page; \
	COMMAND trans3_FlowV_STRATEGY_read; \
	COMMAND trans3_FlowV_STRATEGY_write; \
	VARIABLE trans3_FlowV_ALERT_KEY; \
	MENU trans3_FlowV_ALERT_KEY_page; \
	COMMAND trans3_FlowV_ALERT_KEY_read; \
	COMMAND trans3_FlowV_ALERT_KEY_write; \
	VARIABLE trans3_FlowV_TARGET_MODE; \
	MENU trans3_FlowV_TARGET_MODE_page; \
	COMMAND trans3_FlowV_TARGET_MODE_read; \
	COMMAND trans3_FlowV_TARGET_MODE_write; \
	COLLECTION trans3_FlowV_MODE_BLK; \
	VARIABLE trans3_FlowV_MODE_BLK_Actual; \
	VARIABLE trans3_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans3_FlowV_MODE_BLK_Normal; \
	MENU trans3_FlowV_MODE_BLK_page; \
	COMMAND trans3_FlowV_MODE_BLK_read; \
	COLLECTION trans3_FlowV_ALARM_SUM; \
	VARIABLE trans3_FlowV_ALARM_SUM_Current; \
	VARIABLE trans3_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans3_FlowV_ALARM_SUM_Disabled; \
	MENU trans3_FlowV_ALARM_SUM_page; \
	COMMAND trans3_FlowV_ALARM_SUM_read; \
	VARIABLE trans3_FlowV_CALIBR_FACTOR; \
	MENU trans3_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans3_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans3_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans3_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans3_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans3_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans3_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans3_FlowV_NOMINAL_SIZE; \
	MENU trans3_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans3_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans3_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans3_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans3_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans3_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans3_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans3_FlowV_VOLUME_FLOW; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans3_FlowV_VOLUME_FLOW_page; \
	COMMAND trans3_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans3_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans3_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans3_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans3_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans3_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans3_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans3_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans3_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans3_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans3_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans3_FlowV_VORTEX_FREQ; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans3_FlowV_VORTEX_FREQ_page; \
	COMMAND trans3_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans3_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans3_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans3_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans3_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans3_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans3_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans3_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans3_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans3_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans3_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans3_FlowV_unit_nominal_size; \
	UNIT trans3_FlowV_unit_volume_flow; \
	UNIT trans3_FlowV_unit_vortex_frequency

#define USE_TRANS3_FLOWV_MANDATORY_A \
	USE_TRANS3_FLOWV_MANDATORY_BOTH; \
	MENU trans3_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS3_FLOWV_MANDATORY_B \
	USE_TRANS3_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans3_FlowV_VIEW_1; \
	MENU trans3_FlowV_VIEW_1_page; \
	MENU trans3_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS3_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans3_FlowV_VIEW_2; \
	MENU trans3_FlowV_VIEW_2_page; \
	COLLECTION trans3_FlowV_VIEW_3; \
	MENU trans3_FlowV_VIEW_3_page

#define USE_TRANS3_FLOWV_OPTIONAL_A \
	USE_TRANS3_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans3_FlowV_VIEW_1; \
	MENU trans3_FlowV_VIEW_1_page; \
	MENU trans3_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS3_FLOWV_OPTIONAL_B \
	USE_TRANS3_FLOWV_OPTIONAL_BOTH; \
	MENU trans3_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans3_FlowV_)
#define USE_TRANS3_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans3_FlowV_)
#define USE_TRANS3_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans3_FlowV_)
#define USE_TRANS3_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans3_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_FLOWV_MANDATORY_BOTH \
	BLOCK trans4_FlowV_block; \
	COLLECTION trans4_FlowV_BLOCK_OBJECT; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans4_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans4_FlowV_ST_REV; \
	MENU trans4_FlowV_ST_REV_page; \
	COMMAND trans4_FlowV_ST_REV_read; \
	VARIABLE trans4_FlowV_TAG_DESC; \
	MENU trans4_FlowV_TAG_DESC_page; \
	COMMAND trans4_FlowV_TAG_DESC_read; \
	COMMAND trans4_FlowV_TAG_DESC_write; \
	VARIABLE trans4_FlowV_STRATEGY; \
	MENU trans4_FlowV_STRATEGY_page; \
	COMMAND trans4_FlowV_STRATEGY_read; \
	COMMAND trans4_FlowV_STRATEGY_write; \
	VARIABLE trans4_FlowV_ALERT_KEY; \
	MENU trans4_FlowV_ALERT_KEY_page; \
	COMMAND trans4_FlowV_ALERT_KEY_read; \
	COMMAND trans4_FlowV_ALERT_KEY_write; \
	VARIABLE trans4_FlowV_TARGET_MODE; \
	MENU trans4_FlowV_TARGET_MODE_page; \
	COMMAND trans4_FlowV_TARGET_MODE_read; \
	COMMAND trans4_FlowV_TARGET_MODE_write; \
	COLLECTION trans4_FlowV_MODE_BLK; \
	VARIABLE trans4_FlowV_MODE_BLK_Actual; \
	VARIABLE trans4_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans4_FlowV_MODE_BLK_Normal; \
	MENU trans4_FlowV_MODE_BLK_page; \
	COMMAND trans4_FlowV_MODE_BLK_read; \
	COLLECTION trans4_FlowV_ALARM_SUM; \
	VARIABLE trans4_FlowV_ALARM_SUM_Current; \
	VARIABLE trans4_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans4_FlowV_ALARM_SUM_Disabled; \
	MENU trans4_FlowV_ALARM_SUM_page; \
	COMMAND trans4_FlowV_ALARM_SUM_read; \
	VARIABLE trans4_FlowV_CALIBR_FACTOR; \
	MENU trans4_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans4_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans4_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans4_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans4_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans4_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans4_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans4_FlowV_NOMINAL_SIZE; \
	MENU trans4_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans4_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans4_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans4_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans4_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans4_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans4_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans4_FlowV_VOLUME_FLOW; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans4_FlowV_VOLUME_FLOW_page; \
	COMMAND trans4_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans4_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans4_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans4_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans4_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans4_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans4_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans4_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans4_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans4_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans4_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans4_FlowV_VORTEX_FREQ; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans4_FlowV_VORTEX_FREQ_page; \
	COMMAND trans4_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans4_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans4_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans4_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans4_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans4_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans4_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans4_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans4_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans4_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans4_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans4_FlowV_unit_nominal_size; \
	UNIT trans4_FlowV_unit_volume_flow; \
	UNIT trans4_FlowV_unit_vortex_frequency

#define USE_TRANS4_FLOWV_MANDATORY_A \
	USE_TRANS4_FLOWV_MANDATORY_BOTH; \
	MENU trans4_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS4_FLOWV_MANDATORY_B \
	USE_TRANS4_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans4_FlowV_VIEW_1; \
	MENU trans4_FlowV_VIEW_1_page; \
	MENU trans4_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS4_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans4_FlowV_VIEW_2; \
	MENU trans4_FlowV_VIEW_2_page; \
	COLLECTION trans4_FlowV_VIEW_3; \
	MENU trans4_FlowV_VIEW_3_page

#define USE_TRANS4_FLOWV_OPTIONAL_A \
	USE_TRANS4_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans4_FlowV_VIEW_1; \
	MENU trans4_FlowV_VIEW_1_page; \
	MENU trans4_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS4_FLOWV_OPTIONAL_B \
	USE_TRANS4_FLOWV_OPTIONAL_BOTH; \
	MENU trans4_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans4_FlowV_)
#define USE_TRANS4_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans4_FlowV_)
#define USE_TRANS4_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans4_FlowV_)
#define USE_TRANS4_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans4_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_FLOWV_MANDATORY_BOTH \
	BLOCK trans5_FlowV_block; \
	COLLECTION trans5_FlowV_BLOCK_OBJECT; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans5_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans5_FlowV_ST_REV; \
	MENU trans5_FlowV_ST_REV_page; \
	COMMAND trans5_FlowV_ST_REV_read; \
	VARIABLE trans5_FlowV_TAG_DESC; \
	MENU trans5_FlowV_TAG_DESC_page; \
	COMMAND trans5_FlowV_TAG_DESC_read; \
	COMMAND trans5_FlowV_TAG_DESC_write; \
	VARIABLE trans5_FlowV_STRATEGY; \
	MENU trans5_FlowV_STRATEGY_page; \
	COMMAND trans5_FlowV_STRATEGY_read; \
	COMMAND trans5_FlowV_STRATEGY_write; \
	VARIABLE trans5_FlowV_ALERT_KEY; \
	MENU trans5_FlowV_ALERT_KEY_page; \
	COMMAND trans5_FlowV_ALERT_KEY_read; \
	COMMAND trans5_FlowV_ALERT_KEY_write; \
	VARIABLE trans5_FlowV_TARGET_MODE; \
	MENU trans5_FlowV_TARGET_MODE_page; \
	COMMAND trans5_FlowV_TARGET_MODE_read; \
	COMMAND trans5_FlowV_TARGET_MODE_write; \
	COLLECTION trans5_FlowV_MODE_BLK; \
	VARIABLE trans5_FlowV_MODE_BLK_Actual; \
	VARIABLE trans5_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans5_FlowV_MODE_BLK_Normal; \
	MENU trans5_FlowV_MODE_BLK_page; \
	COMMAND trans5_FlowV_MODE_BLK_read; \
	COLLECTION trans5_FlowV_ALARM_SUM; \
	VARIABLE trans5_FlowV_ALARM_SUM_Current; \
	VARIABLE trans5_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans5_FlowV_ALARM_SUM_Disabled; \
	MENU trans5_FlowV_ALARM_SUM_page; \
	COMMAND trans5_FlowV_ALARM_SUM_read; \
	VARIABLE trans5_FlowV_CALIBR_FACTOR; \
	MENU trans5_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans5_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans5_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans5_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans5_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans5_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans5_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans5_FlowV_NOMINAL_SIZE; \
	MENU trans5_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans5_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans5_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans5_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans5_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans5_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans5_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans5_FlowV_VOLUME_FLOW; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans5_FlowV_VOLUME_FLOW_page; \
	COMMAND trans5_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans5_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans5_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans5_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans5_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans5_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans5_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans5_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans5_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans5_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans5_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans5_FlowV_VORTEX_FREQ; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans5_FlowV_VORTEX_FREQ_page; \
	COMMAND trans5_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans5_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans5_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans5_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans5_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans5_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans5_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans5_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans5_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans5_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans5_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans5_FlowV_unit_nominal_size; \
	UNIT trans5_FlowV_unit_volume_flow; \
	UNIT trans5_FlowV_unit_vortex_frequency

#define USE_TRANS5_FLOWV_MANDATORY_A \
	USE_TRANS5_FLOWV_MANDATORY_BOTH; \
	MENU trans5_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS5_FLOWV_MANDATORY_B \
	USE_TRANS5_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans5_FlowV_VIEW_1; \
	MENU trans5_FlowV_VIEW_1_page; \
	MENU trans5_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS5_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans5_FlowV_VIEW_2; \
	MENU trans5_FlowV_VIEW_2_page; \
	COLLECTION trans5_FlowV_VIEW_3; \
	MENU trans5_FlowV_VIEW_3_page

#define USE_TRANS5_FLOWV_OPTIONAL_A \
	USE_TRANS5_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans5_FlowV_VIEW_1; \
	MENU trans5_FlowV_VIEW_1_page; \
	MENU trans5_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS5_FLOWV_OPTIONAL_B \
	USE_TRANS5_FLOWV_OPTIONAL_BOTH; \
	MENU trans5_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans5_FlowV_)
#define USE_TRANS5_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans5_FlowV_)
#define USE_TRANS5_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans5_FlowV_)
#define USE_TRANS5_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans5_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_FLOWV_MANDATORY_BOTH \
	BLOCK trans6_FlowV_block; \
	COLLECTION trans6_FlowV_BLOCK_OBJECT; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans6_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans6_FlowV_ST_REV; \
	MENU trans6_FlowV_ST_REV_page; \
	COMMAND trans6_FlowV_ST_REV_read; \
	VARIABLE trans6_FlowV_TAG_DESC; \
	MENU trans6_FlowV_TAG_DESC_page; \
	COMMAND trans6_FlowV_TAG_DESC_read; \
	COMMAND trans6_FlowV_TAG_DESC_write; \
	VARIABLE trans6_FlowV_STRATEGY; \
	MENU trans6_FlowV_STRATEGY_page; \
	COMMAND trans6_FlowV_STRATEGY_read; \
	COMMAND trans6_FlowV_STRATEGY_write; \
	VARIABLE trans6_FlowV_ALERT_KEY; \
	MENU trans6_FlowV_ALERT_KEY_page; \
	COMMAND trans6_FlowV_ALERT_KEY_read; \
	COMMAND trans6_FlowV_ALERT_KEY_write; \
	VARIABLE trans6_FlowV_TARGET_MODE; \
	MENU trans6_FlowV_TARGET_MODE_page; \
	COMMAND trans6_FlowV_TARGET_MODE_read; \
	COMMAND trans6_FlowV_TARGET_MODE_write; \
	COLLECTION trans6_FlowV_MODE_BLK; \
	VARIABLE trans6_FlowV_MODE_BLK_Actual; \
	VARIABLE trans6_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans6_FlowV_MODE_BLK_Normal; \
	MENU trans6_FlowV_MODE_BLK_page; \
	COMMAND trans6_FlowV_MODE_BLK_read; \
	COLLECTION trans6_FlowV_ALARM_SUM; \
	VARIABLE trans6_FlowV_ALARM_SUM_Current; \
	VARIABLE trans6_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans6_FlowV_ALARM_SUM_Disabled; \
	MENU trans6_FlowV_ALARM_SUM_page; \
	COMMAND trans6_FlowV_ALARM_SUM_read; \
	VARIABLE trans6_FlowV_CALIBR_FACTOR; \
	MENU trans6_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans6_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans6_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans6_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans6_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans6_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans6_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans6_FlowV_NOMINAL_SIZE; \
	MENU trans6_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans6_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans6_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans6_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans6_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans6_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans6_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans6_FlowV_VOLUME_FLOW; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans6_FlowV_VOLUME_FLOW_page; \
	COMMAND trans6_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans6_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans6_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans6_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans6_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans6_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans6_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans6_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans6_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans6_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans6_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans6_FlowV_VORTEX_FREQ; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans6_FlowV_VORTEX_FREQ_page; \
	COMMAND trans6_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans6_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans6_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans6_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans6_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans6_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans6_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans6_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans6_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans6_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans6_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans6_FlowV_unit_nominal_size; \
	UNIT trans6_FlowV_unit_volume_flow; \
	UNIT trans6_FlowV_unit_vortex_frequency

#define USE_TRANS6_FLOWV_MANDATORY_A \
	USE_TRANS6_FLOWV_MANDATORY_BOTH; \
	MENU trans6_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS6_FLOWV_MANDATORY_B \
	USE_TRANS6_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans6_FlowV_VIEW_1; \
	MENU trans6_FlowV_VIEW_1_page; \
	MENU trans6_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS6_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans6_FlowV_VIEW_2; \
	MENU trans6_FlowV_VIEW_2_page; \
	COLLECTION trans6_FlowV_VIEW_3; \
	MENU trans6_FlowV_VIEW_3_page

#define USE_TRANS6_FLOWV_OPTIONAL_A \
	USE_TRANS6_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans6_FlowV_VIEW_1; \
	MENU trans6_FlowV_VIEW_1_page; \
	MENU trans6_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS6_FLOWV_OPTIONAL_B \
	USE_TRANS6_FLOWV_OPTIONAL_BOTH; \
	MENU trans6_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans6_FlowV_)
#define USE_TRANS6_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans6_FlowV_)
#define USE_TRANS6_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans6_FlowV_)
#define USE_TRANS6_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans6_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_FLOWV_MANDATORY_BOTH \
	BLOCK trans7_FlowV_block; \
	COLLECTION trans7_FlowV_BLOCK_OBJECT; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans7_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans7_FlowV_ST_REV; \
	MENU trans7_FlowV_ST_REV_page; \
	COMMAND trans7_FlowV_ST_REV_read; \
	VARIABLE trans7_FlowV_TAG_DESC; \
	MENU trans7_FlowV_TAG_DESC_page; \
	COMMAND trans7_FlowV_TAG_DESC_read; \
	COMMAND trans7_FlowV_TAG_DESC_write; \
	VARIABLE trans7_FlowV_STRATEGY; \
	MENU trans7_FlowV_STRATEGY_page; \
	COMMAND trans7_FlowV_STRATEGY_read; \
	COMMAND trans7_FlowV_STRATEGY_write; \
	VARIABLE trans7_FlowV_ALERT_KEY; \
	MENU trans7_FlowV_ALERT_KEY_page; \
	COMMAND trans7_FlowV_ALERT_KEY_read; \
	COMMAND trans7_FlowV_ALERT_KEY_write; \
	VARIABLE trans7_FlowV_TARGET_MODE; \
	MENU trans7_FlowV_TARGET_MODE_page; \
	COMMAND trans7_FlowV_TARGET_MODE_read; \
	COMMAND trans7_FlowV_TARGET_MODE_write; \
	COLLECTION trans7_FlowV_MODE_BLK; \
	VARIABLE trans7_FlowV_MODE_BLK_Actual; \
	VARIABLE trans7_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans7_FlowV_MODE_BLK_Normal; \
	MENU trans7_FlowV_MODE_BLK_page; \
	COMMAND trans7_FlowV_MODE_BLK_read; \
	COLLECTION trans7_FlowV_ALARM_SUM; \
	VARIABLE trans7_FlowV_ALARM_SUM_Current; \
	VARIABLE trans7_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans7_FlowV_ALARM_SUM_Disabled; \
	MENU trans7_FlowV_ALARM_SUM_page; \
	COMMAND trans7_FlowV_ALARM_SUM_read; \
	VARIABLE trans7_FlowV_CALIBR_FACTOR; \
	MENU trans7_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans7_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans7_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans7_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans7_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans7_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans7_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans7_FlowV_NOMINAL_SIZE; \
	MENU trans7_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans7_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans7_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans7_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans7_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans7_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans7_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans7_FlowV_VOLUME_FLOW; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans7_FlowV_VOLUME_FLOW_page; \
	COMMAND trans7_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans7_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans7_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans7_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans7_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans7_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans7_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans7_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans7_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans7_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans7_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans7_FlowV_VORTEX_FREQ; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans7_FlowV_VORTEX_FREQ_page; \
	COMMAND trans7_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans7_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans7_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans7_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans7_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans7_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans7_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans7_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans7_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans7_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans7_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans7_FlowV_unit_nominal_size; \
	UNIT trans7_FlowV_unit_volume_flow; \
	UNIT trans7_FlowV_unit_vortex_frequency

#define USE_TRANS7_FLOWV_MANDATORY_A \
	USE_TRANS7_FLOWV_MANDATORY_BOTH; \
	MENU trans7_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS7_FLOWV_MANDATORY_B \
	USE_TRANS7_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans7_FlowV_VIEW_1; \
	MENU trans7_FlowV_VIEW_1_page; \
	MENU trans7_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS7_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans7_FlowV_VIEW_2; \
	MENU trans7_FlowV_VIEW_2_page; \
	COLLECTION trans7_FlowV_VIEW_3; \
	MENU trans7_FlowV_VIEW_3_page

#define USE_TRANS7_FLOWV_OPTIONAL_A \
	USE_TRANS7_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans7_FlowV_VIEW_1; \
	MENU trans7_FlowV_VIEW_1_page; \
	MENU trans7_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS7_FLOWV_OPTIONAL_B \
	USE_TRANS7_FLOWV_OPTIONAL_BOTH; \
	MENU trans7_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans7_FlowV_)
#define USE_TRANS7_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans7_FlowV_)
#define USE_TRANS7_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans7_FlowV_)
#define USE_TRANS7_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans7_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_FLOWV_MANDATORY_BOTH \
	BLOCK trans8_FlowV_block; \
	COLLECTION trans8_FlowV_BLOCK_OBJECT; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans8_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans8_FlowV_ST_REV; \
	MENU trans8_FlowV_ST_REV_page; \
	COMMAND trans8_FlowV_ST_REV_read; \
	VARIABLE trans8_FlowV_TAG_DESC; \
	MENU trans8_FlowV_TAG_DESC_page; \
	COMMAND trans8_FlowV_TAG_DESC_read; \
	COMMAND trans8_FlowV_TAG_DESC_write; \
	VARIABLE trans8_FlowV_STRATEGY; \
	MENU trans8_FlowV_STRATEGY_page; \
	COMMAND trans8_FlowV_STRATEGY_read; \
	COMMAND trans8_FlowV_STRATEGY_write; \
	VARIABLE trans8_FlowV_ALERT_KEY; \
	MENU trans8_FlowV_ALERT_KEY_page; \
	COMMAND trans8_FlowV_ALERT_KEY_read; \
	COMMAND trans8_FlowV_ALERT_KEY_write; \
	VARIABLE trans8_FlowV_TARGET_MODE; \
	MENU trans8_FlowV_TARGET_MODE_page; \
	COMMAND trans8_FlowV_TARGET_MODE_read; \
	COMMAND trans8_FlowV_TARGET_MODE_write; \
	COLLECTION trans8_FlowV_MODE_BLK; \
	VARIABLE trans8_FlowV_MODE_BLK_Actual; \
	VARIABLE trans8_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans8_FlowV_MODE_BLK_Normal; \
	MENU trans8_FlowV_MODE_BLK_page; \
	COMMAND trans8_FlowV_MODE_BLK_read; \
	COLLECTION trans8_FlowV_ALARM_SUM; \
	VARIABLE trans8_FlowV_ALARM_SUM_Current; \
	VARIABLE trans8_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans8_FlowV_ALARM_SUM_Disabled; \
	MENU trans8_FlowV_ALARM_SUM_page; \
	COMMAND trans8_FlowV_ALARM_SUM_read; \
	VARIABLE trans8_FlowV_CALIBR_FACTOR; \
	MENU trans8_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans8_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans8_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans8_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans8_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans8_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans8_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans8_FlowV_NOMINAL_SIZE; \
	MENU trans8_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans8_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans8_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans8_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans8_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans8_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans8_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans8_FlowV_VOLUME_FLOW; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans8_FlowV_VOLUME_FLOW_page; \
	COMMAND trans8_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans8_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans8_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans8_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans8_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans8_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans8_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans8_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans8_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans8_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans8_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans8_FlowV_VORTEX_FREQ; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans8_FlowV_VORTEX_FREQ_page; \
	COMMAND trans8_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans8_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans8_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans8_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans8_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans8_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans8_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans8_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans8_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans8_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans8_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans8_FlowV_unit_nominal_size; \
	UNIT trans8_FlowV_unit_volume_flow; \
	UNIT trans8_FlowV_unit_vortex_frequency

#define USE_TRANS8_FLOWV_MANDATORY_A \
	USE_TRANS8_FLOWV_MANDATORY_BOTH; \
	MENU trans8_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS8_FLOWV_MANDATORY_B \
	USE_TRANS8_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans8_FlowV_VIEW_1; \
	MENU trans8_FlowV_VIEW_1_page; \
	MENU trans8_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS8_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans8_FlowV_VIEW_2; \
	MENU trans8_FlowV_VIEW_2_page; \
	COLLECTION trans8_FlowV_VIEW_3; \
	MENU trans8_FlowV_VIEW_3_page

#define USE_TRANS8_FLOWV_OPTIONAL_A \
	USE_TRANS8_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans8_FlowV_VIEW_1; \
	MENU trans8_FlowV_VIEW_1_page; \
	MENU trans8_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS8_FLOWV_OPTIONAL_B \
	USE_TRANS8_FLOWV_OPTIONAL_BOTH; \
	MENU trans8_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans8_FlowV_)
#define USE_TRANS8_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans8_FlowV_)
#define USE_TRANS8_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans8_FlowV_)
#define USE_TRANS8_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans8_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_FLOWV_MANDATORY_BOTH \
	BLOCK trans9_FlowV_block; \
	COLLECTION trans9_FlowV_BLOCK_OBJECT; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans9_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans9_FlowV_ST_REV; \
	MENU trans9_FlowV_ST_REV_page; \
	COMMAND trans9_FlowV_ST_REV_read; \
	VARIABLE trans9_FlowV_TAG_DESC; \
	MENU trans9_FlowV_TAG_DESC_page; \
	COMMAND trans9_FlowV_TAG_DESC_read; \
	COMMAND trans9_FlowV_TAG_DESC_write; \
	VARIABLE trans9_FlowV_STRATEGY; \
	MENU trans9_FlowV_STRATEGY_page; \
	COMMAND trans9_FlowV_STRATEGY_read; \
	COMMAND trans9_FlowV_STRATEGY_write; \
	VARIABLE trans9_FlowV_ALERT_KEY; \
	MENU trans9_FlowV_ALERT_KEY_page; \
	COMMAND trans9_FlowV_ALERT_KEY_read; \
	COMMAND trans9_FlowV_ALERT_KEY_write; \
	VARIABLE trans9_FlowV_TARGET_MODE; \
	MENU trans9_FlowV_TARGET_MODE_page; \
	COMMAND trans9_FlowV_TARGET_MODE_read; \
	COMMAND trans9_FlowV_TARGET_MODE_write; \
	COLLECTION trans9_FlowV_MODE_BLK; \
	VARIABLE trans9_FlowV_MODE_BLK_Actual; \
	VARIABLE trans9_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans9_FlowV_MODE_BLK_Normal; \
	MENU trans9_FlowV_MODE_BLK_page; \
	COMMAND trans9_FlowV_MODE_BLK_read; \
	COLLECTION trans9_FlowV_ALARM_SUM; \
	VARIABLE trans9_FlowV_ALARM_SUM_Current; \
	VARIABLE trans9_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans9_FlowV_ALARM_SUM_Disabled; \
	MENU trans9_FlowV_ALARM_SUM_page; \
	COMMAND trans9_FlowV_ALARM_SUM_read; \
	VARIABLE trans9_FlowV_CALIBR_FACTOR; \
	MENU trans9_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans9_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans9_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans9_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans9_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans9_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans9_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans9_FlowV_NOMINAL_SIZE; \
	MENU trans9_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans9_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans9_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans9_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans9_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans9_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans9_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans9_FlowV_VOLUME_FLOW; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans9_FlowV_VOLUME_FLOW_page; \
	COMMAND trans9_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans9_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans9_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans9_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans9_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans9_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans9_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans9_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans9_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans9_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans9_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans9_FlowV_VORTEX_FREQ; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans9_FlowV_VORTEX_FREQ_page; \
	COMMAND trans9_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans9_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans9_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans9_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans9_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans9_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans9_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans9_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans9_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans9_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans9_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans9_FlowV_unit_nominal_size; \
	UNIT trans9_FlowV_unit_volume_flow; \
	UNIT trans9_FlowV_unit_vortex_frequency

#define USE_TRANS9_FLOWV_MANDATORY_A \
	USE_TRANS9_FLOWV_MANDATORY_BOTH; \
	MENU trans9_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS9_FLOWV_MANDATORY_B \
	USE_TRANS9_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans9_FlowV_VIEW_1; \
	MENU trans9_FlowV_VIEW_1_page; \
	MENU trans9_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS9_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans9_FlowV_VIEW_2; \
	MENU trans9_FlowV_VIEW_2_page; \
	COLLECTION trans9_FlowV_VIEW_3; \
	MENU trans9_FlowV_VIEW_3_page

#define USE_TRANS9_FLOWV_OPTIONAL_A \
	USE_TRANS9_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans9_FlowV_VIEW_1; \
	MENU trans9_FlowV_VIEW_1_page; \
	MENU trans9_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS9_FLOWV_OPTIONAL_B \
	USE_TRANS9_FLOWV_OPTIONAL_BOTH; \
	MENU trans9_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans9_FlowV_)
#define USE_TRANS9_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans9_FlowV_)
#define USE_TRANS9_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans9_FlowV_)
#define USE_TRANS9_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans9_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_FLOWV_MANDATORY_BOTH \
	BLOCK trans10_FlowV_block; \
	COLLECTION trans10_FlowV_BLOCK_OBJECT; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans10_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans10_FlowV_ST_REV; \
	MENU trans10_FlowV_ST_REV_page; \
	COMMAND trans10_FlowV_ST_REV_read; \
	VARIABLE trans10_FlowV_TAG_DESC; \
	MENU trans10_FlowV_TAG_DESC_page; \
	COMMAND trans10_FlowV_TAG_DESC_read; \
	COMMAND trans10_FlowV_TAG_DESC_write; \
	VARIABLE trans10_FlowV_STRATEGY; \
	MENU trans10_FlowV_STRATEGY_page; \
	COMMAND trans10_FlowV_STRATEGY_read; \
	COMMAND trans10_FlowV_STRATEGY_write; \
	VARIABLE trans10_FlowV_ALERT_KEY; \
	MENU trans10_FlowV_ALERT_KEY_page; \
	COMMAND trans10_FlowV_ALERT_KEY_read; \
	COMMAND trans10_FlowV_ALERT_KEY_write; \
	VARIABLE trans10_FlowV_TARGET_MODE; \
	MENU trans10_FlowV_TARGET_MODE_page; \
	COMMAND trans10_FlowV_TARGET_MODE_read; \
	COMMAND trans10_FlowV_TARGET_MODE_write; \
	COLLECTION trans10_FlowV_MODE_BLK; \
	VARIABLE trans10_FlowV_MODE_BLK_Actual; \
	VARIABLE trans10_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans10_FlowV_MODE_BLK_Normal; \
	MENU trans10_FlowV_MODE_BLK_page; \
	COMMAND trans10_FlowV_MODE_BLK_read; \
	COLLECTION trans10_FlowV_ALARM_SUM; \
	VARIABLE trans10_FlowV_ALARM_SUM_Current; \
	VARIABLE trans10_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans10_FlowV_ALARM_SUM_Disabled; \
	MENU trans10_FlowV_ALARM_SUM_page; \
	COMMAND trans10_FlowV_ALARM_SUM_read; \
	VARIABLE trans10_FlowV_CALIBR_FACTOR; \
	MENU trans10_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans10_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans10_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans10_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans10_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans10_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans10_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans10_FlowV_NOMINAL_SIZE; \
	MENU trans10_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans10_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans10_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans10_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans10_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans10_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans10_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans10_FlowV_VOLUME_FLOW; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans10_FlowV_VOLUME_FLOW_page; \
	COMMAND trans10_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans10_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans10_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans10_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans10_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans10_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans10_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans10_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans10_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans10_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans10_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans10_FlowV_VORTEX_FREQ; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans10_FlowV_VORTEX_FREQ_page; \
	COMMAND trans10_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans10_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans10_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans10_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans10_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans10_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans10_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans10_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans10_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans10_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans10_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans10_FlowV_unit_nominal_size; \
	UNIT trans10_FlowV_unit_volume_flow; \
	UNIT trans10_FlowV_unit_vortex_frequency

#define USE_TRANS10_FLOWV_MANDATORY_A \
	USE_TRANS10_FLOWV_MANDATORY_BOTH; \
	MENU trans10_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS10_FLOWV_MANDATORY_B \
	USE_TRANS10_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans10_FlowV_VIEW_1; \
	MENU trans10_FlowV_VIEW_1_page; \
	MENU trans10_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS10_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans10_FlowV_VIEW_2; \
	MENU trans10_FlowV_VIEW_2_page; \
	COLLECTION trans10_FlowV_VIEW_3; \
	MENU trans10_FlowV_VIEW_3_page

#define USE_TRANS10_FLOWV_OPTIONAL_A \
	USE_TRANS10_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans10_FlowV_VIEW_1; \
	MENU trans10_FlowV_VIEW_1_page; \
	MENU trans10_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS10_FLOWV_OPTIONAL_B \
	USE_TRANS10_FLOWV_OPTIONAL_BOTH; \
	MENU trans10_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans10_FlowV_)
#define USE_TRANS10_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans10_FlowV_)
#define USE_TRANS10_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans10_FlowV_)
#define USE_TRANS10_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans10_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_FLOWV_MANDATORY_BOTH \
	BLOCK trans11_FlowV_block; \
	COLLECTION trans11_FlowV_BLOCK_OBJECT; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans11_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans11_FlowV_ST_REV; \
	MENU trans11_FlowV_ST_REV_page; \
	COMMAND trans11_FlowV_ST_REV_read; \
	VARIABLE trans11_FlowV_TAG_DESC; \
	MENU trans11_FlowV_TAG_DESC_page; \
	COMMAND trans11_FlowV_TAG_DESC_read; \
	COMMAND trans11_FlowV_TAG_DESC_write; \
	VARIABLE trans11_FlowV_STRATEGY; \
	MENU trans11_FlowV_STRATEGY_page; \
	COMMAND trans11_FlowV_STRATEGY_read; \
	COMMAND trans11_FlowV_STRATEGY_write; \
	VARIABLE trans11_FlowV_ALERT_KEY; \
	MENU trans11_FlowV_ALERT_KEY_page; \
	COMMAND trans11_FlowV_ALERT_KEY_read; \
	COMMAND trans11_FlowV_ALERT_KEY_write; \
	VARIABLE trans11_FlowV_TARGET_MODE; \
	MENU trans11_FlowV_TARGET_MODE_page; \
	COMMAND trans11_FlowV_TARGET_MODE_read; \
	COMMAND trans11_FlowV_TARGET_MODE_write; \
	COLLECTION trans11_FlowV_MODE_BLK; \
	VARIABLE trans11_FlowV_MODE_BLK_Actual; \
	VARIABLE trans11_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans11_FlowV_MODE_BLK_Normal; \
	MENU trans11_FlowV_MODE_BLK_page; \
	COMMAND trans11_FlowV_MODE_BLK_read; \
	COLLECTION trans11_FlowV_ALARM_SUM; \
	VARIABLE trans11_FlowV_ALARM_SUM_Current; \
	VARIABLE trans11_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans11_FlowV_ALARM_SUM_Disabled; \
	MENU trans11_FlowV_ALARM_SUM_page; \
	COMMAND trans11_FlowV_ALARM_SUM_read; \
	VARIABLE trans11_FlowV_CALIBR_FACTOR; \
	MENU trans11_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans11_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans11_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans11_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans11_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans11_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans11_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans11_FlowV_NOMINAL_SIZE; \
	MENU trans11_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans11_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans11_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans11_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans11_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans11_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans11_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans11_FlowV_VOLUME_FLOW; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans11_FlowV_VOLUME_FLOW_page; \
	COMMAND trans11_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans11_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans11_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans11_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans11_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans11_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans11_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans11_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans11_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans11_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans11_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans11_FlowV_VORTEX_FREQ; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans11_FlowV_VORTEX_FREQ_page; \
	COMMAND trans11_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans11_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans11_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans11_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans11_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans11_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans11_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans11_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans11_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans11_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans11_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans11_FlowV_unit_nominal_size; \
	UNIT trans11_FlowV_unit_volume_flow; \
	UNIT trans11_FlowV_unit_vortex_frequency

#define USE_TRANS11_FLOWV_MANDATORY_A \
	USE_TRANS11_FLOWV_MANDATORY_BOTH; \
	MENU trans11_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS11_FLOWV_MANDATORY_B \
	USE_TRANS11_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans11_FlowV_VIEW_1; \
	MENU trans11_FlowV_VIEW_1_page; \
	MENU trans11_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS11_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans11_FlowV_VIEW_2; \
	MENU trans11_FlowV_VIEW_2_page; \
	COLLECTION trans11_FlowV_VIEW_3; \
	MENU trans11_FlowV_VIEW_3_page

#define USE_TRANS11_FLOWV_OPTIONAL_A \
	USE_TRANS11_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans11_FlowV_VIEW_1; \
	MENU trans11_FlowV_VIEW_1_page; \
	MENU trans11_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS11_FLOWV_OPTIONAL_B \
	USE_TRANS11_FLOWV_OPTIONAL_BOTH; \
	MENU trans11_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans11_FlowV_)
#define USE_TRANS11_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans11_FlowV_)
#define USE_TRANS11_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans11_FlowV_)
#define USE_TRANS11_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans11_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_FLOWV_MANDATORY_BOTH \
	BLOCK trans12_FlowV_block; \
	COLLECTION trans12_FlowV_BLOCK_OBJECT; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans12_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans12_FlowV_ST_REV; \
	MENU trans12_FlowV_ST_REV_page; \
	COMMAND trans12_FlowV_ST_REV_read; \
	VARIABLE trans12_FlowV_TAG_DESC; \
	MENU trans12_FlowV_TAG_DESC_page; \
	COMMAND trans12_FlowV_TAG_DESC_read; \
	COMMAND trans12_FlowV_TAG_DESC_write; \
	VARIABLE trans12_FlowV_STRATEGY; \
	MENU trans12_FlowV_STRATEGY_page; \
	COMMAND trans12_FlowV_STRATEGY_read; \
	COMMAND trans12_FlowV_STRATEGY_write; \
	VARIABLE trans12_FlowV_ALERT_KEY; \
	MENU trans12_FlowV_ALERT_KEY_page; \
	COMMAND trans12_FlowV_ALERT_KEY_read; \
	COMMAND trans12_FlowV_ALERT_KEY_write; \
	VARIABLE trans12_FlowV_TARGET_MODE; \
	MENU trans12_FlowV_TARGET_MODE_page; \
	COMMAND trans12_FlowV_TARGET_MODE_read; \
	COMMAND trans12_FlowV_TARGET_MODE_write; \
	COLLECTION trans12_FlowV_MODE_BLK; \
	VARIABLE trans12_FlowV_MODE_BLK_Actual; \
	VARIABLE trans12_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans12_FlowV_MODE_BLK_Normal; \
	MENU trans12_FlowV_MODE_BLK_page; \
	COMMAND trans12_FlowV_MODE_BLK_read; \
	COLLECTION trans12_FlowV_ALARM_SUM; \
	VARIABLE trans12_FlowV_ALARM_SUM_Current; \
	VARIABLE trans12_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans12_FlowV_ALARM_SUM_Disabled; \
	MENU trans12_FlowV_ALARM_SUM_page; \
	COMMAND trans12_FlowV_ALARM_SUM_read; \
	VARIABLE trans12_FlowV_CALIBR_FACTOR; \
	MENU trans12_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans12_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans12_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans12_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans12_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans12_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans12_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans12_FlowV_NOMINAL_SIZE; \
	MENU trans12_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans12_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans12_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans12_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans12_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans12_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans12_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans12_FlowV_VOLUME_FLOW; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans12_FlowV_VOLUME_FLOW_page; \
	COMMAND trans12_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans12_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans12_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans12_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans12_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans12_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans12_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans12_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans12_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans12_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans12_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans12_FlowV_VORTEX_FREQ; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans12_FlowV_VORTEX_FREQ_page; \
	COMMAND trans12_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans12_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans12_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans12_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans12_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans12_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans12_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans12_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans12_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans12_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans12_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans12_FlowV_unit_nominal_size; \
	UNIT trans12_FlowV_unit_volume_flow; \
	UNIT trans12_FlowV_unit_vortex_frequency

#define USE_TRANS12_FLOWV_MANDATORY_A \
	USE_TRANS12_FLOWV_MANDATORY_BOTH; \
	MENU trans12_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS12_FLOWV_MANDATORY_B \
	USE_TRANS12_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans12_FlowV_VIEW_1; \
	MENU trans12_FlowV_VIEW_1_page; \
	MENU trans12_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS12_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans12_FlowV_VIEW_2; \
	MENU trans12_FlowV_VIEW_2_page; \
	COLLECTION trans12_FlowV_VIEW_3; \
	MENU trans12_FlowV_VIEW_3_page

#define USE_TRANS12_FLOWV_OPTIONAL_A \
	USE_TRANS12_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans12_FlowV_VIEW_1; \
	MENU trans12_FlowV_VIEW_1_page; \
	MENU trans12_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS12_FLOWV_OPTIONAL_B \
	USE_TRANS12_FLOWV_OPTIONAL_BOTH; \
	MENU trans12_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans12_FlowV_)
#define USE_TRANS12_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans12_FlowV_)
#define USE_TRANS12_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans12_FlowV_)
#define USE_TRANS12_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans12_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_FLOWV_MANDATORY_BOTH \
	BLOCK trans13_FlowV_block; \
	COLLECTION trans13_FlowV_BLOCK_OBJECT; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans13_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans13_FlowV_ST_REV; \
	MENU trans13_FlowV_ST_REV_page; \
	COMMAND trans13_FlowV_ST_REV_read; \
	VARIABLE trans13_FlowV_TAG_DESC; \
	MENU trans13_FlowV_TAG_DESC_page; \
	COMMAND trans13_FlowV_TAG_DESC_read; \
	COMMAND trans13_FlowV_TAG_DESC_write; \
	VARIABLE trans13_FlowV_STRATEGY; \
	MENU trans13_FlowV_STRATEGY_page; \
	COMMAND trans13_FlowV_STRATEGY_read; \
	COMMAND trans13_FlowV_STRATEGY_write; \
	VARIABLE trans13_FlowV_ALERT_KEY; \
	MENU trans13_FlowV_ALERT_KEY_page; \
	COMMAND trans13_FlowV_ALERT_KEY_read; \
	COMMAND trans13_FlowV_ALERT_KEY_write; \
	VARIABLE trans13_FlowV_TARGET_MODE; \
	MENU trans13_FlowV_TARGET_MODE_page; \
	COMMAND trans13_FlowV_TARGET_MODE_read; \
	COMMAND trans13_FlowV_TARGET_MODE_write; \
	COLLECTION trans13_FlowV_MODE_BLK; \
	VARIABLE trans13_FlowV_MODE_BLK_Actual; \
	VARIABLE trans13_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans13_FlowV_MODE_BLK_Normal; \
	MENU trans13_FlowV_MODE_BLK_page; \
	COMMAND trans13_FlowV_MODE_BLK_read; \
	COLLECTION trans13_FlowV_ALARM_SUM; \
	VARIABLE trans13_FlowV_ALARM_SUM_Current; \
	VARIABLE trans13_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans13_FlowV_ALARM_SUM_Disabled; \
	MENU trans13_FlowV_ALARM_SUM_page; \
	COMMAND trans13_FlowV_ALARM_SUM_read; \
	VARIABLE trans13_FlowV_CALIBR_FACTOR; \
	MENU trans13_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans13_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans13_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans13_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans13_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans13_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans13_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans13_FlowV_NOMINAL_SIZE; \
	MENU trans13_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans13_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans13_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans13_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans13_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans13_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans13_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans13_FlowV_VOLUME_FLOW; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans13_FlowV_VOLUME_FLOW_page; \
	COMMAND trans13_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans13_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans13_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans13_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans13_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans13_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans13_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans13_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans13_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans13_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans13_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans13_FlowV_VORTEX_FREQ; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans13_FlowV_VORTEX_FREQ_page; \
	COMMAND trans13_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans13_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans13_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans13_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans13_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans13_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans13_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans13_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans13_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans13_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans13_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans13_FlowV_unit_nominal_size; \
	UNIT trans13_FlowV_unit_volume_flow; \
	UNIT trans13_FlowV_unit_vortex_frequency

#define USE_TRANS13_FLOWV_MANDATORY_A \
	USE_TRANS13_FLOWV_MANDATORY_BOTH; \
	MENU trans13_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS13_FLOWV_MANDATORY_B \
	USE_TRANS13_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans13_FlowV_VIEW_1; \
	MENU trans13_FlowV_VIEW_1_page; \
	MENU trans13_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS13_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans13_FlowV_VIEW_2; \
	MENU trans13_FlowV_VIEW_2_page; \
	COLLECTION trans13_FlowV_VIEW_3; \
	MENU trans13_FlowV_VIEW_3_page

#define USE_TRANS13_FLOWV_OPTIONAL_A \
	USE_TRANS13_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans13_FlowV_VIEW_1; \
	MENU trans13_FlowV_VIEW_1_page; \
	MENU trans13_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS13_FLOWV_OPTIONAL_B \
	USE_TRANS13_FLOWV_OPTIONAL_BOTH; \
	MENU trans13_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans13_FlowV_)
#define USE_TRANS13_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans13_FlowV_)
#define USE_TRANS13_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans13_FlowV_)
#define USE_TRANS13_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans13_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_FLOWV_MANDATORY_BOTH \
	BLOCK trans14_FlowV_block; \
	COLLECTION trans14_FlowV_BLOCK_OBJECT; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans14_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans14_FlowV_ST_REV; \
	MENU trans14_FlowV_ST_REV_page; \
	COMMAND trans14_FlowV_ST_REV_read; \
	VARIABLE trans14_FlowV_TAG_DESC; \
	MENU trans14_FlowV_TAG_DESC_page; \
	COMMAND trans14_FlowV_TAG_DESC_read; \
	COMMAND trans14_FlowV_TAG_DESC_write; \
	VARIABLE trans14_FlowV_STRATEGY; \
	MENU trans14_FlowV_STRATEGY_page; \
	COMMAND trans14_FlowV_STRATEGY_read; \
	COMMAND trans14_FlowV_STRATEGY_write; \
	VARIABLE trans14_FlowV_ALERT_KEY; \
	MENU trans14_FlowV_ALERT_KEY_page; \
	COMMAND trans14_FlowV_ALERT_KEY_read; \
	COMMAND trans14_FlowV_ALERT_KEY_write; \
	VARIABLE trans14_FlowV_TARGET_MODE; \
	MENU trans14_FlowV_TARGET_MODE_page; \
	COMMAND trans14_FlowV_TARGET_MODE_read; \
	COMMAND trans14_FlowV_TARGET_MODE_write; \
	COLLECTION trans14_FlowV_MODE_BLK; \
	VARIABLE trans14_FlowV_MODE_BLK_Actual; \
	VARIABLE trans14_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans14_FlowV_MODE_BLK_Normal; \
	MENU trans14_FlowV_MODE_BLK_page; \
	COMMAND trans14_FlowV_MODE_BLK_read; \
	COLLECTION trans14_FlowV_ALARM_SUM; \
	VARIABLE trans14_FlowV_ALARM_SUM_Current; \
	VARIABLE trans14_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans14_FlowV_ALARM_SUM_Disabled; \
	MENU trans14_FlowV_ALARM_SUM_page; \
	COMMAND trans14_FlowV_ALARM_SUM_read; \
	VARIABLE trans14_FlowV_CALIBR_FACTOR; \
	MENU trans14_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans14_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans14_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans14_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans14_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans14_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans14_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans14_FlowV_NOMINAL_SIZE; \
	MENU trans14_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans14_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans14_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans14_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans14_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans14_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans14_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans14_FlowV_VOLUME_FLOW; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans14_FlowV_VOLUME_FLOW_page; \
	COMMAND trans14_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans14_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans14_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans14_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans14_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans14_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans14_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans14_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans14_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans14_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans14_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans14_FlowV_VORTEX_FREQ; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans14_FlowV_VORTEX_FREQ_page; \
	COMMAND trans14_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans14_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans14_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans14_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans14_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans14_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans14_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans14_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans14_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans14_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans14_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans14_FlowV_unit_nominal_size; \
	UNIT trans14_FlowV_unit_volume_flow; \
	UNIT trans14_FlowV_unit_vortex_frequency

#define USE_TRANS14_FLOWV_MANDATORY_A \
	USE_TRANS14_FLOWV_MANDATORY_BOTH; \
	MENU trans14_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS14_FLOWV_MANDATORY_B \
	USE_TRANS14_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans14_FlowV_VIEW_1; \
	MENU trans14_FlowV_VIEW_1_page; \
	MENU trans14_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS14_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans14_FlowV_VIEW_2; \
	MENU trans14_FlowV_VIEW_2_page; \
	COLLECTION trans14_FlowV_VIEW_3; \
	MENU trans14_FlowV_VIEW_3_page

#define USE_TRANS14_FLOWV_OPTIONAL_A \
	USE_TRANS14_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans14_FlowV_VIEW_1; \
	MENU trans14_FlowV_VIEW_1_page; \
	MENU trans14_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS14_FLOWV_OPTIONAL_B \
	USE_TRANS14_FLOWV_OPTIONAL_BOTH; \
	MENU trans14_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans14_FlowV_)
#define USE_TRANS14_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans14_FlowV_)
#define USE_TRANS14_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans14_FlowV_)
#define USE_TRANS14_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans14_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_FLOWV_MANDATORY_BOTH \
	BLOCK trans15_FlowV_block; \
	COLLECTION trans15_FlowV_BLOCK_OBJECT; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Class; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_FlowV_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_FlowV_BLOCK_OBJECT_page; \
	COMMAND trans15_FlowV_BLOCK_OBJECT_read; \
	VARIABLE trans15_FlowV_ST_REV; \
	MENU trans15_FlowV_ST_REV_page; \
	COMMAND trans15_FlowV_ST_REV_read; \
	VARIABLE trans15_FlowV_TAG_DESC; \
	MENU trans15_FlowV_TAG_DESC_page; \
	COMMAND trans15_FlowV_TAG_DESC_read; \
	COMMAND trans15_FlowV_TAG_DESC_write; \
	VARIABLE trans15_FlowV_STRATEGY; \
	MENU trans15_FlowV_STRATEGY_page; \
	COMMAND trans15_FlowV_STRATEGY_read; \
	COMMAND trans15_FlowV_STRATEGY_write; \
	VARIABLE trans15_FlowV_ALERT_KEY; \
	MENU trans15_FlowV_ALERT_KEY_page; \
	COMMAND trans15_FlowV_ALERT_KEY_read; \
	COMMAND trans15_FlowV_ALERT_KEY_write; \
	VARIABLE trans15_FlowV_TARGET_MODE; \
	MENU trans15_FlowV_TARGET_MODE_page; \
	COMMAND trans15_FlowV_TARGET_MODE_read; \
	COMMAND trans15_FlowV_TARGET_MODE_write; \
	COLLECTION trans15_FlowV_MODE_BLK; \
	VARIABLE trans15_FlowV_MODE_BLK_Actual; \
	VARIABLE trans15_FlowV_MODE_BLK_Permitted; \
	VARIABLE trans15_FlowV_MODE_BLK_Normal; \
	MENU trans15_FlowV_MODE_BLK_page; \
	COMMAND trans15_FlowV_MODE_BLK_read; \
	COLLECTION trans15_FlowV_ALARM_SUM; \
	VARIABLE trans15_FlowV_ALARM_SUM_Current; \
	VARIABLE trans15_FlowV_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_FlowV_ALARM_SUM_Unreported; \
	VARIABLE trans15_FlowV_ALARM_SUM_Disabled; \
	MENU trans15_FlowV_ALARM_SUM_page; \
	COMMAND trans15_FlowV_ALARM_SUM_read; \
	VARIABLE trans15_FlowV_CALIBR_FACTOR; \
	MENU trans15_FlowV_CALIBR_FACTOR_page; \
	COMMAND trans15_FlowV_CALIBR_FACTOR_read; \
	COMMAND trans15_FlowV_CALIBR_FACTOR_write; \
	VARIABLE trans15_FlowV_LOW_FLOW_CUTOFF; \
	MENU trans15_FlowV_LOW_FLOW_CUTOFF_page; \
	COMMAND trans15_FlowV_LOW_FLOW_CUTOFF_read; \
	COMMAND trans15_FlowV_LOW_FLOW_CUTOFF_write; \
	VARIABLE trans15_FlowV_NOMINAL_SIZE; \
	MENU trans15_FlowV_NOMINAL_SIZE_page; \
	COMMAND trans15_FlowV_NOMINAL_SIZE_read; \
	COMMAND trans15_FlowV_NOMINAL_SIZE_write; \
	VARIABLE trans15_FlowV_NOMINAL_SIZE_UNITS; \
	MENU trans15_FlowV_NOMINAL_SIZE_UNITS_page; \
	COMMAND trans15_FlowV_NOMINAL_SIZE_UNITS_read; \
	COMMAND trans15_FlowV_NOMINAL_SIZE_UNITS_write; \
	COLLECTION trans15_FlowV_VOLUME_FLOW; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_Value; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_Status_Condensed; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_Status_Quality; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_Status_Limit; \
	MENU trans15_FlowV_VOLUME_FLOW_page; \
	COMMAND trans15_FlowV_VOLUME_FLOW_read; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_UNITS; \
	MENU trans15_FlowV_VOLUME_FLOW_UNITS_page; \
	COMMAND trans15_FlowV_VOLUME_FLOW_UNITS_read; \
	COMMAND trans15_FlowV_VOLUME_FLOW_UNITS_write; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_LO_LIMIT; \
	MENU trans15_FlowV_VOLUME_FLOW_LO_LIMIT_page; \
	COMMAND trans15_FlowV_VOLUME_FLOW_LO_LIMIT_read; \
	COMMAND trans15_FlowV_VOLUME_FLOW_LO_LIMIT_write; \
	VARIABLE trans15_FlowV_VOLUME_FLOW_HI_LIMIT; \
	MENU trans15_FlowV_VOLUME_FLOW_HI_LIMIT_page; \
	COMMAND trans15_FlowV_VOLUME_FLOW_HI_LIMIT_read; \
	COMMAND trans15_FlowV_VOLUME_FLOW_HI_LIMIT_write; \
	COLLECTION trans15_FlowV_VORTEX_FREQ; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_Value; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_Status_Condensed; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_Status_Quality; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_Status_Limit; \
	MENU trans15_FlowV_VORTEX_FREQ_page; \
	COMMAND trans15_FlowV_VORTEX_FREQ_read; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_UNITS; \
	MENU trans15_FlowV_VORTEX_FREQ_UNITS_page; \
	COMMAND trans15_FlowV_VORTEX_FREQ_UNITS_read; \
	COMMAND trans15_FlowV_VORTEX_FREQ_UNITS_write; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_LO_LIMIT; \
	MENU trans15_FlowV_VORTEX_FREQ_LO_LIMIT_page; \
	COMMAND trans15_FlowV_VORTEX_FREQ_LO_LIMIT_read; \
	COMMAND trans15_FlowV_VORTEX_FREQ_LO_LIMIT_write; \
	VARIABLE trans15_FlowV_VORTEX_FREQ_HI_LIMIT; \
	MENU trans15_FlowV_VORTEX_FREQ_HI_LIMIT_page; \
	COMMAND trans15_FlowV_VORTEX_FREQ_HI_LIMIT_read; \
	COMMAND trans15_FlowV_VORTEX_FREQ_HI_LIMIT_write; \
	UNIT trans15_FlowV_unit_nominal_size; \
	UNIT trans15_FlowV_unit_volume_flow; \
	UNIT trans15_FlowV_unit_vortex_frequency

#define USE_TRANS15_FLOWV_MANDATORY_A \
	USE_TRANS15_FLOWV_MANDATORY_BOTH; \
	MENU trans15_FlowV_Simple_Dialog_Mandatory_A

#define USE_TRANS15_FLOWV_MANDATORY_B \
	USE_TRANS15_FLOWV_MANDATORY_BOTH; \
	COLLECTION trans15_FlowV_VIEW_1; \
	MENU trans15_FlowV_VIEW_1_page; \
	MENU trans15_FlowV_Simple_Dialog_Mandatory_B

#define USE_TRANS15_FLOWV_OPTIONAL_BOTH \
	COLLECTION trans15_FlowV_VIEW_2; \
	MENU trans15_FlowV_VIEW_2_page; \
	COLLECTION trans15_FlowV_VIEW_3; \
	MENU trans15_FlowV_VIEW_3_page

#define USE_TRANS15_FLOWV_OPTIONAL_A \
	USE_TRANS15_FLOWV_OPTIONAL_BOTH; \
	COLLECTION trans15_FlowV_VIEW_1; \
	MENU trans15_FlowV_VIEW_1_page; \
	MENU trans15_FlowV_Simple_Dialog_Optional_A

#define USE_TRANS15_FLOWV_OPTIONAL_B \
	USE_TRANS15_FLOWV_OPTIONAL_BOTH; \
	MENU trans15_FlowV_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_FLOWV_MANDATORY_A USE_TRANS_FLOWV_MANDATORY_A(trans15_FlowV_)
#define USE_TRANS15_FLOWV_MANDATORY_B USE_TRANS_FLOWV_MANDATORY_B(trans15_FlowV_)
#define USE_TRANS15_FLOWV_OPTIONAL_A  USE_TRANS_FLOWV_OPTIONAL_A(trans15_FlowV_)
#define USE_TRANS15_FLOWV_OPTIONAL_B  USE_TRANS_FLOWV_OPTIONAL_B(trans15_FlowV_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_LEVEL_MANDATORY_BOTH \
	BLOCK trans1_Level_block; \
	COLLECTION trans1_Level_BLOCK_OBJECT; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Level_BLOCK_OBJECT_page; \
	COMMAND trans1_Level_BLOCK_OBJECT_read; \
	VARIABLE trans1_Level_ST_REV; \
	MENU trans1_Level_ST_REV_page; \
	COMMAND trans1_Level_ST_REV_read; \
	VARIABLE trans1_Level_TAG_DESC; \
	MENU trans1_Level_TAG_DESC_page; \
	COMMAND trans1_Level_TAG_DESC_read; \
	COMMAND trans1_Level_TAG_DESC_write; \
	VARIABLE trans1_Level_STRATEGY; \
	MENU trans1_Level_STRATEGY_page; \
	COMMAND trans1_Level_STRATEGY_read; \
	COMMAND trans1_Level_STRATEGY_write; \
	VARIABLE trans1_Level_ALERT_KEY; \
	MENU trans1_Level_ALERT_KEY_page; \
	COMMAND trans1_Level_ALERT_KEY_read; \
	COMMAND trans1_Level_ALERT_KEY_write; \
	VARIABLE trans1_Level_TARGET_MODE; \
	MENU trans1_Level_TARGET_MODE_page; \
	COMMAND trans1_Level_TARGET_MODE_read; \
	COMMAND trans1_Level_TARGET_MODE_write; \
	COLLECTION trans1_Level_MODE_BLK; \
	VARIABLE trans1_Level_MODE_BLK_Actual; \
	VARIABLE trans1_Level_MODE_BLK_Permitted; \
	VARIABLE trans1_Level_MODE_BLK_Normal; \
	MENU trans1_Level_MODE_BLK_page; \
	COMMAND trans1_Level_MODE_BLK_read; \
	COLLECTION trans1_Level_ALARM_SUM; \
	VARIABLE trans1_Level_ALARM_SUM_Current; \
	VARIABLE trans1_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Level_ALARM_SUM_Unreported; \
	VARIABLE trans1_Level_ALARM_SUM_Disabled; \
	MENU trans1_Level_ALARM_SUM_page; \
	COMMAND trans1_Level_ALARM_SUM_read

#define USE_TRANS1_LEVEL_MANDATORY_A \
	USE_TRANS1_LEVEL_MANDATORY_BOTH; \
	MENU trans1_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS1_LEVEL_MANDATORY_B \
	USE_TRANS1_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans1_Level_PRIMARY_VALUE; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans1_Level_PRIMARY_VALUE_page; \
	COMMAND trans1_Level_PRIMARY_VALUE_read; \
	VARIABLE trans1_Level_PRIMARY_VALUE_UNIT; \
	MENU trans1_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans1_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans1_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans1_Level_LEVEL; \
	MENU trans1_Level_LEVEL_page; \
	COMMAND trans1_Level_LEVEL_read; \
	VARIABLE trans1_Level_LEVEL_UNIT; \
	MENU trans1_Level_LEVEL_UNIT_page; \
	COMMAND trans1_Level_LEVEL_UNIT_read; \
	COMMAND trans1_Level_LEVEL_UNIT_write; \
	VARIABLE trans1_Level_SENSOR_VALUE; \
	MENU trans1_Level_SENSOR_VALUE_page; \
	COMMAND trans1_Level_SENSOR_VALUE_read; \
	VARIABLE trans1_Level_SENSOR_UNIT; \
	MENU trans1_Level_SENSOR_UNIT_page; \
	COMMAND trans1_Level_SENSOR_UNIT_read; \
	COMMAND trans1_Level_SENSOR_UNIT_write; \
	VARIABLE trans1_Level_SENSOR_OFFSET; \
	MENU trans1_Level_SENSOR_OFFSET_page; \
	COMMAND trans1_Level_SENSOR_OFFSET_read; \
	COMMAND trans1_Level_SENSOR_OFFSET_write; \
	VARIABLE trans1_Level_CAL_TYPE; \
	MENU trans1_Level_CAL_TYPE_page; \
	COMMAND trans1_Level_CAL_TYPE_read; \
	COMMAND trans1_Level_CAL_TYPE_write; \
	VARIABLE trans1_Level_CAL_POINT_LO; \
	MENU trans1_Level_CAL_POINT_LO_page; \
	COMMAND trans1_Level_CAL_POINT_LO_read; \
	COMMAND trans1_Level_CAL_POINT_LO_write; \
	VARIABLE trans1_Level_CAL_POINT_HI; \
	MENU trans1_Level_CAL_POINT_HI_page; \
	COMMAND trans1_Level_CAL_POINT_HI_read; \
	COMMAND trans1_Level_CAL_POINT_HI_write; \
	VARIABLE trans1_Level_LEVEL_LO; \
	MENU trans1_Level_LEVEL_LO_page; \
	COMMAND trans1_Level_LEVEL_LO_read; \
	COMMAND trans1_Level_LEVEL_LO_write; \
	VARIABLE trans1_Level_LEVEL_HI; \
	MENU trans1_Level_LEVEL_HI_page; \
	COMMAND trans1_Level_LEVEL_HI_read; \
	COMMAND trans1_Level_LEVEL_HI_write; \
	VARIABLE trans1_Level_LEVEL_OFFSET; \
	MENU trans1_Level_LEVEL_OFFSET_page; \
	COMMAND trans1_Level_LEVEL_OFFSET_read; \
	COMMAND trans1_Level_LEVEL_OFFSET_write; \
	VARIABLE trans1_Level_LIN_TYPE; \
	MENU trans1_Level_LIN_TYPE_page; \
	COMMAND trans1_Level_LIN_TYPE_read; \
	COMMAND trans1_Level_LIN_TYPE_write; \
	COLLECTION trans1_Level_VIEW_1; \
	MENU trans1_Level_VIEW_1_page; \
	MENU trans1_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans1_Level_unit_level_1; \
	UNIT trans1_Level_unit_primary_value_1; \
	UNIT trans1_Level_unit_sensor_value_1

#define USE_TRANS1_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans1_Level_SECONDARY_VALUE_1; \
	VARIABLE trans1_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans1_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans1_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans1_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans1_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans1_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans1_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans1_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans1_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans1_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans1_Level_SECONDARY_VALUE_2; \
	VARIABLE trans1_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans1_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans1_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans1_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans1_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans1_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans1_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans1_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans1_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans1_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans1_Level_LIN_DIAMETER; \
	MENU trans1_Level_LIN_DIAMETER_page; \
	COMMAND trans1_Level_LIN_DIAMETER_read; \
	COMMAND trans1_Level_LIN_DIAMETER_write; \
	VARIABLE trans1_Level_LIN_VOLUME; \
	MENU trans1_Level_LIN_VOLUME_page; \
	COMMAND trans1_Level_LIN_VOLUME_read; \
	COMMAND trans1_Level_LIN_VOLUME_write; \
	VARIABLE trans1_Level_SENSOR_HIGH_LIMIT; \
	MENU trans1_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans1_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans1_Level_SENSOR_LOW_LIMIT; \
	MENU trans1_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans1_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans1_Level_MAX_SENSOR_VALUE; \
	MENU trans1_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans1_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans1_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans1_Level_MIN_SENSOR_VALUE; \
	MENU trans1_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans1_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans1_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans1_Level_TEMPERATURE; \
	MENU trans1_Level_TEMPERATURE_page; \
	COMMAND trans1_Level_TEMPERATURE_read; \
	VARIABLE trans1_Level_TEMPERATURE_UNIT; \
	MENU trans1_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans1_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans1_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans1_Level_MAX_TEMPERATURE; \
	MENU trans1_Level_MAX_TEMPERATURE_page; \
	COMMAND trans1_Level_MAX_TEMPERATURE_read; \
	COMMAND trans1_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans1_Level_MIN_TEMPERATURE; \
	MENU trans1_Level_MIN_TEMPERATURE_page; \
	COMMAND trans1_Level_MIN_TEMPERATURE_read; \
	COMMAND trans1_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans1_Level_TAB_ENTRY; \
	MENU trans1_Level_TAB_ENTRY_page; \
	COMMAND trans1_Level_TAB_ENTRY_read; \
	COMMAND trans1_Level_TAB_ENTRY_write; \
	COLLECTION trans1_Level_TAB_X_Y_VALUE; \
	VARIABLE trans1_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans1_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans1_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans1_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans1_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans1_Level_TAB_MIN_NUMBER; \
	MENU trans1_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans1_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans1_Level_TAB_MAX_NUMBER; \
	MENU trans1_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans1_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans1_Level_TAB_OP_CODE; \
	MENU trans1_Level_TAB_OP_CODE_page; \
	COMMAND trans1_Level_TAB_OP_CODE_read; \
	COMMAND trans1_Level_TAB_OP_CODE_write; \
	VARIABLE trans1_Level_TAB_STATUS; \
	MENU trans1_Level_TAB_STATUS_page; \
	COMMAND trans1_Level_TAB_STATUS_read; \
	VARIABLE trans1_Level_TAB_ACTUAL_NUMBER; \
	MENU trans1_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans1_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans1_Level_VIEW_2; \
	MENU trans1_Level_VIEW_2_page; \
	COLLECTION trans1_Level_VIEW_3; \
	MENU trans1_Level_VIEW_3_page; \
	UNIT trans1_Level_unit_level_2; \
	UNIT trans1_Level_unit_temperature; \
	UNIT trans1_Level_unit_primary_value_2; \
	UNIT trans1_Level_unit_sensor_value_2; \
	UNIT trans1_Level_unit_secondary_value_1; \
	UNIT trans1_Level_unit_secondary_value_2

#define USE_TRANS1_LEVEL_OPTIONAL_A \
	USE_TRANS1_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans1_Level_PRIMARY_VALUE; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans1_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans1_Level_PRIMARY_VALUE_page; \
	COMMAND trans1_Level_PRIMARY_VALUE_read; \
	VARIABLE trans1_Level_PRIMARY_VALUE_UNIT; \
	MENU trans1_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans1_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans1_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans1_Level_LEVEL; \
	MENU trans1_Level_LEVEL_page; \
	COMMAND trans1_Level_LEVEL_read; \
	VARIABLE trans1_Level_LEVEL_UNIT; \
	MENU trans1_Level_LEVEL_UNIT_page; \
	COMMAND trans1_Level_LEVEL_UNIT_read; \
	COMMAND trans1_Level_LEVEL_UNIT_write; \
	VARIABLE trans1_Level_SENSOR_VALUE; \
	MENU trans1_Level_SENSOR_VALUE_page; \
	COMMAND trans1_Level_SENSOR_VALUE_read; \
	VARIABLE trans1_Level_SENSOR_UNIT; \
	MENU trans1_Level_SENSOR_UNIT_page; \
	COMMAND trans1_Level_SENSOR_UNIT_read; \
	COMMAND trans1_Level_SENSOR_UNIT_write; \
	VARIABLE trans1_Level_SENSOR_OFFSET; \
	MENU trans1_Level_SENSOR_OFFSET_page; \
	COMMAND trans1_Level_SENSOR_OFFSET_read; \
	COMMAND trans1_Level_SENSOR_OFFSET_write; \
	VARIABLE trans1_Level_CAL_TYPE; \
	MENU trans1_Level_CAL_TYPE_page; \
	COMMAND trans1_Level_CAL_TYPE_read; \
	COMMAND trans1_Level_CAL_TYPE_write; \
	VARIABLE trans1_Level_CAL_POINT_LO; \
	MENU trans1_Level_CAL_POINT_LO_page; \
	COMMAND trans1_Level_CAL_POINT_LO_read; \
	COMMAND trans1_Level_CAL_POINT_LO_write; \
	VARIABLE trans1_Level_CAL_POINT_HI; \
	MENU trans1_Level_CAL_POINT_HI_page; \
	COMMAND trans1_Level_CAL_POINT_HI_read; \
	COMMAND trans1_Level_CAL_POINT_HI_write; \
	VARIABLE trans1_Level_LEVEL_LO; \
	MENU trans1_Level_LEVEL_LO_page; \
	COMMAND trans1_Level_LEVEL_LO_read; \
	COMMAND trans1_Level_LEVEL_LO_write; \
	VARIABLE trans1_Level_LEVEL_HI; \
	MENU trans1_Level_LEVEL_HI_page; \
	COMMAND trans1_Level_LEVEL_HI_read; \
	COMMAND trans1_Level_LEVEL_HI_write; \
	VARIABLE trans1_Level_LEVEL_OFFSET; \
	MENU trans1_Level_LEVEL_OFFSET_page; \
	COMMAND trans1_Level_LEVEL_OFFSET_read; \
	COMMAND trans1_Level_LEVEL_OFFSET_write; \
	VARIABLE trans1_Level_LIN_TYPE; \
	MENU trans1_Level_LIN_TYPE_page; \
	COMMAND trans1_Level_LIN_TYPE_read; \
	COMMAND trans1_Level_LIN_TYPE_write; \
	COLLECTION trans1_Level_VIEW_1; \
	MENU trans1_Level_VIEW_1_page; \
	MENU trans1_Level_Simple_Dialog_Optional_A; \
	UNIT trans1_Level_unit_level_1; \
	UNIT trans1_Level_unit_primary_value_1; \
	UNIT trans1_Level_unit_sensor_value_1

#define USE_TRANS1_LEVEL_OPTIONAL_B \
	USE_TRANS1_LEVEL_OPTIONAL_BOTH; \
	MENU trans1_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_LEVEL_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read

#define USE_TRANS_LEVEL_MANDATORY_A(prefix) \
	USE_TRANS_LEVEL_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_LEVEL_MANDATORY_B(prefix) \
	USE_TRANS_LEVEL_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## PRIMARY_VALUE; \
	VARIABLE prefix ## PRIMARY_VALUE_Value; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Condensed; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Quality; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Limit; \
	MENU prefix ## PRIMARY_VALUE_page; \
	COMMAND prefix ## PRIMARY_VALUE_read; \
	VARIABLE prefix ## PRIMARY_VALUE_UNIT; \
	MENU prefix ## PRIMARY_VALUE_UNIT_page; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_read; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_write; \
	VARIABLE prefix ## LEVEL; \
	MENU prefix ## LEVEL_page; \
	COMMAND prefix ## LEVEL_read; \
	VARIABLE prefix ## LEVEL_UNIT; \
	MENU prefix ## LEVEL_UNIT_page; \
	COMMAND prefix ## LEVEL_UNIT_read; \
	COMMAND prefix ## LEVEL_UNIT_write; \
	VARIABLE prefix ## SENSOR_VALUE; \
	MENU prefix ## SENSOR_VALUE_page; \
	COMMAND prefix ## SENSOR_VALUE_read; \
	VARIABLE prefix ## SENSOR_UNIT; \
	MENU prefix ## SENSOR_UNIT_page; \
	COMMAND prefix ## SENSOR_UNIT_read; \
	COMMAND prefix ## SENSOR_UNIT_write; \
	VARIABLE prefix ## SENSOR_OFFSET; \
	MENU prefix ## SENSOR_OFFSET_page; \
	COMMAND prefix ## SENSOR_OFFSET_read; \
	COMMAND prefix ## SENSOR_OFFSET_write; \
	VARIABLE prefix ## CAL_TYPE; \
	MENU prefix ## CAL_TYPE_page; \
	COMMAND prefix ## CAL_TYPE_read; \
	COMMAND prefix ## CAL_TYPE_write; \
	VARIABLE prefix ## CAL_POINT_LO; \
	MENU prefix ## CAL_POINT_LO_page; \
	COMMAND prefix ## CAL_POINT_LO_read; \
	COMMAND prefix ## CAL_POINT_LO_write; \
	VARIABLE prefix ## CAL_POINT_HI; \
	MENU prefix ## CAL_POINT_HI_page; \
	COMMAND prefix ## CAL_POINT_HI_read; \
	COMMAND prefix ## CAL_POINT_HI_write; \
	VARIABLE prefix ## LEVEL_LO; \
	MENU prefix ## LEVEL_LO_page; \
	COMMAND prefix ## LEVEL_LO_read; \
	COMMAND prefix ## LEVEL_LO_write; \
	VARIABLE prefix ## LEVEL_HI; \
	MENU prefix ## LEVEL_HI_page; \
	COMMAND prefix ## LEVEL_HI_read; \
	COMMAND prefix ## LEVEL_HI_write; \
	VARIABLE prefix ## LEVEL_OFFSET; \
	MENU prefix ## LEVEL_OFFSET_page; \
	COMMAND prefix ## LEVEL_OFFSET_read; \
	COMMAND prefix ## LEVEL_OFFSET_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B; \
	UNIT prefix ## unit_level_1; \
	UNIT prefix ## unit_primary_value_1; \
	UNIT prefix ## unit_sensor_value_1

#define USE_TRANS_LEVEL_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## SECONDARY_VALUE_1; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Value; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE prefix ## SECONDARY_VALUE_1_Status_Limit; \
	MENU prefix ## SECONDARY_VALUE_1_page; \
	COMMAND prefix ## SECONDARY_VALUE_1_read; \
	VARIABLE prefix ## SECONDARY_VALUE_1_UNIT; \
	MENU prefix ## SECONDARY_VALUE_1_UNIT_page; \
	COMMAND prefix ## SECONDARY_VALUE_1_UNIT_read; \
	COMMAND prefix ## SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION prefix ## SECONDARY_VALUE_2; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Value; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE prefix ## SECONDARY_VALUE_2_Status_Limit; \
	MENU prefix ## SECONDARY_VALUE_2_page; \
	COMMAND prefix ## SECONDARY_VALUE_2_read; \
	VARIABLE prefix ## SECONDARY_VALUE_2_UNIT; \
	MENU prefix ## SECONDARY_VALUE_2_UNIT_page; \
	COMMAND prefix ## SECONDARY_VALUE_2_UNIT_read; \
	COMMAND prefix ## SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE prefix ## LIN_DIAMETER; \
	MENU prefix ## LIN_DIAMETER_page; \
	COMMAND prefix ## LIN_DIAMETER_read; \
	COMMAND prefix ## LIN_DIAMETER_write; \
	VARIABLE prefix ## LIN_VOLUME; \
	MENU prefix ## LIN_VOLUME_page; \
	COMMAND prefix ## LIN_VOLUME_read; \
	COMMAND prefix ## LIN_VOLUME_write; \
	VARIABLE prefix ## SENSOR_HIGH_LIMIT; \
	MENU prefix ## SENSOR_HIGH_LIMIT_page; \
	COMMAND prefix ## SENSOR_HIGH_LIMIT_read; \
	VARIABLE prefix ## SENSOR_LOW_LIMIT; \
	MENU prefix ## SENSOR_LOW_LIMIT_page; \
	COMMAND prefix ## SENSOR_LOW_LIMIT_read; \
	VARIABLE prefix ## MAX_SENSOR_VALUE; \
	MENU prefix ## MAX_SENSOR_VALUE_page; \
	COMMAND prefix ## MAX_SENSOR_VALUE_read; \
	COMMAND prefix ## MAX_SENSOR_VALUE_write; \
	VARIABLE prefix ## MIN_SENSOR_VALUE; \
	MENU prefix ## MIN_SENSOR_VALUE_page; \
	COMMAND prefix ## MIN_SENSOR_VALUE_read; \
	COMMAND prefix ## MIN_SENSOR_VALUE_write; \
	VARIABLE prefix ## TEMPERATURE; \
	MENU prefix ## TEMPERATURE_page; \
	COMMAND prefix ## TEMPERATURE_read; \
	VARIABLE prefix ## TEMPERATURE_UNIT; \
	MENU prefix ## TEMPERATURE_UNIT_page; \
	COMMAND prefix ## TEMPERATURE_UNIT_read; \
	COMMAND prefix ## TEMPERATURE_UNIT_write; \
	VARIABLE prefix ## MAX_TEMPERATURE; \
	MENU prefix ## MAX_TEMPERATURE_page; \
	COMMAND prefix ## MAX_TEMPERATURE_read; \
	COMMAND prefix ## MAX_TEMPERATURE_write; \
	VARIABLE prefix ## MIN_TEMPERATURE; \
	MENU prefix ## MIN_TEMPERATURE_page; \
	COMMAND prefix ## MIN_TEMPERATURE_read; \
	COMMAND prefix ## MIN_TEMPERATURE_write; \
	VARIABLE prefix ## TAB_ENTRY; \
	MENU prefix ## TAB_ENTRY_page; \
	COMMAND prefix ## TAB_ENTRY_read; \
	COMMAND prefix ## TAB_ENTRY_write; \
	COLLECTION prefix ## TAB_X_Y_VALUE; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Lower_Value; \
	MENU prefix ## TAB_X_Y_VALUE_page; \
	COMMAND prefix ## TAB_X_Y_VALUE_read; \
	COMMAND prefix ## TAB_X_Y_VALUE_write; \
	VARIABLE prefix ## TAB_MIN_NUMBER; \
	MENU prefix ## TAB_MIN_NUMBER_page; \
	COMMAND prefix ## TAB_MIN_NUMBER_read; \
	VARIABLE prefix ## TAB_MAX_NUMBER; \
	MENU prefix ## TAB_MAX_NUMBER_page; \
	COMMAND prefix ## TAB_MAX_NUMBER_read; \
	VARIABLE prefix ## TAB_OP_CODE; \
	MENU prefix ## TAB_OP_CODE_page; \
	COMMAND prefix ## TAB_OP_CODE_read; \
	COMMAND prefix ## TAB_OP_CODE_write; \
	VARIABLE prefix ## TAB_STATUS; \
	MENU prefix ## TAB_STATUS_page; \
	COMMAND prefix ## TAB_STATUS_read; \
	VARIABLE prefix ## TAB_ACTUAL_NUMBER; \
	MENU prefix ## TAB_ACTUAL_NUMBER_page; \
	COMMAND prefix ## TAB_ACTUAL_NUMBER_read; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## unit_level_2; \
	UNIT prefix ## unit_temperature; \
	UNIT prefix ## unit_primary_value_2; \
	UNIT prefix ## unit_sensor_value_2; \
	UNIT prefix ## unit_secondary_value_1; \
	UNIT prefix ## unit_secondary_value_2

#define USE_TRANS_LEVEL_OPTIONAL_A(prefix) \
	USE_TRANS_LEVEL_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## PRIMARY_VALUE; \
	VARIABLE prefix ## PRIMARY_VALUE_Value; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Condensed; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Quality; \
	VARIABLE prefix ## PRIMARY_VALUE_Status_Limit; \
	MENU prefix ## PRIMARY_VALUE_page; \
	COMMAND prefix ## PRIMARY_VALUE_read; \
	VARIABLE prefix ## PRIMARY_VALUE_UNIT; \
	MENU prefix ## PRIMARY_VALUE_UNIT_page; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_read; \
	COMMAND prefix ## PRIMARY_VALUE_UNIT_write; \
	VARIABLE prefix ## LEVEL; \
	MENU prefix ## LEVEL_page; \
	COMMAND prefix ## LEVEL_read; \
	VARIABLE prefix ## LEVEL_UNIT; \
	MENU prefix ## LEVEL_UNIT_page; \
	COMMAND prefix ## LEVEL_UNIT_read; \
	COMMAND prefix ## LEVEL_UNIT_write; \
	VARIABLE prefix ## SENSOR_VALUE; \
	MENU prefix ## SENSOR_VALUE_page; \
	COMMAND prefix ## SENSOR_VALUE_read; \
	VARIABLE prefix ## SENSOR_UNIT; \
	MENU prefix ## SENSOR_UNIT_page; \
	COMMAND prefix ## SENSOR_UNIT_read; \
	COMMAND prefix ## SENSOR_UNIT_write; \
	VARIABLE prefix ## SENSOR_OFFSET; \
	MENU prefix ## SENSOR_OFFSET_page; \
	COMMAND prefix ## SENSOR_OFFSET_read; \
	COMMAND prefix ## SENSOR_OFFSET_write; \
	VARIABLE prefix ## CAL_TYPE; \
	MENU prefix ## CAL_TYPE_page; \
	COMMAND prefix ## CAL_TYPE_read; \
	COMMAND prefix ## CAL_TYPE_write; \
	VARIABLE prefix ## CAL_POINT_LO; \
	MENU prefix ## CAL_POINT_LO_page; \
	COMMAND prefix ## CAL_POINT_LO_read; \
	COMMAND prefix ## CAL_POINT_LO_write; \
	VARIABLE prefix ## CAL_POINT_HI; \
	MENU prefix ## CAL_POINT_HI_page; \
	COMMAND prefix ## CAL_POINT_HI_read; \
	COMMAND prefix ## CAL_POINT_HI_write; \
	VARIABLE prefix ## LEVEL_LO; \
	MENU prefix ## LEVEL_LO_page; \
	COMMAND prefix ## LEVEL_LO_read; \
	COMMAND prefix ## LEVEL_LO_write; \
	VARIABLE prefix ## LEVEL_HI; \
	MENU prefix ## LEVEL_HI_page; \
	COMMAND prefix ## LEVEL_HI_read; \
	COMMAND prefix ## LEVEL_HI_write; \
	VARIABLE prefix ## LEVEL_OFFSET; \
	MENU prefix ## LEVEL_OFFSET_page; \
	COMMAND prefix ## LEVEL_OFFSET_read; \
	COMMAND prefix ## LEVEL_OFFSET_write; \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A; \
	UNIT prefix ## unit_level_1; \
	UNIT prefix ## unit_primary_value_1; \
	UNIT prefix ## unit_sensor_value_1

#define USE_TRANS_LEVEL_OPTIONAL_B(prefix) \
	USE_TRANS_LEVEL_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans1_Level_)
#define USE_TRANS1_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans1_Level_)
#define USE_TRANS1_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans1_Level_)
#define USE_TRANS1_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans1_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_LEVEL_MANDATORY_BOTH \
	BLOCK trans2_Level_block; \
	COLLECTION trans2_Level_BLOCK_OBJECT; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Level_BLOCK_OBJECT_page; \
	COMMAND trans2_Level_BLOCK_OBJECT_read; \
	VARIABLE trans2_Level_ST_REV; \
	MENU trans2_Level_ST_REV_page; \
	COMMAND trans2_Level_ST_REV_read; \
	VARIABLE trans2_Level_TAG_DESC; \
	MENU trans2_Level_TAG_DESC_page; \
	COMMAND trans2_Level_TAG_DESC_read; \
	COMMAND trans2_Level_TAG_DESC_write; \
	VARIABLE trans2_Level_STRATEGY; \
	MENU trans2_Level_STRATEGY_page; \
	COMMAND trans2_Level_STRATEGY_read; \
	COMMAND trans2_Level_STRATEGY_write; \
	VARIABLE trans2_Level_ALERT_KEY; \
	MENU trans2_Level_ALERT_KEY_page; \
	COMMAND trans2_Level_ALERT_KEY_read; \
	COMMAND trans2_Level_ALERT_KEY_write; \
	VARIABLE trans2_Level_TARGET_MODE; \
	MENU trans2_Level_TARGET_MODE_page; \
	COMMAND trans2_Level_TARGET_MODE_read; \
	COMMAND trans2_Level_TARGET_MODE_write; \
	COLLECTION trans2_Level_MODE_BLK; \
	VARIABLE trans2_Level_MODE_BLK_Actual; \
	VARIABLE trans2_Level_MODE_BLK_Permitted; \
	VARIABLE trans2_Level_MODE_BLK_Normal; \
	MENU trans2_Level_MODE_BLK_page; \
	COMMAND trans2_Level_MODE_BLK_read; \
	COLLECTION trans2_Level_ALARM_SUM; \
	VARIABLE trans2_Level_ALARM_SUM_Current; \
	VARIABLE trans2_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Level_ALARM_SUM_Unreported; \
	VARIABLE trans2_Level_ALARM_SUM_Disabled; \
	MENU trans2_Level_ALARM_SUM_page; \
	COMMAND trans2_Level_ALARM_SUM_read

#define USE_TRANS2_LEVEL_MANDATORY_A \
	USE_TRANS2_LEVEL_MANDATORY_BOTH; \
	MENU trans2_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS2_LEVEL_MANDATORY_B \
	USE_TRANS2_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans2_Level_PRIMARY_VALUE; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans2_Level_PRIMARY_VALUE_page; \
	COMMAND trans2_Level_PRIMARY_VALUE_read; \
	VARIABLE trans2_Level_PRIMARY_VALUE_UNIT; \
	MENU trans2_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans2_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans2_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans2_Level_LEVEL; \
	MENU trans2_Level_LEVEL_page; \
	COMMAND trans2_Level_LEVEL_read; \
	VARIABLE trans2_Level_LEVEL_UNIT; \
	MENU trans2_Level_LEVEL_UNIT_page; \
	COMMAND trans2_Level_LEVEL_UNIT_read; \
	COMMAND trans2_Level_LEVEL_UNIT_write; \
	VARIABLE trans2_Level_SENSOR_VALUE; \
	MENU trans2_Level_SENSOR_VALUE_page; \
	COMMAND trans2_Level_SENSOR_VALUE_read; \
	VARIABLE trans2_Level_SENSOR_UNIT; \
	MENU trans2_Level_SENSOR_UNIT_page; \
	COMMAND trans2_Level_SENSOR_UNIT_read; \
	COMMAND trans2_Level_SENSOR_UNIT_write; \
	VARIABLE trans2_Level_SENSOR_OFFSET; \
	MENU trans2_Level_SENSOR_OFFSET_page; \
	COMMAND trans2_Level_SENSOR_OFFSET_read; \
	COMMAND trans2_Level_SENSOR_OFFSET_write; \
	VARIABLE trans2_Level_CAL_TYPE; \
	MENU trans2_Level_CAL_TYPE_page; \
	COMMAND trans2_Level_CAL_TYPE_read; \
	COMMAND trans2_Level_CAL_TYPE_write; \
	VARIABLE trans2_Level_CAL_POINT_LO; \
	MENU trans2_Level_CAL_POINT_LO_page; \
	COMMAND trans2_Level_CAL_POINT_LO_read; \
	COMMAND trans2_Level_CAL_POINT_LO_write; \
	VARIABLE trans2_Level_CAL_POINT_HI; \
	MENU trans2_Level_CAL_POINT_HI_page; \
	COMMAND trans2_Level_CAL_POINT_HI_read; \
	COMMAND trans2_Level_CAL_POINT_HI_write; \
	VARIABLE trans2_Level_LEVEL_LO; \
	MENU trans2_Level_LEVEL_LO_page; \
	COMMAND trans2_Level_LEVEL_LO_read; \
	COMMAND trans2_Level_LEVEL_LO_write; \
	VARIABLE trans2_Level_LEVEL_HI; \
	MENU trans2_Level_LEVEL_HI_page; \
	COMMAND trans2_Level_LEVEL_HI_read; \
	COMMAND trans2_Level_LEVEL_HI_write; \
	VARIABLE trans2_Level_LEVEL_OFFSET; \
	MENU trans2_Level_LEVEL_OFFSET_page; \
	COMMAND trans2_Level_LEVEL_OFFSET_read; \
	COMMAND trans2_Level_LEVEL_OFFSET_write; \
	VARIABLE trans2_Level_LIN_TYPE; \
	MENU trans2_Level_LIN_TYPE_page; \
	COMMAND trans2_Level_LIN_TYPE_read; \
	COMMAND trans2_Level_LIN_TYPE_write; \
	COLLECTION trans2_Level_VIEW_1; \
	MENU trans2_Level_VIEW_1_page; \
	MENU trans2_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans2_Level_unit_level_1; \
	UNIT trans2_Level_unit_primary_value_1; \
	UNIT trans2_Level_unit_sensor_value_1

#define USE_TRANS2_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans2_Level_SECONDARY_VALUE_1; \
	VARIABLE trans2_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans2_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans2_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans2_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans2_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans2_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans2_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans2_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans2_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans2_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans2_Level_SECONDARY_VALUE_2; \
	VARIABLE trans2_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans2_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans2_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans2_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans2_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans2_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans2_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans2_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans2_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans2_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans2_Level_LIN_DIAMETER; \
	MENU trans2_Level_LIN_DIAMETER_page; \
	COMMAND trans2_Level_LIN_DIAMETER_read; \
	COMMAND trans2_Level_LIN_DIAMETER_write; \
	VARIABLE trans2_Level_LIN_VOLUME; \
	MENU trans2_Level_LIN_VOLUME_page; \
	COMMAND trans2_Level_LIN_VOLUME_read; \
	COMMAND trans2_Level_LIN_VOLUME_write; \
	VARIABLE trans2_Level_SENSOR_HIGH_LIMIT; \
	MENU trans2_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans2_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans2_Level_SENSOR_LOW_LIMIT; \
	MENU trans2_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans2_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans2_Level_MAX_SENSOR_VALUE; \
	MENU trans2_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans2_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans2_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans2_Level_MIN_SENSOR_VALUE; \
	MENU trans2_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans2_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans2_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans2_Level_TEMPERATURE; \
	MENU trans2_Level_TEMPERATURE_page; \
	COMMAND trans2_Level_TEMPERATURE_read; \
	VARIABLE trans2_Level_TEMPERATURE_UNIT; \
	MENU trans2_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans2_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans2_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans2_Level_MAX_TEMPERATURE; \
	MENU trans2_Level_MAX_TEMPERATURE_page; \
	COMMAND trans2_Level_MAX_TEMPERATURE_read; \
	COMMAND trans2_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans2_Level_MIN_TEMPERATURE; \
	MENU trans2_Level_MIN_TEMPERATURE_page; \
	COMMAND trans2_Level_MIN_TEMPERATURE_read; \
	COMMAND trans2_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans2_Level_TAB_ENTRY; \
	MENU trans2_Level_TAB_ENTRY_page; \
	COMMAND trans2_Level_TAB_ENTRY_read; \
	COMMAND trans2_Level_TAB_ENTRY_write; \
	COLLECTION trans2_Level_TAB_X_Y_VALUE; \
	VARIABLE trans2_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans2_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans2_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans2_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans2_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans2_Level_TAB_MIN_NUMBER; \
	MENU trans2_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans2_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans2_Level_TAB_MAX_NUMBER; \
	MENU trans2_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans2_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans2_Level_TAB_OP_CODE; \
	MENU trans2_Level_TAB_OP_CODE_page; \
	COMMAND trans2_Level_TAB_OP_CODE_read; \
	COMMAND trans2_Level_TAB_OP_CODE_write; \
	VARIABLE trans2_Level_TAB_STATUS; \
	MENU trans2_Level_TAB_STATUS_page; \
	COMMAND trans2_Level_TAB_STATUS_read; \
	VARIABLE trans2_Level_TAB_ACTUAL_NUMBER; \
	MENU trans2_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans2_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans2_Level_VIEW_2; \
	MENU trans2_Level_VIEW_2_page; \
	COLLECTION trans2_Level_VIEW_3; \
	MENU trans2_Level_VIEW_3_page; \
	UNIT trans2_Level_unit_level_2; \
	UNIT trans2_Level_unit_temperature; \
	UNIT trans2_Level_unit_primary_value_2; \
	UNIT trans2_Level_unit_sensor_value_2; \
	UNIT trans2_Level_unit_secondary_value_1; \
	UNIT trans2_Level_unit_secondary_value_2

#define USE_TRANS2_LEVEL_OPTIONAL_A \
	USE_TRANS2_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans2_Level_PRIMARY_VALUE; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans2_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans2_Level_PRIMARY_VALUE_page; \
	COMMAND trans2_Level_PRIMARY_VALUE_read; \
	VARIABLE trans2_Level_PRIMARY_VALUE_UNIT; \
	MENU trans2_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans2_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans2_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans2_Level_LEVEL; \
	MENU trans2_Level_LEVEL_page; \
	COMMAND trans2_Level_LEVEL_read; \
	VARIABLE trans2_Level_LEVEL_UNIT; \
	MENU trans2_Level_LEVEL_UNIT_page; \
	COMMAND trans2_Level_LEVEL_UNIT_read; \
	COMMAND trans2_Level_LEVEL_UNIT_write; \
	VARIABLE trans2_Level_SENSOR_VALUE; \
	MENU trans2_Level_SENSOR_VALUE_page; \
	COMMAND trans2_Level_SENSOR_VALUE_read; \
	VARIABLE trans2_Level_SENSOR_UNIT; \
	MENU trans2_Level_SENSOR_UNIT_page; \
	COMMAND trans2_Level_SENSOR_UNIT_read; \
	COMMAND trans2_Level_SENSOR_UNIT_write; \
	VARIABLE trans2_Level_SENSOR_OFFSET; \
	MENU trans2_Level_SENSOR_OFFSET_page; \
	COMMAND trans2_Level_SENSOR_OFFSET_read; \
	COMMAND trans2_Level_SENSOR_OFFSET_write; \
	VARIABLE trans2_Level_CAL_TYPE; \
	MENU trans2_Level_CAL_TYPE_page; \
	COMMAND trans2_Level_CAL_TYPE_read; \
	COMMAND trans2_Level_CAL_TYPE_write; \
	VARIABLE trans2_Level_CAL_POINT_LO; \
	MENU trans2_Level_CAL_POINT_LO_page; \
	COMMAND trans2_Level_CAL_POINT_LO_read; \
	COMMAND trans2_Level_CAL_POINT_LO_write; \
	VARIABLE trans2_Level_CAL_POINT_HI; \
	MENU trans2_Level_CAL_POINT_HI_page; \
	COMMAND trans2_Level_CAL_POINT_HI_read; \
	COMMAND trans2_Level_CAL_POINT_HI_write; \
	VARIABLE trans2_Level_LEVEL_LO; \
	MENU trans2_Level_LEVEL_LO_page; \
	COMMAND trans2_Level_LEVEL_LO_read; \
	COMMAND trans2_Level_LEVEL_LO_write; \
	VARIABLE trans2_Level_LEVEL_HI; \
	MENU trans2_Level_LEVEL_HI_page; \
	COMMAND trans2_Level_LEVEL_HI_read; \
	COMMAND trans2_Level_LEVEL_HI_write; \
	VARIABLE trans2_Level_LEVEL_OFFSET; \
	MENU trans2_Level_LEVEL_OFFSET_page; \
	COMMAND trans2_Level_LEVEL_OFFSET_read; \
	COMMAND trans2_Level_LEVEL_OFFSET_write; \
	VARIABLE trans2_Level_LIN_TYPE; \
	MENU trans2_Level_LIN_TYPE_page; \
	COMMAND trans2_Level_LIN_TYPE_read; \
	COMMAND trans2_Level_LIN_TYPE_write; \
	COLLECTION trans2_Level_VIEW_1; \
	MENU trans2_Level_VIEW_1_page; \
	MENU trans2_Level_Simple_Dialog_Optional_A; \
	UNIT trans2_Level_unit_level_1; \
	UNIT trans2_Level_unit_primary_value_1; \
	UNIT trans2_Level_unit_sensor_value_1

#define USE_TRANS2_LEVEL_OPTIONAL_B \
	USE_TRANS2_LEVEL_OPTIONAL_BOTH; \
	MENU trans2_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans2_Level_)
#define USE_TRANS2_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans2_Level_)
#define USE_TRANS2_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans2_Level_)
#define USE_TRANS2_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans2_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_LEVEL_MANDATORY_BOTH \
	BLOCK trans3_Level_block; \
	COLLECTION trans3_Level_BLOCK_OBJECT; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Level_BLOCK_OBJECT_page; \
	COMMAND trans3_Level_BLOCK_OBJECT_read; \
	VARIABLE trans3_Level_ST_REV; \
	MENU trans3_Level_ST_REV_page; \
	COMMAND trans3_Level_ST_REV_read; \
	VARIABLE trans3_Level_TAG_DESC; \
	MENU trans3_Level_TAG_DESC_page; \
	COMMAND trans3_Level_TAG_DESC_read; \
	COMMAND trans3_Level_TAG_DESC_write; \
	VARIABLE trans3_Level_STRATEGY; \
	MENU trans3_Level_STRATEGY_page; \
	COMMAND trans3_Level_STRATEGY_read; \
	COMMAND trans3_Level_STRATEGY_write; \
	VARIABLE trans3_Level_ALERT_KEY; \
	MENU trans3_Level_ALERT_KEY_page; \
	COMMAND trans3_Level_ALERT_KEY_read; \
	COMMAND trans3_Level_ALERT_KEY_write; \
	VARIABLE trans3_Level_TARGET_MODE; \
	MENU trans3_Level_TARGET_MODE_page; \
	COMMAND trans3_Level_TARGET_MODE_read; \
	COMMAND trans3_Level_TARGET_MODE_write; \
	COLLECTION trans3_Level_MODE_BLK; \
	VARIABLE trans3_Level_MODE_BLK_Actual; \
	VARIABLE trans3_Level_MODE_BLK_Permitted; \
	VARIABLE trans3_Level_MODE_BLK_Normal; \
	MENU trans3_Level_MODE_BLK_page; \
	COMMAND trans3_Level_MODE_BLK_read; \
	COLLECTION trans3_Level_ALARM_SUM; \
	VARIABLE trans3_Level_ALARM_SUM_Current; \
	VARIABLE trans3_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Level_ALARM_SUM_Unreported; \
	VARIABLE trans3_Level_ALARM_SUM_Disabled; \
	MENU trans3_Level_ALARM_SUM_page; \
	COMMAND trans3_Level_ALARM_SUM_read

#define USE_TRANS3_LEVEL_MANDATORY_A \
	USE_TRANS3_LEVEL_MANDATORY_BOTH; \
	MENU trans3_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS3_LEVEL_MANDATORY_B \
	USE_TRANS3_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans3_Level_PRIMARY_VALUE; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans3_Level_PRIMARY_VALUE_page; \
	COMMAND trans3_Level_PRIMARY_VALUE_read; \
	VARIABLE trans3_Level_PRIMARY_VALUE_UNIT; \
	MENU trans3_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans3_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans3_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans3_Level_LEVEL; \
	MENU trans3_Level_LEVEL_page; \
	COMMAND trans3_Level_LEVEL_read; \
	VARIABLE trans3_Level_LEVEL_UNIT; \
	MENU trans3_Level_LEVEL_UNIT_page; \
	COMMAND trans3_Level_LEVEL_UNIT_read; \
	COMMAND trans3_Level_LEVEL_UNIT_write; \
	VARIABLE trans3_Level_SENSOR_VALUE; \
	MENU trans3_Level_SENSOR_VALUE_page; \
	COMMAND trans3_Level_SENSOR_VALUE_read; \
	VARIABLE trans3_Level_SENSOR_UNIT; \
	MENU trans3_Level_SENSOR_UNIT_page; \
	COMMAND trans3_Level_SENSOR_UNIT_read; \
	COMMAND trans3_Level_SENSOR_UNIT_write; \
	VARIABLE trans3_Level_SENSOR_OFFSET; \
	MENU trans3_Level_SENSOR_OFFSET_page; \
	COMMAND trans3_Level_SENSOR_OFFSET_read; \
	COMMAND trans3_Level_SENSOR_OFFSET_write; \
	VARIABLE trans3_Level_CAL_TYPE; \
	MENU trans3_Level_CAL_TYPE_page; \
	COMMAND trans3_Level_CAL_TYPE_read; \
	COMMAND trans3_Level_CAL_TYPE_write; \
	VARIABLE trans3_Level_CAL_POINT_LO; \
	MENU trans3_Level_CAL_POINT_LO_page; \
	COMMAND trans3_Level_CAL_POINT_LO_read; \
	COMMAND trans3_Level_CAL_POINT_LO_write; \
	VARIABLE trans3_Level_CAL_POINT_HI; \
	MENU trans3_Level_CAL_POINT_HI_page; \
	COMMAND trans3_Level_CAL_POINT_HI_read; \
	COMMAND trans3_Level_CAL_POINT_HI_write; \
	VARIABLE trans3_Level_LEVEL_LO; \
	MENU trans3_Level_LEVEL_LO_page; \
	COMMAND trans3_Level_LEVEL_LO_read; \
	COMMAND trans3_Level_LEVEL_LO_write; \
	VARIABLE trans3_Level_LEVEL_HI; \
	MENU trans3_Level_LEVEL_HI_page; \
	COMMAND trans3_Level_LEVEL_HI_read; \
	COMMAND trans3_Level_LEVEL_HI_write; \
	VARIABLE trans3_Level_LEVEL_OFFSET; \
	MENU trans3_Level_LEVEL_OFFSET_page; \
	COMMAND trans3_Level_LEVEL_OFFSET_read; \
	COMMAND trans3_Level_LEVEL_OFFSET_write; \
	VARIABLE trans3_Level_LIN_TYPE; \
	MENU trans3_Level_LIN_TYPE_page; \
	COMMAND trans3_Level_LIN_TYPE_read; \
	COMMAND trans3_Level_LIN_TYPE_write; \
	COLLECTION trans3_Level_VIEW_1; \
	MENU trans3_Level_VIEW_1_page; \
	MENU trans3_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans3_Level_unit_level_1; \
	UNIT trans3_Level_unit_primary_value_1; \
	UNIT trans3_Level_unit_sensor_value_1

#define USE_TRANS3_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans3_Level_SECONDARY_VALUE_1; \
	VARIABLE trans3_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans3_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans3_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans3_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans3_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans3_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans3_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans3_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans3_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans3_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans3_Level_SECONDARY_VALUE_2; \
	VARIABLE trans3_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans3_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans3_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans3_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans3_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans3_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans3_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans3_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans3_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans3_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans3_Level_LIN_DIAMETER; \
	MENU trans3_Level_LIN_DIAMETER_page; \
	COMMAND trans3_Level_LIN_DIAMETER_read; \
	COMMAND trans3_Level_LIN_DIAMETER_write; \
	VARIABLE trans3_Level_LIN_VOLUME; \
	MENU trans3_Level_LIN_VOLUME_page; \
	COMMAND trans3_Level_LIN_VOLUME_read; \
	COMMAND trans3_Level_LIN_VOLUME_write; \
	VARIABLE trans3_Level_SENSOR_HIGH_LIMIT; \
	MENU trans3_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans3_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans3_Level_SENSOR_LOW_LIMIT; \
	MENU trans3_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans3_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans3_Level_MAX_SENSOR_VALUE; \
	MENU trans3_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans3_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans3_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans3_Level_MIN_SENSOR_VALUE; \
	MENU trans3_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans3_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans3_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans3_Level_TEMPERATURE; \
	MENU trans3_Level_TEMPERATURE_page; \
	COMMAND trans3_Level_TEMPERATURE_read; \
	VARIABLE trans3_Level_TEMPERATURE_UNIT; \
	MENU trans3_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans3_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans3_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans3_Level_MAX_TEMPERATURE; \
	MENU trans3_Level_MAX_TEMPERATURE_page; \
	COMMAND trans3_Level_MAX_TEMPERATURE_read; \
	COMMAND trans3_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans3_Level_MIN_TEMPERATURE; \
	MENU trans3_Level_MIN_TEMPERATURE_page; \
	COMMAND trans3_Level_MIN_TEMPERATURE_read; \
	COMMAND trans3_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans3_Level_TAB_ENTRY; \
	MENU trans3_Level_TAB_ENTRY_page; \
	COMMAND trans3_Level_TAB_ENTRY_read; \
	COMMAND trans3_Level_TAB_ENTRY_write; \
	COLLECTION trans3_Level_TAB_X_Y_VALUE; \
	VARIABLE trans3_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans3_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans3_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans3_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans3_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans3_Level_TAB_MIN_NUMBER; \
	MENU trans3_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans3_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans3_Level_TAB_MAX_NUMBER; \
	MENU trans3_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans3_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans3_Level_TAB_OP_CODE; \
	MENU trans3_Level_TAB_OP_CODE_page; \
	COMMAND trans3_Level_TAB_OP_CODE_read; \
	COMMAND trans3_Level_TAB_OP_CODE_write; \
	VARIABLE trans3_Level_TAB_STATUS; \
	MENU trans3_Level_TAB_STATUS_page; \
	COMMAND trans3_Level_TAB_STATUS_read; \
	VARIABLE trans3_Level_TAB_ACTUAL_NUMBER; \
	MENU trans3_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans3_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans3_Level_VIEW_2; \
	MENU trans3_Level_VIEW_2_page; \
	COLLECTION trans3_Level_VIEW_3; \
	MENU trans3_Level_VIEW_3_page; \
	UNIT trans3_Level_unit_level_2; \
	UNIT trans3_Level_unit_temperature; \
	UNIT trans3_Level_unit_primary_value_2; \
	UNIT trans3_Level_unit_sensor_value_2; \
	UNIT trans3_Level_unit_secondary_value_1; \
	UNIT trans3_Level_unit_secondary_value_2

#define USE_TRANS3_LEVEL_OPTIONAL_A \
	USE_TRANS3_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans3_Level_PRIMARY_VALUE; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans3_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans3_Level_PRIMARY_VALUE_page; \
	COMMAND trans3_Level_PRIMARY_VALUE_read; \
	VARIABLE trans3_Level_PRIMARY_VALUE_UNIT; \
	MENU trans3_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans3_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans3_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans3_Level_LEVEL; \
	MENU trans3_Level_LEVEL_page; \
	COMMAND trans3_Level_LEVEL_read; \
	VARIABLE trans3_Level_LEVEL_UNIT; \
	MENU trans3_Level_LEVEL_UNIT_page; \
	COMMAND trans3_Level_LEVEL_UNIT_read; \
	COMMAND trans3_Level_LEVEL_UNIT_write; \
	VARIABLE trans3_Level_SENSOR_VALUE; \
	MENU trans3_Level_SENSOR_VALUE_page; \
	COMMAND trans3_Level_SENSOR_VALUE_read; \
	VARIABLE trans3_Level_SENSOR_UNIT; \
	MENU trans3_Level_SENSOR_UNIT_page; \
	COMMAND trans3_Level_SENSOR_UNIT_read; \
	COMMAND trans3_Level_SENSOR_UNIT_write; \
	VARIABLE trans3_Level_SENSOR_OFFSET; \
	MENU trans3_Level_SENSOR_OFFSET_page; \
	COMMAND trans3_Level_SENSOR_OFFSET_read; \
	COMMAND trans3_Level_SENSOR_OFFSET_write; \
	VARIABLE trans3_Level_CAL_TYPE; \
	MENU trans3_Level_CAL_TYPE_page; \
	COMMAND trans3_Level_CAL_TYPE_read; \
	COMMAND trans3_Level_CAL_TYPE_write; \
	VARIABLE trans3_Level_CAL_POINT_LO; \
	MENU trans3_Level_CAL_POINT_LO_page; \
	COMMAND trans3_Level_CAL_POINT_LO_read; \
	COMMAND trans3_Level_CAL_POINT_LO_write; \
	VARIABLE trans3_Level_CAL_POINT_HI; \
	MENU trans3_Level_CAL_POINT_HI_page; \
	COMMAND trans3_Level_CAL_POINT_HI_read; \
	COMMAND trans3_Level_CAL_POINT_HI_write; \
	VARIABLE trans3_Level_LEVEL_LO; \
	MENU trans3_Level_LEVEL_LO_page; \
	COMMAND trans3_Level_LEVEL_LO_read; \
	COMMAND trans3_Level_LEVEL_LO_write; \
	VARIABLE trans3_Level_LEVEL_HI; \
	MENU trans3_Level_LEVEL_HI_page; \
	COMMAND trans3_Level_LEVEL_HI_read; \
	COMMAND trans3_Level_LEVEL_HI_write; \
	VARIABLE trans3_Level_LEVEL_OFFSET; \
	MENU trans3_Level_LEVEL_OFFSET_page; \
	COMMAND trans3_Level_LEVEL_OFFSET_read; \
	COMMAND trans3_Level_LEVEL_OFFSET_write; \
	VARIABLE trans3_Level_LIN_TYPE; \
	MENU trans3_Level_LIN_TYPE_page; \
	COMMAND trans3_Level_LIN_TYPE_read; \
	COMMAND trans3_Level_LIN_TYPE_write; \
	COLLECTION trans3_Level_VIEW_1; \
	MENU trans3_Level_VIEW_1_page; \
	MENU trans3_Level_Simple_Dialog_Optional_A; \
	UNIT trans3_Level_unit_level_1; \
	UNIT trans3_Level_unit_primary_value_1; \
	UNIT trans3_Level_unit_sensor_value_1

#define USE_TRANS3_LEVEL_OPTIONAL_B \
	USE_TRANS3_LEVEL_OPTIONAL_BOTH; \
	MENU trans3_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans3_Level_)
#define USE_TRANS3_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans3_Level_)
#define USE_TRANS3_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans3_Level_)
#define USE_TRANS3_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans3_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_LEVEL_MANDATORY_BOTH \
	BLOCK trans4_Level_block; \
	COLLECTION trans4_Level_BLOCK_OBJECT; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Level_BLOCK_OBJECT_page; \
	COMMAND trans4_Level_BLOCK_OBJECT_read; \
	VARIABLE trans4_Level_ST_REV; \
	MENU trans4_Level_ST_REV_page; \
	COMMAND trans4_Level_ST_REV_read; \
	VARIABLE trans4_Level_TAG_DESC; \
	MENU trans4_Level_TAG_DESC_page; \
	COMMAND trans4_Level_TAG_DESC_read; \
	COMMAND trans4_Level_TAG_DESC_write; \
	VARIABLE trans4_Level_STRATEGY; \
	MENU trans4_Level_STRATEGY_page; \
	COMMAND trans4_Level_STRATEGY_read; \
	COMMAND trans4_Level_STRATEGY_write; \
	VARIABLE trans4_Level_ALERT_KEY; \
	MENU trans4_Level_ALERT_KEY_page; \
	COMMAND trans4_Level_ALERT_KEY_read; \
	COMMAND trans4_Level_ALERT_KEY_write; \
	VARIABLE trans4_Level_TARGET_MODE; \
	MENU trans4_Level_TARGET_MODE_page; \
	COMMAND trans4_Level_TARGET_MODE_read; \
	COMMAND trans4_Level_TARGET_MODE_write; \
	COLLECTION trans4_Level_MODE_BLK; \
	VARIABLE trans4_Level_MODE_BLK_Actual; \
	VARIABLE trans4_Level_MODE_BLK_Permitted; \
	VARIABLE trans4_Level_MODE_BLK_Normal; \
	MENU trans4_Level_MODE_BLK_page; \
	COMMAND trans4_Level_MODE_BLK_read; \
	COLLECTION trans4_Level_ALARM_SUM; \
	VARIABLE trans4_Level_ALARM_SUM_Current; \
	VARIABLE trans4_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Level_ALARM_SUM_Unreported; \
	VARIABLE trans4_Level_ALARM_SUM_Disabled; \
	MENU trans4_Level_ALARM_SUM_page; \
	COMMAND trans4_Level_ALARM_SUM_read

#define USE_TRANS4_LEVEL_MANDATORY_A \
	USE_TRANS4_LEVEL_MANDATORY_BOTH; \
	MENU trans4_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS4_LEVEL_MANDATORY_B \
	USE_TRANS4_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans4_Level_PRIMARY_VALUE; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans4_Level_PRIMARY_VALUE_page; \
	COMMAND trans4_Level_PRIMARY_VALUE_read; \
	VARIABLE trans4_Level_PRIMARY_VALUE_UNIT; \
	MENU trans4_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans4_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans4_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans4_Level_LEVEL; \
	MENU trans4_Level_LEVEL_page; \
	COMMAND trans4_Level_LEVEL_read; \
	VARIABLE trans4_Level_LEVEL_UNIT; \
	MENU trans4_Level_LEVEL_UNIT_page; \
	COMMAND trans4_Level_LEVEL_UNIT_read; \
	COMMAND trans4_Level_LEVEL_UNIT_write; \
	VARIABLE trans4_Level_SENSOR_VALUE; \
	MENU trans4_Level_SENSOR_VALUE_page; \
	COMMAND trans4_Level_SENSOR_VALUE_read; \
	VARIABLE trans4_Level_SENSOR_UNIT; \
	MENU trans4_Level_SENSOR_UNIT_page; \
	COMMAND trans4_Level_SENSOR_UNIT_read; \
	COMMAND trans4_Level_SENSOR_UNIT_write; \
	VARIABLE trans4_Level_SENSOR_OFFSET; \
	MENU trans4_Level_SENSOR_OFFSET_page; \
	COMMAND trans4_Level_SENSOR_OFFSET_read; \
	COMMAND trans4_Level_SENSOR_OFFSET_write; \
	VARIABLE trans4_Level_CAL_TYPE; \
	MENU trans4_Level_CAL_TYPE_page; \
	COMMAND trans4_Level_CAL_TYPE_read; \
	COMMAND trans4_Level_CAL_TYPE_write; \
	VARIABLE trans4_Level_CAL_POINT_LO; \
	MENU trans4_Level_CAL_POINT_LO_page; \
	COMMAND trans4_Level_CAL_POINT_LO_read; \
	COMMAND trans4_Level_CAL_POINT_LO_write; \
	VARIABLE trans4_Level_CAL_POINT_HI; \
	MENU trans4_Level_CAL_POINT_HI_page; \
	COMMAND trans4_Level_CAL_POINT_HI_read; \
	COMMAND trans4_Level_CAL_POINT_HI_write; \
	VARIABLE trans4_Level_LEVEL_LO; \
	MENU trans4_Level_LEVEL_LO_page; \
	COMMAND trans4_Level_LEVEL_LO_read; \
	COMMAND trans4_Level_LEVEL_LO_write; \
	VARIABLE trans4_Level_LEVEL_HI; \
	MENU trans4_Level_LEVEL_HI_page; \
	COMMAND trans4_Level_LEVEL_HI_read; \
	COMMAND trans4_Level_LEVEL_HI_write; \
	VARIABLE trans4_Level_LEVEL_OFFSET; \
	MENU trans4_Level_LEVEL_OFFSET_page; \
	COMMAND trans4_Level_LEVEL_OFFSET_read; \
	COMMAND trans4_Level_LEVEL_OFFSET_write; \
	VARIABLE trans4_Level_LIN_TYPE; \
	MENU trans4_Level_LIN_TYPE_page; \
	COMMAND trans4_Level_LIN_TYPE_read; \
	COMMAND trans4_Level_LIN_TYPE_write; \
	COLLECTION trans4_Level_VIEW_1; \
	MENU trans4_Level_VIEW_1_page; \
	MENU trans4_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans4_Level_unit_level_1; \
	UNIT trans4_Level_unit_primary_value_1; \
	UNIT trans4_Level_unit_sensor_value_1

#define USE_TRANS4_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans4_Level_SECONDARY_VALUE_1; \
	VARIABLE trans4_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans4_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans4_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans4_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans4_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans4_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans4_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans4_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans4_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans4_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans4_Level_SECONDARY_VALUE_2; \
	VARIABLE trans4_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans4_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans4_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans4_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans4_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans4_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans4_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans4_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans4_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans4_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans4_Level_LIN_DIAMETER; \
	MENU trans4_Level_LIN_DIAMETER_page; \
	COMMAND trans4_Level_LIN_DIAMETER_read; \
	COMMAND trans4_Level_LIN_DIAMETER_write; \
	VARIABLE trans4_Level_LIN_VOLUME; \
	MENU trans4_Level_LIN_VOLUME_page; \
	COMMAND trans4_Level_LIN_VOLUME_read; \
	COMMAND trans4_Level_LIN_VOLUME_write; \
	VARIABLE trans4_Level_SENSOR_HIGH_LIMIT; \
	MENU trans4_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans4_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans4_Level_SENSOR_LOW_LIMIT; \
	MENU trans4_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans4_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans4_Level_MAX_SENSOR_VALUE; \
	MENU trans4_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans4_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans4_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans4_Level_MIN_SENSOR_VALUE; \
	MENU trans4_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans4_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans4_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans4_Level_TEMPERATURE; \
	MENU trans4_Level_TEMPERATURE_page; \
	COMMAND trans4_Level_TEMPERATURE_read; \
	VARIABLE trans4_Level_TEMPERATURE_UNIT; \
	MENU trans4_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans4_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans4_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans4_Level_MAX_TEMPERATURE; \
	MENU trans4_Level_MAX_TEMPERATURE_page; \
	COMMAND trans4_Level_MAX_TEMPERATURE_read; \
	COMMAND trans4_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans4_Level_MIN_TEMPERATURE; \
	MENU trans4_Level_MIN_TEMPERATURE_page; \
	COMMAND trans4_Level_MIN_TEMPERATURE_read; \
	COMMAND trans4_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans4_Level_TAB_ENTRY; \
	MENU trans4_Level_TAB_ENTRY_page; \
	COMMAND trans4_Level_TAB_ENTRY_read; \
	COMMAND trans4_Level_TAB_ENTRY_write; \
	COLLECTION trans4_Level_TAB_X_Y_VALUE; \
	VARIABLE trans4_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans4_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans4_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans4_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans4_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans4_Level_TAB_MIN_NUMBER; \
	MENU trans4_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans4_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans4_Level_TAB_MAX_NUMBER; \
	MENU trans4_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans4_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans4_Level_TAB_OP_CODE; \
	MENU trans4_Level_TAB_OP_CODE_page; \
	COMMAND trans4_Level_TAB_OP_CODE_read; \
	COMMAND trans4_Level_TAB_OP_CODE_write; \
	VARIABLE trans4_Level_TAB_STATUS; \
	MENU trans4_Level_TAB_STATUS_page; \
	COMMAND trans4_Level_TAB_STATUS_read; \
	VARIABLE trans4_Level_TAB_ACTUAL_NUMBER; \
	MENU trans4_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans4_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans4_Level_VIEW_2; \
	MENU trans4_Level_VIEW_2_page; \
	COLLECTION trans4_Level_VIEW_3; \
	MENU trans4_Level_VIEW_3_page; \
	UNIT trans4_Level_unit_level_2; \
	UNIT trans4_Level_unit_temperature; \
	UNIT trans4_Level_unit_primary_value_2; \
	UNIT trans4_Level_unit_sensor_value_2; \
	UNIT trans4_Level_unit_secondary_value_1; \
	UNIT trans4_Level_unit_secondary_value_2

#define USE_TRANS4_LEVEL_OPTIONAL_A \
	USE_TRANS4_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans4_Level_PRIMARY_VALUE; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans4_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans4_Level_PRIMARY_VALUE_page; \
	COMMAND trans4_Level_PRIMARY_VALUE_read; \
	VARIABLE trans4_Level_PRIMARY_VALUE_UNIT; \
	MENU trans4_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans4_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans4_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans4_Level_LEVEL; \
	MENU trans4_Level_LEVEL_page; \
	COMMAND trans4_Level_LEVEL_read; \
	VARIABLE trans4_Level_LEVEL_UNIT; \
	MENU trans4_Level_LEVEL_UNIT_page; \
	COMMAND trans4_Level_LEVEL_UNIT_read; \
	COMMAND trans4_Level_LEVEL_UNIT_write; \
	VARIABLE trans4_Level_SENSOR_VALUE; \
	MENU trans4_Level_SENSOR_VALUE_page; \
	COMMAND trans4_Level_SENSOR_VALUE_read; \
	VARIABLE trans4_Level_SENSOR_UNIT; \
	MENU trans4_Level_SENSOR_UNIT_page; \
	COMMAND trans4_Level_SENSOR_UNIT_read; \
	COMMAND trans4_Level_SENSOR_UNIT_write; \
	VARIABLE trans4_Level_SENSOR_OFFSET; \
	MENU trans4_Level_SENSOR_OFFSET_page; \
	COMMAND trans4_Level_SENSOR_OFFSET_read; \
	COMMAND trans4_Level_SENSOR_OFFSET_write; \
	VARIABLE trans4_Level_CAL_TYPE; \
	MENU trans4_Level_CAL_TYPE_page; \
	COMMAND trans4_Level_CAL_TYPE_read; \
	COMMAND trans4_Level_CAL_TYPE_write; \
	VARIABLE trans4_Level_CAL_POINT_LO; \
	MENU trans4_Level_CAL_POINT_LO_page; \
	COMMAND trans4_Level_CAL_POINT_LO_read; \
	COMMAND trans4_Level_CAL_POINT_LO_write; \
	VARIABLE trans4_Level_CAL_POINT_HI; \
	MENU trans4_Level_CAL_POINT_HI_page; \
	COMMAND trans4_Level_CAL_POINT_HI_read; \
	COMMAND trans4_Level_CAL_POINT_HI_write; \
	VARIABLE trans4_Level_LEVEL_LO; \
	MENU trans4_Level_LEVEL_LO_page; \
	COMMAND trans4_Level_LEVEL_LO_read; \
	COMMAND trans4_Level_LEVEL_LO_write; \
	VARIABLE trans4_Level_LEVEL_HI; \
	MENU trans4_Level_LEVEL_HI_page; \
	COMMAND trans4_Level_LEVEL_HI_read; \
	COMMAND trans4_Level_LEVEL_HI_write; \
	VARIABLE trans4_Level_LEVEL_OFFSET; \
	MENU trans4_Level_LEVEL_OFFSET_page; \
	COMMAND trans4_Level_LEVEL_OFFSET_read; \
	COMMAND trans4_Level_LEVEL_OFFSET_write; \
	VARIABLE trans4_Level_LIN_TYPE; \
	MENU trans4_Level_LIN_TYPE_page; \
	COMMAND trans4_Level_LIN_TYPE_read; \
	COMMAND trans4_Level_LIN_TYPE_write; \
	COLLECTION trans4_Level_VIEW_1; \
	MENU trans4_Level_VIEW_1_page; \
	MENU trans4_Level_Simple_Dialog_Optional_A; \
	UNIT trans4_Level_unit_level_1; \
	UNIT trans4_Level_unit_primary_value_1; \
	UNIT trans4_Level_unit_sensor_value_1

#define USE_TRANS4_LEVEL_OPTIONAL_B \
	USE_TRANS4_LEVEL_OPTIONAL_BOTH; \
	MENU trans4_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans4_Level_)
#define USE_TRANS4_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans4_Level_)
#define USE_TRANS4_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans4_Level_)
#define USE_TRANS4_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans4_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_LEVEL_MANDATORY_BOTH \
	BLOCK trans5_Level_block; \
	COLLECTION trans5_Level_BLOCK_OBJECT; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Level_BLOCK_OBJECT_page; \
	COMMAND trans5_Level_BLOCK_OBJECT_read; \
	VARIABLE trans5_Level_ST_REV; \
	MENU trans5_Level_ST_REV_page; \
	COMMAND trans5_Level_ST_REV_read; \
	VARIABLE trans5_Level_TAG_DESC; \
	MENU trans5_Level_TAG_DESC_page; \
	COMMAND trans5_Level_TAG_DESC_read; \
	COMMAND trans5_Level_TAG_DESC_write; \
	VARIABLE trans5_Level_STRATEGY; \
	MENU trans5_Level_STRATEGY_page; \
	COMMAND trans5_Level_STRATEGY_read; \
	COMMAND trans5_Level_STRATEGY_write; \
	VARIABLE trans5_Level_ALERT_KEY; \
	MENU trans5_Level_ALERT_KEY_page; \
	COMMAND trans5_Level_ALERT_KEY_read; \
	COMMAND trans5_Level_ALERT_KEY_write; \
	VARIABLE trans5_Level_TARGET_MODE; \
	MENU trans5_Level_TARGET_MODE_page; \
	COMMAND trans5_Level_TARGET_MODE_read; \
	COMMAND trans5_Level_TARGET_MODE_write; \
	COLLECTION trans5_Level_MODE_BLK; \
	VARIABLE trans5_Level_MODE_BLK_Actual; \
	VARIABLE trans5_Level_MODE_BLK_Permitted; \
	VARIABLE trans5_Level_MODE_BLK_Normal; \
	MENU trans5_Level_MODE_BLK_page; \
	COMMAND trans5_Level_MODE_BLK_read; \
	COLLECTION trans5_Level_ALARM_SUM; \
	VARIABLE trans5_Level_ALARM_SUM_Current; \
	VARIABLE trans5_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Level_ALARM_SUM_Unreported; \
	VARIABLE trans5_Level_ALARM_SUM_Disabled; \
	MENU trans5_Level_ALARM_SUM_page; \
	COMMAND trans5_Level_ALARM_SUM_read

#define USE_TRANS5_LEVEL_MANDATORY_A \
	USE_TRANS5_LEVEL_MANDATORY_BOTH; \
	MENU trans5_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS5_LEVEL_MANDATORY_B \
	USE_TRANS5_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans5_Level_PRIMARY_VALUE; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans5_Level_PRIMARY_VALUE_page; \
	COMMAND trans5_Level_PRIMARY_VALUE_read; \
	VARIABLE trans5_Level_PRIMARY_VALUE_UNIT; \
	MENU trans5_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans5_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans5_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans5_Level_LEVEL; \
	MENU trans5_Level_LEVEL_page; \
	COMMAND trans5_Level_LEVEL_read; \
	VARIABLE trans5_Level_LEVEL_UNIT; \
	MENU trans5_Level_LEVEL_UNIT_page; \
	COMMAND trans5_Level_LEVEL_UNIT_read; \
	COMMAND trans5_Level_LEVEL_UNIT_write; \
	VARIABLE trans5_Level_SENSOR_VALUE; \
	MENU trans5_Level_SENSOR_VALUE_page; \
	COMMAND trans5_Level_SENSOR_VALUE_read; \
	VARIABLE trans5_Level_SENSOR_UNIT; \
	MENU trans5_Level_SENSOR_UNIT_page; \
	COMMAND trans5_Level_SENSOR_UNIT_read; \
	COMMAND trans5_Level_SENSOR_UNIT_write; \
	VARIABLE trans5_Level_SENSOR_OFFSET; \
	MENU trans5_Level_SENSOR_OFFSET_page; \
	COMMAND trans5_Level_SENSOR_OFFSET_read; \
	COMMAND trans5_Level_SENSOR_OFFSET_write; \
	VARIABLE trans5_Level_CAL_TYPE; \
	MENU trans5_Level_CAL_TYPE_page; \
	COMMAND trans5_Level_CAL_TYPE_read; \
	COMMAND trans5_Level_CAL_TYPE_write; \
	VARIABLE trans5_Level_CAL_POINT_LO; \
	MENU trans5_Level_CAL_POINT_LO_page; \
	COMMAND trans5_Level_CAL_POINT_LO_read; \
	COMMAND trans5_Level_CAL_POINT_LO_write; \
	VARIABLE trans5_Level_CAL_POINT_HI; \
	MENU trans5_Level_CAL_POINT_HI_page; \
	COMMAND trans5_Level_CAL_POINT_HI_read; \
	COMMAND trans5_Level_CAL_POINT_HI_write; \
	VARIABLE trans5_Level_LEVEL_LO; \
	MENU trans5_Level_LEVEL_LO_page; \
	COMMAND trans5_Level_LEVEL_LO_read; \
	COMMAND trans5_Level_LEVEL_LO_write; \
	VARIABLE trans5_Level_LEVEL_HI; \
	MENU trans5_Level_LEVEL_HI_page; \
	COMMAND trans5_Level_LEVEL_HI_read; \
	COMMAND trans5_Level_LEVEL_HI_write; \
	VARIABLE trans5_Level_LEVEL_OFFSET; \
	MENU trans5_Level_LEVEL_OFFSET_page; \
	COMMAND trans5_Level_LEVEL_OFFSET_read; \
	COMMAND trans5_Level_LEVEL_OFFSET_write; \
	VARIABLE trans5_Level_LIN_TYPE; \
	MENU trans5_Level_LIN_TYPE_page; \
	COMMAND trans5_Level_LIN_TYPE_read; \
	COMMAND trans5_Level_LIN_TYPE_write; \
	COLLECTION trans5_Level_VIEW_1; \
	MENU trans5_Level_VIEW_1_page; \
	MENU trans5_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans5_Level_unit_level_1; \
	UNIT trans5_Level_unit_primary_value_1; \
	UNIT trans5_Level_unit_sensor_value_1

#define USE_TRANS5_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans5_Level_SECONDARY_VALUE_1; \
	VARIABLE trans5_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans5_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans5_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans5_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans5_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans5_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans5_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans5_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans5_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans5_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans5_Level_SECONDARY_VALUE_2; \
	VARIABLE trans5_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans5_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans5_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans5_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans5_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans5_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans5_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans5_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans5_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans5_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans5_Level_LIN_DIAMETER; \
	MENU trans5_Level_LIN_DIAMETER_page; \
	COMMAND trans5_Level_LIN_DIAMETER_read; \
	COMMAND trans5_Level_LIN_DIAMETER_write; \
	VARIABLE trans5_Level_LIN_VOLUME; \
	MENU trans5_Level_LIN_VOLUME_page; \
	COMMAND trans5_Level_LIN_VOLUME_read; \
	COMMAND trans5_Level_LIN_VOLUME_write; \
	VARIABLE trans5_Level_SENSOR_HIGH_LIMIT; \
	MENU trans5_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans5_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans5_Level_SENSOR_LOW_LIMIT; \
	MENU trans5_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans5_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans5_Level_MAX_SENSOR_VALUE; \
	MENU trans5_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans5_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans5_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans5_Level_MIN_SENSOR_VALUE; \
	MENU trans5_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans5_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans5_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans5_Level_TEMPERATURE; \
	MENU trans5_Level_TEMPERATURE_page; \
	COMMAND trans5_Level_TEMPERATURE_read; \
	VARIABLE trans5_Level_TEMPERATURE_UNIT; \
	MENU trans5_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans5_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans5_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans5_Level_MAX_TEMPERATURE; \
	MENU trans5_Level_MAX_TEMPERATURE_page; \
	COMMAND trans5_Level_MAX_TEMPERATURE_read; \
	COMMAND trans5_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans5_Level_MIN_TEMPERATURE; \
	MENU trans5_Level_MIN_TEMPERATURE_page; \
	COMMAND trans5_Level_MIN_TEMPERATURE_read; \
	COMMAND trans5_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans5_Level_TAB_ENTRY; \
	MENU trans5_Level_TAB_ENTRY_page; \
	COMMAND trans5_Level_TAB_ENTRY_read; \
	COMMAND trans5_Level_TAB_ENTRY_write; \
	COLLECTION trans5_Level_TAB_X_Y_VALUE; \
	VARIABLE trans5_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans5_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans5_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans5_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans5_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans5_Level_TAB_MIN_NUMBER; \
	MENU trans5_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans5_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans5_Level_TAB_MAX_NUMBER; \
	MENU trans5_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans5_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans5_Level_TAB_OP_CODE; \
	MENU trans5_Level_TAB_OP_CODE_page; \
	COMMAND trans5_Level_TAB_OP_CODE_read; \
	COMMAND trans5_Level_TAB_OP_CODE_write; \
	VARIABLE trans5_Level_TAB_STATUS; \
	MENU trans5_Level_TAB_STATUS_page; \
	COMMAND trans5_Level_TAB_STATUS_read; \
	VARIABLE trans5_Level_TAB_ACTUAL_NUMBER; \
	MENU trans5_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans5_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans5_Level_VIEW_2; \
	MENU trans5_Level_VIEW_2_page; \
	COLLECTION trans5_Level_VIEW_3; \
	MENU trans5_Level_VIEW_3_page; \
	UNIT trans5_Level_unit_level_2; \
	UNIT trans5_Level_unit_temperature; \
	UNIT trans5_Level_unit_primary_value_2; \
	UNIT trans5_Level_unit_sensor_value_2; \
	UNIT trans5_Level_unit_secondary_value_1; \
	UNIT trans5_Level_unit_secondary_value_2

#define USE_TRANS5_LEVEL_OPTIONAL_A \
	USE_TRANS5_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans5_Level_PRIMARY_VALUE; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans5_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans5_Level_PRIMARY_VALUE_page; \
	COMMAND trans5_Level_PRIMARY_VALUE_read; \
	VARIABLE trans5_Level_PRIMARY_VALUE_UNIT; \
	MENU trans5_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans5_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans5_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans5_Level_LEVEL; \
	MENU trans5_Level_LEVEL_page; \
	COMMAND trans5_Level_LEVEL_read; \
	VARIABLE trans5_Level_LEVEL_UNIT; \
	MENU trans5_Level_LEVEL_UNIT_page; \
	COMMAND trans5_Level_LEVEL_UNIT_read; \
	COMMAND trans5_Level_LEVEL_UNIT_write; \
	VARIABLE trans5_Level_SENSOR_VALUE; \
	MENU trans5_Level_SENSOR_VALUE_page; \
	COMMAND trans5_Level_SENSOR_VALUE_read; \
	VARIABLE trans5_Level_SENSOR_UNIT; \
	MENU trans5_Level_SENSOR_UNIT_page; \
	COMMAND trans5_Level_SENSOR_UNIT_read; \
	COMMAND trans5_Level_SENSOR_UNIT_write; \
	VARIABLE trans5_Level_SENSOR_OFFSET; \
	MENU trans5_Level_SENSOR_OFFSET_page; \
	COMMAND trans5_Level_SENSOR_OFFSET_read; \
	COMMAND trans5_Level_SENSOR_OFFSET_write; \
	VARIABLE trans5_Level_CAL_TYPE; \
	MENU trans5_Level_CAL_TYPE_page; \
	COMMAND trans5_Level_CAL_TYPE_read; \
	COMMAND trans5_Level_CAL_TYPE_write; \
	VARIABLE trans5_Level_CAL_POINT_LO; \
	MENU trans5_Level_CAL_POINT_LO_page; \
	COMMAND trans5_Level_CAL_POINT_LO_read; \
	COMMAND trans5_Level_CAL_POINT_LO_write; \
	VARIABLE trans5_Level_CAL_POINT_HI; \
	MENU trans5_Level_CAL_POINT_HI_page; \
	COMMAND trans5_Level_CAL_POINT_HI_read; \
	COMMAND trans5_Level_CAL_POINT_HI_write; \
	VARIABLE trans5_Level_LEVEL_LO; \
	MENU trans5_Level_LEVEL_LO_page; \
	COMMAND trans5_Level_LEVEL_LO_read; \
	COMMAND trans5_Level_LEVEL_LO_write; \
	VARIABLE trans5_Level_LEVEL_HI; \
	MENU trans5_Level_LEVEL_HI_page; \
	COMMAND trans5_Level_LEVEL_HI_read; \
	COMMAND trans5_Level_LEVEL_HI_write; \
	VARIABLE trans5_Level_LEVEL_OFFSET; \
	MENU trans5_Level_LEVEL_OFFSET_page; \
	COMMAND trans5_Level_LEVEL_OFFSET_read; \
	COMMAND trans5_Level_LEVEL_OFFSET_write; \
	VARIABLE trans5_Level_LIN_TYPE; \
	MENU trans5_Level_LIN_TYPE_page; \
	COMMAND trans5_Level_LIN_TYPE_read; \
	COMMAND trans5_Level_LIN_TYPE_write; \
	COLLECTION trans5_Level_VIEW_1; \
	MENU trans5_Level_VIEW_1_page; \
	MENU trans5_Level_Simple_Dialog_Optional_A; \
	UNIT trans5_Level_unit_level_1; \
	UNIT trans5_Level_unit_primary_value_1; \
	UNIT trans5_Level_unit_sensor_value_1

#define USE_TRANS5_LEVEL_OPTIONAL_B \
	USE_TRANS5_LEVEL_OPTIONAL_BOTH; \
	MENU trans5_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans5_Level_)
#define USE_TRANS5_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans5_Level_)
#define USE_TRANS5_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans5_Level_)
#define USE_TRANS5_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans5_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_LEVEL_MANDATORY_BOTH \
	BLOCK trans6_Level_block; \
	COLLECTION trans6_Level_BLOCK_OBJECT; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Level_BLOCK_OBJECT_page; \
	COMMAND trans6_Level_BLOCK_OBJECT_read; \
	VARIABLE trans6_Level_ST_REV; \
	MENU trans6_Level_ST_REV_page; \
	COMMAND trans6_Level_ST_REV_read; \
	VARIABLE trans6_Level_TAG_DESC; \
	MENU trans6_Level_TAG_DESC_page; \
	COMMAND trans6_Level_TAG_DESC_read; \
	COMMAND trans6_Level_TAG_DESC_write; \
	VARIABLE trans6_Level_STRATEGY; \
	MENU trans6_Level_STRATEGY_page; \
	COMMAND trans6_Level_STRATEGY_read; \
	COMMAND trans6_Level_STRATEGY_write; \
	VARIABLE trans6_Level_ALERT_KEY; \
	MENU trans6_Level_ALERT_KEY_page; \
	COMMAND trans6_Level_ALERT_KEY_read; \
	COMMAND trans6_Level_ALERT_KEY_write; \
	VARIABLE trans6_Level_TARGET_MODE; \
	MENU trans6_Level_TARGET_MODE_page; \
	COMMAND trans6_Level_TARGET_MODE_read; \
	COMMAND trans6_Level_TARGET_MODE_write; \
	COLLECTION trans6_Level_MODE_BLK; \
	VARIABLE trans6_Level_MODE_BLK_Actual; \
	VARIABLE trans6_Level_MODE_BLK_Permitted; \
	VARIABLE trans6_Level_MODE_BLK_Normal; \
	MENU trans6_Level_MODE_BLK_page; \
	COMMAND trans6_Level_MODE_BLK_read; \
	COLLECTION trans6_Level_ALARM_SUM; \
	VARIABLE trans6_Level_ALARM_SUM_Current; \
	VARIABLE trans6_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Level_ALARM_SUM_Unreported; \
	VARIABLE trans6_Level_ALARM_SUM_Disabled; \
	MENU trans6_Level_ALARM_SUM_page; \
	COMMAND trans6_Level_ALARM_SUM_read

#define USE_TRANS6_LEVEL_MANDATORY_A \
	USE_TRANS6_LEVEL_MANDATORY_BOTH; \
	MENU trans6_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS6_LEVEL_MANDATORY_B \
	USE_TRANS6_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans6_Level_PRIMARY_VALUE; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans6_Level_PRIMARY_VALUE_page; \
	COMMAND trans6_Level_PRIMARY_VALUE_read; \
	VARIABLE trans6_Level_PRIMARY_VALUE_UNIT; \
	MENU trans6_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans6_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans6_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans6_Level_LEVEL; \
	MENU trans6_Level_LEVEL_page; \
	COMMAND trans6_Level_LEVEL_read; \
	VARIABLE trans6_Level_LEVEL_UNIT; \
	MENU trans6_Level_LEVEL_UNIT_page; \
	COMMAND trans6_Level_LEVEL_UNIT_read; \
	COMMAND trans6_Level_LEVEL_UNIT_write; \
	VARIABLE trans6_Level_SENSOR_VALUE; \
	MENU trans6_Level_SENSOR_VALUE_page; \
	COMMAND trans6_Level_SENSOR_VALUE_read; \
	VARIABLE trans6_Level_SENSOR_UNIT; \
	MENU trans6_Level_SENSOR_UNIT_page; \
	COMMAND trans6_Level_SENSOR_UNIT_read; \
	COMMAND trans6_Level_SENSOR_UNIT_write; \
	VARIABLE trans6_Level_SENSOR_OFFSET; \
	MENU trans6_Level_SENSOR_OFFSET_page; \
	COMMAND trans6_Level_SENSOR_OFFSET_read; \
	COMMAND trans6_Level_SENSOR_OFFSET_write; \
	VARIABLE trans6_Level_CAL_TYPE; \
	MENU trans6_Level_CAL_TYPE_page; \
	COMMAND trans6_Level_CAL_TYPE_read; \
	COMMAND trans6_Level_CAL_TYPE_write; \
	VARIABLE trans6_Level_CAL_POINT_LO; \
	MENU trans6_Level_CAL_POINT_LO_page; \
	COMMAND trans6_Level_CAL_POINT_LO_read; \
	COMMAND trans6_Level_CAL_POINT_LO_write; \
	VARIABLE trans6_Level_CAL_POINT_HI; \
	MENU trans6_Level_CAL_POINT_HI_page; \
	COMMAND trans6_Level_CAL_POINT_HI_read; \
	COMMAND trans6_Level_CAL_POINT_HI_write; \
	VARIABLE trans6_Level_LEVEL_LO; \
	MENU trans6_Level_LEVEL_LO_page; \
	COMMAND trans6_Level_LEVEL_LO_read; \
	COMMAND trans6_Level_LEVEL_LO_write; \
	VARIABLE trans6_Level_LEVEL_HI; \
	MENU trans6_Level_LEVEL_HI_page; \
	COMMAND trans6_Level_LEVEL_HI_read; \
	COMMAND trans6_Level_LEVEL_HI_write; \
	VARIABLE trans6_Level_LEVEL_OFFSET; \
	MENU trans6_Level_LEVEL_OFFSET_page; \
	COMMAND trans6_Level_LEVEL_OFFSET_read; \
	COMMAND trans6_Level_LEVEL_OFFSET_write; \
	VARIABLE trans6_Level_LIN_TYPE; \
	MENU trans6_Level_LIN_TYPE_page; \
	COMMAND trans6_Level_LIN_TYPE_read; \
	COMMAND trans6_Level_LIN_TYPE_write; \
	COLLECTION trans6_Level_VIEW_1; \
	MENU trans6_Level_VIEW_1_page; \
	MENU trans6_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans6_Level_unit_level_1; \
	UNIT trans6_Level_unit_primary_value_1; \
	UNIT trans6_Level_unit_sensor_value_1

#define USE_TRANS6_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans6_Level_SECONDARY_VALUE_1; \
	VARIABLE trans6_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans6_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans6_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans6_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans6_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans6_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans6_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans6_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans6_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans6_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans6_Level_SECONDARY_VALUE_2; \
	VARIABLE trans6_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans6_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans6_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans6_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans6_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans6_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans6_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans6_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans6_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans6_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans6_Level_LIN_DIAMETER; \
	MENU trans6_Level_LIN_DIAMETER_page; \
	COMMAND trans6_Level_LIN_DIAMETER_read; \
	COMMAND trans6_Level_LIN_DIAMETER_write; \
	VARIABLE trans6_Level_LIN_VOLUME; \
	MENU trans6_Level_LIN_VOLUME_page; \
	COMMAND trans6_Level_LIN_VOLUME_read; \
	COMMAND trans6_Level_LIN_VOLUME_write; \
	VARIABLE trans6_Level_SENSOR_HIGH_LIMIT; \
	MENU trans6_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans6_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans6_Level_SENSOR_LOW_LIMIT; \
	MENU trans6_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans6_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans6_Level_MAX_SENSOR_VALUE; \
	MENU trans6_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans6_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans6_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans6_Level_MIN_SENSOR_VALUE; \
	MENU trans6_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans6_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans6_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans6_Level_TEMPERATURE; \
	MENU trans6_Level_TEMPERATURE_page; \
	COMMAND trans6_Level_TEMPERATURE_read; \
	VARIABLE trans6_Level_TEMPERATURE_UNIT; \
	MENU trans6_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans6_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans6_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans6_Level_MAX_TEMPERATURE; \
	MENU trans6_Level_MAX_TEMPERATURE_page; \
	COMMAND trans6_Level_MAX_TEMPERATURE_read; \
	COMMAND trans6_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans6_Level_MIN_TEMPERATURE; \
	MENU trans6_Level_MIN_TEMPERATURE_page; \
	COMMAND trans6_Level_MIN_TEMPERATURE_read; \
	COMMAND trans6_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans6_Level_TAB_ENTRY; \
	MENU trans6_Level_TAB_ENTRY_page; \
	COMMAND trans6_Level_TAB_ENTRY_read; \
	COMMAND trans6_Level_TAB_ENTRY_write; \
	COLLECTION trans6_Level_TAB_X_Y_VALUE; \
	VARIABLE trans6_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans6_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans6_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans6_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans6_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans6_Level_TAB_MIN_NUMBER; \
	MENU trans6_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans6_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans6_Level_TAB_MAX_NUMBER; \
	MENU trans6_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans6_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans6_Level_TAB_OP_CODE; \
	MENU trans6_Level_TAB_OP_CODE_page; \
	COMMAND trans6_Level_TAB_OP_CODE_read; \
	COMMAND trans6_Level_TAB_OP_CODE_write; \
	VARIABLE trans6_Level_TAB_STATUS; \
	MENU trans6_Level_TAB_STATUS_page; \
	COMMAND trans6_Level_TAB_STATUS_read; \
	VARIABLE trans6_Level_TAB_ACTUAL_NUMBER; \
	MENU trans6_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans6_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans6_Level_VIEW_2; \
	MENU trans6_Level_VIEW_2_page; \
	COLLECTION trans6_Level_VIEW_3; \
	MENU trans6_Level_VIEW_3_page; \
	UNIT trans6_Level_unit_level_2; \
	UNIT trans6_Level_unit_temperature; \
	UNIT trans6_Level_unit_primary_value_2; \
	UNIT trans6_Level_unit_sensor_value_2; \
	UNIT trans6_Level_unit_secondary_value_1; \
	UNIT trans6_Level_unit_secondary_value_2

#define USE_TRANS6_LEVEL_OPTIONAL_A \
	USE_TRANS6_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans6_Level_PRIMARY_VALUE; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans6_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans6_Level_PRIMARY_VALUE_page; \
	COMMAND trans6_Level_PRIMARY_VALUE_read; \
	VARIABLE trans6_Level_PRIMARY_VALUE_UNIT; \
	MENU trans6_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans6_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans6_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans6_Level_LEVEL; \
	MENU trans6_Level_LEVEL_page; \
	COMMAND trans6_Level_LEVEL_read; \
	VARIABLE trans6_Level_LEVEL_UNIT; \
	MENU trans6_Level_LEVEL_UNIT_page; \
	COMMAND trans6_Level_LEVEL_UNIT_read; \
	COMMAND trans6_Level_LEVEL_UNIT_write; \
	VARIABLE trans6_Level_SENSOR_VALUE; \
	MENU trans6_Level_SENSOR_VALUE_page; \
	COMMAND trans6_Level_SENSOR_VALUE_read; \
	VARIABLE trans6_Level_SENSOR_UNIT; \
	MENU trans6_Level_SENSOR_UNIT_page; \
	COMMAND trans6_Level_SENSOR_UNIT_read; \
	COMMAND trans6_Level_SENSOR_UNIT_write; \
	VARIABLE trans6_Level_SENSOR_OFFSET; \
	MENU trans6_Level_SENSOR_OFFSET_page; \
	COMMAND trans6_Level_SENSOR_OFFSET_read; \
	COMMAND trans6_Level_SENSOR_OFFSET_write; \
	VARIABLE trans6_Level_CAL_TYPE; \
	MENU trans6_Level_CAL_TYPE_page; \
	COMMAND trans6_Level_CAL_TYPE_read; \
	COMMAND trans6_Level_CAL_TYPE_write; \
	VARIABLE trans6_Level_CAL_POINT_LO; \
	MENU trans6_Level_CAL_POINT_LO_page; \
	COMMAND trans6_Level_CAL_POINT_LO_read; \
	COMMAND trans6_Level_CAL_POINT_LO_write; \
	VARIABLE trans6_Level_CAL_POINT_HI; \
	MENU trans6_Level_CAL_POINT_HI_page; \
	COMMAND trans6_Level_CAL_POINT_HI_read; \
	COMMAND trans6_Level_CAL_POINT_HI_write; \
	VARIABLE trans6_Level_LEVEL_LO; \
	MENU trans6_Level_LEVEL_LO_page; \
	COMMAND trans6_Level_LEVEL_LO_read; \
	COMMAND trans6_Level_LEVEL_LO_write; \
	VARIABLE trans6_Level_LEVEL_HI; \
	MENU trans6_Level_LEVEL_HI_page; \
	COMMAND trans6_Level_LEVEL_HI_read; \
	COMMAND trans6_Level_LEVEL_HI_write; \
	VARIABLE trans6_Level_LEVEL_OFFSET; \
	MENU trans6_Level_LEVEL_OFFSET_page; \
	COMMAND trans6_Level_LEVEL_OFFSET_read; \
	COMMAND trans6_Level_LEVEL_OFFSET_write; \
	VARIABLE trans6_Level_LIN_TYPE; \
	MENU trans6_Level_LIN_TYPE_page; \
	COMMAND trans6_Level_LIN_TYPE_read; \
	COMMAND trans6_Level_LIN_TYPE_write; \
	COLLECTION trans6_Level_VIEW_1; \
	MENU trans6_Level_VIEW_1_page; \
	MENU trans6_Level_Simple_Dialog_Optional_A; \
	UNIT trans6_Level_unit_level_1; \
	UNIT trans6_Level_unit_primary_value_1; \
	UNIT trans6_Level_unit_sensor_value_1

#define USE_TRANS6_LEVEL_OPTIONAL_B \
	USE_TRANS6_LEVEL_OPTIONAL_BOTH; \
	MENU trans6_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans6_Level_)
#define USE_TRANS6_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans6_Level_)
#define USE_TRANS6_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans6_Level_)
#define USE_TRANS6_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans6_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_LEVEL_MANDATORY_BOTH \
	BLOCK trans7_Level_block; \
	COLLECTION trans7_Level_BLOCK_OBJECT; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Level_BLOCK_OBJECT_page; \
	COMMAND trans7_Level_BLOCK_OBJECT_read; \
	VARIABLE trans7_Level_ST_REV; \
	MENU trans7_Level_ST_REV_page; \
	COMMAND trans7_Level_ST_REV_read; \
	VARIABLE trans7_Level_TAG_DESC; \
	MENU trans7_Level_TAG_DESC_page; \
	COMMAND trans7_Level_TAG_DESC_read; \
	COMMAND trans7_Level_TAG_DESC_write; \
	VARIABLE trans7_Level_STRATEGY; \
	MENU trans7_Level_STRATEGY_page; \
	COMMAND trans7_Level_STRATEGY_read; \
	COMMAND trans7_Level_STRATEGY_write; \
	VARIABLE trans7_Level_ALERT_KEY; \
	MENU trans7_Level_ALERT_KEY_page; \
	COMMAND trans7_Level_ALERT_KEY_read; \
	COMMAND trans7_Level_ALERT_KEY_write; \
	VARIABLE trans7_Level_TARGET_MODE; \
	MENU trans7_Level_TARGET_MODE_page; \
	COMMAND trans7_Level_TARGET_MODE_read; \
	COMMAND trans7_Level_TARGET_MODE_write; \
	COLLECTION trans7_Level_MODE_BLK; \
	VARIABLE trans7_Level_MODE_BLK_Actual; \
	VARIABLE trans7_Level_MODE_BLK_Permitted; \
	VARIABLE trans7_Level_MODE_BLK_Normal; \
	MENU trans7_Level_MODE_BLK_page; \
	COMMAND trans7_Level_MODE_BLK_read; \
	COLLECTION trans7_Level_ALARM_SUM; \
	VARIABLE trans7_Level_ALARM_SUM_Current; \
	VARIABLE trans7_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Level_ALARM_SUM_Unreported; \
	VARIABLE trans7_Level_ALARM_SUM_Disabled; \
	MENU trans7_Level_ALARM_SUM_page; \
	COMMAND trans7_Level_ALARM_SUM_read

#define USE_TRANS7_LEVEL_MANDATORY_A \
	USE_TRANS7_LEVEL_MANDATORY_BOTH; \
	MENU trans7_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS7_LEVEL_MANDATORY_B \
	USE_TRANS7_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans7_Level_PRIMARY_VALUE; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans7_Level_PRIMARY_VALUE_page; \
	COMMAND trans7_Level_PRIMARY_VALUE_read; \
	VARIABLE trans7_Level_PRIMARY_VALUE_UNIT; \
	MENU trans7_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans7_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans7_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans7_Level_LEVEL; \
	MENU trans7_Level_LEVEL_page; \
	COMMAND trans7_Level_LEVEL_read; \
	VARIABLE trans7_Level_LEVEL_UNIT; \
	MENU trans7_Level_LEVEL_UNIT_page; \
	COMMAND trans7_Level_LEVEL_UNIT_read; \
	COMMAND trans7_Level_LEVEL_UNIT_write; \
	VARIABLE trans7_Level_SENSOR_VALUE; \
	MENU trans7_Level_SENSOR_VALUE_page; \
	COMMAND trans7_Level_SENSOR_VALUE_read; \
	VARIABLE trans7_Level_SENSOR_UNIT; \
	MENU trans7_Level_SENSOR_UNIT_page; \
	COMMAND trans7_Level_SENSOR_UNIT_read; \
	COMMAND trans7_Level_SENSOR_UNIT_write; \
	VARIABLE trans7_Level_SENSOR_OFFSET; \
	MENU trans7_Level_SENSOR_OFFSET_page; \
	COMMAND trans7_Level_SENSOR_OFFSET_read; \
	COMMAND trans7_Level_SENSOR_OFFSET_write; \
	VARIABLE trans7_Level_CAL_TYPE; \
	MENU trans7_Level_CAL_TYPE_page; \
	COMMAND trans7_Level_CAL_TYPE_read; \
	COMMAND trans7_Level_CAL_TYPE_write; \
	VARIABLE trans7_Level_CAL_POINT_LO; \
	MENU trans7_Level_CAL_POINT_LO_page; \
	COMMAND trans7_Level_CAL_POINT_LO_read; \
	COMMAND trans7_Level_CAL_POINT_LO_write; \
	VARIABLE trans7_Level_CAL_POINT_HI; \
	MENU trans7_Level_CAL_POINT_HI_page; \
	COMMAND trans7_Level_CAL_POINT_HI_read; \
	COMMAND trans7_Level_CAL_POINT_HI_write; \
	VARIABLE trans7_Level_LEVEL_LO; \
	MENU trans7_Level_LEVEL_LO_page; \
	COMMAND trans7_Level_LEVEL_LO_read; \
	COMMAND trans7_Level_LEVEL_LO_write; \
	VARIABLE trans7_Level_LEVEL_HI; \
	MENU trans7_Level_LEVEL_HI_page; \
	COMMAND trans7_Level_LEVEL_HI_read; \
	COMMAND trans7_Level_LEVEL_HI_write; \
	VARIABLE trans7_Level_LEVEL_OFFSET; \
	MENU trans7_Level_LEVEL_OFFSET_page; \
	COMMAND trans7_Level_LEVEL_OFFSET_read; \
	COMMAND trans7_Level_LEVEL_OFFSET_write; \
	VARIABLE trans7_Level_LIN_TYPE; \
	MENU trans7_Level_LIN_TYPE_page; \
	COMMAND trans7_Level_LIN_TYPE_read; \
	COMMAND trans7_Level_LIN_TYPE_write; \
	COLLECTION trans7_Level_VIEW_1; \
	MENU trans7_Level_VIEW_1_page; \
	MENU trans7_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans7_Level_unit_level_1; \
	UNIT trans7_Level_unit_primary_value_1; \
	UNIT trans7_Level_unit_sensor_value_1

#define USE_TRANS7_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans7_Level_SECONDARY_VALUE_1; \
	VARIABLE trans7_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans7_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans7_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans7_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans7_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans7_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans7_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans7_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans7_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans7_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans7_Level_SECONDARY_VALUE_2; \
	VARIABLE trans7_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans7_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans7_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans7_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans7_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans7_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans7_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans7_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans7_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans7_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans7_Level_LIN_DIAMETER; \
	MENU trans7_Level_LIN_DIAMETER_page; \
	COMMAND trans7_Level_LIN_DIAMETER_read; \
	COMMAND trans7_Level_LIN_DIAMETER_write; \
	VARIABLE trans7_Level_LIN_VOLUME; \
	MENU trans7_Level_LIN_VOLUME_page; \
	COMMAND trans7_Level_LIN_VOLUME_read; \
	COMMAND trans7_Level_LIN_VOLUME_write; \
	VARIABLE trans7_Level_SENSOR_HIGH_LIMIT; \
	MENU trans7_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans7_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans7_Level_SENSOR_LOW_LIMIT; \
	MENU trans7_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans7_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans7_Level_MAX_SENSOR_VALUE; \
	MENU trans7_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans7_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans7_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans7_Level_MIN_SENSOR_VALUE; \
	MENU trans7_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans7_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans7_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans7_Level_TEMPERATURE; \
	MENU trans7_Level_TEMPERATURE_page; \
	COMMAND trans7_Level_TEMPERATURE_read; \
	VARIABLE trans7_Level_TEMPERATURE_UNIT; \
	MENU trans7_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans7_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans7_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans7_Level_MAX_TEMPERATURE; \
	MENU trans7_Level_MAX_TEMPERATURE_page; \
	COMMAND trans7_Level_MAX_TEMPERATURE_read; \
	COMMAND trans7_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans7_Level_MIN_TEMPERATURE; \
	MENU trans7_Level_MIN_TEMPERATURE_page; \
	COMMAND trans7_Level_MIN_TEMPERATURE_read; \
	COMMAND trans7_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans7_Level_TAB_ENTRY; \
	MENU trans7_Level_TAB_ENTRY_page; \
	COMMAND trans7_Level_TAB_ENTRY_read; \
	COMMAND trans7_Level_TAB_ENTRY_write; \
	COLLECTION trans7_Level_TAB_X_Y_VALUE; \
	VARIABLE trans7_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans7_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans7_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans7_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans7_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans7_Level_TAB_MIN_NUMBER; \
	MENU trans7_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans7_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans7_Level_TAB_MAX_NUMBER; \
	MENU trans7_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans7_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans7_Level_TAB_OP_CODE; \
	MENU trans7_Level_TAB_OP_CODE_page; \
	COMMAND trans7_Level_TAB_OP_CODE_read; \
	COMMAND trans7_Level_TAB_OP_CODE_write; \
	VARIABLE trans7_Level_TAB_STATUS; \
	MENU trans7_Level_TAB_STATUS_page; \
	COMMAND trans7_Level_TAB_STATUS_read; \
	VARIABLE trans7_Level_TAB_ACTUAL_NUMBER; \
	MENU trans7_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans7_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans7_Level_VIEW_2; \
	MENU trans7_Level_VIEW_2_page; \
	COLLECTION trans7_Level_VIEW_3; \
	MENU trans7_Level_VIEW_3_page; \
	UNIT trans7_Level_unit_level_2; \
	UNIT trans7_Level_unit_temperature; \
	UNIT trans7_Level_unit_primary_value_2; \
	UNIT trans7_Level_unit_sensor_value_2; \
	UNIT trans7_Level_unit_secondary_value_1; \
	UNIT trans7_Level_unit_secondary_value_2

#define USE_TRANS7_LEVEL_OPTIONAL_A \
	USE_TRANS7_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans7_Level_PRIMARY_VALUE; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans7_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans7_Level_PRIMARY_VALUE_page; \
	COMMAND trans7_Level_PRIMARY_VALUE_read; \
	VARIABLE trans7_Level_PRIMARY_VALUE_UNIT; \
	MENU trans7_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans7_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans7_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans7_Level_LEVEL; \
	MENU trans7_Level_LEVEL_page; \
	COMMAND trans7_Level_LEVEL_read; \
	VARIABLE trans7_Level_LEVEL_UNIT; \
	MENU trans7_Level_LEVEL_UNIT_page; \
	COMMAND trans7_Level_LEVEL_UNIT_read; \
	COMMAND trans7_Level_LEVEL_UNIT_write; \
	VARIABLE trans7_Level_SENSOR_VALUE; \
	MENU trans7_Level_SENSOR_VALUE_page; \
	COMMAND trans7_Level_SENSOR_VALUE_read; \
	VARIABLE trans7_Level_SENSOR_UNIT; \
	MENU trans7_Level_SENSOR_UNIT_page; \
	COMMAND trans7_Level_SENSOR_UNIT_read; \
	COMMAND trans7_Level_SENSOR_UNIT_write; \
	VARIABLE trans7_Level_SENSOR_OFFSET; \
	MENU trans7_Level_SENSOR_OFFSET_page; \
	COMMAND trans7_Level_SENSOR_OFFSET_read; \
	COMMAND trans7_Level_SENSOR_OFFSET_write; \
	VARIABLE trans7_Level_CAL_TYPE; \
	MENU trans7_Level_CAL_TYPE_page; \
	COMMAND trans7_Level_CAL_TYPE_read; \
	COMMAND trans7_Level_CAL_TYPE_write; \
	VARIABLE trans7_Level_CAL_POINT_LO; \
	MENU trans7_Level_CAL_POINT_LO_page; \
	COMMAND trans7_Level_CAL_POINT_LO_read; \
	COMMAND trans7_Level_CAL_POINT_LO_write; \
	VARIABLE trans7_Level_CAL_POINT_HI; \
	MENU trans7_Level_CAL_POINT_HI_page; \
	COMMAND trans7_Level_CAL_POINT_HI_read; \
	COMMAND trans7_Level_CAL_POINT_HI_write; \
	VARIABLE trans7_Level_LEVEL_LO; \
	MENU trans7_Level_LEVEL_LO_page; \
	COMMAND trans7_Level_LEVEL_LO_read; \
	COMMAND trans7_Level_LEVEL_LO_write; \
	VARIABLE trans7_Level_LEVEL_HI; \
	MENU trans7_Level_LEVEL_HI_page; \
	COMMAND trans7_Level_LEVEL_HI_read; \
	COMMAND trans7_Level_LEVEL_HI_write; \
	VARIABLE trans7_Level_LEVEL_OFFSET; \
	MENU trans7_Level_LEVEL_OFFSET_page; \
	COMMAND trans7_Level_LEVEL_OFFSET_read; \
	COMMAND trans7_Level_LEVEL_OFFSET_write; \
	VARIABLE trans7_Level_LIN_TYPE; \
	MENU trans7_Level_LIN_TYPE_page; \
	COMMAND trans7_Level_LIN_TYPE_read; \
	COMMAND trans7_Level_LIN_TYPE_write; \
	COLLECTION trans7_Level_VIEW_1; \
	MENU trans7_Level_VIEW_1_page; \
	MENU trans7_Level_Simple_Dialog_Optional_A; \
	UNIT trans7_Level_unit_level_1; \
	UNIT trans7_Level_unit_primary_value_1; \
	UNIT trans7_Level_unit_sensor_value_1

#define USE_TRANS7_LEVEL_OPTIONAL_B \
	USE_TRANS7_LEVEL_OPTIONAL_BOTH; \
	MENU trans7_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans7_Level_)
#define USE_TRANS7_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans7_Level_)
#define USE_TRANS7_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans7_Level_)
#define USE_TRANS7_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans7_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_LEVEL_MANDATORY_BOTH \
	BLOCK trans8_Level_block; \
	COLLECTION trans8_Level_BLOCK_OBJECT; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Level_BLOCK_OBJECT_page; \
	COMMAND trans8_Level_BLOCK_OBJECT_read; \
	VARIABLE trans8_Level_ST_REV; \
	MENU trans8_Level_ST_REV_page; \
	COMMAND trans8_Level_ST_REV_read; \
	VARIABLE trans8_Level_TAG_DESC; \
	MENU trans8_Level_TAG_DESC_page; \
	COMMAND trans8_Level_TAG_DESC_read; \
	COMMAND trans8_Level_TAG_DESC_write; \
	VARIABLE trans8_Level_STRATEGY; \
	MENU trans8_Level_STRATEGY_page; \
	COMMAND trans8_Level_STRATEGY_read; \
	COMMAND trans8_Level_STRATEGY_write; \
	VARIABLE trans8_Level_ALERT_KEY; \
	MENU trans8_Level_ALERT_KEY_page; \
	COMMAND trans8_Level_ALERT_KEY_read; \
	COMMAND trans8_Level_ALERT_KEY_write; \
	VARIABLE trans8_Level_TARGET_MODE; \
	MENU trans8_Level_TARGET_MODE_page; \
	COMMAND trans8_Level_TARGET_MODE_read; \
	COMMAND trans8_Level_TARGET_MODE_write; \
	COLLECTION trans8_Level_MODE_BLK; \
	VARIABLE trans8_Level_MODE_BLK_Actual; \
	VARIABLE trans8_Level_MODE_BLK_Permitted; \
	VARIABLE trans8_Level_MODE_BLK_Normal; \
	MENU trans8_Level_MODE_BLK_page; \
	COMMAND trans8_Level_MODE_BLK_read; \
	COLLECTION trans8_Level_ALARM_SUM; \
	VARIABLE trans8_Level_ALARM_SUM_Current; \
	VARIABLE trans8_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Level_ALARM_SUM_Unreported; \
	VARIABLE trans8_Level_ALARM_SUM_Disabled; \
	MENU trans8_Level_ALARM_SUM_page; \
	COMMAND trans8_Level_ALARM_SUM_read

#define USE_TRANS8_LEVEL_MANDATORY_A \
	USE_TRANS8_LEVEL_MANDATORY_BOTH; \
	MENU trans8_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS8_LEVEL_MANDATORY_B \
	USE_TRANS8_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans8_Level_PRIMARY_VALUE; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans8_Level_PRIMARY_VALUE_page; \
	COMMAND trans8_Level_PRIMARY_VALUE_read; \
	VARIABLE trans8_Level_PRIMARY_VALUE_UNIT; \
	MENU trans8_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans8_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans8_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans8_Level_LEVEL; \
	MENU trans8_Level_LEVEL_page; \
	COMMAND trans8_Level_LEVEL_read; \
	VARIABLE trans8_Level_LEVEL_UNIT; \
	MENU trans8_Level_LEVEL_UNIT_page; \
	COMMAND trans8_Level_LEVEL_UNIT_read; \
	COMMAND trans8_Level_LEVEL_UNIT_write; \
	VARIABLE trans8_Level_SENSOR_VALUE; \
	MENU trans8_Level_SENSOR_VALUE_page; \
	COMMAND trans8_Level_SENSOR_VALUE_read; \
	VARIABLE trans8_Level_SENSOR_UNIT; \
	MENU trans8_Level_SENSOR_UNIT_page; \
	COMMAND trans8_Level_SENSOR_UNIT_read; \
	COMMAND trans8_Level_SENSOR_UNIT_write; \
	VARIABLE trans8_Level_SENSOR_OFFSET; \
	MENU trans8_Level_SENSOR_OFFSET_page; \
	COMMAND trans8_Level_SENSOR_OFFSET_read; \
	COMMAND trans8_Level_SENSOR_OFFSET_write; \
	VARIABLE trans8_Level_CAL_TYPE; \
	MENU trans8_Level_CAL_TYPE_page; \
	COMMAND trans8_Level_CAL_TYPE_read; \
	COMMAND trans8_Level_CAL_TYPE_write; \
	VARIABLE trans8_Level_CAL_POINT_LO; \
	MENU trans8_Level_CAL_POINT_LO_page; \
	COMMAND trans8_Level_CAL_POINT_LO_read; \
	COMMAND trans8_Level_CAL_POINT_LO_write; \
	VARIABLE trans8_Level_CAL_POINT_HI; \
	MENU trans8_Level_CAL_POINT_HI_page; \
	COMMAND trans8_Level_CAL_POINT_HI_read; \
	COMMAND trans8_Level_CAL_POINT_HI_write; \
	VARIABLE trans8_Level_LEVEL_LO; \
	MENU trans8_Level_LEVEL_LO_page; \
	COMMAND trans8_Level_LEVEL_LO_read; \
	COMMAND trans8_Level_LEVEL_LO_write; \
	VARIABLE trans8_Level_LEVEL_HI; \
	MENU trans8_Level_LEVEL_HI_page; \
	COMMAND trans8_Level_LEVEL_HI_read; \
	COMMAND trans8_Level_LEVEL_HI_write; \
	VARIABLE trans8_Level_LEVEL_OFFSET; \
	MENU trans8_Level_LEVEL_OFFSET_page; \
	COMMAND trans8_Level_LEVEL_OFFSET_read; \
	COMMAND trans8_Level_LEVEL_OFFSET_write; \
	VARIABLE trans8_Level_LIN_TYPE; \
	MENU trans8_Level_LIN_TYPE_page; \
	COMMAND trans8_Level_LIN_TYPE_read; \
	COMMAND trans8_Level_LIN_TYPE_write; \
	COLLECTION trans8_Level_VIEW_1; \
	MENU trans8_Level_VIEW_1_page; \
	MENU trans8_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans8_Level_unit_level_1; \
	UNIT trans8_Level_unit_primary_value_1; \
	UNIT trans8_Level_unit_sensor_value_1

#define USE_TRANS8_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans8_Level_SECONDARY_VALUE_1; \
	VARIABLE trans8_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans8_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans8_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans8_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans8_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans8_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans8_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans8_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans8_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans8_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans8_Level_SECONDARY_VALUE_2; \
	VARIABLE trans8_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans8_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans8_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans8_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans8_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans8_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans8_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans8_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans8_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans8_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans8_Level_LIN_DIAMETER; \
	MENU trans8_Level_LIN_DIAMETER_page; \
	COMMAND trans8_Level_LIN_DIAMETER_read; \
	COMMAND trans8_Level_LIN_DIAMETER_write; \
	VARIABLE trans8_Level_LIN_VOLUME; \
	MENU trans8_Level_LIN_VOLUME_page; \
	COMMAND trans8_Level_LIN_VOLUME_read; \
	COMMAND trans8_Level_LIN_VOLUME_write; \
	VARIABLE trans8_Level_SENSOR_HIGH_LIMIT; \
	MENU trans8_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans8_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans8_Level_SENSOR_LOW_LIMIT; \
	MENU trans8_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans8_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans8_Level_MAX_SENSOR_VALUE; \
	MENU trans8_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans8_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans8_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans8_Level_MIN_SENSOR_VALUE; \
	MENU trans8_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans8_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans8_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans8_Level_TEMPERATURE; \
	MENU trans8_Level_TEMPERATURE_page; \
	COMMAND trans8_Level_TEMPERATURE_read; \
	VARIABLE trans8_Level_TEMPERATURE_UNIT; \
	MENU trans8_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans8_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans8_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans8_Level_MAX_TEMPERATURE; \
	MENU trans8_Level_MAX_TEMPERATURE_page; \
	COMMAND trans8_Level_MAX_TEMPERATURE_read; \
	COMMAND trans8_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans8_Level_MIN_TEMPERATURE; \
	MENU trans8_Level_MIN_TEMPERATURE_page; \
	COMMAND trans8_Level_MIN_TEMPERATURE_read; \
	COMMAND trans8_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans8_Level_TAB_ENTRY; \
	MENU trans8_Level_TAB_ENTRY_page; \
	COMMAND trans8_Level_TAB_ENTRY_read; \
	COMMAND trans8_Level_TAB_ENTRY_write; \
	COLLECTION trans8_Level_TAB_X_Y_VALUE; \
	VARIABLE trans8_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans8_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans8_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans8_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans8_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans8_Level_TAB_MIN_NUMBER; \
	MENU trans8_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans8_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans8_Level_TAB_MAX_NUMBER; \
	MENU trans8_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans8_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans8_Level_TAB_OP_CODE; \
	MENU trans8_Level_TAB_OP_CODE_page; \
	COMMAND trans8_Level_TAB_OP_CODE_read; \
	COMMAND trans8_Level_TAB_OP_CODE_write; \
	VARIABLE trans8_Level_TAB_STATUS; \
	MENU trans8_Level_TAB_STATUS_page; \
	COMMAND trans8_Level_TAB_STATUS_read; \
	VARIABLE trans8_Level_TAB_ACTUAL_NUMBER; \
	MENU trans8_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans8_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans8_Level_VIEW_2; \
	MENU trans8_Level_VIEW_2_page; \
	COLLECTION trans8_Level_VIEW_3; \
	MENU trans8_Level_VIEW_3_page; \
	UNIT trans8_Level_unit_level_2; \
	UNIT trans8_Level_unit_temperature; \
	UNIT trans8_Level_unit_primary_value_2; \
	UNIT trans8_Level_unit_sensor_value_2; \
	UNIT trans8_Level_unit_secondary_value_1; \
	UNIT trans8_Level_unit_secondary_value_2

#define USE_TRANS8_LEVEL_OPTIONAL_A \
	USE_TRANS8_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans8_Level_PRIMARY_VALUE; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans8_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans8_Level_PRIMARY_VALUE_page; \
	COMMAND trans8_Level_PRIMARY_VALUE_read; \
	VARIABLE trans8_Level_PRIMARY_VALUE_UNIT; \
	MENU trans8_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans8_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans8_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans8_Level_LEVEL; \
	MENU trans8_Level_LEVEL_page; \
	COMMAND trans8_Level_LEVEL_read; \
	VARIABLE trans8_Level_LEVEL_UNIT; \
	MENU trans8_Level_LEVEL_UNIT_page; \
	COMMAND trans8_Level_LEVEL_UNIT_read; \
	COMMAND trans8_Level_LEVEL_UNIT_write; \
	VARIABLE trans8_Level_SENSOR_VALUE; \
	MENU trans8_Level_SENSOR_VALUE_page; \
	COMMAND trans8_Level_SENSOR_VALUE_read; \
	VARIABLE trans8_Level_SENSOR_UNIT; \
	MENU trans8_Level_SENSOR_UNIT_page; \
	COMMAND trans8_Level_SENSOR_UNIT_read; \
	COMMAND trans8_Level_SENSOR_UNIT_write; \
	VARIABLE trans8_Level_SENSOR_OFFSET; \
	MENU trans8_Level_SENSOR_OFFSET_page; \
	COMMAND trans8_Level_SENSOR_OFFSET_read; \
	COMMAND trans8_Level_SENSOR_OFFSET_write; \
	VARIABLE trans8_Level_CAL_TYPE; \
	MENU trans8_Level_CAL_TYPE_page; \
	COMMAND trans8_Level_CAL_TYPE_read; \
	COMMAND trans8_Level_CAL_TYPE_write; \
	VARIABLE trans8_Level_CAL_POINT_LO; \
	MENU trans8_Level_CAL_POINT_LO_page; \
	COMMAND trans8_Level_CAL_POINT_LO_read; \
	COMMAND trans8_Level_CAL_POINT_LO_write; \
	VARIABLE trans8_Level_CAL_POINT_HI; \
	MENU trans8_Level_CAL_POINT_HI_page; \
	COMMAND trans8_Level_CAL_POINT_HI_read; \
	COMMAND trans8_Level_CAL_POINT_HI_write; \
	VARIABLE trans8_Level_LEVEL_LO; \
	MENU trans8_Level_LEVEL_LO_page; \
	COMMAND trans8_Level_LEVEL_LO_read; \
	COMMAND trans8_Level_LEVEL_LO_write; \
	VARIABLE trans8_Level_LEVEL_HI; \
	MENU trans8_Level_LEVEL_HI_page; \
	COMMAND trans8_Level_LEVEL_HI_read; \
	COMMAND trans8_Level_LEVEL_HI_write; \
	VARIABLE trans8_Level_LEVEL_OFFSET; \
	MENU trans8_Level_LEVEL_OFFSET_page; \
	COMMAND trans8_Level_LEVEL_OFFSET_read; \
	COMMAND trans8_Level_LEVEL_OFFSET_write; \
	VARIABLE trans8_Level_LIN_TYPE; \
	MENU trans8_Level_LIN_TYPE_page; \
	COMMAND trans8_Level_LIN_TYPE_read; \
	COMMAND trans8_Level_LIN_TYPE_write; \
	COLLECTION trans8_Level_VIEW_1; \
	MENU trans8_Level_VIEW_1_page; \
	MENU trans8_Level_Simple_Dialog_Optional_A; \
	UNIT trans8_Level_unit_level_1; \
	UNIT trans8_Level_unit_primary_value_1; \
	UNIT trans8_Level_unit_sensor_value_1

#define USE_TRANS8_LEVEL_OPTIONAL_B \
	USE_TRANS8_LEVEL_OPTIONAL_BOTH; \
	MENU trans8_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans8_Level_)
#define USE_TRANS8_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans8_Level_)
#define USE_TRANS8_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans8_Level_)
#define USE_TRANS8_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans8_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_LEVEL_MANDATORY_BOTH \
	BLOCK trans9_Level_block; \
	COLLECTION trans9_Level_BLOCK_OBJECT; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Level_BLOCK_OBJECT_page; \
	COMMAND trans9_Level_BLOCK_OBJECT_read; \
	VARIABLE trans9_Level_ST_REV; \
	MENU trans9_Level_ST_REV_page; \
	COMMAND trans9_Level_ST_REV_read; \
	VARIABLE trans9_Level_TAG_DESC; \
	MENU trans9_Level_TAG_DESC_page; \
	COMMAND trans9_Level_TAG_DESC_read; \
	COMMAND trans9_Level_TAG_DESC_write; \
	VARIABLE trans9_Level_STRATEGY; \
	MENU trans9_Level_STRATEGY_page; \
	COMMAND trans9_Level_STRATEGY_read; \
	COMMAND trans9_Level_STRATEGY_write; \
	VARIABLE trans9_Level_ALERT_KEY; \
	MENU trans9_Level_ALERT_KEY_page; \
	COMMAND trans9_Level_ALERT_KEY_read; \
	COMMAND trans9_Level_ALERT_KEY_write; \
	VARIABLE trans9_Level_TARGET_MODE; \
	MENU trans9_Level_TARGET_MODE_page; \
	COMMAND trans9_Level_TARGET_MODE_read; \
	COMMAND trans9_Level_TARGET_MODE_write; \
	COLLECTION trans9_Level_MODE_BLK; \
	VARIABLE trans9_Level_MODE_BLK_Actual; \
	VARIABLE trans9_Level_MODE_BLK_Permitted; \
	VARIABLE trans9_Level_MODE_BLK_Normal; \
	MENU trans9_Level_MODE_BLK_page; \
	COMMAND trans9_Level_MODE_BLK_read; \
	COLLECTION trans9_Level_ALARM_SUM; \
	VARIABLE trans9_Level_ALARM_SUM_Current; \
	VARIABLE trans9_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Level_ALARM_SUM_Unreported; \
	VARIABLE trans9_Level_ALARM_SUM_Disabled; \
	MENU trans9_Level_ALARM_SUM_page; \
	COMMAND trans9_Level_ALARM_SUM_read

#define USE_TRANS9_LEVEL_MANDATORY_A \
	USE_TRANS9_LEVEL_MANDATORY_BOTH; \
	MENU trans9_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS9_LEVEL_MANDATORY_B \
	USE_TRANS9_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans9_Level_PRIMARY_VALUE; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans9_Level_PRIMARY_VALUE_page; \
	COMMAND trans9_Level_PRIMARY_VALUE_read; \
	VARIABLE trans9_Level_PRIMARY_VALUE_UNIT; \
	MENU trans9_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans9_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans9_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans9_Level_LEVEL; \
	MENU trans9_Level_LEVEL_page; \
	COMMAND trans9_Level_LEVEL_read; \
	VARIABLE trans9_Level_LEVEL_UNIT; \
	MENU trans9_Level_LEVEL_UNIT_page; \
	COMMAND trans9_Level_LEVEL_UNIT_read; \
	COMMAND trans9_Level_LEVEL_UNIT_write; \
	VARIABLE trans9_Level_SENSOR_VALUE; \
	MENU trans9_Level_SENSOR_VALUE_page; \
	COMMAND trans9_Level_SENSOR_VALUE_read; \
	VARIABLE trans9_Level_SENSOR_UNIT; \
	MENU trans9_Level_SENSOR_UNIT_page; \
	COMMAND trans9_Level_SENSOR_UNIT_read; \
	COMMAND trans9_Level_SENSOR_UNIT_write; \
	VARIABLE trans9_Level_SENSOR_OFFSET; \
	MENU trans9_Level_SENSOR_OFFSET_page; \
	COMMAND trans9_Level_SENSOR_OFFSET_read; \
	COMMAND trans9_Level_SENSOR_OFFSET_write; \
	VARIABLE trans9_Level_CAL_TYPE; \
	MENU trans9_Level_CAL_TYPE_page; \
	COMMAND trans9_Level_CAL_TYPE_read; \
	COMMAND trans9_Level_CAL_TYPE_write; \
	VARIABLE trans9_Level_CAL_POINT_LO; \
	MENU trans9_Level_CAL_POINT_LO_page; \
	COMMAND trans9_Level_CAL_POINT_LO_read; \
	COMMAND trans9_Level_CAL_POINT_LO_write; \
	VARIABLE trans9_Level_CAL_POINT_HI; \
	MENU trans9_Level_CAL_POINT_HI_page; \
	COMMAND trans9_Level_CAL_POINT_HI_read; \
	COMMAND trans9_Level_CAL_POINT_HI_write; \
	VARIABLE trans9_Level_LEVEL_LO; \
	MENU trans9_Level_LEVEL_LO_page; \
	COMMAND trans9_Level_LEVEL_LO_read; \
	COMMAND trans9_Level_LEVEL_LO_write; \
	VARIABLE trans9_Level_LEVEL_HI; \
	MENU trans9_Level_LEVEL_HI_page; \
	COMMAND trans9_Level_LEVEL_HI_read; \
	COMMAND trans9_Level_LEVEL_HI_write; \
	VARIABLE trans9_Level_LEVEL_OFFSET; \
	MENU trans9_Level_LEVEL_OFFSET_page; \
	COMMAND trans9_Level_LEVEL_OFFSET_read; \
	COMMAND trans9_Level_LEVEL_OFFSET_write; \
	VARIABLE trans9_Level_LIN_TYPE; \
	MENU trans9_Level_LIN_TYPE_page; \
	COMMAND trans9_Level_LIN_TYPE_read; \
	COMMAND trans9_Level_LIN_TYPE_write; \
	COLLECTION trans9_Level_VIEW_1; \
	MENU trans9_Level_VIEW_1_page; \
	MENU trans9_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans9_Level_unit_level_1; \
	UNIT trans9_Level_unit_primary_value_1; \
	UNIT trans9_Level_unit_sensor_value_1

#define USE_TRANS9_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans9_Level_SECONDARY_VALUE_1; \
	VARIABLE trans9_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans9_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans9_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans9_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans9_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans9_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans9_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans9_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans9_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans9_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans9_Level_SECONDARY_VALUE_2; \
	VARIABLE trans9_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans9_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans9_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans9_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans9_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans9_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans9_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans9_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans9_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans9_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans9_Level_LIN_DIAMETER; \
	MENU trans9_Level_LIN_DIAMETER_page; \
	COMMAND trans9_Level_LIN_DIAMETER_read; \
	COMMAND trans9_Level_LIN_DIAMETER_write; \
	VARIABLE trans9_Level_LIN_VOLUME; \
	MENU trans9_Level_LIN_VOLUME_page; \
	COMMAND trans9_Level_LIN_VOLUME_read; \
	COMMAND trans9_Level_LIN_VOLUME_write; \
	VARIABLE trans9_Level_SENSOR_HIGH_LIMIT; \
	MENU trans9_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans9_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans9_Level_SENSOR_LOW_LIMIT; \
	MENU trans9_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans9_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans9_Level_MAX_SENSOR_VALUE; \
	MENU trans9_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans9_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans9_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans9_Level_MIN_SENSOR_VALUE; \
	MENU trans9_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans9_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans9_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans9_Level_TEMPERATURE; \
	MENU trans9_Level_TEMPERATURE_page; \
	COMMAND trans9_Level_TEMPERATURE_read; \
	VARIABLE trans9_Level_TEMPERATURE_UNIT; \
	MENU trans9_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans9_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans9_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans9_Level_MAX_TEMPERATURE; \
	MENU trans9_Level_MAX_TEMPERATURE_page; \
	COMMAND trans9_Level_MAX_TEMPERATURE_read; \
	COMMAND trans9_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans9_Level_MIN_TEMPERATURE; \
	MENU trans9_Level_MIN_TEMPERATURE_page; \
	COMMAND trans9_Level_MIN_TEMPERATURE_read; \
	COMMAND trans9_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans9_Level_TAB_ENTRY; \
	MENU trans9_Level_TAB_ENTRY_page; \
	COMMAND trans9_Level_TAB_ENTRY_read; \
	COMMAND trans9_Level_TAB_ENTRY_write; \
	COLLECTION trans9_Level_TAB_X_Y_VALUE; \
	VARIABLE trans9_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans9_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans9_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans9_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans9_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans9_Level_TAB_MIN_NUMBER; \
	MENU trans9_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans9_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans9_Level_TAB_MAX_NUMBER; \
	MENU trans9_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans9_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans9_Level_TAB_OP_CODE; \
	MENU trans9_Level_TAB_OP_CODE_page; \
	COMMAND trans9_Level_TAB_OP_CODE_read; \
	COMMAND trans9_Level_TAB_OP_CODE_write; \
	VARIABLE trans9_Level_TAB_STATUS; \
	MENU trans9_Level_TAB_STATUS_page; \
	COMMAND trans9_Level_TAB_STATUS_read; \
	VARIABLE trans9_Level_TAB_ACTUAL_NUMBER; \
	MENU trans9_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans9_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans9_Level_VIEW_2; \
	MENU trans9_Level_VIEW_2_page; \
	COLLECTION trans9_Level_VIEW_3; \
	MENU trans9_Level_VIEW_3_page; \
	UNIT trans9_Level_unit_level_2; \
	UNIT trans9_Level_unit_temperature; \
	UNIT trans9_Level_unit_primary_value_2; \
	UNIT trans9_Level_unit_sensor_value_2; \
	UNIT trans9_Level_unit_secondary_value_1; \
	UNIT trans9_Level_unit_secondary_value_2

#define USE_TRANS9_LEVEL_OPTIONAL_A \
	USE_TRANS9_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans9_Level_PRIMARY_VALUE; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans9_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans9_Level_PRIMARY_VALUE_page; \
	COMMAND trans9_Level_PRIMARY_VALUE_read; \
	VARIABLE trans9_Level_PRIMARY_VALUE_UNIT; \
	MENU trans9_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans9_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans9_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans9_Level_LEVEL; \
	MENU trans9_Level_LEVEL_page; \
	COMMAND trans9_Level_LEVEL_read; \
	VARIABLE trans9_Level_LEVEL_UNIT; \
	MENU trans9_Level_LEVEL_UNIT_page; \
	COMMAND trans9_Level_LEVEL_UNIT_read; \
	COMMAND trans9_Level_LEVEL_UNIT_write; \
	VARIABLE trans9_Level_SENSOR_VALUE; \
	MENU trans9_Level_SENSOR_VALUE_page; \
	COMMAND trans9_Level_SENSOR_VALUE_read; \
	VARIABLE trans9_Level_SENSOR_UNIT; \
	MENU trans9_Level_SENSOR_UNIT_page; \
	COMMAND trans9_Level_SENSOR_UNIT_read; \
	COMMAND trans9_Level_SENSOR_UNIT_write; \
	VARIABLE trans9_Level_SENSOR_OFFSET; \
	MENU trans9_Level_SENSOR_OFFSET_page; \
	COMMAND trans9_Level_SENSOR_OFFSET_read; \
	COMMAND trans9_Level_SENSOR_OFFSET_write; \
	VARIABLE trans9_Level_CAL_TYPE; \
	MENU trans9_Level_CAL_TYPE_page; \
	COMMAND trans9_Level_CAL_TYPE_read; \
	COMMAND trans9_Level_CAL_TYPE_write; \
	VARIABLE trans9_Level_CAL_POINT_LO; \
	MENU trans9_Level_CAL_POINT_LO_page; \
	COMMAND trans9_Level_CAL_POINT_LO_read; \
	COMMAND trans9_Level_CAL_POINT_LO_write; \
	VARIABLE trans9_Level_CAL_POINT_HI; \
	MENU trans9_Level_CAL_POINT_HI_page; \
	COMMAND trans9_Level_CAL_POINT_HI_read; \
	COMMAND trans9_Level_CAL_POINT_HI_write; \
	VARIABLE trans9_Level_LEVEL_LO; \
	MENU trans9_Level_LEVEL_LO_page; \
	COMMAND trans9_Level_LEVEL_LO_read; \
	COMMAND trans9_Level_LEVEL_LO_write; \
	VARIABLE trans9_Level_LEVEL_HI; \
	MENU trans9_Level_LEVEL_HI_page; \
	COMMAND trans9_Level_LEVEL_HI_read; \
	COMMAND trans9_Level_LEVEL_HI_write; \
	VARIABLE trans9_Level_LEVEL_OFFSET; \
	MENU trans9_Level_LEVEL_OFFSET_page; \
	COMMAND trans9_Level_LEVEL_OFFSET_read; \
	COMMAND trans9_Level_LEVEL_OFFSET_write; \
	VARIABLE trans9_Level_LIN_TYPE; \
	MENU trans9_Level_LIN_TYPE_page; \
	COMMAND trans9_Level_LIN_TYPE_read; \
	COMMAND trans9_Level_LIN_TYPE_write; \
	COLLECTION trans9_Level_VIEW_1; \
	MENU trans9_Level_VIEW_1_page; \
	MENU trans9_Level_Simple_Dialog_Optional_A; \
	UNIT trans9_Level_unit_level_1; \
	UNIT trans9_Level_unit_primary_value_1; \
	UNIT trans9_Level_unit_sensor_value_1

#define USE_TRANS9_LEVEL_OPTIONAL_B \
	USE_TRANS9_LEVEL_OPTIONAL_BOTH; \
	MENU trans9_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans9_Level_)
#define USE_TRANS9_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans9_Level_)
#define USE_TRANS9_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans9_Level_)
#define USE_TRANS9_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans9_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_LEVEL_MANDATORY_BOTH \
	BLOCK trans10_Level_block; \
	COLLECTION trans10_Level_BLOCK_OBJECT; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Level_BLOCK_OBJECT_page; \
	COMMAND trans10_Level_BLOCK_OBJECT_read; \
	VARIABLE trans10_Level_ST_REV; \
	MENU trans10_Level_ST_REV_page; \
	COMMAND trans10_Level_ST_REV_read; \
	VARIABLE trans10_Level_TAG_DESC; \
	MENU trans10_Level_TAG_DESC_page; \
	COMMAND trans10_Level_TAG_DESC_read; \
	COMMAND trans10_Level_TAG_DESC_write; \
	VARIABLE trans10_Level_STRATEGY; \
	MENU trans10_Level_STRATEGY_page; \
	COMMAND trans10_Level_STRATEGY_read; \
	COMMAND trans10_Level_STRATEGY_write; \
	VARIABLE trans10_Level_ALERT_KEY; \
	MENU trans10_Level_ALERT_KEY_page; \
	COMMAND trans10_Level_ALERT_KEY_read; \
	COMMAND trans10_Level_ALERT_KEY_write; \
	VARIABLE trans10_Level_TARGET_MODE; \
	MENU trans10_Level_TARGET_MODE_page; \
	COMMAND trans10_Level_TARGET_MODE_read; \
	COMMAND trans10_Level_TARGET_MODE_write; \
	COLLECTION trans10_Level_MODE_BLK; \
	VARIABLE trans10_Level_MODE_BLK_Actual; \
	VARIABLE trans10_Level_MODE_BLK_Permitted; \
	VARIABLE trans10_Level_MODE_BLK_Normal; \
	MENU trans10_Level_MODE_BLK_page; \
	COMMAND trans10_Level_MODE_BLK_read; \
	COLLECTION trans10_Level_ALARM_SUM; \
	VARIABLE trans10_Level_ALARM_SUM_Current; \
	VARIABLE trans10_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Level_ALARM_SUM_Unreported; \
	VARIABLE trans10_Level_ALARM_SUM_Disabled; \
	MENU trans10_Level_ALARM_SUM_page; \
	COMMAND trans10_Level_ALARM_SUM_read

#define USE_TRANS10_LEVEL_MANDATORY_A \
	USE_TRANS10_LEVEL_MANDATORY_BOTH; \
	MENU trans10_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS10_LEVEL_MANDATORY_B \
	USE_TRANS10_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans10_Level_PRIMARY_VALUE; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans10_Level_PRIMARY_VALUE_page; \
	COMMAND trans10_Level_PRIMARY_VALUE_read; \
	VARIABLE trans10_Level_PRIMARY_VALUE_UNIT; \
	MENU trans10_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans10_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans10_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans10_Level_LEVEL; \
	MENU trans10_Level_LEVEL_page; \
	COMMAND trans10_Level_LEVEL_read; \
	VARIABLE trans10_Level_LEVEL_UNIT; \
	MENU trans10_Level_LEVEL_UNIT_page; \
	COMMAND trans10_Level_LEVEL_UNIT_read; \
	COMMAND trans10_Level_LEVEL_UNIT_write; \
	VARIABLE trans10_Level_SENSOR_VALUE; \
	MENU trans10_Level_SENSOR_VALUE_page; \
	COMMAND trans10_Level_SENSOR_VALUE_read; \
	VARIABLE trans10_Level_SENSOR_UNIT; \
	MENU trans10_Level_SENSOR_UNIT_page; \
	COMMAND trans10_Level_SENSOR_UNIT_read; \
	COMMAND trans10_Level_SENSOR_UNIT_write; \
	VARIABLE trans10_Level_SENSOR_OFFSET; \
	MENU trans10_Level_SENSOR_OFFSET_page; \
	COMMAND trans10_Level_SENSOR_OFFSET_read; \
	COMMAND trans10_Level_SENSOR_OFFSET_write; \
	VARIABLE trans10_Level_CAL_TYPE; \
	MENU trans10_Level_CAL_TYPE_page; \
	COMMAND trans10_Level_CAL_TYPE_read; \
	COMMAND trans10_Level_CAL_TYPE_write; \
	VARIABLE trans10_Level_CAL_POINT_LO; \
	MENU trans10_Level_CAL_POINT_LO_page; \
	COMMAND trans10_Level_CAL_POINT_LO_read; \
	COMMAND trans10_Level_CAL_POINT_LO_write; \
	VARIABLE trans10_Level_CAL_POINT_HI; \
	MENU trans10_Level_CAL_POINT_HI_page; \
	COMMAND trans10_Level_CAL_POINT_HI_read; \
	COMMAND trans10_Level_CAL_POINT_HI_write; \
	VARIABLE trans10_Level_LEVEL_LO; \
	MENU trans10_Level_LEVEL_LO_page; \
	COMMAND trans10_Level_LEVEL_LO_read; \
	COMMAND trans10_Level_LEVEL_LO_write; \
	VARIABLE trans10_Level_LEVEL_HI; \
	MENU trans10_Level_LEVEL_HI_page; \
	COMMAND trans10_Level_LEVEL_HI_read; \
	COMMAND trans10_Level_LEVEL_HI_write; \
	VARIABLE trans10_Level_LEVEL_OFFSET; \
	MENU trans10_Level_LEVEL_OFFSET_page; \
	COMMAND trans10_Level_LEVEL_OFFSET_read; \
	COMMAND trans10_Level_LEVEL_OFFSET_write; \
	VARIABLE trans10_Level_LIN_TYPE; \
	MENU trans10_Level_LIN_TYPE_page; \
	COMMAND trans10_Level_LIN_TYPE_read; \
	COMMAND trans10_Level_LIN_TYPE_write; \
	COLLECTION trans10_Level_VIEW_1; \
	MENU trans10_Level_VIEW_1_page; \
	MENU trans10_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans10_Level_unit_level_1; \
	UNIT trans10_Level_unit_primary_value_1; \
	UNIT trans10_Level_unit_sensor_value_1

#define USE_TRANS10_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans10_Level_SECONDARY_VALUE_1; \
	VARIABLE trans10_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans10_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans10_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans10_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans10_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans10_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans10_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans10_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans10_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans10_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans10_Level_SECONDARY_VALUE_2; \
	VARIABLE trans10_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans10_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans10_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans10_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans10_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans10_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans10_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans10_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans10_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans10_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans10_Level_LIN_DIAMETER; \
	MENU trans10_Level_LIN_DIAMETER_page; \
	COMMAND trans10_Level_LIN_DIAMETER_read; \
	COMMAND trans10_Level_LIN_DIAMETER_write; \
	VARIABLE trans10_Level_LIN_VOLUME; \
	MENU trans10_Level_LIN_VOLUME_page; \
	COMMAND trans10_Level_LIN_VOLUME_read; \
	COMMAND trans10_Level_LIN_VOLUME_write; \
	VARIABLE trans10_Level_SENSOR_HIGH_LIMIT; \
	MENU trans10_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans10_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans10_Level_SENSOR_LOW_LIMIT; \
	MENU trans10_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans10_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans10_Level_MAX_SENSOR_VALUE; \
	MENU trans10_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans10_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans10_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans10_Level_MIN_SENSOR_VALUE; \
	MENU trans10_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans10_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans10_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans10_Level_TEMPERATURE; \
	MENU trans10_Level_TEMPERATURE_page; \
	COMMAND trans10_Level_TEMPERATURE_read; \
	VARIABLE trans10_Level_TEMPERATURE_UNIT; \
	MENU trans10_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans10_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans10_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans10_Level_MAX_TEMPERATURE; \
	MENU trans10_Level_MAX_TEMPERATURE_page; \
	COMMAND trans10_Level_MAX_TEMPERATURE_read; \
	COMMAND trans10_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans10_Level_MIN_TEMPERATURE; \
	MENU trans10_Level_MIN_TEMPERATURE_page; \
	COMMAND trans10_Level_MIN_TEMPERATURE_read; \
	COMMAND trans10_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans10_Level_TAB_ENTRY; \
	MENU trans10_Level_TAB_ENTRY_page; \
	COMMAND trans10_Level_TAB_ENTRY_read; \
	COMMAND trans10_Level_TAB_ENTRY_write; \
	COLLECTION trans10_Level_TAB_X_Y_VALUE; \
	VARIABLE trans10_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans10_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans10_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans10_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans10_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans10_Level_TAB_MIN_NUMBER; \
	MENU trans10_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans10_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans10_Level_TAB_MAX_NUMBER; \
	MENU trans10_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans10_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans10_Level_TAB_OP_CODE; \
	MENU trans10_Level_TAB_OP_CODE_page; \
	COMMAND trans10_Level_TAB_OP_CODE_read; \
	COMMAND trans10_Level_TAB_OP_CODE_write; \
	VARIABLE trans10_Level_TAB_STATUS; \
	MENU trans10_Level_TAB_STATUS_page; \
	COMMAND trans10_Level_TAB_STATUS_read; \
	VARIABLE trans10_Level_TAB_ACTUAL_NUMBER; \
	MENU trans10_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans10_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans10_Level_VIEW_2; \
	MENU trans10_Level_VIEW_2_page; \
	COLLECTION trans10_Level_VIEW_3; \
	MENU trans10_Level_VIEW_3_page; \
	UNIT trans10_Level_unit_level_2; \
	UNIT trans10_Level_unit_temperature; \
	UNIT trans10_Level_unit_primary_value_2; \
	UNIT trans10_Level_unit_sensor_value_2; \
	UNIT trans10_Level_unit_secondary_value_1; \
	UNIT trans10_Level_unit_secondary_value_2

#define USE_TRANS10_LEVEL_OPTIONAL_A \
	USE_TRANS10_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans10_Level_PRIMARY_VALUE; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans10_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans10_Level_PRIMARY_VALUE_page; \
	COMMAND trans10_Level_PRIMARY_VALUE_read; \
	VARIABLE trans10_Level_PRIMARY_VALUE_UNIT; \
	MENU trans10_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans10_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans10_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans10_Level_LEVEL; \
	MENU trans10_Level_LEVEL_page; \
	COMMAND trans10_Level_LEVEL_read; \
	VARIABLE trans10_Level_LEVEL_UNIT; \
	MENU trans10_Level_LEVEL_UNIT_page; \
	COMMAND trans10_Level_LEVEL_UNIT_read; \
	COMMAND trans10_Level_LEVEL_UNIT_write; \
	VARIABLE trans10_Level_SENSOR_VALUE; \
	MENU trans10_Level_SENSOR_VALUE_page; \
	COMMAND trans10_Level_SENSOR_VALUE_read; \
	VARIABLE trans10_Level_SENSOR_UNIT; \
	MENU trans10_Level_SENSOR_UNIT_page; \
	COMMAND trans10_Level_SENSOR_UNIT_read; \
	COMMAND trans10_Level_SENSOR_UNIT_write; \
	VARIABLE trans10_Level_SENSOR_OFFSET; \
	MENU trans10_Level_SENSOR_OFFSET_page; \
	COMMAND trans10_Level_SENSOR_OFFSET_read; \
	COMMAND trans10_Level_SENSOR_OFFSET_write; \
	VARIABLE trans10_Level_CAL_TYPE; \
	MENU trans10_Level_CAL_TYPE_page; \
	COMMAND trans10_Level_CAL_TYPE_read; \
	COMMAND trans10_Level_CAL_TYPE_write; \
	VARIABLE trans10_Level_CAL_POINT_LO; \
	MENU trans10_Level_CAL_POINT_LO_page; \
	COMMAND trans10_Level_CAL_POINT_LO_read; \
	COMMAND trans10_Level_CAL_POINT_LO_write; \
	VARIABLE trans10_Level_CAL_POINT_HI; \
	MENU trans10_Level_CAL_POINT_HI_page; \
	COMMAND trans10_Level_CAL_POINT_HI_read; \
	COMMAND trans10_Level_CAL_POINT_HI_write; \
	VARIABLE trans10_Level_LEVEL_LO; \
	MENU trans10_Level_LEVEL_LO_page; \
	COMMAND trans10_Level_LEVEL_LO_read; \
	COMMAND trans10_Level_LEVEL_LO_write; \
	VARIABLE trans10_Level_LEVEL_HI; \
	MENU trans10_Level_LEVEL_HI_page; \
	COMMAND trans10_Level_LEVEL_HI_read; \
	COMMAND trans10_Level_LEVEL_HI_write; \
	VARIABLE trans10_Level_LEVEL_OFFSET; \
	MENU trans10_Level_LEVEL_OFFSET_page; \
	COMMAND trans10_Level_LEVEL_OFFSET_read; \
	COMMAND trans10_Level_LEVEL_OFFSET_write; \
	VARIABLE trans10_Level_LIN_TYPE; \
	MENU trans10_Level_LIN_TYPE_page; \
	COMMAND trans10_Level_LIN_TYPE_read; \
	COMMAND trans10_Level_LIN_TYPE_write; \
	COLLECTION trans10_Level_VIEW_1; \
	MENU trans10_Level_VIEW_1_page; \
	MENU trans10_Level_Simple_Dialog_Optional_A; \
	UNIT trans10_Level_unit_level_1; \
	UNIT trans10_Level_unit_primary_value_1; \
	UNIT trans10_Level_unit_sensor_value_1

#define USE_TRANS10_LEVEL_OPTIONAL_B \
	USE_TRANS10_LEVEL_OPTIONAL_BOTH; \
	MENU trans10_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans10_Level_)
#define USE_TRANS10_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans10_Level_)
#define USE_TRANS10_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans10_Level_)
#define USE_TRANS10_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans10_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_LEVEL_MANDATORY_BOTH \
	BLOCK trans11_Level_block; \
	COLLECTION trans11_Level_BLOCK_OBJECT; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Level_BLOCK_OBJECT_page; \
	COMMAND trans11_Level_BLOCK_OBJECT_read; \
	VARIABLE trans11_Level_ST_REV; \
	MENU trans11_Level_ST_REV_page; \
	COMMAND trans11_Level_ST_REV_read; \
	VARIABLE trans11_Level_TAG_DESC; \
	MENU trans11_Level_TAG_DESC_page; \
	COMMAND trans11_Level_TAG_DESC_read; \
	COMMAND trans11_Level_TAG_DESC_write; \
	VARIABLE trans11_Level_STRATEGY; \
	MENU trans11_Level_STRATEGY_page; \
	COMMAND trans11_Level_STRATEGY_read; \
	COMMAND trans11_Level_STRATEGY_write; \
	VARIABLE trans11_Level_ALERT_KEY; \
	MENU trans11_Level_ALERT_KEY_page; \
	COMMAND trans11_Level_ALERT_KEY_read; \
	COMMAND trans11_Level_ALERT_KEY_write; \
	VARIABLE trans11_Level_TARGET_MODE; \
	MENU trans11_Level_TARGET_MODE_page; \
	COMMAND trans11_Level_TARGET_MODE_read; \
	COMMAND trans11_Level_TARGET_MODE_write; \
	COLLECTION trans11_Level_MODE_BLK; \
	VARIABLE trans11_Level_MODE_BLK_Actual; \
	VARIABLE trans11_Level_MODE_BLK_Permitted; \
	VARIABLE trans11_Level_MODE_BLK_Normal; \
	MENU trans11_Level_MODE_BLK_page; \
	COMMAND trans11_Level_MODE_BLK_read; \
	COLLECTION trans11_Level_ALARM_SUM; \
	VARIABLE trans11_Level_ALARM_SUM_Current; \
	VARIABLE trans11_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Level_ALARM_SUM_Unreported; \
	VARIABLE trans11_Level_ALARM_SUM_Disabled; \
	MENU trans11_Level_ALARM_SUM_page; \
	COMMAND trans11_Level_ALARM_SUM_read

#define USE_TRANS11_LEVEL_MANDATORY_A \
	USE_TRANS11_LEVEL_MANDATORY_BOTH; \
	MENU trans11_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS11_LEVEL_MANDATORY_B \
	USE_TRANS11_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans11_Level_PRIMARY_VALUE; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans11_Level_PRIMARY_VALUE_page; \
	COMMAND trans11_Level_PRIMARY_VALUE_read; \
	VARIABLE trans11_Level_PRIMARY_VALUE_UNIT; \
	MENU trans11_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans11_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans11_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans11_Level_LEVEL; \
	MENU trans11_Level_LEVEL_page; \
	COMMAND trans11_Level_LEVEL_read; \
	VARIABLE trans11_Level_LEVEL_UNIT; \
	MENU trans11_Level_LEVEL_UNIT_page; \
	COMMAND trans11_Level_LEVEL_UNIT_read; \
	COMMAND trans11_Level_LEVEL_UNIT_write; \
	VARIABLE trans11_Level_SENSOR_VALUE; \
	MENU trans11_Level_SENSOR_VALUE_page; \
	COMMAND trans11_Level_SENSOR_VALUE_read; \
	VARIABLE trans11_Level_SENSOR_UNIT; \
	MENU trans11_Level_SENSOR_UNIT_page; \
	COMMAND trans11_Level_SENSOR_UNIT_read; \
	COMMAND trans11_Level_SENSOR_UNIT_write; \
	VARIABLE trans11_Level_SENSOR_OFFSET; \
	MENU trans11_Level_SENSOR_OFFSET_page; \
	COMMAND trans11_Level_SENSOR_OFFSET_read; \
	COMMAND trans11_Level_SENSOR_OFFSET_write; \
	VARIABLE trans11_Level_CAL_TYPE; \
	MENU trans11_Level_CAL_TYPE_page; \
	COMMAND trans11_Level_CAL_TYPE_read; \
	COMMAND trans11_Level_CAL_TYPE_write; \
	VARIABLE trans11_Level_CAL_POINT_LO; \
	MENU trans11_Level_CAL_POINT_LO_page; \
	COMMAND trans11_Level_CAL_POINT_LO_read; \
	COMMAND trans11_Level_CAL_POINT_LO_write; \
	VARIABLE trans11_Level_CAL_POINT_HI; \
	MENU trans11_Level_CAL_POINT_HI_page; \
	COMMAND trans11_Level_CAL_POINT_HI_read; \
	COMMAND trans11_Level_CAL_POINT_HI_write; \
	VARIABLE trans11_Level_LEVEL_LO; \
	MENU trans11_Level_LEVEL_LO_page; \
	COMMAND trans11_Level_LEVEL_LO_read; \
	COMMAND trans11_Level_LEVEL_LO_write; \
	VARIABLE trans11_Level_LEVEL_HI; \
	MENU trans11_Level_LEVEL_HI_page; \
	COMMAND trans11_Level_LEVEL_HI_read; \
	COMMAND trans11_Level_LEVEL_HI_write; \
	VARIABLE trans11_Level_LEVEL_OFFSET; \
	MENU trans11_Level_LEVEL_OFFSET_page; \
	COMMAND trans11_Level_LEVEL_OFFSET_read; \
	COMMAND trans11_Level_LEVEL_OFFSET_write; \
	VARIABLE trans11_Level_LIN_TYPE; \
	MENU trans11_Level_LIN_TYPE_page; \
	COMMAND trans11_Level_LIN_TYPE_read; \
	COMMAND trans11_Level_LIN_TYPE_write; \
	COLLECTION trans11_Level_VIEW_1; \
	MENU trans11_Level_VIEW_1_page; \
	MENU trans11_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans11_Level_unit_level_1; \
	UNIT trans11_Level_unit_primary_value_1; \
	UNIT trans11_Level_unit_sensor_value_1

#define USE_TRANS11_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans11_Level_SECONDARY_VALUE_1; \
	VARIABLE trans11_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans11_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans11_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans11_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans11_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans11_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans11_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans11_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans11_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans11_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans11_Level_SECONDARY_VALUE_2; \
	VARIABLE trans11_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans11_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans11_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans11_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans11_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans11_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans11_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans11_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans11_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans11_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans11_Level_LIN_DIAMETER; \
	MENU trans11_Level_LIN_DIAMETER_page; \
	COMMAND trans11_Level_LIN_DIAMETER_read; \
	COMMAND trans11_Level_LIN_DIAMETER_write; \
	VARIABLE trans11_Level_LIN_VOLUME; \
	MENU trans11_Level_LIN_VOLUME_page; \
	COMMAND trans11_Level_LIN_VOLUME_read; \
	COMMAND trans11_Level_LIN_VOLUME_write; \
	VARIABLE trans11_Level_SENSOR_HIGH_LIMIT; \
	MENU trans11_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans11_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans11_Level_SENSOR_LOW_LIMIT; \
	MENU trans11_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans11_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans11_Level_MAX_SENSOR_VALUE; \
	MENU trans11_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans11_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans11_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans11_Level_MIN_SENSOR_VALUE; \
	MENU trans11_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans11_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans11_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans11_Level_TEMPERATURE; \
	MENU trans11_Level_TEMPERATURE_page; \
	COMMAND trans11_Level_TEMPERATURE_read; \
	VARIABLE trans11_Level_TEMPERATURE_UNIT; \
	MENU trans11_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans11_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans11_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans11_Level_MAX_TEMPERATURE; \
	MENU trans11_Level_MAX_TEMPERATURE_page; \
	COMMAND trans11_Level_MAX_TEMPERATURE_read; \
	COMMAND trans11_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans11_Level_MIN_TEMPERATURE; \
	MENU trans11_Level_MIN_TEMPERATURE_page; \
	COMMAND trans11_Level_MIN_TEMPERATURE_read; \
	COMMAND trans11_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans11_Level_TAB_ENTRY; \
	MENU trans11_Level_TAB_ENTRY_page; \
	COMMAND trans11_Level_TAB_ENTRY_read; \
	COMMAND trans11_Level_TAB_ENTRY_write; \
	COLLECTION trans11_Level_TAB_X_Y_VALUE; \
	VARIABLE trans11_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans11_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans11_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans11_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans11_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans11_Level_TAB_MIN_NUMBER; \
	MENU trans11_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans11_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans11_Level_TAB_MAX_NUMBER; \
	MENU trans11_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans11_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans11_Level_TAB_OP_CODE; \
	MENU trans11_Level_TAB_OP_CODE_page; \
	COMMAND trans11_Level_TAB_OP_CODE_read; \
	COMMAND trans11_Level_TAB_OP_CODE_write; \
	VARIABLE trans11_Level_TAB_STATUS; \
	MENU trans11_Level_TAB_STATUS_page; \
	COMMAND trans11_Level_TAB_STATUS_read; \
	VARIABLE trans11_Level_TAB_ACTUAL_NUMBER; \
	MENU trans11_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans11_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans11_Level_VIEW_2; \
	MENU trans11_Level_VIEW_2_page; \
	COLLECTION trans11_Level_VIEW_3; \
	MENU trans11_Level_VIEW_3_page; \
	UNIT trans11_Level_unit_level_2; \
	UNIT trans11_Level_unit_temperature; \
	UNIT trans11_Level_unit_primary_value_2; \
	UNIT trans11_Level_unit_sensor_value_2; \
	UNIT trans11_Level_unit_secondary_value_1; \
	UNIT trans11_Level_unit_secondary_value_2

#define USE_TRANS11_LEVEL_OPTIONAL_A \
	USE_TRANS11_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans11_Level_PRIMARY_VALUE; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans11_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans11_Level_PRIMARY_VALUE_page; \
	COMMAND trans11_Level_PRIMARY_VALUE_read; \
	VARIABLE trans11_Level_PRIMARY_VALUE_UNIT; \
	MENU trans11_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans11_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans11_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans11_Level_LEVEL; \
	MENU trans11_Level_LEVEL_page; \
	COMMAND trans11_Level_LEVEL_read; \
	VARIABLE trans11_Level_LEVEL_UNIT; \
	MENU trans11_Level_LEVEL_UNIT_page; \
	COMMAND trans11_Level_LEVEL_UNIT_read; \
	COMMAND trans11_Level_LEVEL_UNIT_write; \
	VARIABLE trans11_Level_SENSOR_VALUE; \
	MENU trans11_Level_SENSOR_VALUE_page; \
	COMMAND trans11_Level_SENSOR_VALUE_read; \
	VARIABLE trans11_Level_SENSOR_UNIT; \
	MENU trans11_Level_SENSOR_UNIT_page; \
	COMMAND trans11_Level_SENSOR_UNIT_read; \
	COMMAND trans11_Level_SENSOR_UNIT_write; \
	VARIABLE trans11_Level_SENSOR_OFFSET; \
	MENU trans11_Level_SENSOR_OFFSET_page; \
	COMMAND trans11_Level_SENSOR_OFFSET_read; \
	COMMAND trans11_Level_SENSOR_OFFSET_write; \
	VARIABLE trans11_Level_CAL_TYPE; \
	MENU trans11_Level_CAL_TYPE_page; \
	COMMAND trans11_Level_CAL_TYPE_read; \
	COMMAND trans11_Level_CAL_TYPE_write; \
	VARIABLE trans11_Level_CAL_POINT_LO; \
	MENU trans11_Level_CAL_POINT_LO_page; \
	COMMAND trans11_Level_CAL_POINT_LO_read; \
	COMMAND trans11_Level_CAL_POINT_LO_write; \
	VARIABLE trans11_Level_CAL_POINT_HI; \
	MENU trans11_Level_CAL_POINT_HI_page; \
	COMMAND trans11_Level_CAL_POINT_HI_read; \
	COMMAND trans11_Level_CAL_POINT_HI_write; \
	VARIABLE trans11_Level_LEVEL_LO; \
	MENU trans11_Level_LEVEL_LO_page; \
	COMMAND trans11_Level_LEVEL_LO_read; \
	COMMAND trans11_Level_LEVEL_LO_write; \
	VARIABLE trans11_Level_LEVEL_HI; \
	MENU trans11_Level_LEVEL_HI_page; \
	COMMAND trans11_Level_LEVEL_HI_read; \
	COMMAND trans11_Level_LEVEL_HI_write; \
	VARIABLE trans11_Level_LEVEL_OFFSET; \
	MENU trans11_Level_LEVEL_OFFSET_page; \
	COMMAND trans11_Level_LEVEL_OFFSET_read; \
	COMMAND trans11_Level_LEVEL_OFFSET_write; \
	VARIABLE trans11_Level_LIN_TYPE; \
	MENU trans11_Level_LIN_TYPE_page; \
	COMMAND trans11_Level_LIN_TYPE_read; \
	COMMAND trans11_Level_LIN_TYPE_write; \
	COLLECTION trans11_Level_VIEW_1; \
	MENU trans11_Level_VIEW_1_page; \
	MENU trans11_Level_Simple_Dialog_Optional_A; \
	UNIT trans11_Level_unit_level_1; \
	UNIT trans11_Level_unit_primary_value_1; \
	UNIT trans11_Level_unit_sensor_value_1

#define USE_TRANS11_LEVEL_OPTIONAL_B \
	USE_TRANS11_LEVEL_OPTIONAL_BOTH; \
	MENU trans11_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans11_Level_)
#define USE_TRANS11_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans11_Level_)
#define USE_TRANS11_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans11_Level_)
#define USE_TRANS11_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans11_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_LEVEL_MANDATORY_BOTH \
	BLOCK trans12_Level_block; \
	COLLECTION trans12_Level_BLOCK_OBJECT; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Level_BLOCK_OBJECT_page; \
	COMMAND trans12_Level_BLOCK_OBJECT_read; \
	VARIABLE trans12_Level_ST_REV; \
	MENU trans12_Level_ST_REV_page; \
	COMMAND trans12_Level_ST_REV_read; \
	VARIABLE trans12_Level_TAG_DESC; \
	MENU trans12_Level_TAG_DESC_page; \
	COMMAND trans12_Level_TAG_DESC_read; \
	COMMAND trans12_Level_TAG_DESC_write; \
	VARIABLE trans12_Level_STRATEGY; \
	MENU trans12_Level_STRATEGY_page; \
	COMMAND trans12_Level_STRATEGY_read; \
	COMMAND trans12_Level_STRATEGY_write; \
	VARIABLE trans12_Level_ALERT_KEY; \
	MENU trans12_Level_ALERT_KEY_page; \
	COMMAND trans12_Level_ALERT_KEY_read; \
	COMMAND trans12_Level_ALERT_KEY_write; \
	VARIABLE trans12_Level_TARGET_MODE; \
	MENU trans12_Level_TARGET_MODE_page; \
	COMMAND trans12_Level_TARGET_MODE_read; \
	COMMAND trans12_Level_TARGET_MODE_write; \
	COLLECTION trans12_Level_MODE_BLK; \
	VARIABLE trans12_Level_MODE_BLK_Actual; \
	VARIABLE trans12_Level_MODE_BLK_Permitted; \
	VARIABLE trans12_Level_MODE_BLK_Normal; \
	MENU trans12_Level_MODE_BLK_page; \
	COMMAND trans12_Level_MODE_BLK_read; \
	COLLECTION trans12_Level_ALARM_SUM; \
	VARIABLE trans12_Level_ALARM_SUM_Current; \
	VARIABLE trans12_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Level_ALARM_SUM_Unreported; \
	VARIABLE trans12_Level_ALARM_SUM_Disabled; \
	MENU trans12_Level_ALARM_SUM_page; \
	COMMAND trans12_Level_ALARM_SUM_read

#define USE_TRANS12_LEVEL_MANDATORY_A \
	USE_TRANS12_LEVEL_MANDATORY_BOTH; \
	MENU trans12_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS12_LEVEL_MANDATORY_B \
	USE_TRANS12_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans12_Level_PRIMARY_VALUE; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans12_Level_PRIMARY_VALUE_page; \
	COMMAND trans12_Level_PRIMARY_VALUE_read; \
	VARIABLE trans12_Level_PRIMARY_VALUE_UNIT; \
	MENU trans12_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans12_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans12_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans12_Level_LEVEL; \
	MENU trans12_Level_LEVEL_page; \
	COMMAND trans12_Level_LEVEL_read; \
	VARIABLE trans12_Level_LEVEL_UNIT; \
	MENU trans12_Level_LEVEL_UNIT_page; \
	COMMAND trans12_Level_LEVEL_UNIT_read; \
	COMMAND trans12_Level_LEVEL_UNIT_write; \
	VARIABLE trans12_Level_SENSOR_VALUE; \
	MENU trans12_Level_SENSOR_VALUE_page; \
	COMMAND trans12_Level_SENSOR_VALUE_read; \
	VARIABLE trans12_Level_SENSOR_UNIT; \
	MENU trans12_Level_SENSOR_UNIT_page; \
	COMMAND trans12_Level_SENSOR_UNIT_read; \
	COMMAND trans12_Level_SENSOR_UNIT_write; \
	VARIABLE trans12_Level_SENSOR_OFFSET; \
	MENU trans12_Level_SENSOR_OFFSET_page; \
	COMMAND trans12_Level_SENSOR_OFFSET_read; \
	COMMAND trans12_Level_SENSOR_OFFSET_write; \
	VARIABLE trans12_Level_CAL_TYPE; \
	MENU trans12_Level_CAL_TYPE_page; \
	COMMAND trans12_Level_CAL_TYPE_read; \
	COMMAND trans12_Level_CAL_TYPE_write; \
	VARIABLE trans12_Level_CAL_POINT_LO; \
	MENU trans12_Level_CAL_POINT_LO_page; \
	COMMAND trans12_Level_CAL_POINT_LO_read; \
	COMMAND trans12_Level_CAL_POINT_LO_write; \
	VARIABLE trans12_Level_CAL_POINT_HI; \
	MENU trans12_Level_CAL_POINT_HI_page; \
	COMMAND trans12_Level_CAL_POINT_HI_read; \
	COMMAND trans12_Level_CAL_POINT_HI_write; \
	VARIABLE trans12_Level_LEVEL_LO; \
	MENU trans12_Level_LEVEL_LO_page; \
	COMMAND trans12_Level_LEVEL_LO_read; \
	COMMAND trans12_Level_LEVEL_LO_write; \
	VARIABLE trans12_Level_LEVEL_HI; \
	MENU trans12_Level_LEVEL_HI_page; \
	COMMAND trans12_Level_LEVEL_HI_read; \
	COMMAND trans12_Level_LEVEL_HI_write; \
	VARIABLE trans12_Level_LEVEL_OFFSET; \
	MENU trans12_Level_LEVEL_OFFSET_page; \
	COMMAND trans12_Level_LEVEL_OFFSET_read; \
	COMMAND trans12_Level_LEVEL_OFFSET_write; \
	VARIABLE trans12_Level_LIN_TYPE; \
	MENU trans12_Level_LIN_TYPE_page; \
	COMMAND trans12_Level_LIN_TYPE_read; \
	COMMAND trans12_Level_LIN_TYPE_write; \
	COLLECTION trans12_Level_VIEW_1; \
	MENU trans12_Level_VIEW_1_page; \
	MENU trans12_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans12_Level_unit_level_1; \
	UNIT trans12_Level_unit_primary_value_1; \
	UNIT trans12_Level_unit_sensor_value_1

#define USE_TRANS12_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans12_Level_SECONDARY_VALUE_1; \
	VARIABLE trans12_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans12_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans12_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans12_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans12_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans12_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans12_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans12_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans12_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans12_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans12_Level_SECONDARY_VALUE_2; \
	VARIABLE trans12_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans12_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans12_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans12_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans12_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans12_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans12_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans12_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans12_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans12_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans12_Level_LIN_DIAMETER; \
	MENU trans12_Level_LIN_DIAMETER_page; \
	COMMAND trans12_Level_LIN_DIAMETER_read; \
	COMMAND trans12_Level_LIN_DIAMETER_write; \
	VARIABLE trans12_Level_LIN_VOLUME; \
	MENU trans12_Level_LIN_VOLUME_page; \
	COMMAND trans12_Level_LIN_VOLUME_read; \
	COMMAND trans12_Level_LIN_VOLUME_write; \
	VARIABLE trans12_Level_SENSOR_HIGH_LIMIT; \
	MENU trans12_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans12_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans12_Level_SENSOR_LOW_LIMIT; \
	MENU trans12_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans12_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans12_Level_MAX_SENSOR_VALUE; \
	MENU trans12_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans12_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans12_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans12_Level_MIN_SENSOR_VALUE; \
	MENU trans12_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans12_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans12_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans12_Level_TEMPERATURE; \
	MENU trans12_Level_TEMPERATURE_page; \
	COMMAND trans12_Level_TEMPERATURE_read; \
	VARIABLE trans12_Level_TEMPERATURE_UNIT; \
	MENU trans12_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans12_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans12_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans12_Level_MAX_TEMPERATURE; \
	MENU trans12_Level_MAX_TEMPERATURE_page; \
	COMMAND trans12_Level_MAX_TEMPERATURE_read; \
	COMMAND trans12_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans12_Level_MIN_TEMPERATURE; \
	MENU trans12_Level_MIN_TEMPERATURE_page; \
	COMMAND trans12_Level_MIN_TEMPERATURE_read; \
	COMMAND trans12_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans12_Level_TAB_ENTRY; \
	MENU trans12_Level_TAB_ENTRY_page; \
	COMMAND trans12_Level_TAB_ENTRY_read; \
	COMMAND trans12_Level_TAB_ENTRY_write; \
	COLLECTION trans12_Level_TAB_X_Y_VALUE; \
	VARIABLE trans12_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans12_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans12_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans12_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans12_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans12_Level_TAB_MIN_NUMBER; \
	MENU trans12_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans12_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans12_Level_TAB_MAX_NUMBER; \
	MENU trans12_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans12_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans12_Level_TAB_OP_CODE; \
	MENU trans12_Level_TAB_OP_CODE_page; \
	COMMAND trans12_Level_TAB_OP_CODE_read; \
	COMMAND trans12_Level_TAB_OP_CODE_write; \
	VARIABLE trans12_Level_TAB_STATUS; \
	MENU trans12_Level_TAB_STATUS_page; \
	COMMAND trans12_Level_TAB_STATUS_read; \
	VARIABLE trans12_Level_TAB_ACTUAL_NUMBER; \
	MENU trans12_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans12_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans12_Level_VIEW_2; \
	MENU trans12_Level_VIEW_2_page; \
	COLLECTION trans12_Level_VIEW_3; \
	MENU trans12_Level_VIEW_3_page; \
	UNIT trans12_Level_unit_level_2; \
	UNIT trans12_Level_unit_temperature; \
	UNIT trans12_Level_unit_primary_value_2; \
	UNIT trans12_Level_unit_sensor_value_2; \
	UNIT trans12_Level_unit_secondary_value_1; \
	UNIT trans12_Level_unit_secondary_value_2

#define USE_TRANS12_LEVEL_OPTIONAL_A \
	USE_TRANS12_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans12_Level_PRIMARY_VALUE; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans12_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans12_Level_PRIMARY_VALUE_page; \
	COMMAND trans12_Level_PRIMARY_VALUE_read; \
	VARIABLE trans12_Level_PRIMARY_VALUE_UNIT; \
	MENU trans12_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans12_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans12_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans12_Level_LEVEL; \
	MENU trans12_Level_LEVEL_page; \
	COMMAND trans12_Level_LEVEL_read; \
	VARIABLE trans12_Level_LEVEL_UNIT; \
	MENU trans12_Level_LEVEL_UNIT_page; \
	COMMAND trans12_Level_LEVEL_UNIT_read; \
	COMMAND trans12_Level_LEVEL_UNIT_write; \
	VARIABLE trans12_Level_SENSOR_VALUE; \
	MENU trans12_Level_SENSOR_VALUE_page; \
	COMMAND trans12_Level_SENSOR_VALUE_read; \
	VARIABLE trans12_Level_SENSOR_UNIT; \
	MENU trans12_Level_SENSOR_UNIT_page; \
	COMMAND trans12_Level_SENSOR_UNIT_read; \
	COMMAND trans12_Level_SENSOR_UNIT_write; \
	VARIABLE trans12_Level_SENSOR_OFFSET; \
	MENU trans12_Level_SENSOR_OFFSET_page; \
	COMMAND trans12_Level_SENSOR_OFFSET_read; \
	COMMAND trans12_Level_SENSOR_OFFSET_write; \
	VARIABLE trans12_Level_CAL_TYPE; \
	MENU trans12_Level_CAL_TYPE_page; \
	COMMAND trans12_Level_CAL_TYPE_read; \
	COMMAND trans12_Level_CAL_TYPE_write; \
	VARIABLE trans12_Level_CAL_POINT_LO; \
	MENU trans12_Level_CAL_POINT_LO_page; \
	COMMAND trans12_Level_CAL_POINT_LO_read; \
	COMMAND trans12_Level_CAL_POINT_LO_write; \
	VARIABLE trans12_Level_CAL_POINT_HI; \
	MENU trans12_Level_CAL_POINT_HI_page; \
	COMMAND trans12_Level_CAL_POINT_HI_read; \
	COMMAND trans12_Level_CAL_POINT_HI_write; \
	VARIABLE trans12_Level_LEVEL_LO; \
	MENU trans12_Level_LEVEL_LO_page; \
	COMMAND trans12_Level_LEVEL_LO_read; \
	COMMAND trans12_Level_LEVEL_LO_write; \
	VARIABLE trans12_Level_LEVEL_HI; \
	MENU trans12_Level_LEVEL_HI_page; \
	COMMAND trans12_Level_LEVEL_HI_read; \
	COMMAND trans12_Level_LEVEL_HI_write; \
	VARIABLE trans12_Level_LEVEL_OFFSET; \
	MENU trans12_Level_LEVEL_OFFSET_page; \
	COMMAND trans12_Level_LEVEL_OFFSET_read; \
	COMMAND trans12_Level_LEVEL_OFFSET_write; \
	VARIABLE trans12_Level_LIN_TYPE; \
	MENU trans12_Level_LIN_TYPE_page; \
	COMMAND trans12_Level_LIN_TYPE_read; \
	COMMAND trans12_Level_LIN_TYPE_write; \
	COLLECTION trans12_Level_VIEW_1; \
	MENU trans12_Level_VIEW_1_page; \
	MENU trans12_Level_Simple_Dialog_Optional_A; \
	UNIT trans12_Level_unit_level_1; \
	UNIT trans12_Level_unit_primary_value_1; \
	UNIT trans12_Level_unit_sensor_value_1

#define USE_TRANS12_LEVEL_OPTIONAL_B \
	USE_TRANS12_LEVEL_OPTIONAL_BOTH; \
	MENU trans12_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans12_Level_)
#define USE_TRANS12_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans12_Level_)
#define USE_TRANS12_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans12_Level_)
#define USE_TRANS12_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans12_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_LEVEL_MANDATORY_BOTH \
	BLOCK trans13_Level_block; \
	COLLECTION trans13_Level_BLOCK_OBJECT; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Level_BLOCK_OBJECT_page; \
	COMMAND trans13_Level_BLOCK_OBJECT_read; \
	VARIABLE trans13_Level_ST_REV; \
	MENU trans13_Level_ST_REV_page; \
	COMMAND trans13_Level_ST_REV_read; \
	VARIABLE trans13_Level_TAG_DESC; \
	MENU trans13_Level_TAG_DESC_page; \
	COMMAND trans13_Level_TAG_DESC_read; \
	COMMAND trans13_Level_TAG_DESC_write; \
	VARIABLE trans13_Level_STRATEGY; \
	MENU trans13_Level_STRATEGY_page; \
	COMMAND trans13_Level_STRATEGY_read; \
	COMMAND trans13_Level_STRATEGY_write; \
	VARIABLE trans13_Level_ALERT_KEY; \
	MENU trans13_Level_ALERT_KEY_page; \
	COMMAND trans13_Level_ALERT_KEY_read; \
	COMMAND trans13_Level_ALERT_KEY_write; \
	VARIABLE trans13_Level_TARGET_MODE; \
	MENU trans13_Level_TARGET_MODE_page; \
	COMMAND trans13_Level_TARGET_MODE_read; \
	COMMAND trans13_Level_TARGET_MODE_write; \
	COLLECTION trans13_Level_MODE_BLK; \
	VARIABLE trans13_Level_MODE_BLK_Actual; \
	VARIABLE trans13_Level_MODE_BLK_Permitted; \
	VARIABLE trans13_Level_MODE_BLK_Normal; \
	MENU trans13_Level_MODE_BLK_page; \
	COMMAND trans13_Level_MODE_BLK_read; \
	COLLECTION trans13_Level_ALARM_SUM; \
	VARIABLE trans13_Level_ALARM_SUM_Current; \
	VARIABLE trans13_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Level_ALARM_SUM_Unreported; \
	VARIABLE trans13_Level_ALARM_SUM_Disabled; \
	MENU trans13_Level_ALARM_SUM_page; \
	COMMAND trans13_Level_ALARM_SUM_read

#define USE_TRANS13_LEVEL_MANDATORY_A \
	USE_TRANS13_LEVEL_MANDATORY_BOTH; \
	MENU trans13_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS13_LEVEL_MANDATORY_B \
	USE_TRANS13_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans13_Level_PRIMARY_VALUE; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans13_Level_PRIMARY_VALUE_page; \
	COMMAND trans13_Level_PRIMARY_VALUE_read; \
	VARIABLE trans13_Level_PRIMARY_VALUE_UNIT; \
	MENU trans13_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans13_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans13_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans13_Level_LEVEL; \
	MENU trans13_Level_LEVEL_page; \
	COMMAND trans13_Level_LEVEL_read; \
	VARIABLE trans13_Level_LEVEL_UNIT; \
	MENU trans13_Level_LEVEL_UNIT_page; \
	COMMAND trans13_Level_LEVEL_UNIT_read; \
	COMMAND trans13_Level_LEVEL_UNIT_write; \
	VARIABLE trans13_Level_SENSOR_VALUE; \
	MENU trans13_Level_SENSOR_VALUE_page; \
	COMMAND trans13_Level_SENSOR_VALUE_read; \
	VARIABLE trans13_Level_SENSOR_UNIT; \
	MENU trans13_Level_SENSOR_UNIT_page; \
	COMMAND trans13_Level_SENSOR_UNIT_read; \
	COMMAND trans13_Level_SENSOR_UNIT_write; \
	VARIABLE trans13_Level_SENSOR_OFFSET; \
	MENU trans13_Level_SENSOR_OFFSET_page; \
	COMMAND trans13_Level_SENSOR_OFFSET_read; \
	COMMAND trans13_Level_SENSOR_OFFSET_write; \
	VARIABLE trans13_Level_CAL_TYPE; \
	MENU trans13_Level_CAL_TYPE_page; \
	COMMAND trans13_Level_CAL_TYPE_read; \
	COMMAND trans13_Level_CAL_TYPE_write; \
	VARIABLE trans13_Level_CAL_POINT_LO; \
	MENU trans13_Level_CAL_POINT_LO_page; \
	COMMAND trans13_Level_CAL_POINT_LO_read; \
	COMMAND trans13_Level_CAL_POINT_LO_write; \
	VARIABLE trans13_Level_CAL_POINT_HI; \
	MENU trans13_Level_CAL_POINT_HI_page; \
	COMMAND trans13_Level_CAL_POINT_HI_read; \
	COMMAND trans13_Level_CAL_POINT_HI_write; \
	VARIABLE trans13_Level_LEVEL_LO; \
	MENU trans13_Level_LEVEL_LO_page; \
	COMMAND trans13_Level_LEVEL_LO_read; \
	COMMAND trans13_Level_LEVEL_LO_write; \
	VARIABLE trans13_Level_LEVEL_HI; \
	MENU trans13_Level_LEVEL_HI_page; \
	COMMAND trans13_Level_LEVEL_HI_read; \
	COMMAND trans13_Level_LEVEL_HI_write; \
	VARIABLE trans13_Level_LEVEL_OFFSET; \
	MENU trans13_Level_LEVEL_OFFSET_page; \
	COMMAND trans13_Level_LEVEL_OFFSET_read; \
	COMMAND trans13_Level_LEVEL_OFFSET_write; \
	VARIABLE trans13_Level_LIN_TYPE; \
	MENU trans13_Level_LIN_TYPE_page; \
	COMMAND trans13_Level_LIN_TYPE_read; \
	COMMAND trans13_Level_LIN_TYPE_write; \
	COLLECTION trans13_Level_VIEW_1; \
	MENU trans13_Level_VIEW_1_page; \
	MENU trans13_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans13_Level_unit_level_1; \
	UNIT trans13_Level_unit_primary_value_1; \
	UNIT trans13_Level_unit_sensor_value_1

#define USE_TRANS13_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans13_Level_SECONDARY_VALUE_1; \
	VARIABLE trans13_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans13_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans13_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans13_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans13_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans13_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans13_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans13_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans13_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans13_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans13_Level_SECONDARY_VALUE_2; \
	VARIABLE trans13_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans13_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans13_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans13_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans13_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans13_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans13_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans13_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans13_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans13_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans13_Level_LIN_DIAMETER; \
	MENU trans13_Level_LIN_DIAMETER_page; \
	COMMAND trans13_Level_LIN_DIAMETER_read; \
	COMMAND trans13_Level_LIN_DIAMETER_write; \
	VARIABLE trans13_Level_LIN_VOLUME; \
	MENU trans13_Level_LIN_VOLUME_page; \
	COMMAND trans13_Level_LIN_VOLUME_read; \
	COMMAND trans13_Level_LIN_VOLUME_write; \
	VARIABLE trans13_Level_SENSOR_HIGH_LIMIT; \
	MENU trans13_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans13_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans13_Level_SENSOR_LOW_LIMIT; \
	MENU trans13_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans13_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans13_Level_MAX_SENSOR_VALUE; \
	MENU trans13_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans13_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans13_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans13_Level_MIN_SENSOR_VALUE; \
	MENU trans13_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans13_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans13_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans13_Level_TEMPERATURE; \
	MENU trans13_Level_TEMPERATURE_page; \
	COMMAND trans13_Level_TEMPERATURE_read; \
	VARIABLE trans13_Level_TEMPERATURE_UNIT; \
	MENU trans13_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans13_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans13_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans13_Level_MAX_TEMPERATURE; \
	MENU trans13_Level_MAX_TEMPERATURE_page; \
	COMMAND trans13_Level_MAX_TEMPERATURE_read; \
	COMMAND trans13_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans13_Level_MIN_TEMPERATURE; \
	MENU trans13_Level_MIN_TEMPERATURE_page; \
	COMMAND trans13_Level_MIN_TEMPERATURE_read; \
	COMMAND trans13_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans13_Level_TAB_ENTRY; \
	MENU trans13_Level_TAB_ENTRY_page; \
	COMMAND trans13_Level_TAB_ENTRY_read; \
	COMMAND trans13_Level_TAB_ENTRY_write; \
	COLLECTION trans13_Level_TAB_X_Y_VALUE; \
	VARIABLE trans13_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans13_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans13_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans13_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans13_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans13_Level_TAB_MIN_NUMBER; \
	MENU trans13_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans13_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans13_Level_TAB_MAX_NUMBER; \
	MENU trans13_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans13_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans13_Level_TAB_OP_CODE; \
	MENU trans13_Level_TAB_OP_CODE_page; \
	COMMAND trans13_Level_TAB_OP_CODE_read; \
	COMMAND trans13_Level_TAB_OP_CODE_write; \
	VARIABLE trans13_Level_TAB_STATUS; \
	MENU trans13_Level_TAB_STATUS_page; \
	COMMAND trans13_Level_TAB_STATUS_read; \
	VARIABLE trans13_Level_TAB_ACTUAL_NUMBER; \
	MENU trans13_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans13_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans13_Level_VIEW_2; \
	MENU trans13_Level_VIEW_2_page; \
	COLLECTION trans13_Level_VIEW_3; \
	MENU trans13_Level_VIEW_3_page; \
	UNIT trans13_Level_unit_level_2; \
	UNIT trans13_Level_unit_temperature; \
	UNIT trans13_Level_unit_primary_value_2; \
	UNIT trans13_Level_unit_sensor_value_2; \
	UNIT trans13_Level_unit_secondary_value_1; \
	UNIT trans13_Level_unit_secondary_value_2

#define USE_TRANS13_LEVEL_OPTIONAL_A \
	USE_TRANS13_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans13_Level_PRIMARY_VALUE; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans13_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans13_Level_PRIMARY_VALUE_page; \
	COMMAND trans13_Level_PRIMARY_VALUE_read; \
	VARIABLE trans13_Level_PRIMARY_VALUE_UNIT; \
	MENU trans13_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans13_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans13_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans13_Level_LEVEL; \
	MENU trans13_Level_LEVEL_page; \
	COMMAND trans13_Level_LEVEL_read; \
	VARIABLE trans13_Level_LEVEL_UNIT; \
	MENU trans13_Level_LEVEL_UNIT_page; \
	COMMAND trans13_Level_LEVEL_UNIT_read; \
	COMMAND trans13_Level_LEVEL_UNIT_write; \
	VARIABLE trans13_Level_SENSOR_VALUE; \
	MENU trans13_Level_SENSOR_VALUE_page; \
	COMMAND trans13_Level_SENSOR_VALUE_read; \
	VARIABLE trans13_Level_SENSOR_UNIT; \
	MENU trans13_Level_SENSOR_UNIT_page; \
	COMMAND trans13_Level_SENSOR_UNIT_read; \
	COMMAND trans13_Level_SENSOR_UNIT_write; \
	VARIABLE trans13_Level_SENSOR_OFFSET; \
	MENU trans13_Level_SENSOR_OFFSET_page; \
	COMMAND trans13_Level_SENSOR_OFFSET_read; \
	COMMAND trans13_Level_SENSOR_OFFSET_write; \
	VARIABLE trans13_Level_CAL_TYPE; \
	MENU trans13_Level_CAL_TYPE_page; \
	COMMAND trans13_Level_CAL_TYPE_read; \
	COMMAND trans13_Level_CAL_TYPE_write; \
	VARIABLE trans13_Level_CAL_POINT_LO; \
	MENU trans13_Level_CAL_POINT_LO_page; \
	COMMAND trans13_Level_CAL_POINT_LO_read; \
	COMMAND trans13_Level_CAL_POINT_LO_write; \
	VARIABLE trans13_Level_CAL_POINT_HI; \
	MENU trans13_Level_CAL_POINT_HI_page; \
	COMMAND trans13_Level_CAL_POINT_HI_read; \
	COMMAND trans13_Level_CAL_POINT_HI_write; \
	VARIABLE trans13_Level_LEVEL_LO; \
	MENU trans13_Level_LEVEL_LO_page; \
	COMMAND trans13_Level_LEVEL_LO_read; \
	COMMAND trans13_Level_LEVEL_LO_write; \
	VARIABLE trans13_Level_LEVEL_HI; \
	MENU trans13_Level_LEVEL_HI_page; \
	COMMAND trans13_Level_LEVEL_HI_read; \
	COMMAND trans13_Level_LEVEL_HI_write; \
	VARIABLE trans13_Level_LEVEL_OFFSET; \
	MENU trans13_Level_LEVEL_OFFSET_page; \
	COMMAND trans13_Level_LEVEL_OFFSET_read; \
	COMMAND trans13_Level_LEVEL_OFFSET_write; \
	VARIABLE trans13_Level_LIN_TYPE; \
	MENU trans13_Level_LIN_TYPE_page; \
	COMMAND trans13_Level_LIN_TYPE_read; \
	COMMAND trans13_Level_LIN_TYPE_write; \
	COLLECTION trans13_Level_VIEW_1; \
	MENU trans13_Level_VIEW_1_page; \
	MENU trans13_Level_Simple_Dialog_Optional_A; \
	UNIT trans13_Level_unit_level_1; \
	UNIT trans13_Level_unit_primary_value_1; \
	UNIT trans13_Level_unit_sensor_value_1

#define USE_TRANS13_LEVEL_OPTIONAL_B \
	USE_TRANS13_LEVEL_OPTIONAL_BOTH; \
	MENU trans13_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans13_Level_)
#define USE_TRANS13_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans13_Level_)
#define USE_TRANS13_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans13_Level_)
#define USE_TRANS13_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans13_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_LEVEL_MANDATORY_BOTH \
	BLOCK trans14_Level_block; \
	COLLECTION trans14_Level_BLOCK_OBJECT; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Level_BLOCK_OBJECT_page; \
	COMMAND trans14_Level_BLOCK_OBJECT_read; \
	VARIABLE trans14_Level_ST_REV; \
	MENU trans14_Level_ST_REV_page; \
	COMMAND trans14_Level_ST_REV_read; \
	VARIABLE trans14_Level_TAG_DESC; \
	MENU trans14_Level_TAG_DESC_page; \
	COMMAND trans14_Level_TAG_DESC_read; \
	COMMAND trans14_Level_TAG_DESC_write; \
	VARIABLE trans14_Level_STRATEGY; \
	MENU trans14_Level_STRATEGY_page; \
	COMMAND trans14_Level_STRATEGY_read; \
	COMMAND trans14_Level_STRATEGY_write; \
	VARIABLE trans14_Level_ALERT_KEY; \
	MENU trans14_Level_ALERT_KEY_page; \
	COMMAND trans14_Level_ALERT_KEY_read; \
	COMMAND trans14_Level_ALERT_KEY_write; \
	VARIABLE trans14_Level_TARGET_MODE; \
	MENU trans14_Level_TARGET_MODE_page; \
	COMMAND trans14_Level_TARGET_MODE_read; \
	COMMAND trans14_Level_TARGET_MODE_write; \
	COLLECTION trans14_Level_MODE_BLK; \
	VARIABLE trans14_Level_MODE_BLK_Actual; \
	VARIABLE trans14_Level_MODE_BLK_Permitted; \
	VARIABLE trans14_Level_MODE_BLK_Normal; \
	MENU trans14_Level_MODE_BLK_page; \
	COMMAND trans14_Level_MODE_BLK_read; \
	COLLECTION trans14_Level_ALARM_SUM; \
	VARIABLE trans14_Level_ALARM_SUM_Current; \
	VARIABLE trans14_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Level_ALARM_SUM_Unreported; \
	VARIABLE trans14_Level_ALARM_SUM_Disabled; \
	MENU trans14_Level_ALARM_SUM_page; \
	COMMAND trans14_Level_ALARM_SUM_read

#define USE_TRANS14_LEVEL_MANDATORY_A \
	USE_TRANS14_LEVEL_MANDATORY_BOTH; \
	MENU trans14_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS14_LEVEL_MANDATORY_B \
	USE_TRANS14_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans14_Level_PRIMARY_VALUE; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans14_Level_PRIMARY_VALUE_page; \
	COMMAND trans14_Level_PRIMARY_VALUE_read; \
	VARIABLE trans14_Level_PRIMARY_VALUE_UNIT; \
	MENU trans14_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans14_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans14_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans14_Level_LEVEL; \
	MENU trans14_Level_LEVEL_page; \
	COMMAND trans14_Level_LEVEL_read; \
	VARIABLE trans14_Level_LEVEL_UNIT; \
	MENU trans14_Level_LEVEL_UNIT_page; \
	COMMAND trans14_Level_LEVEL_UNIT_read; \
	COMMAND trans14_Level_LEVEL_UNIT_write; \
	VARIABLE trans14_Level_SENSOR_VALUE; \
	MENU trans14_Level_SENSOR_VALUE_page; \
	COMMAND trans14_Level_SENSOR_VALUE_read; \
	VARIABLE trans14_Level_SENSOR_UNIT; \
	MENU trans14_Level_SENSOR_UNIT_page; \
	COMMAND trans14_Level_SENSOR_UNIT_read; \
	COMMAND trans14_Level_SENSOR_UNIT_write; \
	VARIABLE trans14_Level_SENSOR_OFFSET; \
	MENU trans14_Level_SENSOR_OFFSET_page; \
	COMMAND trans14_Level_SENSOR_OFFSET_read; \
	COMMAND trans14_Level_SENSOR_OFFSET_write; \
	VARIABLE trans14_Level_CAL_TYPE; \
	MENU trans14_Level_CAL_TYPE_page; \
	COMMAND trans14_Level_CAL_TYPE_read; \
	COMMAND trans14_Level_CAL_TYPE_write; \
	VARIABLE trans14_Level_CAL_POINT_LO; \
	MENU trans14_Level_CAL_POINT_LO_page; \
	COMMAND trans14_Level_CAL_POINT_LO_read; \
	COMMAND trans14_Level_CAL_POINT_LO_write; \
	VARIABLE trans14_Level_CAL_POINT_HI; \
	MENU trans14_Level_CAL_POINT_HI_page; \
	COMMAND trans14_Level_CAL_POINT_HI_read; \
	COMMAND trans14_Level_CAL_POINT_HI_write; \
	VARIABLE trans14_Level_LEVEL_LO; \
	MENU trans14_Level_LEVEL_LO_page; \
	COMMAND trans14_Level_LEVEL_LO_read; \
	COMMAND trans14_Level_LEVEL_LO_write; \
	VARIABLE trans14_Level_LEVEL_HI; \
	MENU trans14_Level_LEVEL_HI_page; \
	COMMAND trans14_Level_LEVEL_HI_read; \
	COMMAND trans14_Level_LEVEL_HI_write; \
	VARIABLE trans14_Level_LEVEL_OFFSET; \
	MENU trans14_Level_LEVEL_OFFSET_page; \
	COMMAND trans14_Level_LEVEL_OFFSET_read; \
	COMMAND trans14_Level_LEVEL_OFFSET_write; \
	VARIABLE trans14_Level_LIN_TYPE; \
	MENU trans14_Level_LIN_TYPE_page; \
	COMMAND trans14_Level_LIN_TYPE_read; \
	COMMAND trans14_Level_LIN_TYPE_write; \
	COLLECTION trans14_Level_VIEW_1; \
	MENU trans14_Level_VIEW_1_page; \
	MENU trans14_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans14_Level_unit_level_1; \
	UNIT trans14_Level_unit_primary_value_1; \
	UNIT trans14_Level_unit_sensor_value_1

#define USE_TRANS14_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans14_Level_SECONDARY_VALUE_1; \
	VARIABLE trans14_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans14_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans14_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans14_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans14_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans14_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans14_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans14_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans14_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans14_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans14_Level_SECONDARY_VALUE_2; \
	VARIABLE trans14_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans14_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans14_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans14_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans14_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans14_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans14_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans14_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans14_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans14_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans14_Level_LIN_DIAMETER; \
	MENU trans14_Level_LIN_DIAMETER_page; \
	COMMAND trans14_Level_LIN_DIAMETER_read; \
	COMMAND trans14_Level_LIN_DIAMETER_write; \
	VARIABLE trans14_Level_LIN_VOLUME; \
	MENU trans14_Level_LIN_VOLUME_page; \
	COMMAND trans14_Level_LIN_VOLUME_read; \
	COMMAND trans14_Level_LIN_VOLUME_write; \
	VARIABLE trans14_Level_SENSOR_HIGH_LIMIT; \
	MENU trans14_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans14_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans14_Level_SENSOR_LOW_LIMIT; \
	MENU trans14_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans14_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans14_Level_MAX_SENSOR_VALUE; \
	MENU trans14_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans14_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans14_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans14_Level_MIN_SENSOR_VALUE; \
	MENU trans14_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans14_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans14_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans14_Level_TEMPERATURE; \
	MENU trans14_Level_TEMPERATURE_page; \
	COMMAND trans14_Level_TEMPERATURE_read; \
	VARIABLE trans14_Level_TEMPERATURE_UNIT; \
	MENU trans14_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans14_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans14_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans14_Level_MAX_TEMPERATURE; \
	MENU trans14_Level_MAX_TEMPERATURE_page; \
	COMMAND trans14_Level_MAX_TEMPERATURE_read; \
	COMMAND trans14_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans14_Level_MIN_TEMPERATURE; \
	MENU trans14_Level_MIN_TEMPERATURE_page; \
	COMMAND trans14_Level_MIN_TEMPERATURE_read; \
	COMMAND trans14_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans14_Level_TAB_ENTRY; \
	MENU trans14_Level_TAB_ENTRY_page; \
	COMMAND trans14_Level_TAB_ENTRY_read; \
	COMMAND trans14_Level_TAB_ENTRY_write; \
	COLLECTION trans14_Level_TAB_X_Y_VALUE; \
	VARIABLE trans14_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans14_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans14_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans14_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans14_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans14_Level_TAB_MIN_NUMBER; \
	MENU trans14_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans14_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans14_Level_TAB_MAX_NUMBER; \
	MENU trans14_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans14_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans14_Level_TAB_OP_CODE; \
	MENU trans14_Level_TAB_OP_CODE_page; \
	COMMAND trans14_Level_TAB_OP_CODE_read; \
	COMMAND trans14_Level_TAB_OP_CODE_write; \
	VARIABLE trans14_Level_TAB_STATUS; \
	MENU trans14_Level_TAB_STATUS_page; \
	COMMAND trans14_Level_TAB_STATUS_read; \
	VARIABLE trans14_Level_TAB_ACTUAL_NUMBER; \
	MENU trans14_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans14_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans14_Level_VIEW_2; \
	MENU trans14_Level_VIEW_2_page; \
	COLLECTION trans14_Level_VIEW_3; \
	MENU trans14_Level_VIEW_3_page; \
	UNIT trans14_Level_unit_level_2; \
	UNIT trans14_Level_unit_temperature; \
	UNIT trans14_Level_unit_primary_value_2; \
	UNIT trans14_Level_unit_sensor_value_2; \
	UNIT trans14_Level_unit_secondary_value_1; \
	UNIT trans14_Level_unit_secondary_value_2

#define USE_TRANS14_LEVEL_OPTIONAL_A \
	USE_TRANS14_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans14_Level_PRIMARY_VALUE; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans14_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans14_Level_PRIMARY_VALUE_page; \
	COMMAND trans14_Level_PRIMARY_VALUE_read; \
	VARIABLE trans14_Level_PRIMARY_VALUE_UNIT; \
	MENU trans14_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans14_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans14_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans14_Level_LEVEL; \
	MENU trans14_Level_LEVEL_page; \
	COMMAND trans14_Level_LEVEL_read; \
	VARIABLE trans14_Level_LEVEL_UNIT; \
	MENU trans14_Level_LEVEL_UNIT_page; \
	COMMAND trans14_Level_LEVEL_UNIT_read; \
	COMMAND trans14_Level_LEVEL_UNIT_write; \
	VARIABLE trans14_Level_SENSOR_VALUE; \
	MENU trans14_Level_SENSOR_VALUE_page; \
	COMMAND trans14_Level_SENSOR_VALUE_read; \
	VARIABLE trans14_Level_SENSOR_UNIT; \
	MENU trans14_Level_SENSOR_UNIT_page; \
	COMMAND trans14_Level_SENSOR_UNIT_read; \
	COMMAND trans14_Level_SENSOR_UNIT_write; \
	VARIABLE trans14_Level_SENSOR_OFFSET; \
	MENU trans14_Level_SENSOR_OFFSET_page; \
	COMMAND trans14_Level_SENSOR_OFFSET_read; \
	COMMAND trans14_Level_SENSOR_OFFSET_write; \
	VARIABLE trans14_Level_CAL_TYPE; \
	MENU trans14_Level_CAL_TYPE_page; \
	COMMAND trans14_Level_CAL_TYPE_read; \
	COMMAND trans14_Level_CAL_TYPE_write; \
	VARIABLE trans14_Level_CAL_POINT_LO; \
	MENU trans14_Level_CAL_POINT_LO_page; \
	COMMAND trans14_Level_CAL_POINT_LO_read; \
	COMMAND trans14_Level_CAL_POINT_LO_write; \
	VARIABLE trans14_Level_CAL_POINT_HI; \
	MENU trans14_Level_CAL_POINT_HI_page; \
	COMMAND trans14_Level_CAL_POINT_HI_read; \
	COMMAND trans14_Level_CAL_POINT_HI_write; \
	VARIABLE trans14_Level_LEVEL_LO; \
	MENU trans14_Level_LEVEL_LO_page; \
	COMMAND trans14_Level_LEVEL_LO_read; \
	COMMAND trans14_Level_LEVEL_LO_write; \
	VARIABLE trans14_Level_LEVEL_HI; \
	MENU trans14_Level_LEVEL_HI_page; \
	COMMAND trans14_Level_LEVEL_HI_read; \
	COMMAND trans14_Level_LEVEL_HI_write; \
	VARIABLE trans14_Level_LEVEL_OFFSET; \
	MENU trans14_Level_LEVEL_OFFSET_page; \
	COMMAND trans14_Level_LEVEL_OFFSET_read; \
	COMMAND trans14_Level_LEVEL_OFFSET_write; \
	VARIABLE trans14_Level_LIN_TYPE; \
	MENU trans14_Level_LIN_TYPE_page; \
	COMMAND trans14_Level_LIN_TYPE_read; \
	COMMAND trans14_Level_LIN_TYPE_write; \
	COLLECTION trans14_Level_VIEW_1; \
	MENU trans14_Level_VIEW_1_page; \
	MENU trans14_Level_Simple_Dialog_Optional_A; \
	UNIT trans14_Level_unit_level_1; \
	UNIT trans14_Level_unit_primary_value_1; \
	UNIT trans14_Level_unit_sensor_value_1

#define USE_TRANS14_LEVEL_OPTIONAL_B \
	USE_TRANS14_LEVEL_OPTIONAL_BOTH; \
	MENU trans14_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans14_Level_)
#define USE_TRANS14_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans14_Level_)
#define USE_TRANS14_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans14_Level_)
#define USE_TRANS14_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans14_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_LEVEL_MANDATORY_BOTH \
	BLOCK trans15_Level_block; \
	COLLECTION trans15_Level_BLOCK_OBJECT; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Level_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Level_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Level_BLOCK_OBJECT_page; \
	COMMAND trans15_Level_BLOCK_OBJECT_read; \
	VARIABLE trans15_Level_ST_REV; \
	MENU trans15_Level_ST_REV_page; \
	COMMAND trans15_Level_ST_REV_read; \
	VARIABLE trans15_Level_TAG_DESC; \
	MENU trans15_Level_TAG_DESC_page; \
	COMMAND trans15_Level_TAG_DESC_read; \
	COMMAND trans15_Level_TAG_DESC_write; \
	VARIABLE trans15_Level_STRATEGY; \
	MENU trans15_Level_STRATEGY_page; \
	COMMAND trans15_Level_STRATEGY_read; \
	COMMAND trans15_Level_STRATEGY_write; \
	VARIABLE trans15_Level_ALERT_KEY; \
	MENU trans15_Level_ALERT_KEY_page; \
	COMMAND trans15_Level_ALERT_KEY_read; \
	COMMAND trans15_Level_ALERT_KEY_write; \
	VARIABLE trans15_Level_TARGET_MODE; \
	MENU trans15_Level_TARGET_MODE_page; \
	COMMAND trans15_Level_TARGET_MODE_read; \
	COMMAND trans15_Level_TARGET_MODE_write; \
	COLLECTION trans15_Level_MODE_BLK; \
	VARIABLE trans15_Level_MODE_BLK_Actual; \
	VARIABLE trans15_Level_MODE_BLK_Permitted; \
	VARIABLE trans15_Level_MODE_BLK_Normal; \
	MENU trans15_Level_MODE_BLK_page; \
	COMMAND trans15_Level_MODE_BLK_read; \
	COLLECTION trans15_Level_ALARM_SUM; \
	VARIABLE trans15_Level_ALARM_SUM_Current; \
	VARIABLE trans15_Level_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Level_ALARM_SUM_Unreported; \
	VARIABLE trans15_Level_ALARM_SUM_Disabled; \
	MENU trans15_Level_ALARM_SUM_page; \
	COMMAND trans15_Level_ALARM_SUM_read

#define USE_TRANS15_LEVEL_MANDATORY_A \
	USE_TRANS15_LEVEL_MANDATORY_BOTH; \
	MENU trans15_Level_Simple_Dialog_Mandatory_A

#define USE_TRANS15_LEVEL_MANDATORY_B \
	USE_TRANS15_LEVEL_MANDATORY_BOTH; \
	COLLECTION trans15_Level_PRIMARY_VALUE; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans15_Level_PRIMARY_VALUE_page; \
	COMMAND trans15_Level_PRIMARY_VALUE_read; \
	VARIABLE trans15_Level_PRIMARY_VALUE_UNIT; \
	MENU trans15_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans15_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans15_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans15_Level_LEVEL; \
	MENU trans15_Level_LEVEL_page; \
	COMMAND trans15_Level_LEVEL_read; \
	VARIABLE trans15_Level_LEVEL_UNIT; \
	MENU trans15_Level_LEVEL_UNIT_page; \
	COMMAND trans15_Level_LEVEL_UNIT_read; \
	COMMAND trans15_Level_LEVEL_UNIT_write; \
	VARIABLE trans15_Level_SENSOR_VALUE; \
	MENU trans15_Level_SENSOR_VALUE_page; \
	COMMAND trans15_Level_SENSOR_VALUE_read; \
	VARIABLE trans15_Level_SENSOR_UNIT; \
	MENU trans15_Level_SENSOR_UNIT_page; \
	COMMAND trans15_Level_SENSOR_UNIT_read; \
	COMMAND trans15_Level_SENSOR_UNIT_write; \
	VARIABLE trans15_Level_SENSOR_OFFSET; \
	MENU trans15_Level_SENSOR_OFFSET_page; \
	COMMAND trans15_Level_SENSOR_OFFSET_read; \
	COMMAND trans15_Level_SENSOR_OFFSET_write; \
	VARIABLE trans15_Level_CAL_TYPE; \
	MENU trans15_Level_CAL_TYPE_page; \
	COMMAND trans15_Level_CAL_TYPE_read; \
	COMMAND trans15_Level_CAL_TYPE_write; \
	VARIABLE trans15_Level_CAL_POINT_LO; \
	MENU trans15_Level_CAL_POINT_LO_page; \
	COMMAND trans15_Level_CAL_POINT_LO_read; \
	COMMAND trans15_Level_CAL_POINT_LO_write; \
	VARIABLE trans15_Level_CAL_POINT_HI; \
	MENU trans15_Level_CAL_POINT_HI_page; \
	COMMAND trans15_Level_CAL_POINT_HI_read; \
	COMMAND trans15_Level_CAL_POINT_HI_write; \
	VARIABLE trans15_Level_LEVEL_LO; \
	MENU trans15_Level_LEVEL_LO_page; \
	COMMAND trans15_Level_LEVEL_LO_read; \
	COMMAND trans15_Level_LEVEL_LO_write; \
	VARIABLE trans15_Level_LEVEL_HI; \
	MENU trans15_Level_LEVEL_HI_page; \
	COMMAND trans15_Level_LEVEL_HI_read; \
	COMMAND trans15_Level_LEVEL_HI_write; \
	VARIABLE trans15_Level_LEVEL_OFFSET; \
	MENU trans15_Level_LEVEL_OFFSET_page; \
	COMMAND trans15_Level_LEVEL_OFFSET_read; \
	COMMAND trans15_Level_LEVEL_OFFSET_write; \
	VARIABLE trans15_Level_LIN_TYPE; \
	MENU trans15_Level_LIN_TYPE_page; \
	COMMAND trans15_Level_LIN_TYPE_read; \
	COMMAND trans15_Level_LIN_TYPE_write; \
	COLLECTION trans15_Level_VIEW_1; \
	MENU trans15_Level_VIEW_1_page; \
	MENU trans15_Level_Simple_Dialog_Mandatory_B; \
	UNIT trans15_Level_unit_level_1; \
	UNIT trans15_Level_unit_primary_value_1; \
	UNIT trans15_Level_unit_sensor_value_1

#define USE_TRANS15_LEVEL_OPTIONAL_BOTH \
	COLLECTION trans15_Level_SECONDARY_VALUE_1; \
	VARIABLE trans15_Level_SECONDARY_VALUE_1_Value; \
	VARIABLE trans15_Level_SECONDARY_VALUE_1_Status_Condensed; \
	VARIABLE trans15_Level_SECONDARY_VALUE_1_Status_Quality; \
	VARIABLE trans15_Level_SECONDARY_VALUE_1_Status_Limit; \
	MENU trans15_Level_SECONDARY_VALUE_1_page; \
	COMMAND trans15_Level_SECONDARY_VALUE_1_read; \
	VARIABLE trans15_Level_SECONDARY_VALUE_1_UNIT; \
	MENU trans15_Level_SECONDARY_VALUE_1_UNIT_page; \
	COMMAND trans15_Level_SECONDARY_VALUE_1_UNIT_read; \
	COMMAND trans15_Level_SECONDARY_VALUE_1_UNIT_write; \
	COLLECTION trans15_Level_SECONDARY_VALUE_2; \
	VARIABLE trans15_Level_SECONDARY_VALUE_2_Value; \
	VARIABLE trans15_Level_SECONDARY_VALUE_2_Status_Condensed; \
	VARIABLE trans15_Level_SECONDARY_VALUE_2_Status_Quality; \
	VARIABLE trans15_Level_SECONDARY_VALUE_2_Status_Limit; \
	MENU trans15_Level_SECONDARY_VALUE_2_page; \
	COMMAND trans15_Level_SECONDARY_VALUE_2_read; \
	VARIABLE trans15_Level_SECONDARY_VALUE_2_UNIT; \
	MENU trans15_Level_SECONDARY_VALUE_2_UNIT_page; \
	COMMAND trans15_Level_SECONDARY_VALUE_2_UNIT_read; \
	COMMAND trans15_Level_SECONDARY_VALUE_2_UNIT_write; \
	VARIABLE trans15_Level_LIN_DIAMETER; \
	MENU trans15_Level_LIN_DIAMETER_page; \
	COMMAND trans15_Level_LIN_DIAMETER_read; \
	COMMAND trans15_Level_LIN_DIAMETER_write; \
	VARIABLE trans15_Level_LIN_VOLUME; \
	MENU trans15_Level_LIN_VOLUME_page; \
	COMMAND trans15_Level_LIN_VOLUME_read; \
	COMMAND trans15_Level_LIN_VOLUME_write; \
	VARIABLE trans15_Level_SENSOR_HIGH_LIMIT; \
	MENU trans15_Level_SENSOR_HIGH_LIMIT_page; \
	COMMAND trans15_Level_SENSOR_HIGH_LIMIT_read; \
	VARIABLE trans15_Level_SENSOR_LOW_LIMIT; \
	MENU trans15_Level_SENSOR_LOW_LIMIT_page; \
	COMMAND trans15_Level_SENSOR_LOW_LIMIT_read; \
	VARIABLE trans15_Level_MAX_SENSOR_VALUE; \
	MENU trans15_Level_MAX_SENSOR_VALUE_page; \
	COMMAND trans15_Level_MAX_SENSOR_VALUE_read; \
	COMMAND trans15_Level_MAX_SENSOR_VALUE_write; \
	VARIABLE trans15_Level_MIN_SENSOR_VALUE; \
	MENU trans15_Level_MIN_SENSOR_VALUE_page; \
	COMMAND trans15_Level_MIN_SENSOR_VALUE_read; \
	COMMAND trans15_Level_MIN_SENSOR_VALUE_write; \
	VARIABLE trans15_Level_TEMPERATURE; \
	MENU trans15_Level_TEMPERATURE_page; \
	COMMAND trans15_Level_TEMPERATURE_read; \
	VARIABLE trans15_Level_TEMPERATURE_UNIT; \
	MENU trans15_Level_TEMPERATURE_UNIT_page; \
	COMMAND trans15_Level_TEMPERATURE_UNIT_read; \
	COMMAND trans15_Level_TEMPERATURE_UNIT_write; \
	VARIABLE trans15_Level_MAX_TEMPERATURE; \
	MENU trans15_Level_MAX_TEMPERATURE_page; \
	COMMAND trans15_Level_MAX_TEMPERATURE_read; \
	COMMAND trans15_Level_MAX_TEMPERATURE_write; \
	VARIABLE trans15_Level_MIN_TEMPERATURE; \
	MENU trans15_Level_MIN_TEMPERATURE_page; \
	COMMAND trans15_Level_MIN_TEMPERATURE_read; \
	COMMAND trans15_Level_MIN_TEMPERATURE_write; \
	VARIABLE trans15_Level_TAB_ENTRY; \
	MENU trans15_Level_TAB_ENTRY_page; \
	COMMAND trans15_Level_TAB_ENTRY_read; \
	COMMAND trans15_Level_TAB_ENTRY_write; \
	COLLECTION trans15_Level_TAB_X_Y_VALUE; \
	VARIABLE trans15_Level_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans15_Level_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans15_Level_TAB_X_Y_VALUE_page; \
	COMMAND trans15_Level_TAB_X_Y_VALUE_read; \
	COMMAND trans15_Level_TAB_X_Y_VALUE_write; \
	VARIABLE trans15_Level_TAB_MIN_NUMBER; \
	MENU trans15_Level_TAB_MIN_NUMBER_page; \
	COMMAND trans15_Level_TAB_MIN_NUMBER_read; \
	VARIABLE trans15_Level_TAB_MAX_NUMBER; \
	MENU trans15_Level_TAB_MAX_NUMBER_page; \
	COMMAND trans15_Level_TAB_MAX_NUMBER_read; \
	VARIABLE trans15_Level_TAB_OP_CODE; \
	MENU trans15_Level_TAB_OP_CODE_page; \
	COMMAND trans15_Level_TAB_OP_CODE_read; \
	COMMAND trans15_Level_TAB_OP_CODE_write; \
	VARIABLE trans15_Level_TAB_STATUS; \
	MENU trans15_Level_TAB_STATUS_page; \
	COMMAND trans15_Level_TAB_STATUS_read; \
	VARIABLE trans15_Level_TAB_ACTUAL_NUMBER; \
	MENU trans15_Level_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans15_Level_TAB_ACTUAL_NUMBER_read; \
	COLLECTION trans15_Level_VIEW_2; \
	MENU trans15_Level_VIEW_2_page; \
	COLLECTION trans15_Level_VIEW_3; \
	MENU trans15_Level_VIEW_3_page; \
	UNIT trans15_Level_unit_level_2; \
	UNIT trans15_Level_unit_temperature; \
	UNIT trans15_Level_unit_primary_value_2; \
	UNIT trans15_Level_unit_sensor_value_2; \
	UNIT trans15_Level_unit_secondary_value_1; \
	UNIT trans15_Level_unit_secondary_value_2

#define USE_TRANS15_LEVEL_OPTIONAL_A \
	USE_TRANS15_LEVEL_OPTIONAL_BOTH; \
	COLLECTION trans15_Level_PRIMARY_VALUE; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Value; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Status_Condensed; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Status_Quality; \
	VARIABLE trans15_Level_PRIMARY_VALUE_Status_Limit; \
	MENU trans15_Level_PRIMARY_VALUE_page; \
	COMMAND trans15_Level_PRIMARY_VALUE_read; \
	VARIABLE trans15_Level_PRIMARY_VALUE_UNIT; \
	MENU trans15_Level_PRIMARY_VALUE_UNIT_page; \
	COMMAND trans15_Level_PRIMARY_VALUE_UNIT_read; \
	COMMAND trans15_Level_PRIMARY_VALUE_UNIT_write; \
	VARIABLE trans15_Level_LEVEL; \
	MENU trans15_Level_LEVEL_page; \
	COMMAND trans15_Level_LEVEL_read; \
	VARIABLE trans15_Level_LEVEL_UNIT; \
	MENU trans15_Level_LEVEL_UNIT_page; \
	COMMAND trans15_Level_LEVEL_UNIT_read; \
	COMMAND trans15_Level_LEVEL_UNIT_write; \
	VARIABLE trans15_Level_SENSOR_VALUE; \
	MENU trans15_Level_SENSOR_VALUE_page; \
	COMMAND trans15_Level_SENSOR_VALUE_read; \
	VARIABLE trans15_Level_SENSOR_UNIT; \
	MENU trans15_Level_SENSOR_UNIT_page; \
	COMMAND trans15_Level_SENSOR_UNIT_read; \
	COMMAND trans15_Level_SENSOR_UNIT_write; \
	VARIABLE trans15_Level_SENSOR_OFFSET; \
	MENU trans15_Level_SENSOR_OFFSET_page; \
	COMMAND trans15_Level_SENSOR_OFFSET_read; \
	COMMAND trans15_Level_SENSOR_OFFSET_write; \
	VARIABLE trans15_Level_CAL_TYPE; \
	MENU trans15_Level_CAL_TYPE_page; \
	COMMAND trans15_Level_CAL_TYPE_read; \
	COMMAND trans15_Level_CAL_TYPE_write; \
	VARIABLE trans15_Level_CAL_POINT_LO; \
	MENU trans15_Level_CAL_POINT_LO_page; \
	COMMAND trans15_Level_CAL_POINT_LO_read; \
	COMMAND trans15_Level_CAL_POINT_LO_write; \
	VARIABLE trans15_Level_CAL_POINT_HI; \
	MENU trans15_Level_CAL_POINT_HI_page; \
	COMMAND trans15_Level_CAL_POINT_HI_read; \
	COMMAND trans15_Level_CAL_POINT_HI_write; \
	VARIABLE trans15_Level_LEVEL_LO; \
	MENU trans15_Level_LEVEL_LO_page; \
	COMMAND trans15_Level_LEVEL_LO_read; \
	COMMAND trans15_Level_LEVEL_LO_write; \
	VARIABLE trans15_Level_LEVEL_HI; \
	MENU trans15_Level_LEVEL_HI_page; \
	COMMAND trans15_Level_LEVEL_HI_read; \
	COMMAND trans15_Level_LEVEL_HI_write; \
	VARIABLE trans15_Level_LEVEL_OFFSET; \
	MENU trans15_Level_LEVEL_OFFSET_page; \
	COMMAND trans15_Level_LEVEL_OFFSET_read; \
	COMMAND trans15_Level_LEVEL_OFFSET_write; \
	VARIABLE trans15_Level_LIN_TYPE; \
	MENU trans15_Level_LIN_TYPE_page; \
	COMMAND trans15_Level_LIN_TYPE_read; \
	COMMAND trans15_Level_LIN_TYPE_write; \
	COLLECTION trans15_Level_VIEW_1; \
	MENU trans15_Level_VIEW_1_page; \
	MENU trans15_Level_Simple_Dialog_Optional_A; \
	UNIT trans15_Level_unit_level_1; \
	UNIT trans15_Level_unit_primary_value_1; \
	UNIT trans15_Level_unit_sensor_value_1

#define USE_TRANS15_LEVEL_OPTIONAL_B \
	USE_TRANS15_LEVEL_OPTIONAL_BOTH; \
	MENU trans15_Level_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_LEVEL_MANDATORY_A USE_TRANS_LEVEL_MANDATORY_A(trans15_Level_)
#define USE_TRANS15_LEVEL_MANDATORY_B USE_TRANS_LEVEL_MANDATORY_B(trans15_Level_)
#define USE_TRANS15_LEVEL_OPTIONAL_A  USE_TRANS_LEVEL_OPTIONAL_A(trans15_Level_)
#define USE_TRANS15_LEVEL_OPTIONAL_B  USE_TRANS_LEVEL_OPTIONAL_B(trans15_Level_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans1_Actuator_block; \
	COLLECTION trans1_Actuator_BLOCK_OBJECT; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans1_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans1_Actuator_ST_REV; \
	MENU trans1_Actuator_ST_REV_page; \
	COMMAND trans1_Actuator_ST_REV_read; \
	VARIABLE trans1_Actuator_TAG_DESC; \
	MENU trans1_Actuator_TAG_DESC_page; \
	COMMAND trans1_Actuator_TAG_DESC_read; \
	COMMAND trans1_Actuator_TAG_DESC_write; \
	VARIABLE trans1_Actuator_STRATEGY; \
	MENU trans1_Actuator_STRATEGY_page; \
	COMMAND trans1_Actuator_STRATEGY_read; \
	COMMAND trans1_Actuator_STRATEGY_write; \
	VARIABLE trans1_Actuator_ALERT_KEY; \
	MENU trans1_Actuator_ALERT_KEY_page; \
	COMMAND trans1_Actuator_ALERT_KEY_read; \
	COMMAND trans1_Actuator_ALERT_KEY_write; \
	VARIABLE trans1_Actuator_TARGET_MODE; \
	MENU trans1_Actuator_TARGET_MODE_page; \
	COMMAND trans1_Actuator_TARGET_MODE_read; \
	COMMAND trans1_Actuator_TARGET_MODE_write; \
	COLLECTION trans1_Actuator_MODE_BLK; \
	VARIABLE trans1_Actuator_MODE_BLK_Actual; \
	VARIABLE trans1_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans1_Actuator_MODE_BLK_Normal; \
	MENU trans1_Actuator_MODE_BLK_page; \
	COMMAND trans1_Actuator_MODE_BLK_read; \
	COLLECTION trans1_Actuator_ALARM_SUM; \
	VARIABLE trans1_Actuator_ALARM_SUM_Current; \
	VARIABLE trans1_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans1_Actuator_ALARM_SUM_Disabled; \
	MENU trans1_Actuator_ALARM_SUM_page; \
	COMMAND trans1_Actuator_ALARM_SUM_read

#define USE_TRANS1_ACTUATOR_MANDATORY_A \
	USE_TRANS1_ACTUATOR_MANDATORY_BOTH; \
	MENU trans1_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS1_ACTUATOR_MANDATORY_B \
	USE_TRANS1_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans1_Actuator_LIN_TYPE; \
	MENU trans1_Actuator_LIN_TYPE_page; \
	COMMAND trans1_Actuator_LIN_TYPE_read; \
	COMMAND trans1_Actuator_LIN_TYPE_write; \
	VARIABLE trans1_Actuator_RATED_TRAVEL; \
	MENU trans1_Actuator_RATED_TRAVEL_page; \
	COMMAND trans1_Actuator_RATED_TRAVEL_read; \
	COMMAND trans1_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans1_Actuator_SELF_CALIB_CMD; \
	MENU trans1_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans1_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans1_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans1_Actuator_SELF_CALIB_STATUS; \
	MENU trans1_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans1_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans1_Actuator_SETP_CUTOFF_DEC; \
	MENU trans1_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans1_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans1_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans1_Actuator_SETP_CUTOFF_INC; \
	MENU trans1_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans1_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans1_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans1_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans1_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans1_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans1_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans1_Actuator_TRAVEL_RATE_DEC; \
	MENU trans1_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans1_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans1_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans1_Actuator_TRAVEL_RATE_INC; \
	MENU trans1_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans1_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans1_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans1_Actuator_POSITIONING_VALUE; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans1_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans1_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans1_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans1_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans1_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans1_Actuator_VALVE_MAN; \
	MENU trans1_Actuator_VALVE_MAN_page; \
	COMMAND trans1_Actuator_VALVE_MAN_read; \
	COMMAND trans1_Actuator_VALVE_MAN_write; \
	VARIABLE trans1_Actuator_VALVE_TYPE; \
	MENU trans1_Actuator_VALVE_TYPE_page; \
	COMMAND trans1_Actuator_VALVE_TYPE_read; \
	COMMAND trans1_Actuator_VALVE_TYPE_write; \
	VARIABLE trans1_Actuator_ACTUATOR_TYPE; \
	MENU trans1_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans1_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans1_Actuator_ACTUATOR_ACTION; \
	MENU trans1_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans1_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans1_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans1_Actuator_VIEW_1; \
	MENU trans1_Actuator_VIEW_1_page; \
	MENU trans1_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS1_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans1_Actuator_ACT_ROT_DIR; \
	MENU trans1_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans1_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans1_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans1_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans1_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans1_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans1_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans1_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans1_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans1_Actuator_ACT_TRAV_TIME; \
	MENU trans1_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans1_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans1_Actuator_ANTI_PUMP_CL; \
	MENU trans1_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans1_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans1_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans1_Actuator_ANTI_PUMP_OP; \
	MENU trans1_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans1_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans1_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans1_Actuator_BREAK_STRENGTH; \
	MENU trans1_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans1_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans1_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans1_Actuator_BYPASS_SETP_CL; \
	MENU trans1_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans1_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans1_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans1_Actuator_BYPASS_SETP_OP; \
	MENU trans1_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans1_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans1_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans1_Actuator_TAB_ENTRY; \
	MENU trans1_Actuator_TAB_ENTRY_page; \
	COMMAND trans1_Actuator_TAB_ENTRY_read; \
	COMMAND trans1_Actuator_TAB_ENTRY_write; \
	COLLECTION trans1_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans1_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans1_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans1_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans1_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans1_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans1_Actuator_TAB_MIN_NUMBER; \
	MENU trans1_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans1_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans1_Actuator_TAB_MAX_NUMBER; \
	MENU trans1_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans1_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans1_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans1_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans1_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans1_Actuator_DEADBAND; \
	MENU trans1_Actuator_DEADBAND_page; \
	COMMAND trans1_Actuator_DEADBAND_read; \
	COMMAND trans1_Actuator_DEADBAND_write; \
	VARIABLE trans1_Actuator_DEVICE_CALIB_DATE; \
	MENU trans1_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans1_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans1_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans1_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans1_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans1_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans1_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans1_Actuator_MAX_TORQUE; \
	MENU trans1_Actuator_MAX_TORQUE_page; \
	COMMAND trans1_Actuator_MAX_TORQUE_read; \
	COMMAND trans1_Actuator_MAX_TORQUE_write; \
	VARIABLE trans1_Actuator_MOTOR_ON_TIME; \
	MENU trans1_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans1_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans1_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans1_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans1_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans1_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans1_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans1_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans1_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans1_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans1_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans1_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans1_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans1_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans1_Actuator_SERVO_GAIN_1; \
	MENU trans1_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans1_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans1_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans1_Actuator_SERVO_RATE_1; \
	MENU trans1_Actuator_SERVO_RATE_1_page; \
	COMMAND trans1_Actuator_SERVO_RATE_1_read; \
	COMMAND trans1_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans1_Actuator_SERVO_RESET_1; \
	MENU trans1_Actuator_SERVO_RESET_1_page; \
	COMMAND trans1_Actuator_SERVO_RESET_1_read; \
	COMMAND trans1_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans1_Actuator_SETP_CUTOFF_MODE; \
	MENU trans1_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans1_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans1_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans1_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans1_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans1_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans1_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans1_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans1_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans1_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans1_Actuator_TORQUE_LIM_CL; \
	MENU trans1_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans1_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans1_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans1_Actuator_TORQUE_LIM_OP; \
	MENU trans1_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans1_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans1_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans1_Actuator_TORQUE_UNIT; \
	MENU trans1_Actuator_TORQUE_UNIT_page; \
	COMMAND trans1_Actuator_TORQUE_UNIT_read; \
	COMMAND trans1_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans1_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans1_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans1_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans1_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans1_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans1_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans1_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans1_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans1_Actuator_VALVE_MAINT_DATE; \
	MENU trans1_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans1_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans1_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans1_Actuator_TAB_OP_CODE; \
	MENU trans1_Actuator_TAB_OP_CODE_page; \
	COMMAND trans1_Actuator_TAB_OP_CODE_read; \
	COMMAND trans1_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans1_Actuator_TAB_STATUS; \
	MENU trans1_Actuator_TAB_STATUS_page; \
	COMMAND trans1_Actuator_TAB_STATUS_read; \
	VARIABLE trans1_Actuator_ACTUATOR_MAN; \
	MENU trans1_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans1_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans1_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans1_Actuator_VALVE_SER_NUM; \
	MENU trans1_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans1_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans1_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans1_Actuator_ACTUATOR_SER_NUM; \
	MENU trans1_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans1_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans1_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans1_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans1_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans1_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans1_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans1_Actuator_ADD_GEAR_MAN; \
	MENU trans1_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans1_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans1_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans1_Actuator_ADD_GEAR_ID; \
	MENU trans1_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans1_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans1_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans1_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans1_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans1_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans1_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans1_Actuator_VIEW_2; \
	MENU trans1_Actuator_VIEW_2_page; \
	COLLECTION trans1_Actuator_VIEW_3; \
	MENU trans1_Actuator_VIEW_3_page; \
	COLLECTION trans1_Actuator_VIEW_4; \
	MENU trans1_Actuator_VIEW_4_page

#define USE_TRANS1_ACTUATOR_OPTIONAL_A \
	USE_TRANS1_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans1_Actuator_LIN_TYPE; \
	MENU trans1_Actuator_LIN_TYPE_page; \
	COMMAND trans1_Actuator_LIN_TYPE_read; \
	COMMAND trans1_Actuator_LIN_TYPE_write; \
	VARIABLE trans1_Actuator_RATED_TRAVEL; \
	MENU trans1_Actuator_RATED_TRAVEL_page; \
	COMMAND trans1_Actuator_RATED_TRAVEL_read; \
	COMMAND trans1_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans1_Actuator_SELF_CALIB_CMD; \
	MENU trans1_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans1_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans1_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans1_Actuator_SELF_CALIB_STATUS; \
	MENU trans1_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans1_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans1_Actuator_SETP_CUTOFF_DEC; \
	MENU trans1_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans1_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans1_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans1_Actuator_SETP_CUTOFF_INC; \
	MENU trans1_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans1_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans1_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans1_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans1_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans1_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans1_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans1_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans1_Actuator_TRAVEL_RATE_DEC; \
	MENU trans1_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans1_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans1_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans1_Actuator_TRAVEL_RATE_INC; \
	MENU trans1_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans1_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans1_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans1_Actuator_POSITIONING_VALUE; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans1_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans1_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans1_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans1_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans1_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans1_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans1_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans1_Actuator_VALVE_MAN; \
	MENU trans1_Actuator_VALVE_MAN_page; \
	COMMAND trans1_Actuator_VALVE_MAN_read; \
	COMMAND trans1_Actuator_VALVE_MAN_write; \
	VARIABLE trans1_Actuator_VALVE_TYPE; \
	MENU trans1_Actuator_VALVE_TYPE_page; \
	COMMAND trans1_Actuator_VALVE_TYPE_read; \
	COMMAND trans1_Actuator_VALVE_TYPE_write; \
	VARIABLE trans1_Actuator_ACTUATOR_TYPE; \
	MENU trans1_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans1_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans1_Actuator_ACTUATOR_ACTION; \
	MENU trans1_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans1_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans1_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans1_Actuator_VIEW_1; \
	MENU trans1_Actuator_VIEW_1_page; \
	MENU trans1_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS1_ACTUATOR_OPTIONAL_B \
	USE_TRANS1_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans1_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_ACTUATOR_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read

#define USE_TRANS_ACTUATOR_MANDATORY_A(prefix) \
	USE_TRANS_ACTUATOR_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_ACTUATOR_MANDATORY_B(prefix) \
	USE_TRANS_ACTUATOR_MANDATORY_BOTH(prefix); \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## RATED_TRAVEL; \
	MENU prefix ## RATED_TRAVEL_page; \
	COMMAND prefix ## RATED_TRAVEL_read; \
	COMMAND prefix ## RATED_TRAVEL_write; \
	VARIABLE prefix ## SELF_CALIB_CMD; \
	MENU prefix ## SELF_CALIB_CMD_page; \
	COMMAND prefix ## SELF_CALIB_CMD_read; \
	COMMAND prefix ## SELF_CALIB_CMD_write; \
	VARIABLE prefix ## SELF_CALIB_STATUS; \
	MENU prefix ## SELF_CALIB_STATUS_page; \
	COMMAND prefix ## SELF_CALIB_STATUS_read; \
	VARIABLE prefix ## SETP_CUTOFF_DEC; \
	MENU prefix ## SETP_CUTOFF_DEC_page; \
	COMMAND prefix ## SETP_CUTOFF_DEC_read; \
	COMMAND prefix ## SETP_CUTOFF_DEC_write; \
	VARIABLE prefix ## SETP_CUTOFF_INC; \
	MENU prefix ## SETP_CUTOFF_INC_page; \
	COMMAND prefix ## SETP_CUTOFF_INC_read; \
	COMMAND prefix ## SETP_CUTOFF_INC_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_LOW; \
	MENU prefix ## TRAVEL_LIMIT_LOW_page; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_read; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_UP; \
	MENU prefix ## TRAVEL_LIMIT_UP_page; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_read; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_write; \
	VARIABLE prefix ## TRAVEL_RATE_DEC; \
	MENU prefix ## TRAVEL_RATE_DEC_page; \
	COMMAND prefix ## TRAVEL_RATE_DEC_read; \
	COMMAND prefix ## TRAVEL_RATE_DEC_write; \
	VARIABLE prefix ## TRAVEL_RATE_INC; \
	MENU prefix ## TRAVEL_RATE_INC_page; \
	COMMAND prefix ## TRAVEL_RATE_INC_read; \
	COMMAND prefix ## TRAVEL_RATE_INC_write; \
	COLLECTION prefix ## POSITIONING_VALUE; \
	VARIABLE prefix ## POSITIONING_VALUE_Value; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Condensed; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Quality; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Limit; \
	MENU prefix ## POSITIONING_VALUE_page; \
	COMMAND prefix ## POSITIONING_VALUE_read; \
	COLLECTION prefix ## FEEDBACK_VALUE; \
	VARIABLE prefix ## FEEDBACK_VALUE_Value; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Quality; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Limit; \
	MENU prefix ## FEEDBACK_VALUE_page; \
	COMMAND prefix ## FEEDBACK_VALUE_read; \
	VARIABLE prefix ## VALVE_MAN; \
	MENU prefix ## VALVE_MAN_page; \
	COMMAND prefix ## VALVE_MAN_read; \
	COMMAND prefix ## VALVE_MAN_write; \
	VARIABLE prefix ## VALVE_TYPE; \
	MENU prefix ## VALVE_TYPE_page; \
	COMMAND prefix ## VALVE_TYPE_read; \
	COMMAND prefix ## VALVE_TYPE_write; \
	VARIABLE prefix ## ACTUATOR_TYPE; \
	MENU prefix ## ACTUATOR_TYPE_page; \
	COMMAND prefix ## ACTUATOR_TYPE_read; \
	VARIABLE prefix ## ACTUATOR_ACTION; \
	MENU prefix ## ACTUATOR_ACTION_page; \
	COMMAND prefix ## ACTUATOR_ACTION_read; \
	COMMAND prefix ## ACTUATOR_ACTION_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_ACTUATOR_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ACT_ROT_DIR; \
	MENU prefix ## ACT_ROT_DIR_page; \
	COMMAND prefix ## ACT_ROT_DIR_read; \
	COMMAND prefix ## ACT_ROT_DIR_write; \
	VARIABLE prefix ## ACT_STROKE_TIME_DEC; \
	MENU prefix ## ACT_STROKE_TIME_DEC_page; \
	COMMAND prefix ## ACT_STROKE_TIME_DEC_read; \
	VARIABLE prefix ## ACT_STROKE_TIME_INC; \
	MENU prefix ## ACT_STROKE_TIME_INC_page; \
	COMMAND prefix ## ACT_STROKE_TIME_INC_read; \
	VARIABLE prefix ## ACT_TRAV_TIME; \
	MENU prefix ## ACT_TRAV_TIME_page; \
	COMMAND prefix ## ACT_TRAV_TIME_read; \
	VARIABLE prefix ## ANTI_PUMP_CL; \
	MENU prefix ## ANTI_PUMP_CL_page; \
	COMMAND prefix ## ANTI_PUMP_CL_read; \
	COMMAND prefix ## ANTI_PUMP_CL_write; \
	VARIABLE prefix ## ANTI_PUMP_OP; \
	MENU prefix ## ANTI_PUMP_OP_page; \
	COMMAND prefix ## ANTI_PUMP_OP_read; \
	COMMAND prefix ## ANTI_PUMP_OP_write; \
	VARIABLE prefix ## BREAK_STRENGTH; \
	MENU prefix ## BREAK_STRENGTH_page; \
	COMMAND prefix ## BREAK_STRENGTH_read; \
	COMMAND prefix ## BREAK_STRENGTH_write; \
	VARIABLE prefix ## BYPASS_SETP_CL; \
	MENU prefix ## BYPASS_SETP_CL_page; \
	COMMAND prefix ## BYPASS_SETP_CL_read; \
	COMMAND prefix ## BYPASS_SETP_CL_write; \
	VARIABLE prefix ## BYPASS_SETP_OP; \
	MENU prefix ## BYPASS_SETP_OP_page; \
	COMMAND prefix ## BYPASS_SETP_OP_read; \
	COMMAND prefix ## BYPASS_SETP_OP_write; \
	VARIABLE prefix ## TAB_ENTRY; \
	MENU prefix ## TAB_ENTRY_page; \
	COMMAND prefix ## TAB_ENTRY_read; \
	COMMAND prefix ## TAB_ENTRY_write; \
	COLLECTION prefix ## TAB_X_Y_VALUE; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Lower_Value; \
	MENU prefix ## TAB_X_Y_VALUE_page; \
	COMMAND prefix ## TAB_X_Y_VALUE_read; \
	COMMAND prefix ## TAB_X_Y_VALUE_write; \
	VARIABLE prefix ## TAB_MIN_NUMBER; \
	MENU prefix ## TAB_MIN_NUMBER_page; \
	COMMAND prefix ## TAB_MIN_NUMBER_read; \
	VARIABLE prefix ## TAB_MAX_NUMBER; \
	MENU prefix ## TAB_MAX_NUMBER_page; \
	COMMAND prefix ## TAB_MAX_NUMBER_read; \
	VARIABLE prefix ## TAB_ACTUAL_NUMBER; \
	MENU prefix ## TAB_ACTUAL_NUMBER_page; \
	COMMAND prefix ## TAB_ACTUAL_NUMBER_read; \
	VARIABLE prefix ## DEADBAND; \
	MENU prefix ## DEADBAND_page; \
	COMMAND prefix ## DEADBAND_read; \
	COMMAND prefix ## DEADBAND_write; \
	VARIABLE prefix ## DEVICE_CALIB_DATE; \
	MENU prefix ## DEVICE_CALIB_DATE_page; \
	COMMAND prefix ## DEVICE_CALIB_DATE_read; \
	COMMAND prefix ## DEVICE_CALIB_DATE_write; \
	VARIABLE prefix ## DEVICE_CONFIG_DATE; \
	MENU prefix ## DEVICE_CONFIG_DATE_page; \
	COMMAND prefix ## DEVICE_CONFIG_DATE_read; \
	COMMAND prefix ## DEVICE_CONFIG_DATE_write; \
	VARIABLE prefix ## MAX_TORQUE; \
	MENU prefix ## MAX_TORQUE_page; \
	COMMAND prefix ## MAX_TORQUE_read; \
	COMMAND prefix ## MAX_TORQUE_write; \
	VARIABLE prefix ## MOTOR_ON_TIME; \
	MENU prefix ## MOTOR_ON_TIME_page; \
	COMMAND prefix ## MOTOR_ON_TIME_read; \
	VARIABLE prefix ## NUM_LIMIT_CUT_OFF; \
	MENU prefix ## NUM_LIMIT_CUT_OFF_page; \
	COMMAND prefix ## NUM_LIMIT_CUT_OFF_read; \
	VARIABLE prefix ## NUM_MOT_ON_CYCL; \
	MENU prefix ## NUM_MOT_ON_CYCL_page; \
	COMMAND prefix ## NUM_MOT_ON_CYCL_read; \
	VARIABLE prefix ## NUM_MOT_ON_HOUR; \
	MENU prefix ## NUM_MOT_ON_HOUR_page; \
	COMMAND prefix ## NUM_MOT_ON_HOUR_read; \
	VARIABLE prefix ## NUM_TORQ_CUT_OFF; \
	MENU prefix ## NUM_TORQ_CUT_OFF_page; \
	COMMAND prefix ## NUM_TORQ_CUT_OFF_read; \
	VARIABLE prefix ## SERVO_GAIN_1; \
	MENU prefix ## SERVO_GAIN_1_page; \
	COMMAND prefix ## SERVO_GAIN_1_read; \
	COMMAND prefix ## SERVO_GAIN_1_write; \
	VARIABLE prefix ## SERVO_RATE_1; \
	MENU prefix ## SERVO_RATE_1_page; \
	COMMAND prefix ## SERVO_RATE_1_read; \
	COMMAND prefix ## SERVO_RATE_1_write; \
	VARIABLE prefix ## SERVO_RESET_1; \
	MENU prefix ## SERVO_RESET_1_page; \
	COMMAND prefix ## SERVO_RESET_1_read; \
	COMMAND prefix ## SERVO_RESET_1_write; \
	VARIABLE prefix ## SETP_CUTOFF_MODE; \
	MENU prefix ## SETP_CUTOFF_MODE_page; \
	COMMAND prefix ## SETP_CUTOFF_MODE_read; \
	COMMAND prefix ## SETP_CUTOFF_MODE_write; \
	COLLECTION prefix ## TORQUE_ACTUAL; \
	VARIABLE prefix ## TORQUE_ACTUAL_Value; \
	VARIABLE prefix ## TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE prefix ## TORQUE_ACTUAL_Status_Quality; \
	VARIABLE prefix ## TORQUE_ACTUAL_Status_Limit; \
	MENU prefix ## TORQUE_ACTUAL_page; \
	COMMAND prefix ## TORQUE_ACTUAL_read; \
	VARIABLE prefix ## TORQUE_LIM_CL; \
	MENU prefix ## TORQUE_LIM_CL_page; \
	COMMAND prefix ## TORQUE_LIM_CL_read; \
	COMMAND prefix ## TORQUE_LIM_CL_write; \
	VARIABLE prefix ## TORQUE_LIM_OP; \
	MENU prefix ## TORQUE_LIM_OP_page; \
	COMMAND prefix ## TORQUE_LIM_OP_read; \
	COMMAND prefix ## TORQUE_LIM_OP_write; \
	VARIABLE prefix ## TORQUE_UNIT; \
	MENU prefix ## TORQUE_UNIT_page; \
	COMMAND prefix ## TORQUE_UNIT_read; \
	COMMAND prefix ## TORQUE_UNIT_write; \
	VARIABLE prefix ## TOTAL_VALVE_TRAVEL; \
	MENU prefix ## TOTAL_VALVE_TRAVEL_page; \
	COMMAND prefix ## TOTAL_VALVE_TRAVEL_read; \
	COMMAND prefix ## TOTAL_VALVE_TRAVEL_write; \
	VARIABLE prefix ## TOT_VALVE_TRAV_LIM; \
	MENU prefix ## TOT_VALVE_TRAV_LIM_page; \
	COMMAND prefix ## TOT_VALVE_TRAV_LIM_read; \
	COMMAND prefix ## TOT_VALVE_TRAV_LIM_write; \
	VARIABLE prefix ## VALVE_MAINT_DATE; \
	MENU prefix ## VALVE_MAINT_DATE_page; \
	COMMAND prefix ## VALVE_MAINT_DATE_read; \
	COMMAND prefix ## VALVE_MAINT_DATE_write; \
	VARIABLE prefix ## TAB_OP_CODE; \
	MENU prefix ## TAB_OP_CODE_page; \
	COMMAND prefix ## TAB_OP_CODE_read; \
	COMMAND prefix ## TAB_OP_CODE_write; \
	VARIABLE prefix ## TAB_STATUS; \
	MENU prefix ## TAB_STATUS_page; \
	COMMAND prefix ## TAB_STATUS_read; \
	VARIABLE prefix ## ACTUATOR_MAN; \
	MENU prefix ## ACTUATOR_MAN_page; \
	COMMAND prefix ## ACTUATOR_MAN_read; \
	COMMAND prefix ## ACTUATOR_MAN_write; \
	VARIABLE prefix ## VALVE_SER_NUM; \
	MENU prefix ## VALVE_SER_NUM_page; \
	COMMAND prefix ## VALVE_SER_NUM_read; \
	COMMAND prefix ## VALVE_SER_NUM_write; \
	VARIABLE prefix ## ACTUATOR_SER_NUM; \
	MENU prefix ## ACTUATOR_SER_NUM_page; \
	COMMAND prefix ## ACTUATOR_SER_NUM_read; \
	COMMAND prefix ## ACTUATOR_SER_NUM_write; \
	VARIABLE prefix ## ADD_GEAR_SER_NUM; \
	MENU prefix ## ADD_GEAR_SER_NUM_page; \
	COMMAND prefix ## ADD_GEAR_SER_NUM_read; \
	COMMAND prefix ## ADD_GEAR_SER_NUM_write; \
	VARIABLE prefix ## ADD_GEAR_MAN; \
	MENU prefix ## ADD_GEAR_MAN_page; \
	COMMAND prefix ## ADD_GEAR_MAN_read; \
	COMMAND prefix ## ADD_GEAR_MAN_write; \
	VARIABLE prefix ## ADD_GEAR_ID; \
	MENU prefix ## ADD_GEAR_ID_page; \
	COMMAND prefix ## ADD_GEAR_ID_read; \
	COMMAND prefix ## ADD_GEAR_ID_write; \
	VARIABLE prefix ## ADD_GEAR_INST_DATE; \
	MENU prefix ## ADD_GEAR_INST_DATE_page; \
	COMMAND prefix ## ADD_GEAR_INST_DATE_read; \
	COMMAND prefix ## ADD_GEAR_INST_DATE_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	COLLECTION prefix ## VIEW_4; \
	MENU prefix ## VIEW_4_page

#define USE_TRANS_ACTUATOR_OPTIONAL_A(prefix) \
	USE_TRANS_ACTUATOR_OPTIONAL_BOTH(prefix); \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## RATED_TRAVEL; \
	MENU prefix ## RATED_TRAVEL_page; \
	COMMAND prefix ## RATED_TRAVEL_read; \
	COMMAND prefix ## RATED_TRAVEL_write; \
	VARIABLE prefix ## SELF_CALIB_CMD; \
	MENU prefix ## SELF_CALIB_CMD_page; \
	COMMAND prefix ## SELF_CALIB_CMD_read; \
	COMMAND prefix ## SELF_CALIB_CMD_write; \
	VARIABLE prefix ## SELF_CALIB_STATUS; \
	MENU prefix ## SELF_CALIB_STATUS_page; \
	COMMAND prefix ## SELF_CALIB_STATUS_read; \
	VARIABLE prefix ## SETP_CUTOFF_DEC; \
	MENU prefix ## SETP_CUTOFF_DEC_page; \
	COMMAND prefix ## SETP_CUTOFF_DEC_read; \
	COMMAND prefix ## SETP_CUTOFF_DEC_write; \
	VARIABLE prefix ## SETP_CUTOFF_INC; \
	MENU prefix ## SETP_CUTOFF_INC_page; \
	COMMAND prefix ## SETP_CUTOFF_INC_read; \
	COMMAND prefix ## SETP_CUTOFF_INC_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_LOW; \
	MENU prefix ## TRAVEL_LIMIT_LOW_page; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_read; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_UP; \
	MENU prefix ## TRAVEL_LIMIT_UP_page; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_read; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_write; \
	VARIABLE prefix ## TRAVEL_RATE_DEC; \
	MENU prefix ## TRAVEL_RATE_DEC_page; \
	COMMAND prefix ## TRAVEL_RATE_DEC_read; \
	COMMAND prefix ## TRAVEL_RATE_DEC_write; \
	VARIABLE prefix ## TRAVEL_RATE_INC; \
	MENU prefix ## TRAVEL_RATE_INC_page; \
	COMMAND prefix ## TRAVEL_RATE_INC_read; \
	COMMAND prefix ## TRAVEL_RATE_INC_write; \
	COLLECTION prefix ## POSITIONING_VALUE; \
	VARIABLE prefix ## POSITIONING_VALUE_Value; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Condensed; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Quality; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Limit; \
	MENU prefix ## POSITIONING_VALUE_page; \
	COMMAND prefix ## POSITIONING_VALUE_read; \
	COLLECTION prefix ## FEEDBACK_VALUE; \
	VARIABLE prefix ## FEEDBACK_VALUE_Value; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Quality; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Limit; \
	MENU prefix ## FEEDBACK_VALUE_page; \
	COMMAND prefix ## FEEDBACK_VALUE_read; \
	VARIABLE prefix ## VALVE_MAN; \
	MENU prefix ## VALVE_MAN_page; \
	COMMAND prefix ## VALVE_MAN_read; \
	COMMAND prefix ## VALVE_MAN_write; \
	VARIABLE prefix ## VALVE_TYPE; \
	MENU prefix ## VALVE_TYPE_page; \
	COMMAND prefix ## VALVE_TYPE_read; \
	COMMAND prefix ## VALVE_TYPE_write; \
	VARIABLE prefix ## ACTUATOR_TYPE; \
	MENU prefix ## ACTUATOR_TYPE_page; \
	COMMAND prefix ## ACTUATOR_TYPE_read; \
	VARIABLE prefix ## ACTUATOR_ACTION; \
	MENU prefix ## ACTUATOR_ACTION_page; \
	COMMAND prefix ## ACTUATOR_ACTION_read; \
	COMMAND prefix ## ACTUATOR_ACTION_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_ACTUATOR_OPTIONAL_B(prefix) \
	USE_TRANS_ACTUATOR_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans1_Actuator_)
#define USE_TRANS1_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans1_Actuator_)
#define USE_TRANS1_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans1_Actuator_)
#define USE_TRANS1_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans1_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans2_Actuator_block; \
	COLLECTION trans2_Actuator_BLOCK_OBJECT; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans2_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans2_Actuator_ST_REV; \
	MENU trans2_Actuator_ST_REV_page; \
	COMMAND trans2_Actuator_ST_REV_read; \
	VARIABLE trans2_Actuator_TAG_DESC; \
	MENU trans2_Actuator_TAG_DESC_page; \
	COMMAND trans2_Actuator_TAG_DESC_read; \
	COMMAND trans2_Actuator_TAG_DESC_write; \
	VARIABLE trans2_Actuator_STRATEGY; \
	MENU trans2_Actuator_STRATEGY_page; \
	COMMAND trans2_Actuator_STRATEGY_read; \
	COMMAND trans2_Actuator_STRATEGY_write; \
	VARIABLE trans2_Actuator_ALERT_KEY; \
	MENU trans2_Actuator_ALERT_KEY_page; \
	COMMAND trans2_Actuator_ALERT_KEY_read; \
	COMMAND trans2_Actuator_ALERT_KEY_write; \
	VARIABLE trans2_Actuator_TARGET_MODE; \
	MENU trans2_Actuator_TARGET_MODE_page; \
	COMMAND trans2_Actuator_TARGET_MODE_read; \
	COMMAND trans2_Actuator_TARGET_MODE_write; \
	COLLECTION trans2_Actuator_MODE_BLK; \
	VARIABLE trans2_Actuator_MODE_BLK_Actual; \
	VARIABLE trans2_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans2_Actuator_MODE_BLK_Normal; \
	MENU trans2_Actuator_MODE_BLK_page; \
	COMMAND trans2_Actuator_MODE_BLK_read; \
	COLLECTION trans2_Actuator_ALARM_SUM; \
	VARIABLE trans2_Actuator_ALARM_SUM_Current; \
	VARIABLE trans2_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans2_Actuator_ALARM_SUM_Disabled; \
	MENU trans2_Actuator_ALARM_SUM_page; \
	COMMAND trans2_Actuator_ALARM_SUM_read

#define USE_TRANS2_ACTUATOR_MANDATORY_A \
	USE_TRANS2_ACTUATOR_MANDATORY_BOTH; \
	MENU trans2_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS2_ACTUATOR_MANDATORY_B \
	USE_TRANS2_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans2_Actuator_LIN_TYPE; \
	MENU trans2_Actuator_LIN_TYPE_page; \
	COMMAND trans2_Actuator_LIN_TYPE_read; \
	COMMAND trans2_Actuator_LIN_TYPE_write; \
	VARIABLE trans2_Actuator_RATED_TRAVEL; \
	MENU trans2_Actuator_RATED_TRAVEL_page; \
	COMMAND trans2_Actuator_RATED_TRAVEL_read; \
	COMMAND trans2_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans2_Actuator_SELF_CALIB_CMD; \
	MENU trans2_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans2_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans2_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans2_Actuator_SELF_CALIB_STATUS; \
	MENU trans2_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans2_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans2_Actuator_SETP_CUTOFF_DEC; \
	MENU trans2_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans2_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans2_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans2_Actuator_SETP_CUTOFF_INC; \
	MENU trans2_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans2_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans2_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans2_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans2_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans2_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans2_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans2_Actuator_TRAVEL_RATE_DEC; \
	MENU trans2_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans2_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans2_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans2_Actuator_TRAVEL_RATE_INC; \
	MENU trans2_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans2_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans2_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans2_Actuator_POSITIONING_VALUE; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans2_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans2_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans2_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans2_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans2_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans2_Actuator_VALVE_MAN; \
	MENU trans2_Actuator_VALVE_MAN_page; \
	COMMAND trans2_Actuator_VALVE_MAN_read; \
	COMMAND trans2_Actuator_VALVE_MAN_write; \
	VARIABLE trans2_Actuator_VALVE_TYPE; \
	MENU trans2_Actuator_VALVE_TYPE_page; \
	COMMAND trans2_Actuator_VALVE_TYPE_read; \
	COMMAND trans2_Actuator_VALVE_TYPE_write; \
	VARIABLE trans2_Actuator_ACTUATOR_TYPE; \
	MENU trans2_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans2_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans2_Actuator_ACTUATOR_ACTION; \
	MENU trans2_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans2_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans2_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans2_Actuator_VIEW_1; \
	MENU trans2_Actuator_VIEW_1_page; \
	MENU trans2_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS2_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans2_Actuator_ACT_ROT_DIR; \
	MENU trans2_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans2_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans2_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans2_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans2_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans2_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans2_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans2_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans2_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans2_Actuator_ACT_TRAV_TIME; \
	MENU trans2_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans2_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans2_Actuator_ANTI_PUMP_CL; \
	MENU trans2_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans2_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans2_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans2_Actuator_ANTI_PUMP_OP; \
	MENU trans2_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans2_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans2_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans2_Actuator_BREAK_STRENGTH; \
	MENU trans2_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans2_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans2_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans2_Actuator_BYPASS_SETP_CL; \
	MENU trans2_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans2_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans2_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans2_Actuator_BYPASS_SETP_OP; \
	MENU trans2_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans2_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans2_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans2_Actuator_TAB_ENTRY; \
	MENU trans2_Actuator_TAB_ENTRY_page; \
	COMMAND trans2_Actuator_TAB_ENTRY_read; \
	COMMAND trans2_Actuator_TAB_ENTRY_write; \
	COLLECTION trans2_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans2_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans2_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans2_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans2_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans2_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans2_Actuator_TAB_MIN_NUMBER; \
	MENU trans2_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans2_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans2_Actuator_TAB_MAX_NUMBER; \
	MENU trans2_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans2_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans2_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans2_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans2_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans2_Actuator_DEADBAND; \
	MENU trans2_Actuator_DEADBAND_page; \
	COMMAND trans2_Actuator_DEADBAND_read; \
	COMMAND trans2_Actuator_DEADBAND_write; \
	VARIABLE trans2_Actuator_DEVICE_CALIB_DATE; \
	MENU trans2_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans2_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans2_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans2_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans2_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans2_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans2_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans2_Actuator_MAX_TORQUE; \
	MENU trans2_Actuator_MAX_TORQUE_page; \
	COMMAND trans2_Actuator_MAX_TORQUE_read; \
	COMMAND trans2_Actuator_MAX_TORQUE_write; \
	VARIABLE trans2_Actuator_MOTOR_ON_TIME; \
	MENU trans2_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans2_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans2_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans2_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans2_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans2_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans2_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans2_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans2_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans2_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans2_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans2_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans2_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans2_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans2_Actuator_SERVO_GAIN_1; \
	MENU trans2_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans2_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans2_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans2_Actuator_SERVO_RATE_1; \
	MENU trans2_Actuator_SERVO_RATE_1_page; \
	COMMAND trans2_Actuator_SERVO_RATE_1_read; \
	COMMAND trans2_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans2_Actuator_SERVO_RESET_1; \
	MENU trans2_Actuator_SERVO_RESET_1_page; \
	COMMAND trans2_Actuator_SERVO_RESET_1_read; \
	COMMAND trans2_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans2_Actuator_SETP_CUTOFF_MODE; \
	MENU trans2_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans2_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans2_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans2_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans2_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans2_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans2_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans2_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans2_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans2_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans2_Actuator_TORQUE_LIM_CL; \
	MENU trans2_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans2_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans2_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans2_Actuator_TORQUE_LIM_OP; \
	MENU trans2_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans2_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans2_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans2_Actuator_TORQUE_UNIT; \
	MENU trans2_Actuator_TORQUE_UNIT_page; \
	COMMAND trans2_Actuator_TORQUE_UNIT_read; \
	COMMAND trans2_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans2_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans2_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans2_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans2_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans2_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans2_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans2_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans2_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans2_Actuator_VALVE_MAINT_DATE; \
	MENU trans2_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans2_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans2_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans2_Actuator_TAB_OP_CODE; \
	MENU trans2_Actuator_TAB_OP_CODE_page; \
	COMMAND trans2_Actuator_TAB_OP_CODE_read; \
	COMMAND trans2_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans2_Actuator_TAB_STATUS; \
	MENU trans2_Actuator_TAB_STATUS_page; \
	COMMAND trans2_Actuator_TAB_STATUS_read; \
	VARIABLE trans2_Actuator_ACTUATOR_MAN; \
	MENU trans2_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans2_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans2_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans2_Actuator_VALVE_SER_NUM; \
	MENU trans2_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans2_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans2_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans2_Actuator_ACTUATOR_SER_NUM; \
	MENU trans2_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans2_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans2_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans2_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans2_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans2_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans2_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans2_Actuator_ADD_GEAR_MAN; \
	MENU trans2_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans2_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans2_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans2_Actuator_ADD_GEAR_ID; \
	MENU trans2_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans2_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans2_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans2_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans2_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans2_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans2_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans2_Actuator_VIEW_2; \
	MENU trans2_Actuator_VIEW_2_page; \
	COLLECTION trans2_Actuator_VIEW_3; \
	MENU trans2_Actuator_VIEW_3_page; \
	COLLECTION trans2_Actuator_VIEW_4; \
	MENU trans2_Actuator_VIEW_4_page

#define USE_TRANS2_ACTUATOR_OPTIONAL_A \
	USE_TRANS2_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans2_Actuator_LIN_TYPE; \
	MENU trans2_Actuator_LIN_TYPE_page; \
	COMMAND trans2_Actuator_LIN_TYPE_read; \
	COMMAND trans2_Actuator_LIN_TYPE_write; \
	VARIABLE trans2_Actuator_RATED_TRAVEL; \
	MENU trans2_Actuator_RATED_TRAVEL_page; \
	COMMAND trans2_Actuator_RATED_TRAVEL_read; \
	COMMAND trans2_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans2_Actuator_SELF_CALIB_CMD; \
	MENU trans2_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans2_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans2_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans2_Actuator_SELF_CALIB_STATUS; \
	MENU trans2_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans2_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans2_Actuator_SETP_CUTOFF_DEC; \
	MENU trans2_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans2_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans2_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans2_Actuator_SETP_CUTOFF_INC; \
	MENU trans2_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans2_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans2_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans2_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans2_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans2_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans2_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans2_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans2_Actuator_TRAVEL_RATE_DEC; \
	MENU trans2_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans2_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans2_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans2_Actuator_TRAVEL_RATE_INC; \
	MENU trans2_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans2_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans2_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans2_Actuator_POSITIONING_VALUE; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans2_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans2_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans2_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans2_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans2_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans2_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans2_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans2_Actuator_VALVE_MAN; \
	MENU trans2_Actuator_VALVE_MAN_page; \
	COMMAND trans2_Actuator_VALVE_MAN_read; \
	COMMAND trans2_Actuator_VALVE_MAN_write; \
	VARIABLE trans2_Actuator_VALVE_TYPE; \
	MENU trans2_Actuator_VALVE_TYPE_page; \
	COMMAND trans2_Actuator_VALVE_TYPE_read; \
	COMMAND trans2_Actuator_VALVE_TYPE_write; \
	VARIABLE trans2_Actuator_ACTUATOR_TYPE; \
	MENU trans2_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans2_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans2_Actuator_ACTUATOR_ACTION; \
	MENU trans2_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans2_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans2_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans2_Actuator_VIEW_1; \
	MENU trans2_Actuator_VIEW_1_page; \
	MENU trans2_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS2_ACTUATOR_OPTIONAL_B \
	USE_TRANS2_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans2_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans2_Actuator_)
#define USE_TRANS2_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans2_Actuator_)
#define USE_TRANS2_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans2_Actuator_)
#define USE_TRANS2_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans2_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans3_Actuator_block; \
	COLLECTION trans3_Actuator_BLOCK_OBJECT; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans3_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans3_Actuator_ST_REV; \
	MENU trans3_Actuator_ST_REV_page; \
	COMMAND trans3_Actuator_ST_REV_read; \
	VARIABLE trans3_Actuator_TAG_DESC; \
	MENU trans3_Actuator_TAG_DESC_page; \
	COMMAND trans3_Actuator_TAG_DESC_read; \
	COMMAND trans3_Actuator_TAG_DESC_write; \
	VARIABLE trans3_Actuator_STRATEGY; \
	MENU trans3_Actuator_STRATEGY_page; \
	COMMAND trans3_Actuator_STRATEGY_read; \
	COMMAND trans3_Actuator_STRATEGY_write; \
	VARIABLE trans3_Actuator_ALERT_KEY; \
	MENU trans3_Actuator_ALERT_KEY_page; \
	COMMAND trans3_Actuator_ALERT_KEY_read; \
	COMMAND trans3_Actuator_ALERT_KEY_write; \
	VARIABLE trans3_Actuator_TARGET_MODE; \
	MENU trans3_Actuator_TARGET_MODE_page; \
	COMMAND trans3_Actuator_TARGET_MODE_read; \
	COMMAND trans3_Actuator_TARGET_MODE_write; \
	COLLECTION trans3_Actuator_MODE_BLK; \
	VARIABLE trans3_Actuator_MODE_BLK_Actual; \
	VARIABLE trans3_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans3_Actuator_MODE_BLK_Normal; \
	MENU trans3_Actuator_MODE_BLK_page; \
	COMMAND trans3_Actuator_MODE_BLK_read; \
	COLLECTION trans3_Actuator_ALARM_SUM; \
	VARIABLE trans3_Actuator_ALARM_SUM_Current; \
	VARIABLE trans3_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans3_Actuator_ALARM_SUM_Disabled; \
	MENU trans3_Actuator_ALARM_SUM_page; \
	COMMAND trans3_Actuator_ALARM_SUM_read

#define USE_TRANS3_ACTUATOR_MANDATORY_A \
	USE_TRANS3_ACTUATOR_MANDATORY_BOTH; \
	MENU trans3_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS3_ACTUATOR_MANDATORY_B \
	USE_TRANS3_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans3_Actuator_LIN_TYPE; \
	MENU trans3_Actuator_LIN_TYPE_page; \
	COMMAND trans3_Actuator_LIN_TYPE_read; \
	COMMAND trans3_Actuator_LIN_TYPE_write; \
	VARIABLE trans3_Actuator_RATED_TRAVEL; \
	MENU trans3_Actuator_RATED_TRAVEL_page; \
	COMMAND trans3_Actuator_RATED_TRAVEL_read; \
	COMMAND trans3_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans3_Actuator_SELF_CALIB_CMD; \
	MENU trans3_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans3_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans3_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans3_Actuator_SELF_CALIB_STATUS; \
	MENU trans3_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans3_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans3_Actuator_SETP_CUTOFF_DEC; \
	MENU trans3_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans3_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans3_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans3_Actuator_SETP_CUTOFF_INC; \
	MENU trans3_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans3_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans3_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans3_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans3_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans3_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans3_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans3_Actuator_TRAVEL_RATE_DEC; \
	MENU trans3_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans3_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans3_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans3_Actuator_TRAVEL_RATE_INC; \
	MENU trans3_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans3_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans3_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans3_Actuator_POSITIONING_VALUE; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans3_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans3_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans3_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans3_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans3_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans3_Actuator_VALVE_MAN; \
	MENU trans3_Actuator_VALVE_MAN_page; \
	COMMAND trans3_Actuator_VALVE_MAN_read; \
	COMMAND trans3_Actuator_VALVE_MAN_write; \
	VARIABLE trans3_Actuator_VALVE_TYPE; \
	MENU trans3_Actuator_VALVE_TYPE_page; \
	COMMAND trans3_Actuator_VALVE_TYPE_read; \
	COMMAND trans3_Actuator_VALVE_TYPE_write; \
	VARIABLE trans3_Actuator_ACTUATOR_TYPE; \
	MENU trans3_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans3_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans3_Actuator_ACTUATOR_ACTION; \
	MENU trans3_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans3_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans3_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans3_Actuator_VIEW_1; \
	MENU trans3_Actuator_VIEW_1_page; \
	MENU trans3_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS3_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans3_Actuator_ACT_ROT_DIR; \
	MENU trans3_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans3_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans3_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans3_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans3_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans3_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans3_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans3_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans3_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans3_Actuator_ACT_TRAV_TIME; \
	MENU trans3_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans3_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans3_Actuator_ANTI_PUMP_CL; \
	MENU trans3_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans3_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans3_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans3_Actuator_ANTI_PUMP_OP; \
	MENU trans3_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans3_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans3_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans3_Actuator_BREAK_STRENGTH; \
	MENU trans3_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans3_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans3_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans3_Actuator_BYPASS_SETP_CL; \
	MENU trans3_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans3_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans3_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans3_Actuator_BYPASS_SETP_OP; \
	MENU trans3_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans3_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans3_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans3_Actuator_TAB_ENTRY; \
	MENU trans3_Actuator_TAB_ENTRY_page; \
	COMMAND trans3_Actuator_TAB_ENTRY_read; \
	COMMAND trans3_Actuator_TAB_ENTRY_write; \
	COLLECTION trans3_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans3_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans3_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans3_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans3_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans3_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans3_Actuator_TAB_MIN_NUMBER; \
	MENU trans3_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans3_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans3_Actuator_TAB_MAX_NUMBER; \
	MENU trans3_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans3_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans3_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans3_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans3_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans3_Actuator_DEADBAND; \
	MENU trans3_Actuator_DEADBAND_page; \
	COMMAND trans3_Actuator_DEADBAND_read; \
	COMMAND trans3_Actuator_DEADBAND_write; \
	VARIABLE trans3_Actuator_DEVICE_CALIB_DATE; \
	MENU trans3_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans3_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans3_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans3_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans3_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans3_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans3_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans3_Actuator_MAX_TORQUE; \
	MENU trans3_Actuator_MAX_TORQUE_page; \
	COMMAND trans3_Actuator_MAX_TORQUE_read; \
	COMMAND trans3_Actuator_MAX_TORQUE_write; \
	VARIABLE trans3_Actuator_MOTOR_ON_TIME; \
	MENU trans3_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans3_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans3_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans3_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans3_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans3_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans3_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans3_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans3_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans3_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans3_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans3_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans3_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans3_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans3_Actuator_SERVO_GAIN_1; \
	MENU trans3_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans3_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans3_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans3_Actuator_SERVO_RATE_1; \
	MENU trans3_Actuator_SERVO_RATE_1_page; \
	COMMAND trans3_Actuator_SERVO_RATE_1_read; \
	COMMAND trans3_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans3_Actuator_SERVO_RESET_1; \
	MENU trans3_Actuator_SERVO_RESET_1_page; \
	COMMAND trans3_Actuator_SERVO_RESET_1_read; \
	COMMAND trans3_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans3_Actuator_SETP_CUTOFF_MODE; \
	MENU trans3_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans3_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans3_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans3_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans3_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans3_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans3_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans3_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans3_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans3_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans3_Actuator_TORQUE_LIM_CL; \
	MENU trans3_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans3_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans3_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans3_Actuator_TORQUE_LIM_OP; \
	MENU trans3_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans3_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans3_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans3_Actuator_TORQUE_UNIT; \
	MENU trans3_Actuator_TORQUE_UNIT_page; \
	COMMAND trans3_Actuator_TORQUE_UNIT_read; \
	COMMAND trans3_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans3_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans3_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans3_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans3_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans3_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans3_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans3_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans3_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans3_Actuator_VALVE_MAINT_DATE; \
	MENU trans3_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans3_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans3_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans3_Actuator_TAB_OP_CODE; \
	MENU trans3_Actuator_TAB_OP_CODE_page; \
	COMMAND trans3_Actuator_TAB_OP_CODE_read; \
	COMMAND trans3_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans3_Actuator_TAB_STATUS; \
	MENU trans3_Actuator_TAB_STATUS_page; \
	COMMAND trans3_Actuator_TAB_STATUS_read; \
	VARIABLE trans3_Actuator_ACTUATOR_MAN; \
	MENU trans3_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans3_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans3_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans3_Actuator_VALVE_SER_NUM; \
	MENU trans3_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans3_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans3_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans3_Actuator_ACTUATOR_SER_NUM; \
	MENU trans3_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans3_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans3_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans3_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans3_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans3_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans3_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans3_Actuator_ADD_GEAR_MAN; \
	MENU trans3_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans3_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans3_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans3_Actuator_ADD_GEAR_ID; \
	MENU trans3_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans3_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans3_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans3_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans3_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans3_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans3_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans3_Actuator_VIEW_2; \
	MENU trans3_Actuator_VIEW_2_page; \
	COLLECTION trans3_Actuator_VIEW_3; \
	MENU trans3_Actuator_VIEW_3_page; \
	COLLECTION trans3_Actuator_VIEW_4; \
	MENU trans3_Actuator_VIEW_4_page

#define USE_TRANS3_ACTUATOR_OPTIONAL_A \
	USE_TRANS3_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans3_Actuator_LIN_TYPE; \
	MENU trans3_Actuator_LIN_TYPE_page; \
	COMMAND trans3_Actuator_LIN_TYPE_read; \
	COMMAND trans3_Actuator_LIN_TYPE_write; \
	VARIABLE trans3_Actuator_RATED_TRAVEL; \
	MENU trans3_Actuator_RATED_TRAVEL_page; \
	COMMAND trans3_Actuator_RATED_TRAVEL_read; \
	COMMAND trans3_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans3_Actuator_SELF_CALIB_CMD; \
	MENU trans3_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans3_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans3_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans3_Actuator_SELF_CALIB_STATUS; \
	MENU trans3_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans3_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans3_Actuator_SETP_CUTOFF_DEC; \
	MENU trans3_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans3_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans3_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans3_Actuator_SETP_CUTOFF_INC; \
	MENU trans3_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans3_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans3_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans3_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans3_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans3_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans3_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans3_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans3_Actuator_TRAVEL_RATE_DEC; \
	MENU trans3_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans3_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans3_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans3_Actuator_TRAVEL_RATE_INC; \
	MENU trans3_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans3_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans3_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans3_Actuator_POSITIONING_VALUE; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans3_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans3_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans3_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans3_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans3_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans3_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans3_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans3_Actuator_VALVE_MAN; \
	MENU trans3_Actuator_VALVE_MAN_page; \
	COMMAND trans3_Actuator_VALVE_MAN_read; \
	COMMAND trans3_Actuator_VALVE_MAN_write; \
	VARIABLE trans3_Actuator_VALVE_TYPE; \
	MENU trans3_Actuator_VALVE_TYPE_page; \
	COMMAND trans3_Actuator_VALVE_TYPE_read; \
	COMMAND trans3_Actuator_VALVE_TYPE_write; \
	VARIABLE trans3_Actuator_ACTUATOR_TYPE; \
	MENU trans3_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans3_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans3_Actuator_ACTUATOR_ACTION; \
	MENU trans3_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans3_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans3_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans3_Actuator_VIEW_1; \
	MENU trans3_Actuator_VIEW_1_page; \
	MENU trans3_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS3_ACTUATOR_OPTIONAL_B \
	USE_TRANS3_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans3_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans3_Actuator_)
#define USE_TRANS3_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans3_Actuator_)
#define USE_TRANS3_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans3_Actuator_)
#define USE_TRANS3_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans3_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans4_Actuator_block; \
	COLLECTION trans4_Actuator_BLOCK_OBJECT; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans4_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans4_Actuator_ST_REV; \
	MENU trans4_Actuator_ST_REV_page; \
	COMMAND trans4_Actuator_ST_REV_read; \
	VARIABLE trans4_Actuator_TAG_DESC; \
	MENU trans4_Actuator_TAG_DESC_page; \
	COMMAND trans4_Actuator_TAG_DESC_read; \
	COMMAND trans4_Actuator_TAG_DESC_write; \
	VARIABLE trans4_Actuator_STRATEGY; \
	MENU trans4_Actuator_STRATEGY_page; \
	COMMAND trans4_Actuator_STRATEGY_read; \
	COMMAND trans4_Actuator_STRATEGY_write; \
	VARIABLE trans4_Actuator_ALERT_KEY; \
	MENU trans4_Actuator_ALERT_KEY_page; \
	COMMAND trans4_Actuator_ALERT_KEY_read; \
	COMMAND trans4_Actuator_ALERT_KEY_write; \
	VARIABLE trans4_Actuator_TARGET_MODE; \
	MENU trans4_Actuator_TARGET_MODE_page; \
	COMMAND trans4_Actuator_TARGET_MODE_read; \
	COMMAND trans4_Actuator_TARGET_MODE_write; \
	COLLECTION trans4_Actuator_MODE_BLK; \
	VARIABLE trans4_Actuator_MODE_BLK_Actual; \
	VARIABLE trans4_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans4_Actuator_MODE_BLK_Normal; \
	MENU trans4_Actuator_MODE_BLK_page; \
	COMMAND trans4_Actuator_MODE_BLK_read; \
	COLLECTION trans4_Actuator_ALARM_SUM; \
	VARIABLE trans4_Actuator_ALARM_SUM_Current; \
	VARIABLE trans4_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans4_Actuator_ALARM_SUM_Disabled; \
	MENU trans4_Actuator_ALARM_SUM_page; \
	COMMAND trans4_Actuator_ALARM_SUM_read

#define USE_TRANS4_ACTUATOR_MANDATORY_A \
	USE_TRANS4_ACTUATOR_MANDATORY_BOTH; \
	MENU trans4_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS4_ACTUATOR_MANDATORY_B \
	USE_TRANS4_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans4_Actuator_LIN_TYPE; \
	MENU trans4_Actuator_LIN_TYPE_page; \
	COMMAND trans4_Actuator_LIN_TYPE_read; \
	COMMAND trans4_Actuator_LIN_TYPE_write; \
	VARIABLE trans4_Actuator_RATED_TRAVEL; \
	MENU trans4_Actuator_RATED_TRAVEL_page; \
	COMMAND trans4_Actuator_RATED_TRAVEL_read; \
	COMMAND trans4_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans4_Actuator_SELF_CALIB_CMD; \
	MENU trans4_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans4_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans4_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans4_Actuator_SELF_CALIB_STATUS; \
	MENU trans4_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans4_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans4_Actuator_SETP_CUTOFF_DEC; \
	MENU trans4_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans4_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans4_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans4_Actuator_SETP_CUTOFF_INC; \
	MENU trans4_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans4_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans4_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans4_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans4_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans4_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans4_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans4_Actuator_TRAVEL_RATE_DEC; \
	MENU trans4_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans4_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans4_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans4_Actuator_TRAVEL_RATE_INC; \
	MENU trans4_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans4_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans4_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans4_Actuator_POSITIONING_VALUE; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans4_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans4_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans4_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans4_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans4_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans4_Actuator_VALVE_MAN; \
	MENU trans4_Actuator_VALVE_MAN_page; \
	COMMAND trans4_Actuator_VALVE_MAN_read; \
	COMMAND trans4_Actuator_VALVE_MAN_write; \
	VARIABLE trans4_Actuator_VALVE_TYPE; \
	MENU trans4_Actuator_VALVE_TYPE_page; \
	COMMAND trans4_Actuator_VALVE_TYPE_read; \
	COMMAND trans4_Actuator_VALVE_TYPE_write; \
	VARIABLE trans4_Actuator_ACTUATOR_TYPE; \
	MENU trans4_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans4_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans4_Actuator_ACTUATOR_ACTION; \
	MENU trans4_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans4_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans4_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans4_Actuator_VIEW_1; \
	MENU trans4_Actuator_VIEW_1_page; \
	MENU trans4_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS4_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans4_Actuator_ACT_ROT_DIR; \
	MENU trans4_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans4_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans4_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans4_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans4_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans4_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans4_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans4_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans4_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans4_Actuator_ACT_TRAV_TIME; \
	MENU trans4_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans4_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans4_Actuator_ANTI_PUMP_CL; \
	MENU trans4_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans4_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans4_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans4_Actuator_ANTI_PUMP_OP; \
	MENU trans4_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans4_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans4_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans4_Actuator_BREAK_STRENGTH; \
	MENU trans4_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans4_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans4_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans4_Actuator_BYPASS_SETP_CL; \
	MENU trans4_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans4_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans4_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans4_Actuator_BYPASS_SETP_OP; \
	MENU trans4_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans4_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans4_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans4_Actuator_TAB_ENTRY; \
	MENU trans4_Actuator_TAB_ENTRY_page; \
	COMMAND trans4_Actuator_TAB_ENTRY_read; \
	COMMAND trans4_Actuator_TAB_ENTRY_write; \
	COLLECTION trans4_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans4_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans4_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans4_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans4_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans4_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans4_Actuator_TAB_MIN_NUMBER; \
	MENU trans4_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans4_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans4_Actuator_TAB_MAX_NUMBER; \
	MENU trans4_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans4_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans4_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans4_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans4_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans4_Actuator_DEADBAND; \
	MENU trans4_Actuator_DEADBAND_page; \
	COMMAND trans4_Actuator_DEADBAND_read; \
	COMMAND trans4_Actuator_DEADBAND_write; \
	VARIABLE trans4_Actuator_DEVICE_CALIB_DATE; \
	MENU trans4_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans4_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans4_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans4_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans4_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans4_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans4_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans4_Actuator_MAX_TORQUE; \
	MENU trans4_Actuator_MAX_TORQUE_page; \
	COMMAND trans4_Actuator_MAX_TORQUE_read; \
	COMMAND trans4_Actuator_MAX_TORQUE_write; \
	VARIABLE trans4_Actuator_MOTOR_ON_TIME; \
	MENU trans4_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans4_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans4_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans4_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans4_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans4_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans4_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans4_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans4_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans4_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans4_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans4_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans4_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans4_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans4_Actuator_SERVO_GAIN_1; \
	MENU trans4_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans4_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans4_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans4_Actuator_SERVO_RATE_1; \
	MENU trans4_Actuator_SERVO_RATE_1_page; \
	COMMAND trans4_Actuator_SERVO_RATE_1_read; \
	COMMAND trans4_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans4_Actuator_SERVO_RESET_1; \
	MENU trans4_Actuator_SERVO_RESET_1_page; \
	COMMAND trans4_Actuator_SERVO_RESET_1_read; \
	COMMAND trans4_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans4_Actuator_SETP_CUTOFF_MODE; \
	MENU trans4_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans4_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans4_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans4_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans4_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans4_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans4_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans4_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans4_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans4_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans4_Actuator_TORQUE_LIM_CL; \
	MENU trans4_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans4_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans4_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans4_Actuator_TORQUE_LIM_OP; \
	MENU trans4_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans4_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans4_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans4_Actuator_TORQUE_UNIT; \
	MENU trans4_Actuator_TORQUE_UNIT_page; \
	COMMAND trans4_Actuator_TORQUE_UNIT_read; \
	COMMAND trans4_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans4_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans4_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans4_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans4_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans4_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans4_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans4_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans4_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans4_Actuator_VALVE_MAINT_DATE; \
	MENU trans4_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans4_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans4_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans4_Actuator_TAB_OP_CODE; \
	MENU trans4_Actuator_TAB_OP_CODE_page; \
	COMMAND trans4_Actuator_TAB_OP_CODE_read; \
	COMMAND trans4_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans4_Actuator_TAB_STATUS; \
	MENU trans4_Actuator_TAB_STATUS_page; \
	COMMAND trans4_Actuator_TAB_STATUS_read; \
	VARIABLE trans4_Actuator_ACTUATOR_MAN; \
	MENU trans4_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans4_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans4_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans4_Actuator_VALVE_SER_NUM; \
	MENU trans4_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans4_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans4_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans4_Actuator_ACTUATOR_SER_NUM; \
	MENU trans4_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans4_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans4_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans4_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans4_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans4_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans4_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans4_Actuator_ADD_GEAR_MAN; \
	MENU trans4_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans4_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans4_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans4_Actuator_ADD_GEAR_ID; \
	MENU trans4_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans4_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans4_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans4_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans4_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans4_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans4_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans4_Actuator_VIEW_2; \
	MENU trans4_Actuator_VIEW_2_page; \
	COLLECTION trans4_Actuator_VIEW_3; \
	MENU trans4_Actuator_VIEW_3_page; \
	COLLECTION trans4_Actuator_VIEW_4; \
	MENU trans4_Actuator_VIEW_4_page

#define USE_TRANS4_ACTUATOR_OPTIONAL_A \
	USE_TRANS4_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans4_Actuator_LIN_TYPE; \
	MENU trans4_Actuator_LIN_TYPE_page; \
	COMMAND trans4_Actuator_LIN_TYPE_read; \
	COMMAND trans4_Actuator_LIN_TYPE_write; \
	VARIABLE trans4_Actuator_RATED_TRAVEL; \
	MENU trans4_Actuator_RATED_TRAVEL_page; \
	COMMAND trans4_Actuator_RATED_TRAVEL_read; \
	COMMAND trans4_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans4_Actuator_SELF_CALIB_CMD; \
	MENU trans4_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans4_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans4_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans4_Actuator_SELF_CALIB_STATUS; \
	MENU trans4_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans4_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans4_Actuator_SETP_CUTOFF_DEC; \
	MENU trans4_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans4_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans4_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans4_Actuator_SETP_CUTOFF_INC; \
	MENU trans4_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans4_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans4_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans4_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans4_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans4_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans4_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans4_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans4_Actuator_TRAVEL_RATE_DEC; \
	MENU trans4_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans4_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans4_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans4_Actuator_TRAVEL_RATE_INC; \
	MENU trans4_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans4_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans4_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans4_Actuator_POSITIONING_VALUE; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans4_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans4_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans4_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans4_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans4_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans4_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans4_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans4_Actuator_VALVE_MAN; \
	MENU trans4_Actuator_VALVE_MAN_page; \
	COMMAND trans4_Actuator_VALVE_MAN_read; \
	COMMAND trans4_Actuator_VALVE_MAN_write; \
	VARIABLE trans4_Actuator_VALVE_TYPE; \
	MENU trans4_Actuator_VALVE_TYPE_page; \
	COMMAND trans4_Actuator_VALVE_TYPE_read; \
	COMMAND trans4_Actuator_VALVE_TYPE_write; \
	VARIABLE trans4_Actuator_ACTUATOR_TYPE; \
	MENU trans4_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans4_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans4_Actuator_ACTUATOR_ACTION; \
	MENU trans4_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans4_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans4_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans4_Actuator_VIEW_1; \
	MENU trans4_Actuator_VIEW_1_page; \
	MENU trans4_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS4_ACTUATOR_OPTIONAL_B \
	USE_TRANS4_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans4_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans4_Actuator_)
#define USE_TRANS4_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans4_Actuator_)
#define USE_TRANS4_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans4_Actuator_)
#define USE_TRANS4_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans4_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans5_Actuator_block; \
	COLLECTION trans5_Actuator_BLOCK_OBJECT; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans5_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans5_Actuator_ST_REV; \
	MENU trans5_Actuator_ST_REV_page; \
	COMMAND trans5_Actuator_ST_REV_read; \
	VARIABLE trans5_Actuator_TAG_DESC; \
	MENU trans5_Actuator_TAG_DESC_page; \
	COMMAND trans5_Actuator_TAG_DESC_read; \
	COMMAND trans5_Actuator_TAG_DESC_write; \
	VARIABLE trans5_Actuator_STRATEGY; \
	MENU trans5_Actuator_STRATEGY_page; \
	COMMAND trans5_Actuator_STRATEGY_read; \
	COMMAND trans5_Actuator_STRATEGY_write; \
	VARIABLE trans5_Actuator_ALERT_KEY; \
	MENU trans5_Actuator_ALERT_KEY_page; \
	COMMAND trans5_Actuator_ALERT_KEY_read; \
	COMMAND trans5_Actuator_ALERT_KEY_write; \
	VARIABLE trans5_Actuator_TARGET_MODE; \
	MENU trans5_Actuator_TARGET_MODE_page; \
	COMMAND trans5_Actuator_TARGET_MODE_read; \
	COMMAND trans5_Actuator_TARGET_MODE_write; \
	COLLECTION trans5_Actuator_MODE_BLK; \
	VARIABLE trans5_Actuator_MODE_BLK_Actual; \
	VARIABLE trans5_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans5_Actuator_MODE_BLK_Normal; \
	MENU trans5_Actuator_MODE_BLK_page; \
	COMMAND trans5_Actuator_MODE_BLK_read; \
	COLLECTION trans5_Actuator_ALARM_SUM; \
	VARIABLE trans5_Actuator_ALARM_SUM_Current; \
	VARIABLE trans5_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans5_Actuator_ALARM_SUM_Disabled; \
	MENU trans5_Actuator_ALARM_SUM_page; \
	COMMAND trans5_Actuator_ALARM_SUM_read

#define USE_TRANS5_ACTUATOR_MANDATORY_A \
	USE_TRANS5_ACTUATOR_MANDATORY_BOTH; \
	MENU trans5_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS5_ACTUATOR_MANDATORY_B \
	USE_TRANS5_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans5_Actuator_LIN_TYPE; \
	MENU trans5_Actuator_LIN_TYPE_page; \
	COMMAND trans5_Actuator_LIN_TYPE_read; \
	COMMAND trans5_Actuator_LIN_TYPE_write; \
	VARIABLE trans5_Actuator_RATED_TRAVEL; \
	MENU trans5_Actuator_RATED_TRAVEL_page; \
	COMMAND trans5_Actuator_RATED_TRAVEL_read; \
	COMMAND trans5_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans5_Actuator_SELF_CALIB_CMD; \
	MENU trans5_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans5_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans5_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans5_Actuator_SELF_CALIB_STATUS; \
	MENU trans5_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans5_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans5_Actuator_SETP_CUTOFF_DEC; \
	MENU trans5_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans5_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans5_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans5_Actuator_SETP_CUTOFF_INC; \
	MENU trans5_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans5_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans5_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans5_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans5_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans5_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans5_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans5_Actuator_TRAVEL_RATE_DEC; \
	MENU trans5_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans5_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans5_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans5_Actuator_TRAVEL_RATE_INC; \
	MENU trans5_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans5_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans5_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans5_Actuator_POSITIONING_VALUE; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans5_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans5_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans5_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans5_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans5_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans5_Actuator_VALVE_MAN; \
	MENU trans5_Actuator_VALVE_MAN_page; \
	COMMAND trans5_Actuator_VALVE_MAN_read; \
	COMMAND trans5_Actuator_VALVE_MAN_write; \
	VARIABLE trans5_Actuator_VALVE_TYPE; \
	MENU trans5_Actuator_VALVE_TYPE_page; \
	COMMAND trans5_Actuator_VALVE_TYPE_read; \
	COMMAND trans5_Actuator_VALVE_TYPE_write; \
	VARIABLE trans5_Actuator_ACTUATOR_TYPE; \
	MENU trans5_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans5_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans5_Actuator_ACTUATOR_ACTION; \
	MENU trans5_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans5_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans5_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans5_Actuator_VIEW_1; \
	MENU trans5_Actuator_VIEW_1_page; \
	MENU trans5_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS5_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans5_Actuator_ACT_ROT_DIR; \
	MENU trans5_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans5_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans5_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans5_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans5_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans5_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans5_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans5_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans5_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans5_Actuator_ACT_TRAV_TIME; \
	MENU trans5_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans5_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans5_Actuator_ANTI_PUMP_CL; \
	MENU trans5_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans5_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans5_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans5_Actuator_ANTI_PUMP_OP; \
	MENU trans5_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans5_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans5_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans5_Actuator_BREAK_STRENGTH; \
	MENU trans5_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans5_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans5_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans5_Actuator_BYPASS_SETP_CL; \
	MENU trans5_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans5_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans5_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans5_Actuator_BYPASS_SETP_OP; \
	MENU trans5_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans5_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans5_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans5_Actuator_TAB_ENTRY; \
	MENU trans5_Actuator_TAB_ENTRY_page; \
	COMMAND trans5_Actuator_TAB_ENTRY_read; \
	COMMAND trans5_Actuator_TAB_ENTRY_write; \
	COLLECTION trans5_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans5_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans5_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans5_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans5_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans5_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans5_Actuator_TAB_MIN_NUMBER; \
	MENU trans5_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans5_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans5_Actuator_TAB_MAX_NUMBER; \
	MENU trans5_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans5_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans5_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans5_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans5_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans5_Actuator_DEADBAND; \
	MENU trans5_Actuator_DEADBAND_page; \
	COMMAND trans5_Actuator_DEADBAND_read; \
	COMMAND trans5_Actuator_DEADBAND_write; \
	VARIABLE trans5_Actuator_DEVICE_CALIB_DATE; \
	MENU trans5_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans5_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans5_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans5_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans5_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans5_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans5_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans5_Actuator_MAX_TORQUE; \
	MENU trans5_Actuator_MAX_TORQUE_page; \
	COMMAND trans5_Actuator_MAX_TORQUE_read; \
	COMMAND trans5_Actuator_MAX_TORQUE_write; \
	VARIABLE trans5_Actuator_MOTOR_ON_TIME; \
	MENU trans5_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans5_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans5_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans5_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans5_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans5_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans5_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans5_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans5_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans5_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans5_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans5_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans5_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans5_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans5_Actuator_SERVO_GAIN_1; \
	MENU trans5_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans5_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans5_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans5_Actuator_SERVO_RATE_1; \
	MENU trans5_Actuator_SERVO_RATE_1_page; \
	COMMAND trans5_Actuator_SERVO_RATE_1_read; \
	COMMAND trans5_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans5_Actuator_SERVO_RESET_1; \
	MENU trans5_Actuator_SERVO_RESET_1_page; \
	COMMAND trans5_Actuator_SERVO_RESET_1_read; \
	COMMAND trans5_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans5_Actuator_SETP_CUTOFF_MODE; \
	MENU trans5_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans5_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans5_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans5_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans5_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans5_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans5_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans5_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans5_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans5_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans5_Actuator_TORQUE_LIM_CL; \
	MENU trans5_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans5_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans5_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans5_Actuator_TORQUE_LIM_OP; \
	MENU trans5_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans5_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans5_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans5_Actuator_TORQUE_UNIT; \
	MENU trans5_Actuator_TORQUE_UNIT_page; \
	COMMAND trans5_Actuator_TORQUE_UNIT_read; \
	COMMAND trans5_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans5_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans5_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans5_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans5_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans5_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans5_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans5_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans5_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans5_Actuator_VALVE_MAINT_DATE; \
	MENU trans5_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans5_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans5_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans5_Actuator_TAB_OP_CODE; \
	MENU trans5_Actuator_TAB_OP_CODE_page; \
	COMMAND trans5_Actuator_TAB_OP_CODE_read; \
	COMMAND trans5_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans5_Actuator_TAB_STATUS; \
	MENU trans5_Actuator_TAB_STATUS_page; \
	COMMAND trans5_Actuator_TAB_STATUS_read; \
	VARIABLE trans5_Actuator_ACTUATOR_MAN; \
	MENU trans5_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans5_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans5_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans5_Actuator_VALVE_SER_NUM; \
	MENU trans5_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans5_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans5_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans5_Actuator_ACTUATOR_SER_NUM; \
	MENU trans5_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans5_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans5_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans5_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans5_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans5_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans5_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans5_Actuator_ADD_GEAR_MAN; \
	MENU trans5_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans5_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans5_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans5_Actuator_ADD_GEAR_ID; \
	MENU trans5_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans5_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans5_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans5_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans5_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans5_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans5_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans5_Actuator_VIEW_2; \
	MENU trans5_Actuator_VIEW_2_page; \
	COLLECTION trans5_Actuator_VIEW_3; \
	MENU trans5_Actuator_VIEW_3_page; \
	COLLECTION trans5_Actuator_VIEW_4; \
	MENU trans5_Actuator_VIEW_4_page

#define USE_TRANS5_ACTUATOR_OPTIONAL_A \
	USE_TRANS5_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans5_Actuator_LIN_TYPE; \
	MENU trans5_Actuator_LIN_TYPE_page; \
	COMMAND trans5_Actuator_LIN_TYPE_read; \
	COMMAND trans5_Actuator_LIN_TYPE_write; \
	VARIABLE trans5_Actuator_RATED_TRAVEL; \
	MENU trans5_Actuator_RATED_TRAVEL_page; \
	COMMAND trans5_Actuator_RATED_TRAVEL_read; \
	COMMAND trans5_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans5_Actuator_SELF_CALIB_CMD; \
	MENU trans5_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans5_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans5_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans5_Actuator_SELF_CALIB_STATUS; \
	MENU trans5_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans5_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans5_Actuator_SETP_CUTOFF_DEC; \
	MENU trans5_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans5_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans5_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans5_Actuator_SETP_CUTOFF_INC; \
	MENU trans5_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans5_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans5_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans5_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans5_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans5_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans5_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans5_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans5_Actuator_TRAVEL_RATE_DEC; \
	MENU trans5_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans5_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans5_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans5_Actuator_TRAVEL_RATE_INC; \
	MENU trans5_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans5_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans5_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans5_Actuator_POSITIONING_VALUE; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans5_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans5_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans5_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans5_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans5_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans5_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans5_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans5_Actuator_VALVE_MAN; \
	MENU trans5_Actuator_VALVE_MAN_page; \
	COMMAND trans5_Actuator_VALVE_MAN_read; \
	COMMAND trans5_Actuator_VALVE_MAN_write; \
	VARIABLE trans5_Actuator_VALVE_TYPE; \
	MENU trans5_Actuator_VALVE_TYPE_page; \
	COMMAND trans5_Actuator_VALVE_TYPE_read; \
	COMMAND trans5_Actuator_VALVE_TYPE_write; \
	VARIABLE trans5_Actuator_ACTUATOR_TYPE; \
	MENU trans5_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans5_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans5_Actuator_ACTUATOR_ACTION; \
	MENU trans5_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans5_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans5_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans5_Actuator_VIEW_1; \
	MENU trans5_Actuator_VIEW_1_page; \
	MENU trans5_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS5_ACTUATOR_OPTIONAL_B \
	USE_TRANS5_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans5_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans5_Actuator_)
#define USE_TRANS5_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans5_Actuator_)
#define USE_TRANS5_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans5_Actuator_)
#define USE_TRANS5_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans5_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans6_Actuator_block; \
	COLLECTION trans6_Actuator_BLOCK_OBJECT; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans6_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans6_Actuator_ST_REV; \
	MENU trans6_Actuator_ST_REV_page; \
	COMMAND trans6_Actuator_ST_REV_read; \
	VARIABLE trans6_Actuator_TAG_DESC; \
	MENU trans6_Actuator_TAG_DESC_page; \
	COMMAND trans6_Actuator_TAG_DESC_read; \
	COMMAND trans6_Actuator_TAG_DESC_write; \
	VARIABLE trans6_Actuator_STRATEGY; \
	MENU trans6_Actuator_STRATEGY_page; \
	COMMAND trans6_Actuator_STRATEGY_read; \
	COMMAND trans6_Actuator_STRATEGY_write; \
	VARIABLE trans6_Actuator_ALERT_KEY; \
	MENU trans6_Actuator_ALERT_KEY_page; \
	COMMAND trans6_Actuator_ALERT_KEY_read; \
	COMMAND trans6_Actuator_ALERT_KEY_write; \
	VARIABLE trans6_Actuator_TARGET_MODE; \
	MENU trans6_Actuator_TARGET_MODE_page; \
	COMMAND trans6_Actuator_TARGET_MODE_read; \
	COMMAND trans6_Actuator_TARGET_MODE_write; \
	COLLECTION trans6_Actuator_MODE_BLK; \
	VARIABLE trans6_Actuator_MODE_BLK_Actual; \
	VARIABLE trans6_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans6_Actuator_MODE_BLK_Normal; \
	MENU trans6_Actuator_MODE_BLK_page; \
	COMMAND trans6_Actuator_MODE_BLK_read; \
	COLLECTION trans6_Actuator_ALARM_SUM; \
	VARIABLE trans6_Actuator_ALARM_SUM_Current; \
	VARIABLE trans6_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans6_Actuator_ALARM_SUM_Disabled; \
	MENU trans6_Actuator_ALARM_SUM_page; \
	COMMAND trans6_Actuator_ALARM_SUM_read

#define USE_TRANS6_ACTUATOR_MANDATORY_A \
	USE_TRANS6_ACTUATOR_MANDATORY_BOTH; \
	MENU trans6_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS6_ACTUATOR_MANDATORY_B \
	USE_TRANS6_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans6_Actuator_LIN_TYPE; \
	MENU trans6_Actuator_LIN_TYPE_page; \
	COMMAND trans6_Actuator_LIN_TYPE_read; \
	COMMAND trans6_Actuator_LIN_TYPE_write; \
	VARIABLE trans6_Actuator_RATED_TRAVEL; \
	MENU trans6_Actuator_RATED_TRAVEL_page; \
	COMMAND trans6_Actuator_RATED_TRAVEL_read; \
	COMMAND trans6_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans6_Actuator_SELF_CALIB_CMD; \
	MENU trans6_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans6_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans6_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans6_Actuator_SELF_CALIB_STATUS; \
	MENU trans6_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans6_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans6_Actuator_SETP_CUTOFF_DEC; \
	MENU trans6_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans6_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans6_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans6_Actuator_SETP_CUTOFF_INC; \
	MENU trans6_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans6_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans6_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans6_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans6_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans6_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans6_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans6_Actuator_TRAVEL_RATE_DEC; \
	MENU trans6_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans6_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans6_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans6_Actuator_TRAVEL_RATE_INC; \
	MENU trans6_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans6_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans6_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans6_Actuator_POSITIONING_VALUE; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans6_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans6_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans6_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans6_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans6_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans6_Actuator_VALVE_MAN; \
	MENU trans6_Actuator_VALVE_MAN_page; \
	COMMAND trans6_Actuator_VALVE_MAN_read; \
	COMMAND trans6_Actuator_VALVE_MAN_write; \
	VARIABLE trans6_Actuator_VALVE_TYPE; \
	MENU trans6_Actuator_VALVE_TYPE_page; \
	COMMAND trans6_Actuator_VALVE_TYPE_read; \
	COMMAND trans6_Actuator_VALVE_TYPE_write; \
	VARIABLE trans6_Actuator_ACTUATOR_TYPE; \
	MENU trans6_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans6_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans6_Actuator_ACTUATOR_ACTION; \
	MENU trans6_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans6_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans6_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans6_Actuator_VIEW_1; \
	MENU trans6_Actuator_VIEW_1_page; \
	MENU trans6_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS6_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans6_Actuator_ACT_ROT_DIR; \
	MENU trans6_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans6_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans6_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans6_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans6_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans6_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans6_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans6_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans6_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans6_Actuator_ACT_TRAV_TIME; \
	MENU trans6_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans6_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans6_Actuator_ANTI_PUMP_CL; \
	MENU trans6_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans6_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans6_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans6_Actuator_ANTI_PUMP_OP; \
	MENU trans6_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans6_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans6_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans6_Actuator_BREAK_STRENGTH; \
	MENU trans6_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans6_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans6_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans6_Actuator_BYPASS_SETP_CL; \
	MENU trans6_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans6_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans6_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans6_Actuator_BYPASS_SETP_OP; \
	MENU trans6_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans6_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans6_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans6_Actuator_TAB_ENTRY; \
	MENU trans6_Actuator_TAB_ENTRY_page; \
	COMMAND trans6_Actuator_TAB_ENTRY_read; \
	COMMAND trans6_Actuator_TAB_ENTRY_write; \
	COLLECTION trans6_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans6_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans6_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans6_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans6_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans6_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans6_Actuator_TAB_MIN_NUMBER; \
	MENU trans6_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans6_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans6_Actuator_TAB_MAX_NUMBER; \
	MENU trans6_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans6_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans6_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans6_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans6_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans6_Actuator_DEADBAND; \
	MENU trans6_Actuator_DEADBAND_page; \
	COMMAND trans6_Actuator_DEADBAND_read; \
	COMMAND trans6_Actuator_DEADBAND_write; \
	VARIABLE trans6_Actuator_DEVICE_CALIB_DATE; \
	MENU trans6_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans6_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans6_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans6_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans6_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans6_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans6_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans6_Actuator_MAX_TORQUE; \
	MENU trans6_Actuator_MAX_TORQUE_page; \
	COMMAND trans6_Actuator_MAX_TORQUE_read; \
	COMMAND trans6_Actuator_MAX_TORQUE_write; \
	VARIABLE trans6_Actuator_MOTOR_ON_TIME; \
	MENU trans6_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans6_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans6_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans6_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans6_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans6_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans6_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans6_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans6_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans6_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans6_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans6_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans6_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans6_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans6_Actuator_SERVO_GAIN_1; \
	MENU trans6_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans6_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans6_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans6_Actuator_SERVO_RATE_1; \
	MENU trans6_Actuator_SERVO_RATE_1_page; \
	COMMAND trans6_Actuator_SERVO_RATE_1_read; \
	COMMAND trans6_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans6_Actuator_SERVO_RESET_1; \
	MENU trans6_Actuator_SERVO_RESET_1_page; \
	COMMAND trans6_Actuator_SERVO_RESET_1_read; \
	COMMAND trans6_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans6_Actuator_SETP_CUTOFF_MODE; \
	MENU trans6_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans6_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans6_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans6_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans6_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans6_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans6_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans6_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans6_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans6_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans6_Actuator_TORQUE_LIM_CL; \
	MENU trans6_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans6_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans6_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans6_Actuator_TORQUE_LIM_OP; \
	MENU trans6_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans6_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans6_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans6_Actuator_TORQUE_UNIT; \
	MENU trans6_Actuator_TORQUE_UNIT_page; \
	COMMAND trans6_Actuator_TORQUE_UNIT_read; \
	COMMAND trans6_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans6_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans6_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans6_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans6_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans6_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans6_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans6_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans6_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans6_Actuator_VALVE_MAINT_DATE; \
	MENU trans6_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans6_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans6_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans6_Actuator_TAB_OP_CODE; \
	MENU trans6_Actuator_TAB_OP_CODE_page; \
	COMMAND trans6_Actuator_TAB_OP_CODE_read; \
	COMMAND trans6_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans6_Actuator_TAB_STATUS; \
	MENU trans6_Actuator_TAB_STATUS_page; \
	COMMAND trans6_Actuator_TAB_STATUS_read; \
	VARIABLE trans6_Actuator_ACTUATOR_MAN; \
	MENU trans6_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans6_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans6_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans6_Actuator_VALVE_SER_NUM; \
	MENU trans6_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans6_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans6_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans6_Actuator_ACTUATOR_SER_NUM; \
	MENU trans6_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans6_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans6_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans6_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans6_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans6_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans6_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans6_Actuator_ADD_GEAR_MAN; \
	MENU trans6_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans6_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans6_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans6_Actuator_ADD_GEAR_ID; \
	MENU trans6_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans6_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans6_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans6_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans6_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans6_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans6_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans6_Actuator_VIEW_2; \
	MENU trans6_Actuator_VIEW_2_page; \
	COLLECTION trans6_Actuator_VIEW_3; \
	MENU trans6_Actuator_VIEW_3_page; \
	COLLECTION trans6_Actuator_VIEW_4; \
	MENU trans6_Actuator_VIEW_4_page

#define USE_TRANS6_ACTUATOR_OPTIONAL_A \
	USE_TRANS6_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans6_Actuator_LIN_TYPE; \
	MENU trans6_Actuator_LIN_TYPE_page; \
	COMMAND trans6_Actuator_LIN_TYPE_read; \
	COMMAND trans6_Actuator_LIN_TYPE_write; \
	VARIABLE trans6_Actuator_RATED_TRAVEL; \
	MENU trans6_Actuator_RATED_TRAVEL_page; \
	COMMAND trans6_Actuator_RATED_TRAVEL_read; \
	COMMAND trans6_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans6_Actuator_SELF_CALIB_CMD; \
	MENU trans6_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans6_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans6_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans6_Actuator_SELF_CALIB_STATUS; \
	MENU trans6_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans6_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans6_Actuator_SETP_CUTOFF_DEC; \
	MENU trans6_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans6_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans6_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans6_Actuator_SETP_CUTOFF_INC; \
	MENU trans6_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans6_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans6_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans6_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans6_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans6_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans6_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans6_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans6_Actuator_TRAVEL_RATE_DEC; \
	MENU trans6_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans6_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans6_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans6_Actuator_TRAVEL_RATE_INC; \
	MENU trans6_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans6_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans6_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans6_Actuator_POSITIONING_VALUE; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans6_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans6_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans6_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans6_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans6_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans6_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans6_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans6_Actuator_VALVE_MAN; \
	MENU trans6_Actuator_VALVE_MAN_page; \
	COMMAND trans6_Actuator_VALVE_MAN_read; \
	COMMAND trans6_Actuator_VALVE_MAN_write; \
	VARIABLE trans6_Actuator_VALVE_TYPE; \
	MENU trans6_Actuator_VALVE_TYPE_page; \
	COMMAND trans6_Actuator_VALVE_TYPE_read; \
	COMMAND trans6_Actuator_VALVE_TYPE_write; \
	VARIABLE trans6_Actuator_ACTUATOR_TYPE; \
	MENU trans6_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans6_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans6_Actuator_ACTUATOR_ACTION; \
	MENU trans6_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans6_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans6_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans6_Actuator_VIEW_1; \
	MENU trans6_Actuator_VIEW_1_page; \
	MENU trans6_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS6_ACTUATOR_OPTIONAL_B \
	USE_TRANS6_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans6_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans6_Actuator_)
#define USE_TRANS6_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans6_Actuator_)
#define USE_TRANS6_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans6_Actuator_)
#define USE_TRANS6_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans6_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans7_Actuator_block; \
	COLLECTION trans7_Actuator_BLOCK_OBJECT; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans7_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans7_Actuator_ST_REV; \
	MENU trans7_Actuator_ST_REV_page; \
	COMMAND trans7_Actuator_ST_REV_read; \
	VARIABLE trans7_Actuator_TAG_DESC; \
	MENU trans7_Actuator_TAG_DESC_page; \
	COMMAND trans7_Actuator_TAG_DESC_read; \
	COMMAND trans7_Actuator_TAG_DESC_write; \
	VARIABLE trans7_Actuator_STRATEGY; \
	MENU trans7_Actuator_STRATEGY_page; \
	COMMAND trans7_Actuator_STRATEGY_read; \
	COMMAND trans7_Actuator_STRATEGY_write; \
	VARIABLE trans7_Actuator_ALERT_KEY; \
	MENU trans7_Actuator_ALERT_KEY_page; \
	COMMAND trans7_Actuator_ALERT_KEY_read; \
	COMMAND trans7_Actuator_ALERT_KEY_write; \
	VARIABLE trans7_Actuator_TARGET_MODE; \
	MENU trans7_Actuator_TARGET_MODE_page; \
	COMMAND trans7_Actuator_TARGET_MODE_read; \
	COMMAND trans7_Actuator_TARGET_MODE_write; \
	COLLECTION trans7_Actuator_MODE_BLK; \
	VARIABLE trans7_Actuator_MODE_BLK_Actual; \
	VARIABLE trans7_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans7_Actuator_MODE_BLK_Normal; \
	MENU trans7_Actuator_MODE_BLK_page; \
	COMMAND trans7_Actuator_MODE_BLK_read; \
	COLLECTION trans7_Actuator_ALARM_SUM; \
	VARIABLE trans7_Actuator_ALARM_SUM_Current; \
	VARIABLE trans7_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans7_Actuator_ALARM_SUM_Disabled; \
	MENU trans7_Actuator_ALARM_SUM_page; \
	COMMAND trans7_Actuator_ALARM_SUM_read

#define USE_TRANS7_ACTUATOR_MANDATORY_A \
	USE_TRANS7_ACTUATOR_MANDATORY_BOTH; \
	MENU trans7_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS7_ACTUATOR_MANDATORY_B \
	USE_TRANS7_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans7_Actuator_LIN_TYPE; \
	MENU trans7_Actuator_LIN_TYPE_page; \
	COMMAND trans7_Actuator_LIN_TYPE_read; \
	COMMAND trans7_Actuator_LIN_TYPE_write; \
	VARIABLE trans7_Actuator_RATED_TRAVEL; \
	MENU trans7_Actuator_RATED_TRAVEL_page; \
	COMMAND trans7_Actuator_RATED_TRAVEL_read; \
	COMMAND trans7_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans7_Actuator_SELF_CALIB_CMD; \
	MENU trans7_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans7_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans7_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans7_Actuator_SELF_CALIB_STATUS; \
	MENU trans7_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans7_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans7_Actuator_SETP_CUTOFF_DEC; \
	MENU trans7_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans7_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans7_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans7_Actuator_SETP_CUTOFF_INC; \
	MENU trans7_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans7_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans7_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans7_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans7_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans7_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans7_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans7_Actuator_TRAVEL_RATE_DEC; \
	MENU trans7_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans7_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans7_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans7_Actuator_TRAVEL_RATE_INC; \
	MENU trans7_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans7_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans7_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans7_Actuator_POSITIONING_VALUE; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans7_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans7_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans7_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans7_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans7_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans7_Actuator_VALVE_MAN; \
	MENU trans7_Actuator_VALVE_MAN_page; \
	COMMAND trans7_Actuator_VALVE_MAN_read; \
	COMMAND trans7_Actuator_VALVE_MAN_write; \
	VARIABLE trans7_Actuator_VALVE_TYPE; \
	MENU trans7_Actuator_VALVE_TYPE_page; \
	COMMAND trans7_Actuator_VALVE_TYPE_read; \
	COMMAND trans7_Actuator_VALVE_TYPE_write; \
	VARIABLE trans7_Actuator_ACTUATOR_TYPE; \
	MENU trans7_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans7_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans7_Actuator_ACTUATOR_ACTION; \
	MENU trans7_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans7_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans7_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans7_Actuator_VIEW_1; \
	MENU trans7_Actuator_VIEW_1_page; \
	MENU trans7_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS7_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans7_Actuator_ACT_ROT_DIR; \
	MENU trans7_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans7_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans7_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans7_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans7_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans7_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans7_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans7_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans7_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans7_Actuator_ACT_TRAV_TIME; \
	MENU trans7_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans7_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans7_Actuator_ANTI_PUMP_CL; \
	MENU trans7_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans7_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans7_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans7_Actuator_ANTI_PUMP_OP; \
	MENU trans7_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans7_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans7_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans7_Actuator_BREAK_STRENGTH; \
	MENU trans7_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans7_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans7_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans7_Actuator_BYPASS_SETP_CL; \
	MENU trans7_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans7_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans7_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans7_Actuator_BYPASS_SETP_OP; \
	MENU trans7_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans7_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans7_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans7_Actuator_TAB_ENTRY; \
	MENU trans7_Actuator_TAB_ENTRY_page; \
	COMMAND trans7_Actuator_TAB_ENTRY_read; \
	COMMAND trans7_Actuator_TAB_ENTRY_write; \
	COLLECTION trans7_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans7_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans7_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans7_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans7_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans7_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans7_Actuator_TAB_MIN_NUMBER; \
	MENU trans7_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans7_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans7_Actuator_TAB_MAX_NUMBER; \
	MENU trans7_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans7_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans7_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans7_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans7_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans7_Actuator_DEADBAND; \
	MENU trans7_Actuator_DEADBAND_page; \
	COMMAND trans7_Actuator_DEADBAND_read; \
	COMMAND trans7_Actuator_DEADBAND_write; \
	VARIABLE trans7_Actuator_DEVICE_CALIB_DATE; \
	MENU trans7_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans7_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans7_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans7_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans7_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans7_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans7_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans7_Actuator_MAX_TORQUE; \
	MENU trans7_Actuator_MAX_TORQUE_page; \
	COMMAND trans7_Actuator_MAX_TORQUE_read; \
	COMMAND trans7_Actuator_MAX_TORQUE_write; \
	VARIABLE trans7_Actuator_MOTOR_ON_TIME; \
	MENU trans7_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans7_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans7_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans7_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans7_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans7_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans7_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans7_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans7_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans7_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans7_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans7_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans7_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans7_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans7_Actuator_SERVO_GAIN_1; \
	MENU trans7_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans7_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans7_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans7_Actuator_SERVO_RATE_1; \
	MENU trans7_Actuator_SERVO_RATE_1_page; \
	COMMAND trans7_Actuator_SERVO_RATE_1_read; \
	COMMAND trans7_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans7_Actuator_SERVO_RESET_1; \
	MENU trans7_Actuator_SERVO_RESET_1_page; \
	COMMAND trans7_Actuator_SERVO_RESET_1_read; \
	COMMAND trans7_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans7_Actuator_SETP_CUTOFF_MODE; \
	MENU trans7_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans7_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans7_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans7_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans7_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans7_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans7_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans7_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans7_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans7_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans7_Actuator_TORQUE_LIM_CL; \
	MENU trans7_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans7_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans7_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans7_Actuator_TORQUE_LIM_OP; \
	MENU trans7_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans7_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans7_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans7_Actuator_TORQUE_UNIT; \
	MENU trans7_Actuator_TORQUE_UNIT_page; \
	COMMAND trans7_Actuator_TORQUE_UNIT_read; \
	COMMAND trans7_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans7_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans7_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans7_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans7_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans7_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans7_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans7_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans7_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans7_Actuator_VALVE_MAINT_DATE; \
	MENU trans7_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans7_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans7_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans7_Actuator_TAB_OP_CODE; \
	MENU trans7_Actuator_TAB_OP_CODE_page; \
	COMMAND trans7_Actuator_TAB_OP_CODE_read; \
	COMMAND trans7_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans7_Actuator_TAB_STATUS; \
	MENU trans7_Actuator_TAB_STATUS_page; \
	COMMAND trans7_Actuator_TAB_STATUS_read; \
	VARIABLE trans7_Actuator_ACTUATOR_MAN; \
	MENU trans7_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans7_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans7_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans7_Actuator_VALVE_SER_NUM; \
	MENU trans7_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans7_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans7_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans7_Actuator_ACTUATOR_SER_NUM; \
	MENU trans7_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans7_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans7_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans7_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans7_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans7_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans7_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans7_Actuator_ADD_GEAR_MAN; \
	MENU trans7_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans7_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans7_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans7_Actuator_ADD_GEAR_ID; \
	MENU trans7_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans7_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans7_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans7_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans7_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans7_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans7_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans7_Actuator_VIEW_2; \
	MENU trans7_Actuator_VIEW_2_page; \
	COLLECTION trans7_Actuator_VIEW_3; \
	MENU trans7_Actuator_VIEW_3_page; \
	COLLECTION trans7_Actuator_VIEW_4; \
	MENU trans7_Actuator_VIEW_4_page

#define USE_TRANS7_ACTUATOR_OPTIONAL_A \
	USE_TRANS7_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans7_Actuator_LIN_TYPE; \
	MENU trans7_Actuator_LIN_TYPE_page; \
	COMMAND trans7_Actuator_LIN_TYPE_read; \
	COMMAND trans7_Actuator_LIN_TYPE_write; \
	VARIABLE trans7_Actuator_RATED_TRAVEL; \
	MENU trans7_Actuator_RATED_TRAVEL_page; \
	COMMAND trans7_Actuator_RATED_TRAVEL_read; \
	COMMAND trans7_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans7_Actuator_SELF_CALIB_CMD; \
	MENU trans7_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans7_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans7_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans7_Actuator_SELF_CALIB_STATUS; \
	MENU trans7_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans7_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans7_Actuator_SETP_CUTOFF_DEC; \
	MENU trans7_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans7_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans7_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans7_Actuator_SETP_CUTOFF_INC; \
	MENU trans7_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans7_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans7_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans7_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans7_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans7_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans7_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans7_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans7_Actuator_TRAVEL_RATE_DEC; \
	MENU trans7_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans7_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans7_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans7_Actuator_TRAVEL_RATE_INC; \
	MENU trans7_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans7_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans7_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans7_Actuator_POSITIONING_VALUE; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans7_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans7_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans7_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans7_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans7_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans7_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans7_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans7_Actuator_VALVE_MAN; \
	MENU trans7_Actuator_VALVE_MAN_page; \
	COMMAND trans7_Actuator_VALVE_MAN_read; \
	COMMAND trans7_Actuator_VALVE_MAN_write; \
	VARIABLE trans7_Actuator_VALVE_TYPE; \
	MENU trans7_Actuator_VALVE_TYPE_page; \
	COMMAND trans7_Actuator_VALVE_TYPE_read; \
	COMMAND trans7_Actuator_VALVE_TYPE_write; \
	VARIABLE trans7_Actuator_ACTUATOR_TYPE; \
	MENU trans7_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans7_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans7_Actuator_ACTUATOR_ACTION; \
	MENU trans7_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans7_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans7_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans7_Actuator_VIEW_1; \
	MENU trans7_Actuator_VIEW_1_page; \
	MENU trans7_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS7_ACTUATOR_OPTIONAL_B \
	USE_TRANS7_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans7_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans7_Actuator_)
#define USE_TRANS7_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans7_Actuator_)
#define USE_TRANS7_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans7_Actuator_)
#define USE_TRANS7_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans7_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans8_Actuator_block; \
	COLLECTION trans8_Actuator_BLOCK_OBJECT; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans8_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans8_Actuator_ST_REV; \
	MENU trans8_Actuator_ST_REV_page; \
	COMMAND trans8_Actuator_ST_REV_read; \
	VARIABLE trans8_Actuator_TAG_DESC; \
	MENU trans8_Actuator_TAG_DESC_page; \
	COMMAND trans8_Actuator_TAG_DESC_read; \
	COMMAND trans8_Actuator_TAG_DESC_write; \
	VARIABLE trans8_Actuator_STRATEGY; \
	MENU trans8_Actuator_STRATEGY_page; \
	COMMAND trans8_Actuator_STRATEGY_read; \
	COMMAND trans8_Actuator_STRATEGY_write; \
	VARIABLE trans8_Actuator_ALERT_KEY; \
	MENU trans8_Actuator_ALERT_KEY_page; \
	COMMAND trans8_Actuator_ALERT_KEY_read; \
	COMMAND trans8_Actuator_ALERT_KEY_write; \
	VARIABLE trans8_Actuator_TARGET_MODE; \
	MENU trans8_Actuator_TARGET_MODE_page; \
	COMMAND trans8_Actuator_TARGET_MODE_read; \
	COMMAND trans8_Actuator_TARGET_MODE_write; \
	COLLECTION trans8_Actuator_MODE_BLK; \
	VARIABLE trans8_Actuator_MODE_BLK_Actual; \
	VARIABLE trans8_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans8_Actuator_MODE_BLK_Normal; \
	MENU trans8_Actuator_MODE_BLK_page; \
	COMMAND trans8_Actuator_MODE_BLK_read; \
	COLLECTION trans8_Actuator_ALARM_SUM; \
	VARIABLE trans8_Actuator_ALARM_SUM_Current; \
	VARIABLE trans8_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans8_Actuator_ALARM_SUM_Disabled; \
	MENU trans8_Actuator_ALARM_SUM_page; \
	COMMAND trans8_Actuator_ALARM_SUM_read

#define USE_TRANS8_ACTUATOR_MANDATORY_A \
	USE_TRANS8_ACTUATOR_MANDATORY_BOTH; \
	MENU trans8_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS8_ACTUATOR_MANDATORY_B \
	USE_TRANS8_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans8_Actuator_LIN_TYPE; \
	MENU trans8_Actuator_LIN_TYPE_page; \
	COMMAND trans8_Actuator_LIN_TYPE_read; \
	COMMAND trans8_Actuator_LIN_TYPE_write; \
	VARIABLE trans8_Actuator_RATED_TRAVEL; \
	MENU trans8_Actuator_RATED_TRAVEL_page; \
	COMMAND trans8_Actuator_RATED_TRAVEL_read; \
	COMMAND trans8_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans8_Actuator_SELF_CALIB_CMD; \
	MENU trans8_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans8_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans8_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans8_Actuator_SELF_CALIB_STATUS; \
	MENU trans8_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans8_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans8_Actuator_SETP_CUTOFF_DEC; \
	MENU trans8_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans8_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans8_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans8_Actuator_SETP_CUTOFF_INC; \
	MENU trans8_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans8_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans8_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans8_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans8_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans8_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans8_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans8_Actuator_TRAVEL_RATE_DEC; \
	MENU trans8_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans8_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans8_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans8_Actuator_TRAVEL_RATE_INC; \
	MENU trans8_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans8_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans8_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans8_Actuator_POSITIONING_VALUE; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans8_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans8_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans8_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans8_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans8_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans8_Actuator_VALVE_MAN; \
	MENU trans8_Actuator_VALVE_MAN_page; \
	COMMAND trans8_Actuator_VALVE_MAN_read; \
	COMMAND trans8_Actuator_VALVE_MAN_write; \
	VARIABLE trans8_Actuator_VALVE_TYPE; \
	MENU trans8_Actuator_VALVE_TYPE_page; \
	COMMAND trans8_Actuator_VALVE_TYPE_read; \
	COMMAND trans8_Actuator_VALVE_TYPE_write; \
	VARIABLE trans8_Actuator_ACTUATOR_TYPE; \
	MENU trans8_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans8_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans8_Actuator_ACTUATOR_ACTION; \
	MENU trans8_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans8_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans8_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans8_Actuator_VIEW_1; \
	MENU trans8_Actuator_VIEW_1_page; \
	MENU trans8_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS8_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans8_Actuator_ACT_ROT_DIR; \
	MENU trans8_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans8_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans8_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans8_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans8_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans8_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans8_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans8_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans8_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans8_Actuator_ACT_TRAV_TIME; \
	MENU trans8_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans8_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans8_Actuator_ANTI_PUMP_CL; \
	MENU trans8_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans8_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans8_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans8_Actuator_ANTI_PUMP_OP; \
	MENU trans8_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans8_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans8_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans8_Actuator_BREAK_STRENGTH; \
	MENU trans8_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans8_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans8_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans8_Actuator_BYPASS_SETP_CL; \
	MENU trans8_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans8_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans8_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans8_Actuator_BYPASS_SETP_OP; \
	MENU trans8_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans8_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans8_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans8_Actuator_TAB_ENTRY; \
	MENU trans8_Actuator_TAB_ENTRY_page; \
	COMMAND trans8_Actuator_TAB_ENTRY_read; \
	COMMAND trans8_Actuator_TAB_ENTRY_write; \
	COLLECTION trans8_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans8_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans8_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans8_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans8_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans8_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans8_Actuator_TAB_MIN_NUMBER; \
	MENU trans8_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans8_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans8_Actuator_TAB_MAX_NUMBER; \
	MENU trans8_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans8_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans8_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans8_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans8_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans8_Actuator_DEADBAND; \
	MENU trans8_Actuator_DEADBAND_page; \
	COMMAND trans8_Actuator_DEADBAND_read; \
	COMMAND trans8_Actuator_DEADBAND_write; \
	VARIABLE trans8_Actuator_DEVICE_CALIB_DATE; \
	MENU trans8_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans8_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans8_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans8_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans8_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans8_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans8_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans8_Actuator_MAX_TORQUE; \
	MENU trans8_Actuator_MAX_TORQUE_page; \
	COMMAND trans8_Actuator_MAX_TORQUE_read; \
	COMMAND trans8_Actuator_MAX_TORQUE_write; \
	VARIABLE trans8_Actuator_MOTOR_ON_TIME; \
	MENU trans8_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans8_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans8_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans8_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans8_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans8_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans8_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans8_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans8_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans8_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans8_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans8_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans8_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans8_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans8_Actuator_SERVO_GAIN_1; \
	MENU trans8_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans8_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans8_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans8_Actuator_SERVO_RATE_1; \
	MENU trans8_Actuator_SERVO_RATE_1_page; \
	COMMAND trans8_Actuator_SERVO_RATE_1_read; \
	COMMAND trans8_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans8_Actuator_SERVO_RESET_1; \
	MENU trans8_Actuator_SERVO_RESET_1_page; \
	COMMAND trans8_Actuator_SERVO_RESET_1_read; \
	COMMAND trans8_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans8_Actuator_SETP_CUTOFF_MODE; \
	MENU trans8_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans8_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans8_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans8_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans8_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans8_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans8_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans8_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans8_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans8_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans8_Actuator_TORQUE_LIM_CL; \
	MENU trans8_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans8_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans8_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans8_Actuator_TORQUE_LIM_OP; \
	MENU trans8_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans8_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans8_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans8_Actuator_TORQUE_UNIT; \
	MENU trans8_Actuator_TORQUE_UNIT_page; \
	COMMAND trans8_Actuator_TORQUE_UNIT_read; \
	COMMAND trans8_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans8_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans8_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans8_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans8_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans8_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans8_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans8_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans8_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans8_Actuator_VALVE_MAINT_DATE; \
	MENU trans8_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans8_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans8_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans8_Actuator_TAB_OP_CODE; \
	MENU trans8_Actuator_TAB_OP_CODE_page; \
	COMMAND trans8_Actuator_TAB_OP_CODE_read; \
	COMMAND trans8_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans8_Actuator_TAB_STATUS; \
	MENU trans8_Actuator_TAB_STATUS_page; \
	COMMAND trans8_Actuator_TAB_STATUS_read; \
	VARIABLE trans8_Actuator_ACTUATOR_MAN; \
	MENU trans8_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans8_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans8_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans8_Actuator_VALVE_SER_NUM; \
	MENU trans8_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans8_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans8_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans8_Actuator_ACTUATOR_SER_NUM; \
	MENU trans8_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans8_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans8_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans8_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans8_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans8_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans8_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans8_Actuator_ADD_GEAR_MAN; \
	MENU trans8_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans8_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans8_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans8_Actuator_ADD_GEAR_ID; \
	MENU trans8_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans8_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans8_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans8_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans8_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans8_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans8_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans8_Actuator_VIEW_2; \
	MENU trans8_Actuator_VIEW_2_page; \
	COLLECTION trans8_Actuator_VIEW_3; \
	MENU trans8_Actuator_VIEW_3_page; \
	COLLECTION trans8_Actuator_VIEW_4; \
	MENU trans8_Actuator_VIEW_4_page

#define USE_TRANS8_ACTUATOR_OPTIONAL_A \
	USE_TRANS8_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans8_Actuator_LIN_TYPE; \
	MENU trans8_Actuator_LIN_TYPE_page; \
	COMMAND trans8_Actuator_LIN_TYPE_read; \
	COMMAND trans8_Actuator_LIN_TYPE_write; \
	VARIABLE trans8_Actuator_RATED_TRAVEL; \
	MENU trans8_Actuator_RATED_TRAVEL_page; \
	COMMAND trans8_Actuator_RATED_TRAVEL_read; \
	COMMAND trans8_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans8_Actuator_SELF_CALIB_CMD; \
	MENU trans8_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans8_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans8_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans8_Actuator_SELF_CALIB_STATUS; \
	MENU trans8_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans8_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans8_Actuator_SETP_CUTOFF_DEC; \
	MENU trans8_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans8_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans8_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans8_Actuator_SETP_CUTOFF_INC; \
	MENU trans8_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans8_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans8_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans8_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans8_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans8_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans8_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans8_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans8_Actuator_TRAVEL_RATE_DEC; \
	MENU trans8_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans8_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans8_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans8_Actuator_TRAVEL_RATE_INC; \
	MENU trans8_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans8_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans8_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans8_Actuator_POSITIONING_VALUE; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans8_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans8_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans8_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans8_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans8_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans8_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans8_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans8_Actuator_VALVE_MAN; \
	MENU trans8_Actuator_VALVE_MAN_page; \
	COMMAND trans8_Actuator_VALVE_MAN_read; \
	COMMAND trans8_Actuator_VALVE_MAN_write; \
	VARIABLE trans8_Actuator_VALVE_TYPE; \
	MENU trans8_Actuator_VALVE_TYPE_page; \
	COMMAND trans8_Actuator_VALVE_TYPE_read; \
	COMMAND trans8_Actuator_VALVE_TYPE_write; \
	VARIABLE trans8_Actuator_ACTUATOR_TYPE; \
	MENU trans8_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans8_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans8_Actuator_ACTUATOR_ACTION; \
	MENU trans8_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans8_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans8_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans8_Actuator_VIEW_1; \
	MENU trans8_Actuator_VIEW_1_page; \
	MENU trans8_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS8_ACTUATOR_OPTIONAL_B \
	USE_TRANS8_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans8_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans8_Actuator_)
#define USE_TRANS8_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans8_Actuator_)
#define USE_TRANS8_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans8_Actuator_)
#define USE_TRANS8_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans8_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans9_Actuator_block; \
	COLLECTION trans9_Actuator_BLOCK_OBJECT; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans9_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans9_Actuator_ST_REV; \
	MENU trans9_Actuator_ST_REV_page; \
	COMMAND trans9_Actuator_ST_REV_read; \
	VARIABLE trans9_Actuator_TAG_DESC; \
	MENU trans9_Actuator_TAG_DESC_page; \
	COMMAND trans9_Actuator_TAG_DESC_read; \
	COMMAND trans9_Actuator_TAG_DESC_write; \
	VARIABLE trans9_Actuator_STRATEGY; \
	MENU trans9_Actuator_STRATEGY_page; \
	COMMAND trans9_Actuator_STRATEGY_read; \
	COMMAND trans9_Actuator_STRATEGY_write; \
	VARIABLE trans9_Actuator_ALERT_KEY; \
	MENU trans9_Actuator_ALERT_KEY_page; \
	COMMAND trans9_Actuator_ALERT_KEY_read; \
	COMMAND trans9_Actuator_ALERT_KEY_write; \
	VARIABLE trans9_Actuator_TARGET_MODE; \
	MENU trans9_Actuator_TARGET_MODE_page; \
	COMMAND trans9_Actuator_TARGET_MODE_read; \
	COMMAND trans9_Actuator_TARGET_MODE_write; \
	COLLECTION trans9_Actuator_MODE_BLK; \
	VARIABLE trans9_Actuator_MODE_BLK_Actual; \
	VARIABLE trans9_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans9_Actuator_MODE_BLK_Normal; \
	MENU trans9_Actuator_MODE_BLK_page; \
	COMMAND trans9_Actuator_MODE_BLK_read; \
	COLLECTION trans9_Actuator_ALARM_SUM; \
	VARIABLE trans9_Actuator_ALARM_SUM_Current; \
	VARIABLE trans9_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans9_Actuator_ALARM_SUM_Disabled; \
	MENU trans9_Actuator_ALARM_SUM_page; \
	COMMAND trans9_Actuator_ALARM_SUM_read

#define USE_TRANS9_ACTUATOR_MANDATORY_A \
	USE_TRANS9_ACTUATOR_MANDATORY_BOTH; \
	MENU trans9_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS9_ACTUATOR_MANDATORY_B \
	USE_TRANS9_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans9_Actuator_LIN_TYPE; \
	MENU trans9_Actuator_LIN_TYPE_page; \
	COMMAND trans9_Actuator_LIN_TYPE_read; \
	COMMAND trans9_Actuator_LIN_TYPE_write; \
	VARIABLE trans9_Actuator_RATED_TRAVEL; \
	MENU trans9_Actuator_RATED_TRAVEL_page; \
	COMMAND trans9_Actuator_RATED_TRAVEL_read; \
	COMMAND trans9_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans9_Actuator_SELF_CALIB_CMD; \
	MENU trans9_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans9_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans9_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans9_Actuator_SELF_CALIB_STATUS; \
	MENU trans9_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans9_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans9_Actuator_SETP_CUTOFF_DEC; \
	MENU trans9_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans9_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans9_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans9_Actuator_SETP_CUTOFF_INC; \
	MENU trans9_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans9_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans9_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans9_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans9_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans9_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans9_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans9_Actuator_TRAVEL_RATE_DEC; \
	MENU trans9_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans9_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans9_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans9_Actuator_TRAVEL_RATE_INC; \
	MENU trans9_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans9_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans9_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans9_Actuator_POSITIONING_VALUE; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans9_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans9_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans9_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans9_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans9_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans9_Actuator_VALVE_MAN; \
	MENU trans9_Actuator_VALVE_MAN_page; \
	COMMAND trans9_Actuator_VALVE_MAN_read; \
	COMMAND trans9_Actuator_VALVE_MAN_write; \
	VARIABLE trans9_Actuator_VALVE_TYPE; \
	MENU trans9_Actuator_VALVE_TYPE_page; \
	COMMAND trans9_Actuator_VALVE_TYPE_read; \
	COMMAND trans9_Actuator_VALVE_TYPE_write; \
	VARIABLE trans9_Actuator_ACTUATOR_TYPE; \
	MENU trans9_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans9_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans9_Actuator_ACTUATOR_ACTION; \
	MENU trans9_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans9_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans9_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans9_Actuator_VIEW_1; \
	MENU trans9_Actuator_VIEW_1_page; \
	MENU trans9_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS9_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans9_Actuator_ACT_ROT_DIR; \
	MENU trans9_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans9_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans9_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans9_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans9_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans9_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans9_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans9_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans9_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans9_Actuator_ACT_TRAV_TIME; \
	MENU trans9_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans9_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans9_Actuator_ANTI_PUMP_CL; \
	MENU trans9_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans9_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans9_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans9_Actuator_ANTI_PUMP_OP; \
	MENU trans9_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans9_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans9_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans9_Actuator_BREAK_STRENGTH; \
	MENU trans9_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans9_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans9_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans9_Actuator_BYPASS_SETP_CL; \
	MENU trans9_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans9_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans9_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans9_Actuator_BYPASS_SETP_OP; \
	MENU trans9_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans9_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans9_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans9_Actuator_TAB_ENTRY; \
	MENU trans9_Actuator_TAB_ENTRY_page; \
	COMMAND trans9_Actuator_TAB_ENTRY_read; \
	COMMAND trans9_Actuator_TAB_ENTRY_write; \
	COLLECTION trans9_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans9_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans9_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans9_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans9_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans9_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans9_Actuator_TAB_MIN_NUMBER; \
	MENU trans9_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans9_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans9_Actuator_TAB_MAX_NUMBER; \
	MENU trans9_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans9_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans9_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans9_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans9_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans9_Actuator_DEADBAND; \
	MENU trans9_Actuator_DEADBAND_page; \
	COMMAND trans9_Actuator_DEADBAND_read; \
	COMMAND trans9_Actuator_DEADBAND_write; \
	VARIABLE trans9_Actuator_DEVICE_CALIB_DATE; \
	MENU trans9_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans9_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans9_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans9_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans9_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans9_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans9_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans9_Actuator_MAX_TORQUE; \
	MENU trans9_Actuator_MAX_TORQUE_page; \
	COMMAND trans9_Actuator_MAX_TORQUE_read; \
	COMMAND trans9_Actuator_MAX_TORQUE_write; \
	VARIABLE trans9_Actuator_MOTOR_ON_TIME; \
	MENU trans9_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans9_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans9_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans9_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans9_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans9_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans9_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans9_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans9_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans9_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans9_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans9_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans9_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans9_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans9_Actuator_SERVO_GAIN_1; \
	MENU trans9_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans9_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans9_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans9_Actuator_SERVO_RATE_1; \
	MENU trans9_Actuator_SERVO_RATE_1_page; \
	COMMAND trans9_Actuator_SERVO_RATE_1_read; \
	COMMAND trans9_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans9_Actuator_SERVO_RESET_1; \
	MENU trans9_Actuator_SERVO_RESET_1_page; \
	COMMAND trans9_Actuator_SERVO_RESET_1_read; \
	COMMAND trans9_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans9_Actuator_SETP_CUTOFF_MODE; \
	MENU trans9_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans9_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans9_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans9_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans9_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans9_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans9_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans9_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans9_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans9_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans9_Actuator_TORQUE_LIM_CL; \
	MENU trans9_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans9_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans9_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans9_Actuator_TORQUE_LIM_OP; \
	MENU trans9_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans9_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans9_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans9_Actuator_TORQUE_UNIT; \
	MENU trans9_Actuator_TORQUE_UNIT_page; \
	COMMAND trans9_Actuator_TORQUE_UNIT_read; \
	COMMAND trans9_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans9_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans9_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans9_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans9_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans9_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans9_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans9_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans9_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans9_Actuator_VALVE_MAINT_DATE; \
	MENU trans9_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans9_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans9_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans9_Actuator_TAB_OP_CODE; \
	MENU trans9_Actuator_TAB_OP_CODE_page; \
	COMMAND trans9_Actuator_TAB_OP_CODE_read; \
	COMMAND trans9_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans9_Actuator_TAB_STATUS; \
	MENU trans9_Actuator_TAB_STATUS_page; \
	COMMAND trans9_Actuator_TAB_STATUS_read; \
	VARIABLE trans9_Actuator_ACTUATOR_MAN; \
	MENU trans9_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans9_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans9_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans9_Actuator_VALVE_SER_NUM; \
	MENU trans9_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans9_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans9_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans9_Actuator_ACTUATOR_SER_NUM; \
	MENU trans9_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans9_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans9_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans9_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans9_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans9_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans9_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans9_Actuator_ADD_GEAR_MAN; \
	MENU trans9_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans9_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans9_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans9_Actuator_ADD_GEAR_ID; \
	MENU trans9_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans9_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans9_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans9_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans9_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans9_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans9_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans9_Actuator_VIEW_2; \
	MENU trans9_Actuator_VIEW_2_page; \
	COLLECTION trans9_Actuator_VIEW_3; \
	MENU trans9_Actuator_VIEW_3_page; \
	COLLECTION trans9_Actuator_VIEW_4; \
	MENU trans9_Actuator_VIEW_4_page

#define USE_TRANS9_ACTUATOR_OPTIONAL_A \
	USE_TRANS9_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans9_Actuator_LIN_TYPE; \
	MENU trans9_Actuator_LIN_TYPE_page; \
	COMMAND trans9_Actuator_LIN_TYPE_read; \
	COMMAND trans9_Actuator_LIN_TYPE_write; \
	VARIABLE trans9_Actuator_RATED_TRAVEL; \
	MENU trans9_Actuator_RATED_TRAVEL_page; \
	COMMAND trans9_Actuator_RATED_TRAVEL_read; \
	COMMAND trans9_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans9_Actuator_SELF_CALIB_CMD; \
	MENU trans9_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans9_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans9_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans9_Actuator_SELF_CALIB_STATUS; \
	MENU trans9_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans9_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans9_Actuator_SETP_CUTOFF_DEC; \
	MENU trans9_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans9_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans9_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans9_Actuator_SETP_CUTOFF_INC; \
	MENU trans9_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans9_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans9_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans9_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans9_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans9_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans9_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans9_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans9_Actuator_TRAVEL_RATE_DEC; \
	MENU trans9_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans9_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans9_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans9_Actuator_TRAVEL_RATE_INC; \
	MENU trans9_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans9_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans9_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans9_Actuator_POSITIONING_VALUE; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans9_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans9_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans9_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans9_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans9_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans9_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans9_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans9_Actuator_VALVE_MAN; \
	MENU trans9_Actuator_VALVE_MAN_page; \
	COMMAND trans9_Actuator_VALVE_MAN_read; \
	COMMAND trans9_Actuator_VALVE_MAN_write; \
	VARIABLE trans9_Actuator_VALVE_TYPE; \
	MENU trans9_Actuator_VALVE_TYPE_page; \
	COMMAND trans9_Actuator_VALVE_TYPE_read; \
	COMMAND trans9_Actuator_VALVE_TYPE_write; \
	VARIABLE trans9_Actuator_ACTUATOR_TYPE; \
	MENU trans9_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans9_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans9_Actuator_ACTUATOR_ACTION; \
	MENU trans9_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans9_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans9_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans9_Actuator_VIEW_1; \
	MENU trans9_Actuator_VIEW_1_page; \
	MENU trans9_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS9_ACTUATOR_OPTIONAL_B \
	USE_TRANS9_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans9_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans9_Actuator_)
#define USE_TRANS9_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans9_Actuator_)
#define USE_TRANS9_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans9_Actuator_)
#define USE_TRANS9_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans9_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans10_Actuator_block; \
	COLLECTION trans10_Actuator_BLOCK_OBJECT; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans10_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans10_Actuator_ST_REV; \
	MENU trans10_Actuator_ST_REV_page; \
	COMMAND trans10_Actuator_ST_REV_read; \
	VARIABLE trans10_Actuator_TAG_DESC; \
	MENU trans10_Actuator_TAG_DESC_page; \
	COMMAND trans10_Actuator_TAG_DESC_read; \
	COMMAND trans10_Actuator_TAG_DESC_write; \
	VARIABLE trans10_Actuator_STRATEGY; \
	MENU trans10_Actuator_STRATEGY_page; \
	COMMAND trans10_Actuator_STRATEGY_read; \
	COMMAND trans10_Actuator_STRATEGY_write; \
	VARIABLE trans10_Actuator_ALERT_KEY; \
	MENU trans10_Actuator_ALERT_KEY_page; \
	COMMAND trans10_Actuator_ALERT_KEY_read; \
	COMMAND trans10_Actuator_ALERT_KEY_write; \
	VARIABLE trans10_Actuator_TARGET_MODE; \
	MENU trans10_Actuator_TARGET_MODE_page; \
	COMMAND trans10_Actuator_TARGET_MODE_read; \
	COMMAND trans10_Actuator_TARGET_MODE_write; \
	COLLECTION trans10_Actuator_MODE_BLK; \
	VARIABLE trans10_Actuator_MODE_BLK_Actual; \
	VARIABLE trans10_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans10_Actuator_MODE_BLK_Normal; \
	MENU trans10_Actuator_MODE_BLK_page; \
	COMMAND trans10_Actuator_MODE_BLK_read; \
	COLLECTION trans10_Actuator_ALARM_SUM; \
	VARIABLE trans10_Actuator_ALARM_SUM_Current; \
	VARIABLE trans10_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans10_Actuator_ALARM_SUM_Disabled; \
	MENU trans10_Actuator_ALARM_SUM_page; \
	COMMAND trans10_Actuator_ALARM_SUM_read

#define USE_TRANS10_ACTUATOR_MANDATORY_A \
	USE_TRANS10_ACTUATOR_MANDATORY_BOTH; \
	MENU trans10_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS10_ACTUATOR_MANDATORY_B \
	USE_TRANS10_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans10_Actuator_LIN_TYPE; \
	MENU trans10_Actuator_LIN_TYPE_page; \
	COMMAND trans10_Actuator_LIN_TYPE_read; \
	COMMAND trans10_Actuator_LIN_TYPE_write; \
	VARIABLE trans10_Actuator_RATED_TRAVEL; \
	MENU trans10_Actuator_RATED_TRAVEL_page; \
	COMMAND trans10_Actuator_RATED_TRAVEL_read; \
	COMMAND trans10_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans10_Actuator_SELF_CALIB_CMD; \
	MENU trans10_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans10_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans10_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans10_Actuator_SELF_CALIB_STATUS; \
	MENU trans10_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans10_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans10_Actuator_SETP_CUTOFF_DEC; \
	MENU trans10_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans10_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans10_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans10_Actuator_SETP_CUTOFF_INC; \
	MENU trans10_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans10_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans10_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans10_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans10_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans10_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans10_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans10_Actuator_TRAVEL_RATE_DEC; \
	MENU trans10_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans10_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans10_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans10_Actuator_TRAVEL_RATE_INC; \
	MENU trans10_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans10_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans10_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans10_Actuator_POSITIONING_VALUE; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans10_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans10_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans10_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans10_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans10_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans10_Actuator_VALVE_MAN; \
	MENU trans10_Actuator_VALVE_MAN_page; \
	COMMAND trans10_Actuator_VALVE_MAN_read; \
	COMMAND trans10_Actuator_VALVE_MAN_write; \
	VARIABLE trans10_Actuator_VALVE_TYPE; \
	MENU trans10_Actuator_VALVE_TYPE_page; \
	COMMAND trans10_Actuator_VALVE_TYPE_read; \
	COMMAND trans10_Actuator_VALVE_TYPE_write; \
	VARIABLE trans10_Actuator_ACTUATOR_TYPE; \
	MENU trans10_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans10_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans10_Actuator_ACTUATOR_ACTION; \
	MENU trans10_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans10_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans10_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans10_Actuator_VIEW_1; \
	MENU trans10_Actuator_VIEW_1_page; \
	MENU trans10_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS10_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans10_Actuator_ACT_ROT_DIR; \
	MENU trans10_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans10_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans10_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans10_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans10_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans10_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans10_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans10_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans10_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans10_Actuator_ACT_TRAV_TIME; \
	MENU trans10_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans10_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans10_Actuator_ANTI_PUMP_CL; \
	MENU trans10_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans10_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans10_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans10_Actuator_ANTI_PUMP_OP; \
	MENU trans10_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans10_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans10_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans10_Actuator_BREAK_STRENGTH; \
	MENU trans10_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans10_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans10_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans10_Actuator_BYPASS_SETP_CL; \
	MENU trans10_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans10_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans10_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans10_Actuator_BYPASS_SETP_OP; \
	MENU trans10_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans10_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans10_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans10_Actuator_TAB_ENTRY; \
	MENU trans10_Actuator_TAB_ENTRY_page; \
	COMMAND trans10_Actuator_TAB_ENTRY_read; \
	COMMAND trans10_Actuator_TAB_ENTRY_write; \
	COLLECTION trans10_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans10_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans10_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans10_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans10_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans10_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans10_Actuator_TAB_MIN_NUMBER; \
	MENU trans10_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans10_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans10_Actuator_TAB_MAX_NUMBER; \
	MENU trans10_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans10_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans10_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans10_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans10_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans10_Actuator_DEADBAND; \
	MENU trans10_Actuator_DEADBAND_page; \
	COMMAND trans10_Actuator_DEADBAND_read; \
	COMMAND trans10_Actuator_DEADBAND_write; \
	VARIABLE trans10_Actuator_DEVICE_CALIB_DATE; \
	MENU trans10_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans10_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans10_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans10_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans10_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans10_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans10_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans10_Actuator_MAX_TORQUE; \
	MENU trans10_Actuator_MAX_TORQUE_page; \
	COMMAND trans10_Actuator_MAX_TORQUE_read; \
	COMMAND trans10_Actuator_MAX_TORQUE_write; \
	VARIABLE trans10_Actuator_MOTOR_ON_TIME; \
	MENU trans10_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans10_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans10_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans10_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans10_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans10_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans10_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans10_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans10_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans10_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans10_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans10_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans10_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans10_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans10_Actuator_SERVO_GAIN_1; \
	MENU trans10_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans10_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans10_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans10_Actuator_SERVO_RATE_1; \
	MENU trans10_Actuator_SERVO_RATE_1_page; \
	COMMAND trans10_Actuator_SERVO_RATE_1_read; \
	COMMAND trans10_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans10_Actuator_SERVO_RESET_1; \
	MENU trans10_Actuator_SERVO_RESET_1_page; \
	COMMAND trans10_Actuator_SERVO_RESET_1_read; \
	COMMAND trans10_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans10_Actuator_SETP_CUTOFF_MODE; \
	MENU trans10_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans10_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans10_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans10_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans10_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans10_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans10_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans10_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans10_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans10_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans10_Actuator_TORQUE_LIM_CL; \
	MENU trans10_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans10_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans10_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans10_Actuator_TORQUE_LIM_OP; \
	MENU trans10_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans10_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans10_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans10_Actuator_TORQUE_UNIT; \
	MENU trans10_Actuator_TORQUE_UNIT_page; \
	COMMAND trans10_Actuator_TORQUE_UNIT_read; \
	COMMAND trans10_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans10_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans10_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans10_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans10_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans10_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans10_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans10_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans10_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans10_Actuator_VALVE_MAINT_DATE; \
	MENU trans10_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans10_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans10_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans10_Actuator_TAB_OP_CODE; \
	MENU trans10_Actuator_TAB_OP_CODE_page; \
	COMMAND trans10_Actuator_TAB_OP_CODE_read; \
	COMMAND trans10_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans10_Actuator_TAB_STATUS; \
	MENU trans10_Actuator_TAB_STATUS_page; \
	COMMAND trans10_Actuator_TAB_STATUS_read; \
	VARIABLE trans10_Actuator_ACTUATOR_MAN; \
	MENU trans10_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans10_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans10_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans10_Actuator_VALVE_SER_NUM; \
	MENU trans10_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans10_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans10_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans10_Actuator_ACTUATOR_SER_NUM; \
	MENU trans10_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans10_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans10_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans10_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans10_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans10_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans10_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans10_Actuator_ADD_GEAR_MAN; \
	MENU trans10_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans10_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans10_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans10_Actuator_ADD_GEAR_ID; \
	MENU trans10_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans10_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans10_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans10_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans10_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans10_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans10_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans10_Actuator_VIEW_2; \
	MENU trans10_Actuator_VIEW_2_page; \
	COLLECTION trans10_Actuator_VIEW_3; \
	MENU trans10_Actuator_VIEW_3_page; \
	COLLECTION trans10_Actuator_VIEW_4; \
	MENU trans10_Actuator_VIEW_4_page

#define USE_TRANS10_ACTUATOR_OPTIONAL_A \
	USE_TRANS10_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans10_Actuator_LIN_TYPE; \
	MENU trans10_Actuator_LIN_TYPE_page; \
	COMMAND trans10_Actuator_LIN_TYPE_read; \
	COMMAND trans10_Actuator_LIN_TYPE_write; \
	VARIABLE trans10_Actuator_RATED_TRAVEL; \
	MENU trans10_Actuator_RATED_TRAVEL_page; \
	COMMAND trans10_Actuator_RATED_TRAVEL_read; \
	COMMAND trans10_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans10_Actuator_SELF_CALIB_CMD; \
	MENU trans10_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans10_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans10_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans10_Actuator_SELF_CALIB_STATUS; \
	MENU trans10_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans10_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans10_Actuator_SETP_CUTOFF_DEC; \
	MENU trans10_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans10_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans10_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans10_Actuator_SETP_CUTOFF_INC; \
	MENU trans10_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans10_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans10_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans10_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans10_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans10_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans10_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans10_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans10_Actuator_TRAVEL_RATE_DEC; \
	MENU trans10_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans10_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans10_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans10_Actuator_TRAVEL_RATE_INC; \
	MENU trans10_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans10_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans10_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans10_Actuator_POSITIONING_VALUE; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans10_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans10_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans10_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans10_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans10_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans10_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans10_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans10_Actuator_VALVE_MAN; \
	MENU trans10_Actuator_VALVE_MAN_page; \
	COMMAND trans10_Actuator_VALVE_MAN_read; \
	COMMAND trans10_Actuator_VALVE_MAN_write; \
	VARIABLE trans10_Actuator_VALVE_TYPE; \
	MENU trans10_Actuator_VALVE_TYPE_page; \
	COMMAND trans10_Actuator_VALVE_TYPE_read; \
	COMMAND trans10_Actuator_VALVE_TYPE_write; \
	VARIABLE trans10_Actuator_ACTUATOR_TYPE; \
	MENU trans10_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans10_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans10_Actuator_ACTUATOR_ACTION; \
	MENU trans10_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans10_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans10_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans10_Actuator_VIEW_1; \
	MENU trans10_Actuator_VIEW_1_page; \
	MENU trans10_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS10_ACTUATOR_OPTIONAL_B \
	USE_TRANS10_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans10_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans10_Actuator_)
#define USE_TRANS10_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans10_Actuator_)
#define USE_TRANS10_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans10_Actuator_)
#define USE_TRANS10_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans10_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans11_Actuator_block; \
	COLLECTION trans11_Actuator_BLOCK_OBJECT; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans11_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans11_Actuator_ST_REV; \
	MENU trans11_Actuator_ST_REV_page; \
	COMMAND trans11_Actuator_ST_REV_read; \
	VARIABLE trans11_Actuator_TAG_DESC; \
	MENU trans11_Actuator_TAG_DESC_page; \
	COMMAND trans11_Actuator_TAG_DESC_read; \
	COMMAND trans11_Actuator_TAG_DESC_write; \
	VARIABLE trans11_Actuator_STRATEGY; \
	MENU trans11_Actuator_STRATEGY_page; \
	COMMAND trans11_Actuator_STRATEGY_read; \
	COMMAND trans11_Actuator_STRATEGY_write; \
	VARIABLE trans11_Actuator_ALERT_KEY; \
	MENU trans11_Actuator_ALERT_KEY_page; \
	COMMAND trans11_Actuator_ALERT_KEY_read; \
	COMMAND trans11_Actuator_ALERT_KEY_write; \
	VARIABLE trans11_Actuator_TARGET_MODE; \
	MENU trans11_Actuator_TARGET_MODE_page; \
	COMMAND trans11_Actuator_TARGET_MODE_read; \
	COMMAND trans11_Actuator_TARGET_MODE_write; \
	COLLECTION trans11_Actuator_MODE_BLK; \
	VARIABLE trans11_Actuator_MODE_BLK_Actual; \
	VARIABLE trans11_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans11_Actuator_MODE_BLK_Normal; \
	MENU trans11_Actuator_MODE_BLK_page; \
	COMMAND trans11_Actuator_MODE_BLK_read; \
	COLLECTION trans11_Actuator_ALARM_SUM; \
	VARIABLE trans11_Actuator_ALARM_SUM_Current; \
	VARIABLE trans11_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans11_Actuator_ALARM_SUM_Disabled; \
	MENU trans11_Actuator_ALARM_SUM_page; \
	COMMAND trans11_Actuator_ALARM_SUM_read

#define USE_TRANS11_ACTUATOR_MANDATORY_A \
	USE_TRANS11_ACTUATOR_MANDATORY_BOTH; \
	MENU trans11_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS11_ACTUATOR_MANDATORY_B \
	USE_TRANS11_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans11_Actuator_LIN_TYPE; \
	MENU trans11_Actuator_LIN_TYPE_page; \
	COMMAND trans11_Actuator_LIN_TYPE_read; \
	COMMAND trans11_Actuator_LIN_TYPE_write; \
	VARIABLE trans11_Actuator_RATED_TRAVEL; \
	MENU trans11_Actuator_RATED_TRAVEL_page; \
	COMMAND trans11_Actuator_RATED_TRAVEL_read; \
	COMMAND trans11_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans11_Actuator_SELF_CALIB_CMD; \
	MENU trans11_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans11_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans11_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans11_Actuator_SELF_CALIB_STATUS; \
	MENU trans11_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans11_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans11_Actuator_SETP_CUTOFF_DEC; \
	MENU trans11_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans11_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans11_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans11_Actuator_SETP_CUTOFF_INC; \
	MENU trans11_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans11_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans11_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans11_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans11_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans11_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans11_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans11_Actuator_TRAVEL_RATE_DEC; \
	MENU trans11_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans11_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans11_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans11_Actuator_TRAVEL_RATE_INC; \
	MENU trans11_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans11_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans11_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans11_Actuator_POSITIONING_VALUE; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans11_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans11_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans11_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans11_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans11_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans11_Actuator_VALVE_MAN; \
	MENU trans11_Actuator_VALVE_MAN_page; \
	COMMAND trans11_Actuator_VALVE_MAN_read; \
	COMMAND trans11_Actuator_VALVE_MAN_write; \
	VARIABLE trans11_Actuator_VALVE_TYPE; \
	MENU trans11_Actuator_VALVE_TYPE_page; \
	COMMAND trans11_Actuator_VALVE_TYPE_read; \
	COMMAND trans11_Actuator_VALVE_TYPE_write; \
	VARIABLE trans11_Actuator_ACTUATOR_TYPE; \
	MENU trans11_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans11_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans11_Actuator_ACTUATOR_ACTION; \
	MENU trans11_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans11_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans11_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans11_Actuator_VIEW_1; \
	MENU trans11_Actuator_VIEW_1_page; \
	MENU trans11_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS11_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans11_Actuator_ACT_ROT_DIR; \
	MENU trans11_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans11_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans11_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans11_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans11_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans11_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans11_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans11_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans11_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans11_Actuator_ACT_TRAV_TIME; \
	MENU trans11_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans11_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans11_Actuator_ANTI_PUMP_CL; \
	MENU trans11_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans11_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans11_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans11_Actuator_ANTI_PUMP_OP; \
	MENU trans11_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans11_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans11_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans11_Actuator_BREAK_STRENGTH; \
	MENU trans11_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans11_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans11_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans11_Actuator_BYPASS_SETP_CL; \
	MENU trans11_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans11_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans11_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans11_Actuator_BYPASS_SETP_OP; \
	MENU trans11_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans11_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans11_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans11_Actuator_TAB_ENTRY; \
	MENU trans11_Actuator_TAB_ENTRY_page; \
	COMMAND trans11_Actuator_TAB_ENTRY_read; \
	COMMAND trans11_Actuator_TAB_ENTRY_write; \
	COLLECTION trans11_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans11_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans11_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans11_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans11_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans11_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans11_Actuator_TAB_MIN_NUMBER; \
	MENU trans11_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans11_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans11_Actuator_TAB_MAX_NUMBER; \
	MENU trans11_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans11_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans11_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans11_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans11_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans11_Actuator_DEADBAND; \
	MENU trans11_Actuator_DEADBAND_page; \
	COMMAND trans11_Actuator_DEADBAND_read; \
	COMMAND trans11_Actuator_DEADBAND_write; \
	VARIABLE trans11_Actuator_DEVICE_CALIB_DATE; \
	MENU trans11_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans11_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans11_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans11_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans11_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans11_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans11_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans11_Actuator_MAX_TORQUE; \
	MENU trans11_Actuator_MAX_TORQUE_page; \
	COMMAND trans11_Actuator_MAX_TORQUE_read; \
	COMMAND trans11_Actuator_MAX_TORQUE_write; \
	VARIABLE trans11_Actuator_MOTOR_ON_TIME; \
	MENU trans11_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans11_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans11_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans11_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans11_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans11_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans11_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans11_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans11_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans11_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans11_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans11_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans11_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans11_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans11_Actuator_SERVO_GAIN_1; \
	MENU trans11_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans11_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans11_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans11_Actuator_SERVO_RATE_1; \
	MENU trans11_Actuator_SERVO_RATE_1_page; \
	COMMAND trans11_Actuator_SERVO_RATE_1_read; \
	COMMAND trans11_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans11_Actuator_SERVO_RESET_1; \
	MENU trans11_Actuator_SERVO_RESET_1_page; \
	COMMAND trans11_Actuator_SERVO_RESET_1_read; \
	COMMAND trans11_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans11_Actuator_SETP_CUTOFF_MODE; \
	MENU trans11_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans11_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans11_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans11_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans11_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans11_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans11_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans11_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans11_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans11_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans11_Actuator_TORQUE_LIM_CL; \
	MENU trans11_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans11_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans11_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans11_Actuator_TORQUE_LIM_OP; \
	MENU trans11_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans11_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans11_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans11_Actuator_TORQUE_UNIT; \
	MENU trans11_Actuator_TORQUE_UNIT_page; \
	COMMAND trans11_Actuator_TORQUE_UNIT_read; \
	COMMAND trans11_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans11_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans11_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans11_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans11_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans11_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans11_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans11_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans11_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans11_Actuator_VALVE_MAINT_DATE; \
	MENU trans11_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans11_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans11_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans11_Actuator_TAB_OP_CODE; \
	MENU trans11_Actuator_TAB_OP_CODE_page; \
	COMMAND trans11_Actuator_TAB_OP_CODE_read; \
	COMMAND trans11_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans11_Actuator_TAB_STATUS; \
	MENU trans11_Actuator_TAB_STATUS_page; \
	COMMAND trans11_Actuator_TAB_STATUS_read; \
	VARIABLE trans11_Actuator_ACTUATOR_MAN; \
	MENU trans11_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans11_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans11_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans11_Actuator_VALVE_SER_NUM; \
	MENU trans11_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans11_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans11_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans11_Actuator_ACTUATOR_SER_NUM; \
	MENU trans11_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans11_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans11_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans11_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans11_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans11_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans11_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans11_Actuator_ADD_GEAR_MAN; \
	MENU trans11_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans11_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans11_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans11_Actuator_ADD_GEAR_ID; \
	MENU trans11_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans11_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans11_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans11_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans11_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans11_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans11_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans11_Actuator_VIEW_2; \
	MENU trans11_Actuator_VIEW_2_page; \
	COLLECTION trans11_Actuator_VIEW_3; \
	MENU trans11_Actuator_VIEW_3_page; \
	COLLECTION trans11_Actuator_VIEW_4; \
	MENU trans11_Actuator_VIEW_4_page

#define USE_TRANS11_ACTUATOR_OPTIONAL_A \
	USE_TRANS11_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans11_Actuator_LIN_TYPE; \
	MENU trans11_Actuator_LIN_TYPE_page; \
	COMMAND trans11_Actuator_LIN_TYPE_read; \
	COMMAND trans11_Actuator_LIN_TYPE_write; \
	VARIABLE trans11_Actuator_RATED_TRAVEL; \
	MENU trans11_Actuator_RATED_TRAVEL_page; \
	COMMAND trans11_Actuator_RATED_TRAVEL_read; \
	COMMAND trans11_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans11_Actuator_SELF_CALIB_CMD; \
	MENU trans11_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans11_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans11_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans11_Actuator_SELF_CALIB_STATUS; \
	MENU trans11_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans11_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans11_Actuator_SETP_CUTOFF_DEC; \
	MENU trans11_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans11_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans11_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans11_Actuator_SETP_CUTOFF_INC; \
	MENU trans11_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans11_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans11_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans11_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans11_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans11_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans11_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans11_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans11_Actuator_TRAVEL_RATE_DEC; \
	MENU trans11_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans11_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans11_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans11_Actuator_TRAVEL_RATE_INC; \
	MENU trans11_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans11_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans11_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans11_Actuator_POSITIONING_VALUE; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans11_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans11_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans11_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans11_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans11_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans11_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans11_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans11_Actuator_VALVE_MAN; \
	MENU trans11_Actuator_VALVE_MAN_page; \
	COMMAND trans11_Actuator_VALVE_MAN_read; \
	COMMAND trans11_Actuator_VALVE_MAN_write; \
	VARIABLE trans11_Actuator_VALVE_TYPE; \
	MENU trans11_Actuator_VALVE_TYPE_page; \
	COMMAND trans11_Actuator_VALVE_TYPE_read; \
	COMMAND trans11_Actuator_VALVE_TYPE_write; \
	VARIABLE trans11_Actuator_ACTUATOR_TYPE; \
	MENU trans11_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans11_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans11_Actuator_ACTUATOR_ACTION; \
	MENU trans11_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans11_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans11_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans11_Actuator_VIEW_1; \
	MENU trans11_Actuator_VIEW_1_page; \
	MENU trans11_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS11_ACTUATOR_OPTIONAL_B \
	USE_TRANS11_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans11_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans11_Actuator_)
#define USE_TRANS11_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans11_Actuator_)
#define USE_TRANS11_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans11_Actuator_)
#define USE_TRANS11_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans11_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans12_Actuator_block; \
	COLLECTION trans12_Actuator_BLOCK_OBJECT; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans12_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans12_Actuator_ST_REV; \
	MENU trans12_Actuator_ST_REV_page; \
	COMMAND trans12_Actuator_ST_REV_read; \
	VARIABLE trans12_Actuator_TAG_DESC; \
	MENU trans12_Actuator_TAG_DESC_page; \
	COMMAND trans12_Actuator_TAG_DESC_read; \
	COMMAND trans12_Actuator_TAG_DESC_write; \
	VARIABLE trans12_Actuator_STRATEGY; \
	MENU trans12_Actuator_STRATEGY_page; \
	COMMAND trans12_Actuator_STRATEGY_read; \
	COMMAND trans12_Actuator_STRATEGY_write; \
	VARIABLE trans12_Actuator_ALERT_KEY; \
	MENU trans12_Actuator_ALERT_KEY_page; \
	COMMAND trans12_Actuator_ALERT_KEY_read; \
	COMMAND trans12_Actuator_ALERT_KEY_write; \
	VARIABLE trans12_Actuator_TARGET_MODE; \
	MENU trans12_Actuator_TARGET_MODE_page; \
	COMMAND trans12_Actuator_TARGET_MODE_read; \
	COMMAND trans12_Actuator_TARGET_MODE_write; \
	COLLECTION trans12_Actuator_MODE_BLK; \
	VARIABLE trans12_Actuator_MODE_BLK_Actual; \
	VARIABLE trans12_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans12_Actuator_MODE_BLK_Normal; \
	MENU trans12_Actuator_MODE_BLK_page; \
	COMMAND trans12_Actuator_MODE_BLK_read; \
	COLLECTION trans12_Actuator_ALARM_SUM; \
	VARIABLE trans12_Actuator_ALARM_SUM_Current; \
	VARIABLE trans12_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans12_Actuator_ALARM_SUM_Disabled; \
	MENU trans12_Actuator_ALARM_SUM_page; \
	COMMAND trans12_Actuator_ALARM_SUM_read

#define USE_TRANS12_ACTUATOR_MANDATORY_A \
	USE_TRANS12_ACTUATOR_MANDATORY_BOTH; \
	MENU trans12_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS12_ACTUATOR_MANDATORY_B \
	USE_TRANS12_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans12_Actuator_LIN_TYPE; \
	MENU trans12_Actuator_LIN_TYPE_page; \
	COMMAND trans12_Actuator_LIN_TYPE_read; \
	COMMAND trans12_Actuator_LIN_TYPE_write; \
	VARIABLE trans12_Actuator_RATED_TRAVEL; \
	MENU trans12_Actuator_RATED_TRAVEL_page; \
	COMMAND trans12_Actuator_RATED_TRAVEL_read; \
	COMMAND trans12_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans12_Actuator_SELF_CALIB_CMD; \
	MENU trans12_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans12_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans12_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans12_Actuator_SELF_CALIB_STATUS; \
	MENU trans12_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans12_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans12_Actuator_SETP_CUTOFF_DEC; \
	MENU trans12_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans12_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans12_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans12_Actuator_SETP_CUTOFF_INC; \
	MENU trans12_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans12_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans12_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans12_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans12_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans12_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans12_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans12_Actuator_TRAVEL_RATE_DEC; \
	MENU trans12_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans12_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans12_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans12_Actuator_TRAVEL_RATE_INC; \
	MENU trans12_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans12_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans12_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans12_Actuator_POSITIONING_VALUE; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans12_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans12_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans12_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans12_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans12_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans12_Actuator_VALVE_MAN; \
	MENU trans12_Actuator_VALVE_MAN_page; \
	COMMAND trans12_Actuator_VALVE_MAN_read; \
	COMMAND trans12_Actuator_VALVE_MAN_write; \
	VARIABLE trans12_Actuator_VALVE_TYPE; \
	MENU trans12_Actuator_VALVE_TYPE_page; \
	COMMAND trans12_Actuator_VALVE_TYPE_read; \
	COMMAND trans12_Actuator_VALVE_TYPE_write; \
	VARIABLE trans12_Actuator_ACTUATOR_TYPE; \
	MENU trans12_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans12_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans12_Actuator_ACTUATOR_ACTION; \
	MENU trans12_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans12_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans12_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans12_Actuator_VIEW_1; \
	MENU trans12_Actuator_VIEW_1_page; \
	MENU trans12_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS12_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans12_Actuator_ACT_ROT_DIR; \
	MENU trans12_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans12_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans12_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans12_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans12_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans12_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans12_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans12_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans12_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans12_Actuator_ACT_TRAV_TIME; \
	MENU trans12_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans12_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans12_Actuator_ANTI_PUMP_CL; \
	MENU trans12_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans12_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans12_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans12_Actuator_ANTI_PUMP_OP; \
	MENU trans12_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans12_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans12_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans12_Actuator_BREAK_STRENGTH; \
	MENU trans12_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans12_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans12_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans12_Actuator_BYPASS_SETP_CL; \
	MENU trans12_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans12_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans12_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans12_Actuator_BYPASS_SETP_OP; \
	MENU trans12_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans12_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans12_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans12_Actuator_TAB_ENTRY; \
	MENU trans12_Actuator_TAB_ENTRY_page; \
	COMMAND trans12_Actuator_TAB_ENTRY_read; \
	COMMAND trans12_Actuator_TAB_ENTRY_write; \
	COLLECTION trans12_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans12_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans12_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans12_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans12_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans12_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans12_Actuator_TAB_MIN_NUMBER; \
	MENU trans12_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans12_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans12_Actuator_TAB_MAX_NUMBER; \
	MENU trans12_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans12_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans12_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans12_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans12_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans12_Actuator_DEADBAND; \
	MENU trans12_Actuator_DEADBAND_page; \
	COMMAND trans12_Actuator_DEADBAND_read; \
	COMMAND trans12_Actuator_DEADBAND_write; \
	VARIABLE trans12_Actuator_DEVICE_CALIB_DATE; \
	MENU trans12_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans12_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans12_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans12_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans12_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans12_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans12_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans12_Actuator_MAX_TORQUE; \
	MENU trans12_Actuator_MAX_TORQUE_page; \
	COMMAND trans12_Actuator_MAX_TORQUE_read; \
	COMMAND trans12_Actuator_MAX_TORQUE_write; \
	VARIABLE trans12_Actuator_MOTOR_ON_TIME; \
	MENU trans12_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans12_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans12_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans12_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans12_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans12_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans12_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans12_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans12_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans12_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans12_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans12_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans12_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans12_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans12_Actuator_SERVO_GAIN_1; \
	MENU trans12_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans12_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans12_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans12_Actuator_SERVO_RATE_1; \
	MENU trans12_Actuator_SERVO_RATE_1_page; \
	COMMAND trans12_Actuator_SERVO_RATE_1_read; \
	COMMAND trans12_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans12_Actuator_SERVO_RESET_1; \
	MENU trans12_Actuator_SERVO_RESET_1_page; \
	COMMAND trans12_Actuator_SERVO_RESET_1_read; \
	COMMAND trans12_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans12_Actuator_SETP_CUTOFF_MODE; \
	MENU trans12_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans12_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans12_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans12_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans12_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans12_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans12_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans12_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans12_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans12_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans12_Actuator_TORQUE_LIM_CL; \
	MENU trans12_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans12_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans12_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans12_Actuator_TORQUE_LIM_OP; \
	MENU trans12_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans12_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans12_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans12_Actuator_TORQUE_UNIT; \
	MENU trans12_Actuator_TORQUE_UNIT_page; \
	COMMAND trans12_Actuator_TORQUE_UNIT_read; \
	COMMAND trans12_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans12_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans12_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans12_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans12_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans12_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans12_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans12_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans12_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans12_Actuator_VALVE_MAINT_DATE; \
	MENU trans12_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans12_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans12_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans12_Actuator_TAB_OP_CODE; \
	MENU trans12_Actuator_TAB_OP_CODE_page; \
	COMMAND trans12_Actuator_TAB_OP_CODE_read; \
	COMMAND trans12_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans12_Actuator_TAB_STATUS; \
	MENU trans12_Actuator_TAB_STATUS_page; \
	COMMAND trans12_Actuator_TAB_STATUS_read; \
	VARIABLE trans12_Actuator_ACTUATOR_MAN; \
	MENU trans12_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans12_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans12_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans12_Actuator_VALVE_SER_NUM; \
	MENU trans12_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans12_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans12_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans12_Actuator_ACTUATOR_SER_NUM; \
	MENU trans12_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans12_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans12_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans12_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans12_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans12_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans12_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans12_Actuator_ADD_GEAR_MAN; \
	MENU trans12_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans12_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans12_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans12_Actuator_ADD_GEAR_ID; \
	MENU trans12_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans12_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans12_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans12_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans12_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans12_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans12_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans12_Actuator_VIEW_2; \
	MENU trans12_Actuator_VIEW_2_page; \
	COLLECTION trans12_Actuator_VIEW_3; \
	MENU trans12_Actuator_VIEW_3_page; \
	COLLECTION trans12_Actuator_VIEW_4; \
	MENU trans12_Actuator_VIEW_4_page

#define USE_TRANS12_ACTUATOR_OPTIONAL_A \
	USE_TRANS12_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans12_Actuator_LIN_TYPE; \
	MENU trans12_Actuator_LIN_TYPE_page; \
	COMMAND trans12_Actuator_LIN_TYPE_read; \
	COMMAND trans12_Actuator_LIN_TYPE_write; \
	VARIABLE trans12_Actuator_RATED_TRAVEL; \
	MENU trans12_Actuator_RATED_TRAVEL_page; \
	COMMAND trans12_Actuator_RATED_TRAVEL_read; \
	COMMAND trans12_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans12_Actuator_SELF_CALIB_CMD; \
	MENU trans12_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans12_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans12_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans12_Actuator_SELF_CALIB_STATUS; \
	MENU trans12_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans12_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans12_Actuator_SETP_CUTOFF_DEC; \
	MENU trans12_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans12_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans12_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans12_Actuator_SETP_CUTOFF_INC; \
	MENU trans12_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans12_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans12_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans12_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans12_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans12_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans12_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans12_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans12_Actuator_TRAVEL_RATE_DEC; \
	MENU trans12_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans12_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans12_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans12_Actuator_TRAVEL_RATE_INC; \
	MENU trans12_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans12_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans12_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans12_Actuator_POSITIONING_VALUE; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans12_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans12_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans12_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans12_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans12_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans12_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans12_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans12_Actuator_VALVE_MAN; \
	MENU trans12_Actuator_VALVE_MAN_page; \
	COMMAND trans12_Actuator_VALVE_MAN_read; \
	COMMAND trans12_Actuator_VALVE_MAN_write; \
	VARIABLE trans12_Actuator_VALVE_TYPE; \
	MENU trans12_Actuator_VALVE_TYPE_page; \
	COMMAND trans12_Actuator_VALVE_TYPE_read; \
	COMMAND trans12_Actuator_VALVE_TYPE_write; \
	VARIABLE trans12_Actuator_ACTUATOR_TYPE; \
	MENU trans12_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans12_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans12_Actuator_ACTUATOR_ACTION; \
	MENU trans12_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans12_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans12_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans12_Actuator_VIEW_1; \
	MENU trans12_Actuator_VIEW_1_page; \
	MENU trans12_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS12_ACTUATOR_OPTIONAL_B \
	USE_TRANS12_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans12_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans12_Actuator_)
#define USE_TRANS12_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans12_Actuator_)
#define USE_TRANS12_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans12_Actuator_)
#define USE_TRANS12_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans12_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans13_Actuator_block; \
	COLLECTION trans13_Actuator_BLOCK_OBJECT; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans13_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans13_Actuator_ST_REV; \
	MENU trans13_Actuator_ST_REV_page; \
	COMMAND trans13_Actuator_ST_REV_read; \
	VARIABLE trans13_Actuator_TAG_DESC; \
	MENU trans13_Actuator_TAG_DESC_page; \
	COMMAND trans13_Actuator_TAG_DESC_read; \
	COMMAND trans13_Actuator_TAG_DESC_write; \
	VARIABLE trans13_Actuator_STRATEGY; \
	MENU trans13_Actuator_STRATEGY_page; \
	COMMAND trans13_Actuator_STRATEGY_read; \
	COMMAND trans13_Actuator_STRATEGY_write; \
	VARIABLE trans13_Actuator_ALERT_KEY; \
	MENU trans13_Actuator_ALERT_KEY_page; \
	COMMAND trans13_Actuator_ALERT_KEY_read; \
	COMMAND trans13_Actuator_ALERT_KEY_write; \
	VARIABLE trans13_Actuator_TARGET_MODE; \
	MENU trans13_Actuator_TARGET_MODE_page; \
	COMMAND trans13_Actuator_TARGET_MODE_read; \
	COMMAND trans13_Actuator_TARGET_MODE_write; \
	COLLECTION trans13_Actuator_MODE_BLK; \
	VARIABLE trans13_Actuator_MODE_BLK_Actual; \
	VARIABLE trans13_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans13_Actuator_MODE_BLK_Normal; \
	MENU trans13_Actuator_MODE_BLK_page; \
	COMMAND trans13_Actuator_MODE_BLK_read; \
	COLLECTION trans13_Actuator_ALARM_SUM; \
	VARIABLE trans13_Actuator_ALARM_SUM_Current; \
	VARIABLE trans13_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans13_Actuator_ALARM_SUM_Disabled; \
	MENU trans13_Actuator_ALARM_SUM_page; \
	COMMAND trans13_Actuator_ALARM_SUM_read

#define USE_TRANS13_ACTUATOR_MANDATORY_A \
	USE_TRANS13_ACTUATOR_MANDATORY_BOTH; \
	MENU trans13_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS13_ACTUATOR_MANDATORY_B \
	USE_TRANS13_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans13_Actuator_LIN_TYPE; \
	MENU trans13_Actuator_LIN_TYPE_page; \
	COMMAND trans13_Actuator_LIN_TYPE_read; \
	COMMAND trans13_Actuator_LIN_TYPE_write; \
	VARIABLE trans13_Actuator_RATED_TRAVEL; \
	MENU trans13_Actuator_RATED_TRAVEL_page; \
	COMMAND trans13_Actuator_RATED_TRAVEL_read; \
	COMMAND trans13_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans13_Actuator_SELF_CALIB_CMD; \
	MENU trans13_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans13_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans13_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans13_Actuator_SELF_CALIB_STATUS; \
	MENU trans13_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans13_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans13_Actuator_SETP_CUTOFF_DEC; \
	MENU trans13_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans13_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans13_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans13_Actuator_SETP_CUTOFF_INC; \
	MENU trans13_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans13_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans13_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans13_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans13_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans13_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans13_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans13_Actuator_TRAVEL_RATE_DEC; \
	MENU trans13_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans13_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans13_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans13_Actuator_TRAVEL_RATE_INC; \
	MENU trans13_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans13_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans13_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans13_Actuator_POSITIONING_VALUE; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans13_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans13_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans13_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans13_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans13_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans13_Actuator_VALVE_MAN; \
	MENU trans13_Actuator_VALVE_MAN_page; \
	COMMAND trans13_Actuator_VALVE_MAN_read; \
	COMMAND trans13_Actuator_VALVE_MAN_write; \
	VARIABLE trans13_Actuator_VALVE_TYPE; \
	MENU trans13_Actuator_VALVE_TYPE_page; \
	COMMAND trans13_Actuator_VALVE_TYPE_read; \
	COMMAND trans13_Actuator_VALVE_TYPE_write; \
	VARIABLE trans13_Actuator_ACTUATOR_TYPE; \
	MENU trans13_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans13_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans13_Actuator_ACTUATOR_ACTION; \
	MENU trans13_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans13_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans13_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans13_Actuator_VIEW_1; \
	MENU trans13_Actuator_VIEW_1_page; \
	MENU trans13_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS13_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans13_Actuator_ACT_ROT_DIR; \
	MENU trans13_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans13_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans13_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans13_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans13_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans13_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans13_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans13_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans13_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans13_Actuator_ACT_TRAV_TIME; \
	MENU trans13_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans13_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans13_Actuator_ANTI_PUMP_CL; \
	MENU trans13_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans13_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans13_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans13_Actuator_ANTI_PUMP_OP; \
	MENU trans13_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans13_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans13_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans13_Actuator_BREAK_STRENGTH; \
	MENU trans13_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans13_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans13_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans13_Actuator_BYPASS_SETP_CL; \
	MENU trans13_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans13_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans13_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans13_Actuator_BYPASS_SETP_OP; \
	MENU trans13_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans13_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans13_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans13_Actuator_TAB_ENTRY; \
	MENU trans13_Actuator_TAB_ENTRY_page; \
	COMMAND trans13_Actuator_TAB_ENTRY_read; \
	COMMAND trans13_Actuator_TAB_ENTRY_write; \
	COLLECTION trans13_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans13_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans13_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans13_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans13_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans13_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans13_Actuator_TAB_MIN_NUMBER; \
	MENU trans13_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans13_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans13_Actuator_TAB_MAX_NUMBER; \
	MENU trans13_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans13_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans13_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans13_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans13_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans13_Actuator_DEADBAND; \
	MENU trans13_Actuator_DEADBAND_page; \
	COMMAND trans13_Actuator_DEADBAND_read; \
	COMMAND trans13_Actuator_DEADBAND_write; \
	VARIABLE trans13_Actuator_DEVICE_CALIB_DATE; \
	MENU trans13_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans13_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans13_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans13_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans13_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans13_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans13_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans13_Actuator_MAX_TORQUE; \
	MENU trans13_Actuator_MAX_TORQUE_page; \
	COMMAND trans13_Actuator_MAX_TORQUE_read; \
	COMMAND trans13_Actuator_MAX_TORQUE_write; \
	VARIABLE trans13_Actuator_MOTOR_ON_TIME; \
	MENU trans13_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans13_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans13_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans13_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans13_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans13_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans13_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans13_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans13_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans13_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans13_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans13_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans13_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans13_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans13_Actuator_SERVO_GAIN_1; \
	MENU trans13_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans13_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans13_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans13_Actuator_SERVO_RATE_1; \
	MENU trans13_Actuator_SERVO_RATE_1_page; \
	COMMAND trans13_Actuator_SERVO_RATE_1_read; \
	COMMAND trans13_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans13_Actuator_SERVO_RESET_1; \
	MENU trans13_Actuator_SERVO_RESET_1_page; \
	COMMAND trans13_Actuator_SERVO_RESET_1_read; \
	COMMAND trans13_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans13_Actuator_SETP_CUTOFF_MODE; \
	MENU trans13_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans13_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans13_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans13_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans13_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans13_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans13_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans13_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans13_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans13_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans13_Actuator_TORQUE_LIM_CL; \
	MENU trans13_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans13_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans13_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans13_Actuator_TORQUE_LIM_OP; \
	MENU trans13_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans13_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans13_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans13_Actuator_TORQUE_UNIT; \
	MENU trans13_Actuator_TORQUE_UNIT_page; \
	COMMAND trans13_Actuator_TORQUE_UNIT_read; \
	COMMAND trans13_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans13_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans13_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans13_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans13_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans13_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans13_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans13_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans13_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans13_Actuator_VALVE_MAINT_DATE; \
	MENU trans13_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans13_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans13_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans13_Actuator_TAB_OP_CODE; \
	MENU trans13_Actuator_TAB_OP_CODE_page; \
	COMMAND trans13_Actuator_TAB_OP_CODE_read; \
	COMMAND trans13_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans13_Actuator_TAB_STATUS; \
	MENU trans13_Actuator_TAB_STATUS_page; \
	COMMAND trans13_Actuator_TAB_STATUS_read; \
	VARIABLE trans13_Actuator_ACTUATOR_MAN; \
	MENU trans13_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans13_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans13_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans13_Actuator_VALVE_SER_NUM; \
	MENU trans13_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans13_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans13_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans13_Actuator_ACTUATOR_SER_NUM; \
	MENU trans13_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans13_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans13_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans13_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans13_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans13_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans13_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans13_Actuator_ADD_GEAR_MAN; \
	MENU trans13_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans13_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans13_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans13_Actuator_ADD_GEAR_ID; \
	MENU trans13_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans13_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans13_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans13_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans13_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans13_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans13_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans13_Actuator_VIEW_2; \
	MENU trans13_Actuator_VIEW_2_page; \
	COLLECTION trans13_Actuator_VIEW_3; \
	MENU trans13_Actuator_VIEW_3_page; \
	COLLECTION trans13_Actuator_VIEW_4; \
	MENU trans13_Actuator_VIEW_4_page

#define USE_TRANS13_ACTUATOR_OPTIONAL_A \
	USE_TRANS13_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans13_Actuator_LIN_TYPE; \
	MENU trans13_Actuator_LIN_TYPE_page; \
	COMMAND trans13_Actuator_LIN_TYPE_read; \
	COMMAND trans13_Actuator_LIN_TYPE_write; \
	VARIABLE trans13_Actuator_RATED_TRAVEL; \
	MENU trans13_Actuator_RATED_TRAVEL_page; \
	COMMAND trans13_Actuator_RATED_TRAVEL_read; \
	COMMAND trans13_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans13_Actuator_SELF_CALIB_CMD; \
	MENU trans13_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans13_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans13_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans13_Actuator_SELF_CALIB_STATUS; \
	MENU trans13_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans13_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans13_Actuator_SETP_CUTOFF_DEC; \
	MENU trans13_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans13_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans13_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans13_Actuator_SETP_CUTOFF_INC; \
	MENU trans13_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans13_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans13_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans13_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans13_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans13_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans13_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans13_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans13_Actuator_TRAVEL_RATE_DEC; \
	MENU trans13_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans13_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans13_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans13_Actuator_TRAVEL_RATE_INC; \
	MENU trans13_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans13_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans13_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans13_Actuator_POSITIONING_VALUE; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans13_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans13_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans13_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans13_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans13_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans13_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans13_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans13_Actuator_VALVE_MAN; \
	MENU trans13_Actuator_VALVE_MAN_page; \
	COMMAND trans13_Actuator_VALVE_MAN_read; \
	COMMAND trans13_Actuator_VALVE_MAN_write; \
	VARIABLE trans13_Actuator_VALVE_TYPE; \
	MENU trans13_Actuator_VALVE_TYPE_page; \
	COMMAND trans13_Actuator_VALVE_TYPE_read; \
	COMMAND trans13_Actuator_VALVE_TYPE_write; \
	VARIABLE trans13_Actuator_ACTUATOR_TYPE; \
	MENU trans13_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans13_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans13_Actuator_ACTUATOR_ACTION; \
	MENU trans13_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans13_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans13_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans13_Actuator_VIEW_1; \
	MENU trans13_Actuator_VIEW_1_page; \
	MENU trans13_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS13_ACTUATOR_OPTIONAL_B \
	USE_TRANS13_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans13_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans13_Actuator_)
#define USE_TRANS13_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans13_Actuator_)
#define USE_TRANS13_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans13_Actuator_)
#define USE_TRANS13_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans13_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans14_Actuator_block; \
	COLLECTION trans14_Actuator_BLOCK_OBJECT; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans14_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans14_Actuator_ST_REV; \
	MENU trans14_Actuator_ST_REV_page; \
	COMMAND trans14_Actuator_ST_REV_read; \
	VARIABLE trans14_Actuator_TAG_DESC; \
	MENU trans14_Actuator_TAG_DESC_page; \
	COMMAND trans14_Actuator_TAG_DESC_read; \
	COMMAND trans14_Actuator_TAG_DESC_write; \
	VARIABLE trans14_Actuator_STRATEGY; \
	MENU trans14_Actuator_STRATEGY_page; \
	COMMAND trans14_Actuator_STRATEGY_read; \
	COMMAND trans14_Actuator_STRATEGY_write; \
	VARIABLE trans14_Actuator_ALERT_KEY; \
	MENU trans14_Actuator_ALERT_KEY_page; \
	COMMAND trans14_Actuator_ALERT_KEY_read; \
	COMMAND trans14_Actuator_ALERT_KEY_write; \
	VARIABLE trans14_Actuator_TARGET_MODE; \
	MENU trans14_Actuator_TARGET_MODE_page; \
	COMMAND trans14_Actuator_TARGET_MODE_read; \
	COMMAND trans14_Actuator_TARGET_MODE_write; \
	COLLECTION trans14_Actuator_MODE_BLK; \
	VARIABLE trans14_Actuator_MODE_BLK_Actual; \
	VARIABLE trans14_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans14_Actuator_MODE_BLK_Normal; \
	MENU trans14_Actuator_MODE_BLK_page; \
	COMMAND trans14_Actuator_MODE_BLK_read; \
	COLLECTION trans14_Actuator_ALARM_SUM; \
	VARIABLE trans14_Actuator_ALARM_SUM_Current; \
	VARIABLE trans14_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans14_Actuator_ALARM_SUM_Disabled; \
	MENU trans14_Actuator_ALARM_SUM_page; \
	COMMAND trans14_Actuator_ALARM_SUM_read

#define USE_TRANS14_ACTUATOR_MANDATORY_A \
	USE_TRANS14_ACTUATOR_MANDATORY_BOTH; \
	MENU trans14_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS14_ACTUATOR_MANDATORY_B \
	USE_TRANS14_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans14_Actuator_LIN_TYPE; \
	MENU trans14_Actuator_LIN_TYPE_page; \
	COMMAND trans14_Actuator_LIN_TYPE_read; \
	COMMAND trans14_Actuator_LIN_TYPE_write; \
	VARIABLE trans14_Actuator_RATED_TRAVEL; \
	MENU trans14_Actuator_RATED_TRAVEL_page; \
	COMMAND trans14_Actuator_RATED_TRAVEL_read; \
	COMMAND trans14_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans14_Actuator_SELF_CALIB_CMD; \
	MENU trans14_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans14_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans14_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans14_Actuator_SELF_CALIB_STATUS; \
	MENU trans14_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans14_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans14_Actuator_SETP_CUTOFF_DEC; \
	MENU trans14_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans14_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans14_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans14_Actuator_SETP_CUTOFF_INC; \
	MENU trans14_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans14_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans14_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans14_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans14_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans14_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans14_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans14_Actuator_TRAVEL_RATE_DEC; \
	MENU trans14_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans14_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans14_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans14_Actuator_TRAVEL_RATE_INC; \
	MENU trans14_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans14_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans14_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans14_Actuator_POSITIONING_VALUE; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans14_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans14_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans14_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans14_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans14_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans14_Actuator_VALVE_MAN; \
	MENU trans14_Actuator_VALVE_MAN_page; \
	COMMAND trans14_Actuator_VALVE_MAN_read; \
	COMMAND trans14_Actuator_VALVE_MAN_write; \
	VARIABLE trans14_Actuator_VALVE_TYPE; \
	MENU trans14_Actuator_VALVE_TYPE_page; \
	COMMAND trans14_Actuator_VALVE_TYPE_read; \
	COMMAND trans14_Actuator_VALVE_TYPE_write; \
	VARIABLE trans14_Actuator_ACTUATOR_TYPE; \
	MENU trans14_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans14_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans14_Actuator_ACTUATOR_ACTION; \
	MENU trans14_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans14_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans14_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans14_Actuator_VIEW_1; \
	MENU trans14_Actuator_VIEW_1_page; \
	MENU trans14_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS14_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans14_Actuator_ACT_ROT_DIR; \
	MENU trans14_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans14_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans14_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans14_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans14_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans14_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans14_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans14_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans14_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans14_Actuator_ACT_TRAV_TIME; \
	MENU trans14_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans14_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans14_Actuator_ANTI_PUMP_CL; \
	MENU trans14_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans14_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans14_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans14_Actuator_ANTI_PUMP_OP; \
	MENU trans14_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans14_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans14_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans14_Actuator_BREAK_STRENGTH; \
	MENU trans14_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans14_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans14_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans14_Actuator_BYPASS_SETP_CL; \
	MENU trans14_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans14_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans14_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans14_Actuator_BYPASS_SETP_OP; \
	MENU trans14_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans14_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans14_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans14_Actuator_TAB_ENTRY; \
	MENU trans14_Actuator_TAB_ENTRY_page; \
	COMMAND trans14_Actuator_TAB_ENTRY_read; \
	COMMAND trans14_Actuator_TAB_ENTRY_write; \
	COLLECTION trans14_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans14_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans14_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans14_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans14_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans14_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans14_Actuator_TAB_MIN_NUMBER; \
	MENU trans14_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans14_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans14_Actuator_TAB_MAX_NUMBER; \
	MENU trans14_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans14_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans14_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans14_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans14_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans14_Actuator_DEADBAND; \
	MENU trans14_Actuator_DEADBAND_page; \
	COMMAND trans14_Actuator_DEADBAND_read; \
	COMMAND trans14_Actuator_DEADBAND_write; \
	VARIABLE trans14_Actuator_DEVICE_CALIB_DATE; \
	MENU trans14_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans14_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans14_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans14_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans14_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans14_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans14_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans14_Actuator_MAX_TORQUE; \
	MENU trans14_Actuator_MAX_TORQUE_page; \
	COMMAND trans14_Actuator_MAX_TORQUE_read; \
	COMMAND trans14_Actuator_MAX_TORQUE_write; \
	VARIABLE trans14_Actuator_MOTOR_ON_TIME; \
	MENU trans14_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans14_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans14_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans14_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans14_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans14_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans14_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans14_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans14_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans14_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans14_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans14_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans14_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans14_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans14_Actuator_SERVO_GAIN_1; \
	MENU trans14_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans14_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans14_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans14_Actuator_SERVO_RATE_1; \
	MENU trans14_Actuator_SERVO_RATE_1_page; \
	COMMAND trans14_Actuator_SERVO_RATE_1_read; \
	COMMAND trans14_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans14_Actuator_SERVO_RESET_1; \
	MENU trans14_Actuator_SERVO_RESET_1_page; \
	COMMAND trans14_Actuator_SERVO_RESET_1_read; \
	COMMAND trans14_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans14_Actuator_SETP_CUTOFF_MODE; \
	MENU trans14_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans14_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans14_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans14_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans14_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans14_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans14_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans14_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans14_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans14_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans14_Actuator_TORQUE_LIM_CL; \
	MENU trans14_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans14_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans14_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans14_Actuator_TORQUE_LIM_OP; \
	MENU trans14_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans14_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans14_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans14_Actuator_TORQUE_UNIT; \
	MENU trans14_Actuator_TORQUE_UNIT_page; \
	COMMAND trans14_Actuator_TORQUE_UNIT_read; \
	COMMAND trans14_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans14_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans14_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans14_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans14_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans14_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans14_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans14_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans14_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans14_Actuator_VALVE_MAINT_DATE; \
	MENU trans14_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans14_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans14_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans14_Actuator_TAB_OP_CODE; \
	MENU trans14_Actuator_TAB_OP_CODE_page; \
	COMMAND trans14_Actuator_TAB_OP_CODE_read; \
	COMMAND trans14_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans14_Actuator_TAB_STATUS; \
	MENU trans14_Actuator_TAB_STATUS_page; \
	COMMAND trans14_Actuator_TAB_STATUS_read; \
	VARIABLE trans14_Actuator_ACTUATOR_MAN; \
	MENU trans14_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans14_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans14_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans14_Actuator_VALVE_SER_NUM; \
	MENU trans14_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans14_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans14_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans14_Actuator_ACTUATOR_SER_NUM; \
	MENU trans14_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans14_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans14_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans14_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans14_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans14_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans14_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans14_Actuator_ADD_GEAR_MAN; \
	MENU trans14_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans14_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans14_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans14_Actuator_ADD_GEAR_ID; \
	MENU trans14_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans14_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans14_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans14_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans14_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans14_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans14_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans14_Actuator_VIEW_2; \
	MENU trans14_Actuator_VIEW_2_page; \
	COLLECTION trans14_Actuator_VIEW_3; \
	MENU trans14_Actuator_VIEW_3_page; \
	COLLECTION trans14_Actuator_VIEW_4; \
	MENU trans14_Actuator_VIEW_4_page

#define USE_TRANS14_ACTUATOR_OPTIONAL_A \
	USE_TRANS14_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans14_Actuator_LIN_TYPE; \
	MENU trans14_Actuator_LIN_TYPE_page; \
	COMMAND trans14_Actuator_LIN_TYPE_read; \
	COMMAND trans14_Actuator_LIN_TYPE_write; \
	VARIABLE trans14_Actuator_RATED_TRAVEL; \
	MENU trans14_Actuator_RATED_TRAVEL_page; \
	COMMAND trans14_Actuator_RATED_TRAVEL_read; \
	COMMAND trans14_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans14_Actuator_SELF_CALIB_CMD; \
	MENU trans14_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans14_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans14_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans14_Actuator_SELF_CALIB_STATUS; \
	MENU trans14_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans14_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans14_Actuator_SETP_CUTOFF_DEC; \
	MENU trans14_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans14_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans14_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans14_Actuator_SETP_CUTOFF_INC; \
	MENU trans14_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans14_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans14_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans14_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans14_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans14_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans14_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans14_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans14_Actuator_TRAVEL_RATE_DEC; \
	MENU trans14_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans14_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans14_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans14_Actuator_TRAVEL_RATE_INC; \
	MENU trans14_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans14_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans14_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans14_Actuator_POSITIONING_VALUE; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans14_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans14_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans14_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans14_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans14_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans14_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans14_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans14_Actuator_VALVE_MAN; \
	MENU trans14_Actuator_VALVE_MAN_page; \
	COMMAND trans14_Actuator_VALVE_MAN_read; \
	COMMAND trans14_Actuator_VALVE_MAN_write; \
	VARIABLE trans14_Actuator_VALVE_TYPE; \
	MENU trans14_Actuator_VALVE_TYPE_page; \
	COMMAND trans14_Actuator_VALVE_TYPE_read; \
	COMMAND trans14_Actuator_VALVE_TYPE_write; \
	VARIABLE trans14_Actuator_ACTUATOR_TYPE; \
	MENU trans14_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans14_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans14_Actuator_ACTUATOR_ACTION; \
	MENU trans14_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans14_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans14_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans14_Actuator_VIEW_1; \
	MENU trans14_Actuator_VIEW_1_page; \
	MENU trans14_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS14_ACTUATOR_OPTIONAL_B \
	USE_TRANS14_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans14_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans14_Actuator_)
#define USE_TRANS14_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans14_Actuator_)
#define USE_TRANS14_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans14_Actuator_)
#define USE_TRANS14_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans14_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_ACTUATOR_MANDATORY_BOTH \
	BLOCK trans15_Actuator_block; \
	COLLECTION trans15_Actuator_BLOCK_OBJECT; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Actuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Actuator_BLOCK_OBJECT_page; \
	COMMAND trans15_Actuator_BLOCK_OBJECT_read; \
	VARIABLE trans15_Actuator_ST_REV; \
	MENU trans15_Actuator_ST_REV_page; \
	COMMAND trans15_Actuator_ST_REV_read; \
	VARIABLE trans15_Actuator_TAG_DESC; \
	MENU trans15_Actuator_TAG_DESC_page; \
	COMMAND trans15_Actuator_TAG_DESC_read; \
	COMMAND trans15_Actuator_TAG_DESC_write; \
	VARIABLE trans15_Actuator_STRATEGY; \
	MENU trans15_Actuator_STRATEGY_page; \
	COMMAND trans15_Actuator_STRATEGY_read; \
	COMMAND trans15_Actuator_STRATEGY_write; \
	VARIABLE trans15_Actuator_ALERT_KEY; \
	MENU trans15_Actuator_ALERT_KEY_page; \
	COMMAND trans15_Actuator_ALERT_KEY_read; \
	COMMAND trans15_Actuator_ALERT_KEY_write; \
	VARIABLE trans15_Actuator_TARGET_MODE; \
	MENU trans15_Actuator_TARGET_MODE_page; \
	COMMAND trans15_Actuator_TARGET_MODE_read; \
	COMMAND trans15_Actuator_TARGET_MODE_write; \
	COLLECTION trans15_Actuator_MODE_BLK; \
	VARIABLE trans15_Actuator_MODE_BLK_Actual; \
	VARIABLE trans15_Actuator_MODE_BLK_Permitted; \
	VARIABLE trans15_Actuator_MODE_BLK_Normal; \
	MENU trans15_Actuator_MODE_BLK_page; \
	COMMAND trans15_Actuator_MODE_BLK_read; \
	COLLECTION trans15_Actuator_ALARM_SUM; \
	VARIABLE trans15_Actuator_ALARM_SUM_Current; \
	VARIABLE trans15_Actuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Actuator_ALARM_SUM_Unreported; \
	VARIABLE trans15_Actuator_ALARM_SUM_Disabled; \
	MENU trans15_Actuator_ALARM_SUM_page; \
	COMMAND trans15_Actuator_ALARM_SUM_read

#define USE_TRANS15_ACTUATOR_MANDATORY_A \
	USE_TRANS15_ACTUATOR_MANDATORY_BOTH; \
	MENU trans15_Actuator_Simple_Dialog_Mandatory_A

#define USE_TRANS15_ACTUATOR_MANDATORY_B \
	USE_TRANS15_ACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans15_Actuator_LIN_TYPE; \
	MENU trans15_Actuator_LIN_TYPE_page; \
	COMMAND trans15_Actuator_LIN_TYPE_read; \
	COMMAND trans15_Actuator_LIN_TYPE_write; \
	VARIABLE trans15_Actuator_RATED_TRAVEL; \
	MENU trans15_Actuator_RATED_TRAVEL_page; \
	COMMAND trans15_Actuator_RATED_TRAVEL_read; \
	COMMAND trans15_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans15_Actuator_SELF_CALIB_CMD; \
	MENU trans15_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans15_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans15_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans15_Actuator_SELF_CALIB_STATUS; \
	MENU trans15_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans15_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans15_Actuator_SETP_CUTOFF_DEC; \
	MENU trans15_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans15_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans15_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans15_Actuator_SETP_CUTOFF_INC; \
	MENU trans15_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans15_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans15_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans15_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans15_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans15_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans15_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans15_Actuator_TRAVEL_RATE_DEC; \
	MENU trans15_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans15_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans15_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans15_Actuator_TRAVEL_RATE_INC; \
	MENU trans15_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans15_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans15_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans15_Actuator_POSITIONING_VALUE; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans15_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans15_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans15_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans15_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans15_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans15_Actuator_VALVE_MAN; \
	MENU trans15_Actuator_VALVE_MAN_page; \
	COMMAND trans15_Actuator_VALVE_MAN_read; \
	COMMAND trans15_Actuator_VALVE_MAN_write; \
	VARIABLE trans15_Actuator_VALVE_TYPE; \
	MENU trans15_Actuator_VALVE_TYPE_page; \
	COMMAND trans15_Actuator_VALVE_TYPE_read; \
	COMMAND trans15_Actuator_VALVE_TYPE_write; \
	VARIABLE trans15_Actuator_ACTUATOR_TYPE; \
	MENU trans15_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans15_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans15_Actuator_ACTUATOR_ACTION; \
	MENU trans15_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans15_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans15_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans15_Actuator_VIEW_1; \
	MENU trans15_Actuator_VIEW_1_page; \
	MENU trans15_Actuator_Simple_Dialog_Mandatory_B

#define USE_TRANS15_ACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans15_Actuator_ACT_ROT_DIR; \
	MENU trans15_Actuator_ACT_ROT_DIR_page; \
	COMMAND trans15_Actuator_ACT_ROT_DIR_read; \
	COMMAND trans15_Actuator_ACT_ROT_DIR_write; \
	VARIABLE trans15_Actuator_ACT_STROKE_TIME_DEC; \
	MENU trans15_Actuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans15_Actuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans15_Actuator_ACT_STROKE_TIME_INC; \
	MENU trans15_Actuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans15_Actuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans15_Actuator_ACT_TRAV_TIME; \
	MENU trans15_Actuator_ACT_TRAV_TIME_page; \
	COMMAND trans15_Actuator_ACT_TRAV_TIME_read; \
	VARIABLE trans15_Actuator_ANTI_PUMP_CL; \
	MENU trans15_Actuator_ANTI_PUMP_CL_page; \
	COMMAND trans15_Actuator_ANTI_PUMP_CL_read; \
	COMMAND trans15_Actuator_ANTI_PUMP_CL_write; \
	VARIABLE trans15_Actuator_ANTI_PUMP_OP; \
	MENU trans15_Actuator_ANTI_PUMP_OP_page; \
	COMMAND trans15_Actuator_ANTI_PUMP_OP_read; \
	COMMAND trans15_Actuator_ANTI_PUMP_OP_write; \
	VARIABLE trans15_Actuator_BREAK_STRENGTH; \
	MENU trans15_Actuator_BREAK_STRENGTH_page; \
	COMMAND trans15_Actuator_BREAK_STRENGTH_read; \
	COMMAND trans15_Actuator_BREAK_STRENGTH_write; \
	VARIABLE trans15_Actuator_BYPASS_SETP_CL; \
	MENU trans15_Actuator_BYPASS_SETP_CL_page; \
	COMMAND trans15_Actuator_BYPASS_SETP_CL_read; \
	COMMAND trans15_Actuator_BYPASS_SETP_CL_write; \
	VARIABLE trans15_Actuator_BYPASS_SETP_OP; \
	MENU trans15_Actuator_BYPASS_SETP_OP_page; \
	COMMAND trans15_Actuator_BYPASS_SETP_OP_read; \
	COMMAND trans15_Actuator_BYPASS_SETP_OP_write; \
	VARIABLE trans15_Actuator_TAB_ENTRY; \
	MENU trans15_Actuator_TAB_ENTRY_page; \
	COMMAND trans15_Actuator_TAB_ENTRY_read; \
	COMMAND trans15_Actuator_TAB_ENTRY_write; \
	COLLECTION trans15_Actuator_TAB_X_Y_VALUE; \
	VARIABLE trans15_Actuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans15_Actuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans15_Actuator_TAB_X_Y_VALUE_page; \
	COMMAND trans15_Actuator_TAB_X_Y_VALUE_read; \
	COMMAND trans15_Actuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans15_Actuator_TAB_MIN_NUMBER; \
	MENU trans15_Actuator_TAB_MIN_NUMBER_page; \
	COMMAND trans15_Actuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans15_Actuator_TAB_MAX_NUMBER; \
	MENU trans15_Actuator_TAB_MAX_NUMBER_page; \
	COMMAND trans15_Actuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans15_Actuator_TAB_ACTUAL_NUMBER; \
	MENU trans15_Actuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans15_Actuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans15_Actuator_DEADBAND; \
	MENU trans15_Actuator_DEADBAND_page; \
	COMMAND trans15_Actuator_DEADBAND_read; \
	COMMAND trans15_Actuator_DEADBAND_write; \
	VARIABLE trans15_Actuator_DEVICE_CALIB_DATE; \
	MENU trans15_Actuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans15_Actuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans15_Actuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans15_Actuator_DEVICE_CONFIG_DATE; \
	MENU trans15_Actuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans15_Actuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans15_Actuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans15_Actuator_MAX_TORQUE; \
	MENU trans15_Actuator_MAX_TORQUE_page; \
	COMMAND trans15_Actuator_MAX_TORQUE_read; \
	COMMAND trans15_Actuator_MAX_TORQUE_write; \
	VARIABLE trans15_Actuator_MOTOR_ON_TIME; \
	MENU trans15_Actuator_MOTOR_ON_TIME_page; \
	COMMAND trans15_Actuator_MOTOR_ON_TIME_read; \
	VARIABLE trans15_Actuator_NUM_LIMIT_CUT_OFF; \
	MENU trans15_Actuator_NUM_LIMIT_CUT_OFF_page; \
	COMMAND trans15_Actuator_NUM_LIMIT_CUT_OFF_read; \
	VARIABLE trans15_Actuator_NUM_MOT_ON_CYCL; \
	MENU trans15_Actuator_NUM_MOT_ON_CYCL_page; \
	COMMAND trans15_Actuator_NUM_MOT_ON_CYCL_read; \
	VARIABLE trans15_Actuator_NUM_MOT_ON_HOUR; \
	MENU trans15_Actuator_NUM_MOT_ON_HOUR_page; \
	COMMAND trans15_Actuator_NUM_MOT_ON_HOUR_read; \
	VARIABLE trans15_Actuator_NUM_TORQ_CUT_OFF; \
	MENU trans15_Actuator_NUM_TORQ_CUT_OFF_page; \
	COMMAND trans15_Actuator_NUM_TORQ_CUT_OFF_read; \
	VARIABLE trans15_Actuator_SERVO_GAIN_1; \
	MENU trans15_Actuator_SERVO_GAIN_1_page; \
	COMMAND trans15_Actuator_SERVO_GAIN_1_read; \
	COMMAND trans15_Actuator_SERVO_GAIN_1_write; \
	VARIABLE trans15_Actuator_SERVO_RATE_1; \
	MENU trans15_Actuator_SERVO_RATE_1_page; \
	COMMAND trans15_Actuator_SERVO_RATE_1_read; \
	COMMAND trans15_Actuator_SERVO_RATE_1_write; \
	VARIABLE trans15_Actuator_SERVO_RESET_1; \
	MENU trans15_Actuator_SERVO_RESET_1_page; \
	COMMAND trans15_Actuator_SERVO_RESET_1_read; \
	COMMAND trans15_Actuator_SERVO_RESET_1_write; \
	VARIABLE trans15_Actuator_SETP_CUTOFF_MODE; \
	MENU trans15_Actuator_SETP_CUTOFF_MODE_page; \
	COMMAND trans15_Actuator_SETP_CUTOFF_MODE_read; \
	COMMAND trans15_Actuator_SETP_CUTOFF_MODE_write; \
	COLLECTION trans15_Actuator_TORQUE_ACTUAL; \
	VARIABLE trans15_Actuator_TORQUE_ACTUAL_Value; \
	VARIABLE trans15_Actuator_TORQUE_ACTUAL_Status_Condensed; \
	VARIABLE trans15_Actuator_TORQUE_ACTUAL_Status_Quality; \
	VARIABLE trans15_Actuator_TORQUE_ACTUAL_Status_Limit; \
	MENU trans15_Actuator_TORQUE_ACTUAL_page; \
	COMMAND trans15_Actuator_TORQUE_ACTUAL_read; \
	VARIABLE trans15_Actuator_TORQUE_LIM_CL; \
	MENU trans15_Actuator_TORQUE_LIM_CL_page; \
	COMMAND trans15_Actuator_TORQUE_LIM_CL_read; \
	COMMAND trans15_Actuator_TORQUE_LIM_CL_write; \
	VARIABLE trans15_Actuator_TORQUE_LIM_OP; \
	MENU trans15_Actuator_TORQUE_LIM_OP_page; \
	COMMAND trans15_Actuator_TORQUE_LIM_OP_read; \
	COMMAND trans15_Actuator_TORQUE_LIM_OP_write; \
	VARIABLE trans15_Actuator_TORQUE_UNIT; \
	MENU trans15_Actuator_TORQUE_UNIT_page; \
	COMMAND trans15_Actuator_TORQUE_UNIT_read; \
	COMMAND trans15_Actuator_TORQUE_UNIT_write; \
	VARIABLE trans15_Actuator_TOTAL_VALVE_TRAVEL; \
	MENU trans15_Actuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans15_Actuator_TOTAL_VALVE_TRAVEL_read; \
	COMMAND trans15_Actuator_TOTAL_VALVE_TRAVEL_write; \
	VARIABLE trans15_Actuator_TOT_VALVE_TRAV_LIM; \
	MENU trans15_Actuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans15_Actuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans15_Actuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans15_Actuator_VALVE_MAINT_DATE; \
	MENU trans15_Actuator_VALVE_MAINT_DATE_page; \
	COMMAND trans15_Actuator_VALVE_MAINT_DATE_read; \
	COMMAND trans15_Actuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans15_Actuator_TAB_OP_CODE; \
	MENU trans15_Actuator_TAB_OP_CODE_page; \
	COMMAND trans15_Actuator_TAB_OP_CODE_read; \
	COMMAND trans15_Actuator_TAB_OP_CODE_write; \
	VARIABLE trans15_Actuator_TAB_STATUS; \
	MENU trans15_Actuator_TAB_STATUS_page; \
	COMMAND trans15_Actuator_TAB_STATUS_read; \
	VARIABLE trans15_Actuator_ACTUATOR_MAN; \
	MENU trans15_Actuator_ACTUATOR_MAN_page; \
	COMMAND trans15_Actuator_ACTUATOR_MAN_read; \
	COMMAND trans15_Actuator_ACTUATOR_MAN_write; \
	VARIABLE trans15_Actuator_VALVE_SER_NUM; \
	MENU trans15_Actuator_VALVE_SER_NUM_page; \
	COMMAND trans15_Actuator_VALVE_SER_NUM_read; \
	COMMAND trans15_Actuator_VALVE_SER_NUM_write; \
	VARIABLE trans15_Actuator_ACTUATOR_SER_NUM; \
	MENU trans15_Actuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans15_Actuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans15_Actuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans15_Actuator_ADD_GEAR_SER_NUM; \
	MENU trans15_Actuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans15_Actuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans15_Actuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans15_Actuator_ADD_GEAR_MAN; \
	MENU trans15_Actuator_ADD_GEAR_MAN_page; \
	COMMAND trans15_Actuator_ADD_GEAR_MAN_read; \
	COMMAND trans15_Actuator_ADD_GEAR_MAN_write; \
	VARIABLE trans15_Actuator_ADD_GEAR_ID; \
	MENU trans15_Actuator_ADD_GEAR_ID_page; \
	COMMAND trans15_Actuator_ADD_GEAR_ID_read; \
	COMMAND trans15_Actuator_ADD_GEAR_ID_write; \
	VARIABLE trans15_Actuator_ADD_GEAR_INST_DATE; \
	MENU trans15_Actuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans15_Actuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans15_Actuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans15_Actuator_VIEW_2; \
	MENU trans15_Actuator_VIEW_2_page; \
	COLLECTION trans15_Actuator_VIEW_3; \
	MENU trans15_Actuator_VIEW_3_page; \
	COLLECTION trans15_Actuator_VIEW_4; \
	MENU trans15_Actuator_VIEW_4_page

#define USE_TRANS15_ACTUATOR_OPTIONAL_A \
	USE_TRANS15_ACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans15_Actuator_LIN_TYPE; \
	MENU trans15_Actuator_LIN_TYPE_page; \
	COMMAND trans15_Actuator_LIN_TYPE_read; \
	COMMAND trans15_Actuator_LIN_TYPE_write; \
	VARIABLE trans15_Actuator_RATED_TRAVEL; \
	MENU trans15_Actuator_RATED_TRAVEL_page; \
	COMMAND trans15_Actuator_RATED_TRAVEL_read; \
	COMMAND trans15_Actuator_RATED_TRAVEL_write; \
	VARIABLE trans15_Actuator_SELF_CALIB_CMD; \
	MENU trans15_Actuator_SELF_CALIB_CMD_page; \
	COMMAND trans15_Actuator_SELF_CALIB_CMD_read; \
	COMMAND trans15_Actuator_SELF_CALIB_CMD_write; \
	VARIABLE trans15_Actuator_SELF_CALIB_STATUS; \
	MENU trans15_Actuator_SELF_CALIB_STATUS_page; \
	COMMAND trans15_Actuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans15_Actuator_SETP_CUTOFF_DEC; \
	MENU trans15_Actuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans15_Actuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans15_Actuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans15_Actuator_SETP_CUTOFF_INC; \
	MENU trans15_Actuator_SETP_CUTOFF_INC_page; \
	COMMAND trans15_Actuator_SETP_CUTOFF_INC_read; \
	COMMAND trans15_Actuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans15_Actuator_TRAVEL_LIMIT_LOW; \
	MENU trans15_Actuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans15_Actuator_TRAVEL_LIMIT_UP; \
	MENU trans15_Actuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans15_Actuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans15_Actuator_TRAVEL_RATE_DEC; \
	MENU trans15_Actuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans15_Actuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans15_Actuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans15_Actuator_TRAVEL_RATE_INC; \
	MENU trans15_Actuator_TRAVEL_RATE_INC_page; \
	COMMAND trans15_Actuator_TRAVEL_RATE_INC_read; \
	COMMAND trans15_Actuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans15_Actuator_POSITIONING_VALUE; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Value; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans15_Actuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans15_Actuator_POSITIONING_VALUE_page; \
	COMMAND trans15_Actuator_POSITIONING_VALUE_read; \
	COLLECTION trans15_Actuator_FEEDBACK_VALUE; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans15_Actuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans15_Actuator_FEEDBACK_VALUE_page; \
	COMMAND trans15_Actuator_FEEDBACK_VALUE_read; \
	VARIABLE trans15_Actuator_VALVE_MAN; \
	MENU trans15_Actuator_VALVE_MAN_page; \
	COMMAND trans15_Actuator_VALVE_MAN_read; \
	COMMAND trans15_Actuator_VALVE_MAN_write; \
	VARIABLE trans15_Actuator_VALVE_TYPE; \
	MENU trans15_Actuator_VALVE_TYPE_page; \
	COMMAND trans15_Actuator_VALVE_TYPE_read; \
	COMMAND trans15_Actuator_VALVE_TYPE_write; \
	VARIABLE trans15_Actuator_ACTUATOR_TYPE; \
	MENU trans15_Actuator_ACTUATOR_TYPE_page; \
	COMMAND trans15_Actuator_ACTUATOR_TYPE_read; \
	VARIABLE trans15_Actuator_ACTUATOR_ACTION; \
	MENU trans15_Actuator_ACTUATOR_ACTION_page; \
	COMMAND trans15_Actuator_ACTUATOR_ACTION_read; \
	COMMAND trans15_Actuator_ACTUATOR_ACTION_write; \
	COLLECTION trans15_Actuator_VIEW_1; \
	MENU trans15_Actuator_VIEW_1_page; \
	MENU trans15_Actuator_Simple_Dialog_Optional_A

#define USE_TRANS15_ACTUATOR_OPTIONAL_B \
	USE_TRANS15_ACTUATOR_OPTIONAL_BOTH; \
	MENU trans15_Actuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_ACTUATOR_MANDATORY_A USE_TRANS_ACTUATOR_MANDATORY_A(trans15_Actuator_)
#define USE_TRANS15_ACTUATOR_MANDATORY_B USE_TRANS_ACTUATOR_MANDATORY_B(trans15_Actuator_)
#define USE_TRANS15_ACTUATOR_OPTIONAL_A  USE_TRANS_ACTUATOR_OPTIONAL_A(trans15_Actuator_)
#define USE_TRANS15_ACTUATOR_OPTIONAL_B  USE_TRANS_ACTUATOR_OPTIONAL_B(trans15_Actuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans1_PneumaticActuator_block; \
	COLLECTION trans1_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans1_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans1_PneumaticActuator_ST_REV; \
	MENU trans1_PneumaticActuator_ST_REV_page; \
	COMMAND trans1_PneumaticActuator_ST_REV_read; \
	VARIABLE trans1_PneumaticActuator_TAG_DESC; \
	MENU trans1_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans1_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans1_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans1_PneumaticActuator_STRATEGY; \
	MENU trans1_PneumaticActuator_STRATEGY_page; \
	COMMAND trans1_PneumaticActuator_STRATEGY_read; \
	COMMAND trans1_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans1_PneumaticActuator_ALERT_KEY; \
	MENU trans1_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans1_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans1_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans1_PneumaticActuator_TARGET_MODE; \
	MENU trans1_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans1_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans1_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans1_PneumaticActuator_MODE_BLK; \
	VARIABLE trans1_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans1_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans1_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans1_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans1_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans1_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans1_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans1_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans1_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans1_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans1_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans1_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans1_PneumaticActuator_LIN_TYPE; \
	MENU trans1_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans1_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans1_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans1_PneumaticActuator_RATED_TRAVEL; \
	MENU trans1_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans1_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans1_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans1_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans1_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans1_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans1_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans1_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans1_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans1_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans1_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans1_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans1_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans1_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans1_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans1_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans1_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans1_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans1_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans1_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans1_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans1_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans1_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans1_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans1_PneumaticActuator_VALVE_MAN; \
	MENU trans1_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans1_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans1_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans1_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans1_PneumaticActuator_VALVE_TYPE; \
	MENU trans1_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans1_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans1_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans1_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans1_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans1_PneumaticActuator_VIEW_1; \
	MENU trans1_PneumaticActuator_VIEW_1_page; \
	MENU trans1_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans1_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans1_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans1_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans1_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans1_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans1_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans1_PneumaticActuator_TAB_ENTRY; \
	MENU trans1_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans1_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans1_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans1_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans1_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans1_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans1_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans1_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans1_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans1_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans1_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans1_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans1_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans1_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans1_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans1_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans1_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans1_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans1_PneumaticActuator_DEADBAND; \
	MENU trans1_PneumaticActuator_DEADBAND_page; \
	COMMAND trans1_PneumaticActuator_DEADBAND_read; \
	COMMAND trans1_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans1_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans1_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans1_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans1_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans1_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans1_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans1_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans1_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans1_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans1_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans1_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans1_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans1_PneumaticActuator_SERVO_RATE_1; \
	MENU trans1_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans1_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans1_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans1_PneumaticActuator_SERVO_RESET_1; \
	MENU trans1_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans1_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans1_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans1_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans1_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans1_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans1_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans1_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans1_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans1_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans1_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans1_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans1_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans1_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans1_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans1_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans1_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans1_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans1_PneumaticActuator_SERVO_RATE_2; \
	MENU trans1_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans1_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans1_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans1_PneumaticActuator_SERVO_RESET_2; \
	MENU trans1_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans1_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans1_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans1_PneumaticActuator_TAB_OP_CODE; \
	MENU trans1_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans1_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans1_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans1_PneumaticActuator_TAB_STATUS; \
	MENU trans1_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans1_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans1_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans1_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans1_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans1_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans1_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans1_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans1_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans1_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans1_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans1_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans1_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans1_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans1_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans1_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans1_PneumaticActuator_VIEW_2; \
	MENU trans1_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans1_PneumaticActuator_VIEW_3; \
	MENU trans1_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans1_PneumaticActuator_VIEW_4; \
	MENU trans1_PneumaticActuator_VIEW_4_page

#define USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans1_PneumaticActuator_LIN_TYPE; \
	MENU trans1_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans1_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans1_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans1_PneumaticActuator_RATED_TRAVEL; \
	MENU trans1_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans1_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans1_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans1_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans1_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans1_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans1_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans1_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans1_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans1_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans1_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans1_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans1_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans1_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans1_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans1_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans1_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans1_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans1_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans1_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans1_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans1_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans1_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans1_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans1_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans1_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans1_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans1_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans1_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans1_PneumaticActuator_VALVE_MAN; \
	MENU trans1_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans1_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans1_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans1_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans1_PneumaticActuator_VALVE_TYPE; \
	MENU trans1_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans1_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans1_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans1_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans1_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans1_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans1_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans1_PneumaticActuator_VIEW_1; \
	MENU trans1_PneumaticActuator_VIEW_1_page; \
	MENU trans1_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans1_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_PNEUMATICACTUATOR_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read

#define USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(prefix) \
	USE_TRANS_PNEUMATICACTUATOR_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(prefix) \
	USE_TRANS_PNEUMATICACTUATOR_MANDATORY_BOTH(prefix); \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## RATED_TRAVEL; \
	MENU prefix ## RATED_TRAVEL_page; \
	COMMAND prefix ## RATED_TRAVEL_read; \
	COMMAND prefix ## RATED_TRAVEL_write; \
	VARIABLE prefix ## SELF_CALIB_CMD; \
	MENU prefix ## SELF_CALIB_CMD_page; \
	COMMAND prefix ## SELF_CALIB_CMD_read; \
	COMMAND prefix ## SELF_CALIB_CMD_write; \
	VARIABLE prefix ## SELF_CALIB_STATUS; \
	MENU prefix ## SELF_CALIB_STATUS_page; \
	COMMAND prefix ## SELF_CALIB_STATUS_read; \
	VARIABLE prefix ## SETP_CUTOFF_DEC; \
	MENU prefix ## SETP_CUTOFF_DEC_page; \
	COMMAND prefix ## SETP_CUTOFF_DEC_read; \
	COMMAND prefix ## SETP_CUTOFF_DEC_write; \
	VARIABLE prefix ## SETP_CUTOFF_INC; \
	MENU prefix ## SETP_CUTOFF_INC_page; \
	COMMAND prefix ## SETP_CUTOFF_INC_read; \
	COMMAND prefix ## SETP_CUTOFF_INC_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_LOW; \
	MENU prefix ## TRAVEL_LIMIT_LOW_page; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_read; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_UP; \
	MENU prefix ## TRAVEL_LIMIT_UP_page; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_read; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_write; \
	VARIABLE prefix ## TRAVEL_RATE_DEC; \
	MENU prefix ## TRAVEL_RATE_DEC_page; \
	COMMAND prefix ## TRAVEL_RATE_DEC_read; \
	COMMAND prefix ## TRAVEL_RATE_DEC_write; \
	VARIABLE prefix ## TRAVEL_RATE_INC; \
	MENU prefix ## TRAVEL_RATE_INC_page; \
	COMMAND prefix ## TRAVEL_RATE_INC_read; \
	COMMAND prefix ## TRAVEL_RATE_INC_write; \
	COLLECTION prefix ## POSITIONING_VALUE; \
	VARIABLE prefix ## POSITIONING_VALUE_Value; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Condensed; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Quality; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Limit; \
	MENU prefix ## POSITIONING_VALUE_page; \
	COMMAND prefix ## POSITIONING_VALUE_read; \
	COLLECTION prefix ## FEEDBACK_VALUE; \
	VARIABLE prefix ## FEEDBACK_VALUE_Value; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Quality; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Limit; \
	MENU prefix ## FEEDBACK_VALUE_page; \
	COMMAND prefix ## FEEDBACK_VALUE_read; \
	VARIABLE prefix ## VALVE_MAN; \
	MENU prefix ## VALVE_MAN_page; \
	COMMAND prefix ## VALVE_MAN_read; \
	COMMAND prefix ## VALVE_MAN_write; \
	VARIABLE prefix ## ACTUATOR_MAN; \
	MENU prefix ## ACTUATOR_MAN_page; \
	COMMAND prefix ## ACTUATOR_MAN_read; \
	COMMAND prefix ## ACTUATOR_MAN_write; \
	VARIABLE prefix ## VALVE_TYPE; \
	MENU prefix ## VALVE_TYPE_page; \
	COMMAND prefix ## VALVE_TYPE_read; \
	COMMAND prefix ## VALVE_TYPE_write; \
	VARIABLE prefix ## ACTUATOR_TYPE; \
	MENU prefix ## ACTUATOR_TYPE_page; \
	COMMAND prefix ## ACTUATOR_TYPE_read; \
	VARIABLE prefix ## ACTUATOR_ACTION; \
	MENU prefix ## ACTUATOR_ACTION_page; \
	COMMAND prefix ## ACTUATOR_ACTION_read; \
	COMMAND prefix ## ACTUATOR_ACTION_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## ACT_STROKE_TIME_DEC; \
	MENU prefix ## ACT_STROKE_TIME_DEC_page; \
	COMMAND prefix ## ACT_STROKE_TIME_DEC_read; \
	VARIABLE prefix ## ACT_STROKE_TIME_INC; \
	MENU prefix ## ACT_STROKE_TIME_INC_page; \
	COMMAND prefix ## ACT_STROKE_TIME_INC_read; \
	VARIABLE prefix ## TAB_ENTRY; \
	MENU prefix ## TAB_ENTRY_page; \
	COMMAND prefix ## TAB_ENTRY_read; \
	COMMAND prefix ## TAB_ENTRY_write; \
	COLLECTION prefix ## TAB_X_Y_VALUE; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE prefix ## TAB_X_Y_VALUE_Lower_Value; \
	MENU prefix ## TAB_X_Y_VALUE_page; \
	COMMAND prefix ## TAB_X_Y_VALUE_read; \
	COMMAND prefix ## TAB_X_Y_VALUE_write; \
	VARIABLE prefix ## TAB_MIN_NUMBER; \
	MENU prefix ## TAB_MIN_NUMBER_page; \
	COMMAND prefix ## TAB_MIN_NUMBER_read; \
	VARIABLE prefix ## TAB_MAX_NUMBER; \
	MENU prefix ## TAB_MAX_NUMBER_page; \
	COMMAND prefix ## TAB_MAX_NUMBER_read; \
	VARIABLE prefix ## TAB_ACTUAL_NUMBER; \
	MENU prefix ## TAB_ACTUAL_NUMBER_page; \
	COMMAND prefix ## TAB_ACTUAL_NUMBER_read; \
	VARIABLE prefix ## DEADBAND; \
	MENU prefix ## DEADBAND_page; \
	COMMAND prefix ## DEADBAND_read; \
	COMMAND prefix ## DEADBAND_write; \
	VARIABLE prefix ## DEVICE_CALIB_DATE; \
	MENU prefix ## DEVICE_CALIB_DATE_page; \
	COMMAND prefix ## DEVICE_CALIB_DATE_read; \
	COMMAND prefix ## DEVICE_CALIB_DATE_write; \
	VARIABLE prefix ## DEVICE_CONFIG_DATE; \
	MENU prefix ## DEVICE_CONFIG_DATE_page; \
	COMMAND prefix ## DEVICE_CONFIG_DATE_read; \
	COMMAND prefix ## DEVICE_CONFIG_DATE_write; \
	VARIABLE prefix ## SERVO_GAIN_1; \
	MENU prefix ## SERVO_GAIN_1_page; \
	COMMAND prefix ## SERVO_GAIN_1_read; \
	COMMAND prefix ## SERVO_GAIN_1_write; \
	VARIABLE prefix ## SERVO_RATE_1; \
	MENU prefix ## SERVO_RATE_1_page; \
	COMMAND prefix ## SERVO_RATE_1_read; \
	COMMAND prefix ## SERVO_RATE_1_write; \
	VARIABLE prefix ## SERVO_RESET_1; \
	MENU prefix ## SERVO_RESET_1_page; \
	COMMAND prefix ## SERVO_RESET_1_read; \
	COMMAND prefix ## SERVO_RESET_1_write; \
	VARIABLE prefix ## TOTAL_VALVE_TRAVEL; \
	MENU prefix ## TOTAL_VALVE_TRAVEL_page; \
	COMMAND prefix ## TOTAL_VALVE_TRAVEL_read; \
	VARIABLE prefix ## TOT_VALVE_TRAV_LIM; \
	MENU prefix ## TOT_VALVE_TRAV_LIM_page; \
	COMMAND prefix ## TOT_VALVE_TRAV_LIM_read; \
	COMMAND prefix ## TOT_VALVE_TRAV_LIM_write; \
	VARIABLE prefix ## VALVE_MAINT_DATE; \
	MENU prefix ## VALVE_MAINT_DATE_page; \
	COMMAND prefix ## VALVE_MAINT_DATE_read; \
	COMMAND prefix ## VALVE_MAINT_DATE_write; \
	VARIABLE prefix ## SERVO_GAIN_2; \
	MENU prefix ## SERVO_GAIN_2_page; \
	COMMAND prefix ## SERVO_GAIN_2_read; \
	COMMAND prefix ## SERVO_GAIN_2_write; \
	VARIABLE prefix ## SERVO_RATE_2; \
	MENU prefix ## SERVO_RATE_2_page; \
	COMMAND prefix ## SERVO_RATE_2_read; \
	COMMAND prefix ## SERVO_RATE_2_write; \
	VARIABLE prefix ## SERVO_RESET_2; \
	MENU prefix ## SERVO_RESET_2_page; \
	COMMAND prefix ## SERVO_RESET_2_read; \
	COMMAND prefix ## SERVO_RESET_2_write; \
	VARIABLE prefix ## TAB_OP_CODE; \
	MENU prefix ## TAB_OP_CODE_page; \
	COMMAND prefix ## TAB_OP_CODE_read; \
	COMMAND prefix ## TAB_OP_CODE_write; \
	VARIABLE prefix ## TAB_STATUS; \
	MENU prefix ## TAB_STATUS_page; \
	COMMAND prefix ## TAB_STATUS_read; \
	VARIABLE prefix ## VALVE_SER_NUM; \
	MENU prefix ## VALVE_SER_NUM_page; \
	COMMAND prefix ## VALVE_SER_NUM_read; \
	COMMAND prefix ## VALVE_SER_NUM_write; \
	VARIABLE prefix ## ACTUATOR_SER_NUM; \
	MENU prefix ## ACTUATOR_SER_NUM_page; \
	COMMAND prefix ## ACTUATOR_SER_NUM_read; \
	COMMAND prefix ## ACTUATOR_SER_NUM_write; \
	VARIABLE prefix ## ADD_GEAR_SER_NUM; \
	MENU prefix ## ADD_GEAR_SER_NUM_page; \
	COMMAND prefix ## ADD_GEAR_SER_NUM_read; \
	COMMAND prefix ## ADD_GEAR_SER_NUM_write; \
	VARIABLE prefix ## ADD_GEAR_MAN; \
	MENU prefix ## ADD_GEAR_MAN_page; \
	COMMAND prefix ## ADD_GEAR_MAN_read; \
	COMMAND prefix ## ADD_GEAR_MAN_write; \
	VARIABLE prefix ## ADD_GEAR_ID; \
	MENU prefix ## ADD_GEAR_ID_page; \
	COMMAND prefix ## ADD_GEAR_ID_read; \
	COMMAND prefix ## ADD_GEAR_ID_write; \
	VARIABLE prefix ## ADD_GEAR_INST_DATE; \
	MENU prefix ## ADD_GEAR_INST_DATE_page; \
	COMMAND prefix ## ADD_GEAR_INST_DATE_read; \
	COMMAND prefix ## ADD_GEAR_INST_DATE_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	COLLECTION prefix ## VIEW_4; \
	MENU prefix ## VIEW_4_page

#define USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(prefix) \
	USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_BOTH(prefix); \
	VARIABLE prefix ## LIN_TYPE; \
	MENU prefix ## LIN_TYPE_page; \
	COMMAND prefix ## LIN_TYPE_read; \
	COMMAND prefix ## LIN_TYPE_write; \
	VARIABLE prefix ## RATED_TRAVEL; \
	MENU prefix ## RATED_TRAVEL_page; \
	COMMAND prefix ## RATED_TRAVEL_read; \
	COMMAND prefix ## RATED_TRAVEL_write; \
	VARIABLE prefix ## SELF_CALIB_CMD; \
	MENU prefix ## SELF_CALIB_CMD_page; \
	COMMAND prefix ## SELF_CALIB_CMD_read; \
	COMMAND prefix ## SELF_CALIB_CMD_write; \
	VARIABLE prefix ## SELF_CALIB_STATUS; \
	MENU prefix ## SELF_CALIB_STATUS_page; \
	COMMAND prefix ## SELF_CALIB_STATUS_read; \
	VARIABLE prefix ## SETP_CUTOFF_DEC; \
	MENU prefix ## SETP_CUTOFF_DEC_page; \
	COMMAND prefix ## SETP_CUTOFF_DEC_read; \
	COMMAND prefix ## SETP_CUTOFF_DEC_write; \
	VARIABLE prefix ## SETP_CUTOFF_INC; \
	MENU prefix ## SETP_CUTOFF_INC_page; \
	COMMAND prefix ## SETP_CUTOFF_INC_read; \
	COMMAND prefix ## SETP_CUTOFF_INC_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_LOW; \
	MENU prefix ## TRAVEL_LIMIT_LOW_page; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_read; \
	COMMAND prefix ## TRAVEL_LIMIT_LOW_write; \
	VARIABLE prefix ## TRAVEL_LIMIT_UP; \
	MENU prefix ## TRAVEL_LIMIT_UP_page; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_read; \
	COMMAND prefix ## TRAVEL_LIMIT_UP_write; \
	VARIABLE prefix ## TRAVEL_RATE_DEC; \
	MENU prefix ## TRAVEL_RATE_DEC_page; \
	COMMAND prefix ## TRAVEL_RATE_DEC_read; \
	COMMAND prefix ## TRAVEL_RATE_DEC_write; \
	VARIABLE prefix ## TRAVEL_RATE_INC; \
	MENU prefix ## TRAVEL_RATE_INC_page; \
	COMMAND prefix ## TRAVEL_RATE_INC_read; \
	COMMAND prefix ## TRAVEL_RATE_INC_write; \
	COLLECTION prefix ## POSITIONING_VALUE; \
	VARIABLE prefix ## POSITIONING_VALUE_Value; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Condensed; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Quality; \
	VARIABLE prefix ## POSITIONING_VALUE_Status_Limit; \
	MENU prefix ## POSITIONING_VALUE_page; \
	COMMAND prefix ## POSITIONING_VALUE_read; \
	COLLECTION prefix ## FEEDBACK_VALUE; \
	VARIABLE prefix ## FEEDBACK_VALUE_Value; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Quality; \
	VARIABLE prefix ## FEEDBACK_VALUE_Status_Limit; \
	MENU prefix ## FEEDBACK_VALUE_page; \
	COMMAND prefix ## FEEDBACK_VALUE_read; \
	VARIABLE prefix ## VALVE_MAN; \
	MENU prefix ## VALVE_MAN_page; \
	COMMAND prefix ## VALVE_MAN_read; \
	COMMAND prefix ## VALVE_MAN_write; \
	VARIABLE prefix ## ACTUATOR_MAN; \
	MENU prefix ## ACTUATOR_MAN_page; \
	COMMAND prefix ## ACTUATOR_MAN_read; \
	COMMAND prefix ## ACTUATOR_MAN_write; \
	VARIABLE prefix ## VALVE_TYPE; \
	MENU prefix ## VALVE_TYPE_page; \
	COMMAND prefix ## VALVE_TYPE_read; \
	COMMAND prefix ## VALVE_TYPE_write; \
	VARIABLE prefix ## ACTUATOR_TYPE; \
	MENU prefix ## ACTUATOR_TYPE_page; \
	COMMAND prefix ## ACTUATOR_TYPE_read; \
	VARIABLE prefix ## ACTUATOR_ACTION; \
	MENU prefix ## ACTUATOR_ACTION_page; \
	COMMAND prefix ## ACTUATOR_ACTION_read; \
	COMMAND prefix ## ACTUATOR_ACTION_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(prefix) \
	USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans1_PneumaticActuator_)
#define USE_TRANS1_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans1_PneumaticActuator_)
#define USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans1_PneumaticActuator_)
#define USE_TRANS1_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans1_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans2_PneumaticActuator_block; \
	COLLECTION trans2_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans2_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans2_PneumaticActuator_ST_REV; \
	MENU trans2_PneumaticActuator_ST_REV_page; \
	COMMAND trans2_PneumaticActuator_ST_REV_read; \
	VARIABLE trans2_PneumaticActuator_TAG_DESC; \
	MENU trans2_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans2_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans2_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans2_PneumaticActuator_STRATEGY; \
	MENU trans2_PneumaticActuator_STRATEGY_page; \
	COMMAND trans2_PneumaticActuator_STRATEGY_read; \
	COMMAND trans2_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans2_PneumaticActuator_ALERT_KEY; \
	MENU trans2_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans2_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans2_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans2_PneumaticActuator_TARGET_MODE; \
	MENU trans2_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans2_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans2_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans2_PneumaticActuator_MODE_BLK; \
	VARIABLE trans2_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans2_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans2_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans2_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans2_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans2_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans2_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans2_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans2_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans2_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans2_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans2_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans2_PneumaticActuator_LIN_TYPE; \
	MENU trans2_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans2_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans2_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans2_PneumaticActuator_RATED_TRAVEL; \
	MENU trans2_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans2_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans2_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans2_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans2_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans2_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans2_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans2_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans2_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans2_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans2_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans2_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans2_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans2_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans2_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans2_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans2_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans2_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans2_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans2_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans2_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans2_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans2_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans2_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans2_PneumaticActuator_VALVE_MAN; \
	MENU trans2_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans2_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans2_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans2_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans2_PneumaticActuator_VALVE_TYPE; \
	MENU trans2_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans2_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans2_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans2_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans2_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans2_PneumaticActuator_VIEW_1; \
	MENU trans2_PneumaticActuator_VIEW_1_page; \
	MENU trans2_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans2_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans2_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans2_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans2_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans2_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans2_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans2_PneumaticActuator_TAB_ENTRY; \
	MENU trans2_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans2_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans2_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans2_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans2_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans2_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans2_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans2_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans2_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans2_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans2_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans2_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans2_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans2_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans2_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans2_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans2_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans2_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans2_PneumaticActuator_DEADBAND; \
	MENU trans2_PneumaticActuator_DEADBAND_page; \
	COMMAND trans2_PneumaticActuator_DEADBAND_read; \
	COMMAND trans2_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans2_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans2_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans2_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans2_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans2_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans2_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans2_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans2_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans2_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans2_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans2_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans2_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans2_PneumaticActuator_SERVO_RATE_1; \
	MENU trans2_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans2_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans2_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans2_PneumaticActuator_SERVO_RESET_1; \
	MENU trans2_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans2_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans2_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans2_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans2_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans2_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans2_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans2_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans2_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans2_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans2_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans2_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans2_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans2_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans2_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans2_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans2_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans2_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans2_PneumaticActuator_SERVO_RATE_2; \
	MENU trans2_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans2_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans2_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans2_PneumaticActuator_SERVO_RESET_2; \
	MENU trans2_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans2_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans2_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans2_PneumaticActuator_TAB_OP_CODE; \
	MENU trans2_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans2_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans2_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans2_PneumaticActuator_TAB_STATUS; \
	MENU trans2_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans2_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans2_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans2_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans2_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans2_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans2_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans2_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans2_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans2_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans2_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans2_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans2_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans2_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans2_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans2_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans2_PneumaticActuator_VIEW_2; \
	MENU trans2_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans2_PneumaticActuator_VIEW_3; \
	MENU trans2_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans2_PneumaticActuator_VIEW_4; \
	MENU trans2_PneumaticActuator_VIEW_4_page

#define USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans2_PneumaticActuator_LIN_TYPE; \
	MENU trans2_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans2_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans2_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans2_PneumaticActuator_RATED_TRAVEL; \
	MENU trans2_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans2_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans2_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans2_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans2_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans2_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans2_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans2_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans2_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans2_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans2_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans2_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans2_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans2_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans2_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans2_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans2_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans2_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans2_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans2_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans2_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans2_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans2_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans2_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans2_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans2_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans2_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans2_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans2_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans2_PneumaticActuator_VALVE_MAN; \
	MENU trans2_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans2_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans2_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans2_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans2_PneumaticActuator_VALVE_TYPE; \
	MENU trans2_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans2_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans2_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans2_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans2_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans2_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans2_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans2_PneumaticActuator_VIEW_1; \
	MENU trans2_PneumaticActuator_VIEW_1_page; \
	MENU trans2_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans2_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans2_PneumaticActuator_)
#define USE_TRANS2_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans2_PneumaticActuator_)
#define USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans2_PneumaticActuator_)
#define USE_TRANS2_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans2_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans3_PneumaticActuator_block; \
	COLLECTION trans3_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans3_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans3_PneumaticActuator_ST_REV; \
	MENU trans3_PneumaticActuator_ST_REV_page; \
	COMMAND trans3_PneumaticActuator_ST_REV_read; \
	VARIABLE trans3_PneumaticActuator_TAG_DESC; \
	MENU trans3_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans3_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans3_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans3_PneumaticActuator_STRATEGY; \
	MENU trans3_PneumaticActuator_STRATEGY_page; \
	COMMAND trans3_PneumaticActuator_STRATEGY_read; \
	COMMAND trans3_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans3_PneumaticActuator_ALERT_KEY; \
	MENU trans3_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans3_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans3_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans3_PneumaticActuator_TARGET_MODE; \
	MENU trans3_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans3_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans3_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans3_PneumaticActuator_MODE_BLK; \
	VARIABLE trans3_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans3_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans3_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans3_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans3_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans3_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans3_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans3_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans3_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans3_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans3_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans3_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans3_PneumaticActuator_LIN_TYPE; \
	MENU trans3_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans3_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans3_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans3_PneumaticActuator_RATED_TRAVEL; \
	MENU trans3_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans3_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans3_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans3_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans3_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans3_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans3_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans3_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans3_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans3_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans3_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans3_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans3_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans3_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans3_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans3_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans3_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans3_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans3_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans3_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans3_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans3_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans3_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans3_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans3_PneumaticActuator_VALVE_MAN; \
	MENU trans3_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans3_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans3_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans3_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans3_PneumaticActuator_VALVE_TYPE; \
	MENU trans3_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans3_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans3_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans3_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans3_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans3_PneumaticActuator_VIEW_1; \
	MENU trans3_PneumaticActuator_VIEW_1_page; \
	MENU trans3_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans3_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans3_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans3_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans3_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans3_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans3_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans3_PneumaticActuator_TAB_ENTRY; \
	MENU trans3_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans3_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans3_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans3_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans3_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans3_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans3_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans3_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans3_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans3_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans3_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans3_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans3_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans3_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans3_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans3_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans3_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans3_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans3_PneumaticActuator_DEADBAND; \
	MENU trans3_PneumaticActuator_DEADBAND_page; \
	COMMAND trans3_PneumaticActuator_DEADBAND_read; \
	COMMAND trans3_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans3_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans3_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans3_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans3_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans3_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans3_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans3_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans3_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans3_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans3_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans3_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans3_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans3_PneumaticActuator_SERVO_RATE_1; \
	MENU trans3_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans3_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans3_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans3_PneumaticActuator_SERVO_RESET_1; \
	MENU trans3_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans3_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans3_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans3_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans3_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans3_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans3_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans3_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans3_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans3_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans3_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans3_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans3_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans3_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans3_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans3_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans3_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans3_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans3_PneumaticActuator_SERVO_RATE_2; \
	MENU trans3_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans3_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans3_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans3_PneumaticActuator_SERVO_RESET_2; \
	MENU trans3_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans3_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans3_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans3_PneumaticActuator_TAB_OP_CODE; \
	MENU trans3_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans3_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans3_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans3_PneumaticActuator_TAB_STATUS; \
	MENU trans3_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans3_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans3_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans3_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans3_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans3_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans3_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans3_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans3_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans3_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans3_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans3_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans3_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans3_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans3_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans3_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans3_PneumaticActuator_VIEW_2; \
	MENU trans3_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans3_PneumaticActuator_VIEW_3; \
	MENU trans3_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans3_PneumaticActuator_VIEW_4; \
	MENU trans3_PneumaticActuator_VIEW_4_page

#define USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans3_PneumaticActuator_LIN_TYPE; \
	MENU trans3_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans3_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans3_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans3_PneumaticActuator_RATED_TRAVEL; \
	MENU trans3_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans3_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans3_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans3_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans3_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans3_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans3_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans3_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans3_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans3_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans3_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans3_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans3_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans3_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans3_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans3_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans3_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans3_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans3_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans3_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans3_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans3_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans3_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans3_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans3_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans3_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans3_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans3_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans3_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans3_PneumaticActuator_VALVE_MAN; \
	MENU trans3_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans3_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans3_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans3_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans3_PneumaticActuator_VALVE_TYPE; \
	MENU trans3_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans3_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans3_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans3_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans3_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans3_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans3_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans3_PneumaticActuator_VIEW_1; \
	MENU trans3_PneumaticActuator_VIEW_1_page; \
	MENU trans3_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans3_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans3_PneumaticActuator_)
#define USE_TRANS3_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans3_PneumaticActuator_)
#define USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans3_PneumaticActuator_)
#define USE_TRANS3_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans3_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans4_PneumaticActuator_block; \
	COLLECTION trans4_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans4_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans4_PneumaticActuator_ST_REV; \
	MENU trans4_PneumaticActuator_ST_REV_page; \
	COMMAND trans4_PneumaticActuator_ST_REV_read; \
	VARIABLE trans4_PneumaticActuator_TAG_DESC; \
	MENU trans4_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans4_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans4_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans4_PneumaticActuator_STRATEGY; \
	MENU trans4_PneumaticActuator_STRATEGY_page; \
	COMMAND trans4_PneumaticActuator_STRATEGY_read; \
	COMMAND trans4_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans4_PneumaticActuator_ALERT_KEY; \
	MENU trans4_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans4_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans4_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans4_PneumaticActuator_TARGET_MODE; \
	MENU trans4_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans4_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans4_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans4_PneumaticActuator_MODE_BLK; \
	VARIABLE trans4_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans4_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans4_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans4_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans4_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans4_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans4_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans4_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans4_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans4_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans4_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans4_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans4_PneumaticActuator_LIN_TYPE; \
	MENU trans4_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans4_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans4_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans4_PneumaticActuator_RATED_TRAVEL; \
	MENU trans4_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans4_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans4_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans4_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans4_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans4_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans4_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans4_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans4_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans4_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans4_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans4_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans4_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans4_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans4_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans4_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans4_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans4_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans4_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans4_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans4_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans4_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans4_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans4_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans4_PneumaticActuator_VALVE_MAN; \
	MENU trans4_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans4_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans4_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans4_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans4_PneumaticActuator_VALVE_TYPE; \
	MENU trans4_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans4_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans4_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans4_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans4_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans4_PneumaticActuator_VIEW_1; \
	MENU trans4_PneumaticActuator_VIEW_1_page; \
	MENU trans4_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans4_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans4_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans4_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans4_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans4_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans4_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans4_PneumaticActuator_TAB_ENTRY; \
	MENU trans4_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans4_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans4_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans4_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans4_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans4_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans4_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans4_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans4_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans4_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans4_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans4_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans4_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans4_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans4_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans4_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans4_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans4_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans4_PneumaticActuator_DEADBAND; \
	MENU trans4_PneumaticActuator_DEADBAND_page; \
	COMMAND trans4_PneumaticActuator_DEADBAND_read; \
	COMMAND trans4_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans4_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans4_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans4_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans4_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans4_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans4_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans4_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans4_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans4_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans4_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans4_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans4_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans4_PneumaticActuator_SERVO_RATE_1; \
	MENU trans4_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans4_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans4_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans4_PneumaticActuator_SERVO_RESET_1; \
	MENU trans4_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans4_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans4_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans4_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans4_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans4_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans4_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans4_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans4_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans4_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans4_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans4_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans4_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans4_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans4_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans4_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans4_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans4_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans4_PneumaticActuator_SERVO_RATE_2; \
	MENU trans4_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans4_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans4_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans4_PneumaticActuator_SERVO_RESET_2; \
	MENU trans4_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans4_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans4_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans4_PneumaticActuator_TAB_OP_CODE; \
	MENU trans4_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans4_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans4_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans4_PneumaticActuator_TAB_STATUS; \
	MENU trans4_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans4_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans4_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans4_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans4_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans4_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans4_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans4_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans4_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans4_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans4_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans4_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans4_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans4_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans4_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans4_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans4_PneumaticActuator_VIEW_2; \
	MENU trans4_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans4_PneumaticActuator_VIEW_3; \
	MENU trans4_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans4_PneumaticActuator_VIEW_4; \
	MENU trans4_PneumaticActuator_VIEW_4_page

#define USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans4_PneumaticActuator_LIN_TYPE; \
	MENU trans4_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans4_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans4_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans4_PneumaticActuator_RATED_TRAVEL; \
	MENU trans4_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans4_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans4_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans4_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans4_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans4_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans4_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans4_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans4_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans4_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans4_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans4_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans4_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans4_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans4_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans4_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans4_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans4_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans4_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans4_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans4_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans4_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans4_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans4_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans4_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans4_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans4_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans4_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans4_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans4_PneumaticActuator_VALVE_MAN; \
	MENU trans4_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans4_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans4_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans4_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans4_PneumaticActuator_VALVE_TYPE; \
	MENU trans4_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans4_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans4_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans4_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans4_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans4_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans4_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans4_PneumaticActuator_VIEW_1; \
	MENU trans4_PneumaticActuator_VIEW_1_page; \
	MENU trans4_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans4_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans4_PneumaticActuator_)
#define USE_TRANS4_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans4_PneumaticActuator_)
#define USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans4_PneumaticActuator_)
#define USE_TRANS4_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans4_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans5_PneumaticActuator_block; \
	COLLECTION trans5_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans5_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans5_PneumaticActuator_ST_REV; \
	MENU trans5_PneumaticActuator_ST_REV_page; \
	COMMAND trans5_PneumaticActuator_ST_REV_read; \
	VARIABLE trans5_PneumaticActuator_TAG_DESC; \
	MENU trans5_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans5_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans5_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans5_PneumaticActuator_STRATEGY; \
	MENU trans5_PneumaticActuator_STRATEGY_page; \
	COMMAND trans5_PneumaticActuator_STRATEGY_read; \
	COMMAND trans5_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans5_PneumaticActuator_ALERT_KEY; \
	MENU trans5_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans5_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans5_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans5_PneumaticActuator_TARGET_MODE; \
	MENU trans5_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans5_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans5_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans5_PneumaticActuator_MODE_BLK; \
	VARIABLE trans5_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans5_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans5_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans5_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans5_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans5_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans5_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans5_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans5_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans5_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans5_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans5_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans5_PneumaticActuator_LIN_TYPE; \
	MENU trans5_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans5_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans5_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans5_PneumaticActuator_RATED_TRAVEL; \
	MENU trans5_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans5_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans5_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans5_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans5_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans5_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans5_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans5_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans5_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans5_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans5_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans5_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans5_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans5_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans5_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans5_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans5_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans5_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans5_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans5_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans5_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans5_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans5_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans5_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans5_PneumaticActuator_VALVE_MAN; \
	MENU trans5_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans5_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans5_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans5_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans5_PneumaticActuator_VALVE_TYPE; \
	MENU trans5_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans5_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans5_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans5_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans5_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans5_PneumaticActuator_VIEW_1; \
	MENU trans5_PneumaticActuator_VIEW_1_page; \
	MENU trans5_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans5_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans5_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans5_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans5_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans5_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans5_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans5_PneumaticActuator_TAB_ENTRY; \
	MENU trans5_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans5_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans5_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans5_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans5_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans5_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans5_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans5_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans5_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans5_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans5_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans5_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans5_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans5_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans5_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans5_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans5_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans5_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans5_PneumaticActuator_DEADBAND; \
	MENU trans5_PneumaticActuator_DEADBAND_page; \
	COMMAND trans5_PneumaticActuator_DEADBAND_read; \
	COMMAND trans5_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans5_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans5_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans5_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans5_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans5_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans5_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans5_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans5_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans5_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans5_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans5_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans5_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans5_PneumaticActuator_SERVO_RATE_1; \
	MENU trans5_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans5_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans5_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans5_PneumaticActuator_SERVO_RESET_1; \
	MENU trans5_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans5_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans5_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans5_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans5_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans5_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans5_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans5_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans5_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans5_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans5_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans5_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans5_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans5_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans5_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans5_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans5_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans5_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans5_PneumaticActuator_SERVO_RATE_2; \
	MENU trans5_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans5_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans5_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans5_PneumaticActuator_SERVO_RESET_2; \
	MENU trans5_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans5_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans5_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans5_PneumaticActuator_TAB_OP_CODE; \
	MENU trans5_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans5_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans5_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans5_PneumaticActuator_TAB_STATUS; \
	MENU trans5_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans5_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans5_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans5_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans5_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans5_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans5_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans5_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans5_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans5_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans5_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans5_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans5_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans5_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans5_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans5_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans5_PneumaticActuator_VIEW_2; \
	MENU trans5_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans5_PneumaticActuator_VIEW_3; \
	MENU trans5_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans5_PneumaticActuator_VIEW_4; \
	MENU trans5_PneumaticActuator_VIEW_4_page

#define USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans5_PneumaticActuator_LIN_TYPE; \
	MENU trans5_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans5_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans5_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans5_PneumaticActuator_RATED_TRAVEL; \
	MENU trans5_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans5_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans5_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans5_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans5_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans5_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans5_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans5_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans5_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans5_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans5_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans5_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans5_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans5_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans5_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans5_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans5_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans5_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans5_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans5_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans5_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans5_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans5_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans5_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans5_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans5_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans5_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans5_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans5_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans5_PneumaticActuator_VALVE_MAN; \
	MENU trans5_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans5_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans5_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans5_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans5_PneumaticActuator_VALVE_TYPE; \
	MENU trans5_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans5_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans5_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans5_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans5_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans5_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans5_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans5_PneumaticActuator_VIEW_1; \
	MENU trans5_PneumaticActuator_VIEW_1_page; \
	MENU trans5_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans5_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans5_PneumaticActuator_)
#define USE_TRANS5_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans5_PneumaticActuator_)
#define USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans5_PneumaticActuator_)
#define USE_TRANS5_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans5_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans6_PneumaticActuator_block; \
	COLLECTION trans6_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans6_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans6_PneumaticActuator_ST_REV; \
	MENU trans6_PneumaticActuator_ST_REV_page; \
	COMMAND trans6_PneumaticActuator_ST_REV_read; \
	VARIABLE trans6_PneumaticActuator_TAG_DESC; \
	MENU trans6_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans6_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans6_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans6_PneumaticActuator_STRATEGY; \
	MENU trans6_PneumaticActuator_STRATEGY_page; \
	COMMAND trans6_PneumaticActuator_STRATEGY_read; \
	COMMAND trans6_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans6_PneumaticActuator_ALERT_KEY; \
	MENU trans6_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans6_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans6_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans6_PneumaticActuator_TARGET_MODE; \
	MENU trans6_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans6_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans6_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans6_PneumaticActuator_MODE_BLK; \
	VARIABLE trans6_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans6_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans6_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans6_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans6_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans6_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans6_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans6_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans6_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans6_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans6_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans6_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans6_PneumaticActuator_LIN_TYPE; \
	MENU trans6_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans6_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans6_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans6_PneumaticActuator_RATED_TRAVEL; \
	MENU trans6_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans6_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans6_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans6_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans6_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans6_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans6_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans6_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans6_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans6_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans6_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans6_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans6_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans6_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans6_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans6_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans6_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans6_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans6_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans6_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans6_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans6_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans6_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans6_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans6_PneumaticActuator_VALVE_MAN; \
	MENU trans6_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans6_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans6_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans6_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans6_PneumaticActuator_VALVE_TYPE; \
	MENU trans6_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans6_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans6_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans6_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans6_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans6_PneumaticActuator_VIEW_1; \
	MENU trans6_PneumaticActuator_VIEW_1_page; \
	MENU trans6_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans6_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans6_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans6_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans6_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans6_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans6_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans6_PneumaticActuator_TAB_ENTRY; \
	MENU trans6_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans6_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans6_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans6_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans6_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans6_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans6_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans6_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans6_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans6_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans6_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans6_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans6_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans6_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans6_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans6_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans6_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans6_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans6_PneumaticActuator_DEADBAND; \
	MENU trans6_PneumaticActuator_DEADBAND_page; \
	COMMAND trans6_PneumaticActuator_DEADBAND_read; \
	COMMAND trans6_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans6_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans6_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans6_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans6_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans6_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans6_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans6_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans6_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans6_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans6_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans6_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans6_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans6_PneumaticActuator_SERVO_RATE_1; \
	MENU trans6_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans6_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans6_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans6_PneumaticActuator_SERVO_RESET_1; \
	MENU trans6_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans6_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans6_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans6_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans6_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans6_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans6_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans6_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans6_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans6_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans6_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans6_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans6_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans6_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans6_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans6_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans6_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans6_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans6_PneumaticActuator_SERVO_RATE_2; \
	MENU trans6_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans6_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans6_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans6_PneumaticActuator_SERVO_RESET_2; \
	MENU trans6_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans6_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans6_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans6_PneumaticActuator_TAB_OP_CODE; \
	MENU trans6_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans6_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans6_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans6_PneumaticActuator_TAB_STATUS; \
	MENU trans6_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans6_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans6_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans6_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans6_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans6_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans6_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans6_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans6_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans6_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans6_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans6_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans6_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans6_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans6_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans6_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans6_PneumaticActuator_VIEW_2; \
	MENU trans6_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans6_PneumaticActuator_VIEW_3; \
	MENU trans6_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans6_PneumaticActuator_VIEW_4; \
	MENU trans6_PneumaticActuator_VIEW_4_page

#define USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans6_PneumaticActuator_LIN_TYPE; \
	MENU trans6_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans6_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans6_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans6_PneumaticActuator_RATED_TRAVEL; \
	MENU trans6_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans6_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans6_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans6_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans6_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans6_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans6_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans6_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans6_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans6_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans6_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans6_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans6_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans6_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans6_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans6_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans6_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans6_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans6_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans6_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans6_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans6_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans6_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans6_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans6_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans6_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans6_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans6_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans6_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans6_PneumaticActuator_VALVE_MAN; \
	MENU trans6_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans6_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans6_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans6_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans6_PneumaticActuator_VALVE_TYPE; \
	MENU trans6_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans6_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans6_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans6_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans6_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans6_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans6_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans6_PneumaticActuator_VIEW_1; \
	MENU trans6_PneumaticActuator_VIEW_1_page; \
	MENU trans6_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans6_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans6_PneumaticActuator_)
#define USE_TRANS6_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans6_PneumaticActuator_)
#define USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans6_PneumaticActuator_)
#define USE_TRANS6_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans6_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans7_PneumaticActuator_block; \
	COLLECTION trans7_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans7_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans7_PneumaticActuator_ST_REV; \
	MENU trans7_PneumaticActuator_ST_REV_page; \
	COMMAND trans7_PneumaticActuator_ST_REV_read; \
	VARIABLE trans7_PneumaticActuator_TAG_DESC; \
	MENU trans7_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans7_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans7_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans7_PneumaticActuator_STRATEGY; \
	MENU trans7_PneumaticActuator_STRATEGY_page; \
	COMMAND trans7_PneumaticActuator_STRATEGY_read; \
	COMMAND trans7_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans7_PneumaticActuator_ALERT_KEY; \
	MENU trans7_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans7_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans7_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans7_PneumaticActuator_TARGET_MODE; \
	MENU trans7_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans7_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans7_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans7_PneumaticActuator_MODE_BLK; \
	VARIABLE trans7_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans7_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans7_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans7_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans7_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans7_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans7_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans7_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans7_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans7_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans7_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans7_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans7_PneumaticActuator_LIN_TYPE; \
	MENU trans7_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans7_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans7_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans7_PneumaticActuator_RATED_TRAVEL; \
	MENU trans7_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans7_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans7_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans7_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans7_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans7_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans7_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans7_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans7_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans7_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans7_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans7_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans7_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans7_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans7_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans7_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans7_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans7_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans7_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans7_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans7_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans7_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans7_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans7_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans7_PneumaticActuator_VALVE_MAN; \
	MENU trans7_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans7_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans7_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans7_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans7_PneumaticActuator_VALVE_TYPE; \
	MENU trans7_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans7_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans7_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans7_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans7_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans7_PneumaticActuator_VIEW_1; \
	MENU trans7_PneumaticActuator_VIEW_1_page; \
	MENU trans7_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans7_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans7_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans7_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans7_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans7_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans7_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans7_PneumaticActuator_TAB_ENTRY; \
	MENU trans7_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans7_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans7_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans7_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans7_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans7_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans7_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans7_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans7_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans7_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans7_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans7_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans7_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans7_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans7_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans7_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans7_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans7_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans7_PneumaticActuator_DEADBAND; \
	MENU trans7_PneumaticActuator_DEADBAND_page; \
	COMMAND trans7_PneumaticActuator_DEADBAND_read; \
	COMMAND trans7_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans7_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans7_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans7_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans7_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans7_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans7_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans7_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans7_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans7_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans7_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans7_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans7_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans7_PneumaticActuator_SERVO_RATE_1; \
	MENU trans7_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans7_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans7_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans7_PneumaticActuator_SERVO_RESET_1; \
	MENU trans7_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans7_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans7_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans7_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans7_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans7_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans7_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans7_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans7_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans7_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans7_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans7_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans7_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans7_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans7_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans7_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans7_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans7_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans7_PneumaticActuator_SERVO_RATE_2; \
	MENU trans7_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans7_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans7_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans7_PneumaticActuator_SERVO_RESET_2; \
	MENU trans7_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans7_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans7_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans7_PneumaticActuator_TAB_OP_CODE; \
	MENU trans7_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans7_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans7_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans7_PneumaticActuator_TAB_STATUS; \
	MENU trans7_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans7_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans7_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans7_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans7_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans7_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans7_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans7_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans7_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans7_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans7_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans7_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans7_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans7_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans7_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans7_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans7_PneumaticActuator_VIEW_2; \
	MENU trans7_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans7_PneumaticActuator_VIEW_3; \
	MENU trans7_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans7_PneumaticActuator_VIEW_4; \
	MENU trans7_PneumaticActuator_VIEW_4_page

#define USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans7_PneumaticActuator_LIN_TYPE; \
	MENU trans7_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans7_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans7_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans7_PneumaticActuator_RATED_TRAVEL; \
	MENU trans7_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans7_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans7_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans7_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans7_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans7_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans7_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans7_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans7_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans7_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans7_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans7_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans7_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans7_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans7_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans7_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans7_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans7_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans7_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans7_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans7_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans7_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans7_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans7_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans7_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans7_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans7_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans7_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans7_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans7_PneumaticActuator_VALVE_MAN; \
	MENU trans7_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans7_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans7_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans7_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans7_PneumaticActuator_VALVE_TYPE; \
	MENU trans7_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans7_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans7_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans7_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans7_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans7_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans7_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans7_PneumaticActuator_VIEW_1; \
	MENU trans7_PneumaticActuator_VIEW_1_page; \
	MENU trans7_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans7_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans7_PneumaticActuator_)
#define USE_TRANS7_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans7_PneumaticActuator_)
#define USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans7_PneumaticActuator_)
#define USE_TRANS7_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans7_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans8_PneumaticActuator_block; \
	COLLECTION trans8_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans8_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans8_PneumaticActuator_ST_REV; \
	MENU trans8_PneumaticActuator_ST_REV_page; \
	COMMAND trans8_PneumaticActuator_ST_REV_read; \
	VARIABLE trans8_PneumaticActuator_TAG_DESC; \
	MENU trans8_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans8_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans8_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans8_PneumaticActuator_STRATEGY; \
	MENU trans8_PneumaticActuator_STRATEGY_page; \
	COMMAND trans8_PneumaticActuator_STRATEGY_read; \
	COMMAND trans8_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans8_PneumaticActuator_ALERT_KEY; \
	MENU trans8_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans8_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans8_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans8_PneumaticActuator_TARGET_MODE; \
	MENU trans8_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans8_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans8_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans8_PneumaticActuator_MODE_BLK; \
	VARIABLE trans8_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans8_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans8_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans8_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans8_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans8_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans8_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans8_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans8_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans8_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans8_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans8_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans8_PneumaticActuator_LIN_TYPE; \
	MENU trans8_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans8_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans8_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans8_PneumaticActuator_RATED_TRAVEL; \
	MENU trans8_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans8_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans8_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans8_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans8_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans8_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans8_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans8_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans8_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans8_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans8_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans8_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans8_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans8_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans8_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans8_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans8_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans8_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans8_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans8_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans8_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans8_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans8_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans8_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans8_PneumaticActuator_VALVE_MAN; \
	MENU trans8_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans8_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans8_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans8_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans8_PneumaticActuator_VALVE_TYPE; \
	MENU trans8_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans8_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans8_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans8_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans8_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans8_PneumaticActuator_VIEW_1; \
	MENU trans8_PneumaticActuator_VIEW_1_page; \
	MENU trans8_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans8_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans8_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans8_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans8_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans8_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans8_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans8_PneumaticActuator_TAB_ENTRY; \
	MENU trans8_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans8_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans8_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans8_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans8_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans8_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans8_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans8_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans8_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans8_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans8_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans8_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans8_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans8_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans8_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans8_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans8_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans8_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans8_PneumaticActuator_DEADBAND; \
	MENU trans8_PneumaticActuator_DEADBAND_page; \
	COMMAND trans8_PneumaticActuator_DEADBAND_read; \
	COMMAND trans8_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans8_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans8_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans8_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans8_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans8_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans8_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans8_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans8_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans8_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans8_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans8_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans8_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans8_PneumaticActuator_SERVO_RATE_1; \
	MENU trans8_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans8_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans8_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans8_PneumaticActuator_SERVO_RESET_1; \
	MENU trans8_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans8_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans8_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans8_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans8_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans8_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans8_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans8_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans8_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans8_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans8_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans8_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans8_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans8_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans8_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans8_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans8_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans8_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans8_PneumaticActuator_SERVO_RATE_2; \
	MENU trans8_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans8_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans8_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans8_PneumaticActuator_SERVO_RESET_2; \
	MENU trans8_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans8_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans8_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans8_PneumaticActuator_TAB_OP_CODE; \
	MENU trans8_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans8_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans8_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans8_PneumaticActuator_TAB_STATUS; \
	MENU trans8_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans8_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans8_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans8_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans8_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans8_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans8_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans8_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans8_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans8_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans8_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans8_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans8_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans8_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans8_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans8_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans8_PneumaticActuator_VIEW_2; \
	MENU trans8_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans8_PneumaticActuator_VIEW_3; \
	MENU trans8_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans8_PneumaticActuator_VIEW_4; \
	MENU trans8_PneumaticActuator_VIEW_4_page

#define USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans8_PneumaticActuator_LIN_TYPE; \
	MENU trans8_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans8_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans8_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans8_PneumaticActuator_RATED_TRAVEL; \
	MENU trans8_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans8_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans8_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans8_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans8_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans8_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans8_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans8_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans8_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans8_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans8_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans8_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans8_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans8_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans8_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans8_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans8_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans8_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans8_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans8_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans8_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans8_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans8_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans8_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans8_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans8_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans8_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans8_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans8_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans8_PneumaticActuator_VALVE_MAN; \
	MENU trans8_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans8_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans8_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans8_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans8_PneumaticActuator_VALVE_TYPE; \
	MENU trans8_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans8_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans8_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans8_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans8_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans8_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans8_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans8_PneumaticActuator_VIEW_1; \
	MENU trans8_PneumaticActuator_VIEW_1_page; \
	MENU trans8_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans8_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans8_PneumaticActuator_)
#define USE_TRANS8_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans8_PneumaticActuator_)
#define USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans8_PneumaticActuator_)
#define USE_TRANS8_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans8_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans9_PneumaticActuator_block; \
	COLLECTION trans9_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans9_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans9_PneumaticActuator_ST_REV; \
	MENU trans9_PneumaticActuator_ST_REV_page; \
	COMMAND trans9_PneumaticActuator_ST_REV_read; \
	VARIABLE trans9_PneumaticActuator_TAG_DESC; \
	MENU trans9_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans9_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans9_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans9_PneumaticActuator_STRATEGY; \
	MENU trans9_PneumaticActuator_STRATEGY_page; \
	COMMAND trans9_PneumaticActuator_STRATEGY_read; \
	COMMAND trans9_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans9_PneumaticActuator_ALERT_KEY; \
	MENU trans9_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans9_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans9_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans9_PneumaticActuator_TARGET_MODE; \
	MENU trans9_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans9_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans9_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans9_PneumaticActuator_MODE_BLK; \
	VARIABLE trans9_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans9_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans9_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans9_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans9_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans9_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans9_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans9_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans9_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans9_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans9_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans9_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans9_PneumaticActuator_LIN_TYPE; \
	MENU trans9_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans9_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans9_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans9_PneumaticActuator_RATED_TRAVEL; \
	MENU trans9_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans9_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans9_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans9_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans9_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans9_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans9_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans9_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans9_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans9_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans9_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans9_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans9_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans9_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans9_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans9_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans9_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans9_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans9_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans9_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans9_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans9_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans9_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans9_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans9_PneumaticActuator_VALVE_MAN; \
	MENU trans9_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans9_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans9_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans9_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans9_PneumaticActuator_VALVE_TYPE; \
	MENU trans9_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans9_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans9_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans9_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans9_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans9_PneumaticActuator_VIEW_1; \
	MENU trans9_PneumaticActuator_VIEW_1_page; \
	MENU trans9_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans9_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans9_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans9_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans9_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans9_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans9_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans9_PneumaticActuator_TAB_ENTRY; \
	MENU trans9_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans9_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans9_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans9_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans9_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans9_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans9_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans9_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans9_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans9_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans9_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans9_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans9_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans9_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans9_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans9_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans9_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans9_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans9_PneumaticActuator_DEADBAND; \
	MENU trans9_PneumaticActuator_DEADBAND_page; \
	COMMAND trans9_PneumaticActuator_DEADBAND_read; \
	COMMAND trans9_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans9_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans9_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans9_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans9_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans9_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans9_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans9_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans9_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans9_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans9_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans9_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans9_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans9_PneumaticActuator_SERVO_RATE_1; \
	MENU trans9_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans9_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans9_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans9_PneumaticActuator_SERVO_RESET_1; \
	MENU trans9_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans9_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans9_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans9_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans9_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans9_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans9_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans9_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans9_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans9_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans9_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans9_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans9_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans9_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans9_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans9_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans9_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans9_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans9_PneumaticActuator_SERVO_RATE_2; \
	MENU trans9_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans9_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans9_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans9_PneumaticActuator_SERVO_RESET_2; \
	MENU trans9_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans9_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans9_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans9_PneumaticActuator_TAB_OP_CODE; \
	MENU trans9_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans9_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans9_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans9_PneumaticActuator_TAB_STATUS; \
	MENU trans9_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans9_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans9_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans9_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans9_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans9_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans9_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans9_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans9_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans9_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans9_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans9_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans9_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans9_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans9_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans9_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans9_PneumaticActuator_VIEW_2; \
	MENU trans9_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans9_PneumaticActuator_VIEW_3; \
	MENU trans9_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans9_PneumaticActuator_VIEW_4; \
	MENU trans9_PneumaticActuator_VIEW_4_page

#define USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans9_PneumaticActuator_LIN_TYPE; \
	MENU trans9_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans9_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans9_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans9_PneumaticActuator_RATED_TRAVEL; \
	MENU trans9_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans9_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans9_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans9_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans9_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans9_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans9_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans9_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans9_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans9_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans9_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans9_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans9_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans9_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans9_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans9_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans9_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans9_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans9_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans9_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans9_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans9_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans9_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans9_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans9_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans9_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans9_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans9_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans9_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans9_PneumaticActuator_VALVE_MAN; \
	MENU trans9_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans9_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans9_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans9_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans9_PneumaticActuator_VALVE_TYPE; \
	MENU trans9_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans9_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans9_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans9_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans9_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans9_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans9_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans9_PneumaticActuator_VIEW_1; \
	MENU trans9_PneumaticActuator_VIEW_1_page; \
	MENU trans9_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans9_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans9_PneumaticActuator_)
#define USE_TRANS9_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans9_PneumaticActuator_)
#define USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans9_PneumaticActuator_)
#define USE_TRANS9_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans9_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans10_PneumaticActuator_block; \
	COLLECTION trans10_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans10_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans10_PneumaticActuator_ST_REV; \
	MENU trans10_PneumaticActuator_ST_REV_page; \
	COMMAND trans10_PneumaticActuator_ST_REV_read; \
	VARIABLE trans10_PneumaticActuator_TAG_DESC; \
	MENU trans10_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans10_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans10_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans10_PneumaticActuator_STRATEGY; \
	MENU trans10_PneumaticActuator_STRATEGY_page; \
	COMMAND trans10_PneumaticActuator_STRATEGY_read; \
	COMMAND trans10_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans10_PneumaticActuator_ALERT_KEY; \
	MENU trans10_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans10_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans10_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans10_PneumaticActuator_TARGET_MODE; \
	MENU trans10_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans10_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans10_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans10_PneumaticActuator_MODE_BLK; \
	VARIABLE trans10_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans10_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans10_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans10_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans10_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans10_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans10_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans10_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans10_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans10_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans10_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans10_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans10_PneumaticActuator_LIN_TYPE; \
	MENU trans10_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans10_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans10_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans10_PneumaticActuator_RATED_TRAVEL; \
	MENU trans10_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans10_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans10_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans10_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans10_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans10_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans10_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans10_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans10_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans10_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans10_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans10_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans10_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans10_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans10_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans10_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans10_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans10_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans10_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans10_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans10_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans10_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans10_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans10_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans10_PneumaticActuator_VALVE_MAN; \
	MENU trans10_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans10_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans10_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans10_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans10_PneumaticActuator_VALVE_TYPE; \
	MENU trans10_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans10_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans10_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans10_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans10_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans10_PneumaticActuator_VIEW_1; \
	MENU trans10_PneumaticActuator_VIEW_1_page; \
	MENU trans10_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans10_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans10_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans10_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans10_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans10_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans10_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans10_PneumaticActuator_TAB_ENTRY; \
	MENU trans10_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans10_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans10_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans10_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans10_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans10_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans10_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans10_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans10_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans10_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans10_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans10_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans10_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans10_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans10_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans10_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans10_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans10_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans10_PneumaticActuator_DEADBAND; \
	MENU trans10_PneumaticActuator_DEADBAND_page; \
	COMMAND trans10_PneumaticActuator_DEADBAND_read; \
	COMMAND trans10_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans10_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans10_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans10_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans10_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans10_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans10_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans10_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans10_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans10_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans10_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans10_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans10_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans10_PneumaticActuator_SERVO_RATE_1; \
	MENU trans10_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans10_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans10_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans10_PneumaticActuator_SERVO_RESET_1; \
	MENU trans10_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans10_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans10_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans10_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans10_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans10_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans10_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans10_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans10_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans10_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans10_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans10_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans10_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans10_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans10_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans10_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans10_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans10_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans10_PneumaticActuator_SERVO_RATE_2; \
	MENU trans10_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans10_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans10_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans10_PneumaticActuator_SERVO_RESET_2; \
	MENU trans10_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans10_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans10_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans10_PneumaticActuator_TAB_OP_CODE; \
	MENU trans10_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans10_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans10_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans10_PneumaticActuator_TAB_STATUS; \
	MENU trans10_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans10_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans10_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans10_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans10_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans10_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans10_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans10_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans10_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans10_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans10_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans10_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans10_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans10_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans10_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans10_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans10_PneumaticActuator_VIEW_2; \
	MENU trans10_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans10_PneumaticActuator_VIEW_3; \
	MENU trans10_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans10_PneumaticActuator_VIEW_4; \
	MENU trans10_PneumaticActuator_VIEW_4_page

#define USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans10_PneumaticActuator_LIN_TYPE; \
	MENU trans10_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans10_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans10_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans10_PneumaticActuator_RATED_TRAVEL; \
	MENU trans10_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans10_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans10_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans10_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans10_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans10_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans10_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans10_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans10_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans10_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans10_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans10_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans10_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans10_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans10_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans10_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans10_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans10_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans10_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans10_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans10_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans10_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans10_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans10_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans10_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans10_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans10_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans10_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans10_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans10_PneumaticActuator_VALVE_MAN; \
	MENU trans10_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans10_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans10_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans10_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans10_PneumaticActuator_VALVE_TYPE; \
	MENU trans10_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans10_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans10_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans10_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans10_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans10_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans10_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans10_PneumaticActuator_VIEW_1; \
	MENU trans10_PneumaticActuator_VIEW_1_page; \
	MENU trans10_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans10_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans10_PneumaticActuator_)
#define USE_TRANS10_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans10_PneumaticActuator_)
#define USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans10_PneumaticActuator_)
#define USE_TRANS10_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans10_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans11_PneumaticActuator_block; \
	COLLECTION trans11_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans11_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans11_PneumaticActuator_ST_REV; \
	MENU trans11_PneumaticActuator_ST_REV_page; \
	COMMAND trans11_PneumaticActuator_ST_REV_read; \
	VARIABLE trans11_PneumaticActuator_TAG_DESC; \
	MENU trans11_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans11_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans11_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans11_PneumaticActuator_STRATEGY; \
	MENU trans11_PneumaticActuator_STRATEGY_page; \
	COMMAND trans11_PneumaticActuator_STRATEGY_read; \
	COMMAND trans11_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans11_PneumaticActuator_ALERT_KEY; \
	MENU trans11_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans11_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans11_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans11_PneumaticActuator_TARGET_MODE; \
	MENU trans11_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans11_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans11_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans11_PneumaticActuator_MODE_BLK; \
	VARIABLE trans11_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans11_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans11_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans11_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans11_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans11_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans11_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans11_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans11_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans11_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans11_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans11_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans11_PneumaticActuator_LIN_TYPE; \
	MENU trans11_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans11_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans11_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans11_PneumaticActuator_RATED_TRAVEL; \
	MENU trans11_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans11_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans11_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans11_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans11_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans11_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans11_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans11_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans11_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans11_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans11_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans11_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans11_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans11_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans11_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans11_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans11_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans11_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans11_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans11_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans11_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans11_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans11_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans11_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans11_PneumaticActuator_VALVE_MAN; \
	MENU trans11_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans11_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans11_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans11_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans11_PneumaticActuator_VALVE_TYPE; \
	MENU trans11_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans11_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans11_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans11_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans11_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans11_PneumaticActuator_VIEW_1; \
	MENU trans11_PneumaticActuator_VIEW_1_page; \
	MENU trans11_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans11_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans11_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans11_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans11_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans11_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans11_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans11_PneumaticActuator_TAB_ENTRY; \
	MENU trans11_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans11_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans11_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans11_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans11_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans11_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans11_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans11_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans11_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans11_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans11_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans11_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans11_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans11_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans11_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans11_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans11_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans11_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans11_PneumaticActuator_DEADBAND; \
	MENU trans11_PneumaticActuator_DEADBAND_page; \
	COMMAND trans11_PneumaticActuator_DEADBAND_read; \
	COMMAND trans11_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans11_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans11_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans11_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans11_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans11_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans11_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans11_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans11_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans11_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans11_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans11_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans11_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans11_PneumaticActuator_SERVO_RATE_1; \
	MENU trans11_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans11_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans11_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans11_PneumaticActuator_SERVO_RESET_1; \
	MENU trans11_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans11_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans11_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans11_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans11_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans11_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans11_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans11_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans11_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans11_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans11_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans11_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans11_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans11_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans11_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans11_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans11_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans11_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans11_PneumaticActuator_SERVO_RATE_2; \
	MENU trans11_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans11_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans11_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans11_PneumaticActuator_SERVO_RESET_2; \
	MENU trans11_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans11_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans11_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans11_PneumaticActuator_TAB_OP_CODE; \
	MENU trans11_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans11_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans11_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans11_PneumaticActuator_TAB_STATUS; \
	MENU trans11_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans11_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans11_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans11_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans11_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans11_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans11_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans11_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans11_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans11_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans11_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans11_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans11_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans11_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans11_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans11_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans11_PneumaticActuator_VIEW_2; \
	MENU trans11_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans11_PneumaticActuator_VIEW_3; \
	MENU trans11_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans11_PneumaticActuator_VIEW_4; \
	MENU trans11_PneumaticActuator_VIEW_4_page

#define USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans11_PneumaticActuator_LIN_TYPE; \
	MENU trans11_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans11_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans11_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans11_PneumaticActuator_RATED_TRAVEL; \
	MENU trans11_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans11_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans11_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans11_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans11_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans11_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans11_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans11_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans11_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans11_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans11_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans11_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans11_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans11_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans11_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans11_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans11_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans11_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans11_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans11_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans11_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans11_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans11_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans11_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans11_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans11_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans11_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans11_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans11_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans11_PneumaticActuator_VALVE_MAN; \
	MENU trans11_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans11_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans11_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans11_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans11_PneumaticActuator_VALVE_TYPE; \
	MENU trans11_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans11_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans11_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans11_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans11_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans11_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans11_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans11_PneumaticActuator_VIEW_1; \
	MENU trans11_PneumaticActuator_VIEW_1_page; \
	MENU trans11_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans11_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans11_PneumaticActuator_)
#define USE_TRANS11_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans11_PneumaticActuator_)
#define USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans11_PneumaticActuator_)
#define USE_TRANS11_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans11_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans12_PneumaticActuator_block; \
	COLLECTION trans12_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans12_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans12_PneumaticActuator_ST_REV; \
	MENU trans12_PneumaticActuator_ST_REV_page; \
	COMMAND trans12_PneumaticActuator_ST_REV_read; \
	VARIABLE trans12_PneumaticActuator_TAG_DESC; \
	MENU trans12_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans12_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans12_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans12_PneumaticActuator_STRATEGY; \
	MENU trans12_PneumaticActuator_STRATEGY_page; \
	COMMAND trans12_PneumaticActuator_STRATEGY_read; \
	COMMAND trans12_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans12_PneumaticActuator_ALERT_KEY; \
	MENU trans12_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans12_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans12_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans12_PneumaticActuator_TARGET_MODE; \
	MENU trans12_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans12_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans12_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans12_PneumaticActuator_MODE_BLK; \
	VARIABLE trans12_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans12_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans12_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans12_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans12_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans12_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans12_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans12_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans12_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans12_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans12_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans12_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans12_PneumaticActuator_LIN_TYPE; \
	MENU trans12_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans12_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans12_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans12_PneumaticActuator_RATED_TRAVEL; \
	MENU trans12_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans12_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans12_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans12_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans12_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans12_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans12_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans12_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans12_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans12_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans12_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans12_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans12_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans12_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans12_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans12_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans12_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans12_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans12_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans12_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans12_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans12_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans12_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans12_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans12_PneumaticActuator_VALVE_MAN; \
	MENU trans12_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans12_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans12_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans12_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans12_PneumaticActuator_VALVE_TYPE; \
	MENU trans12_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans12_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans12_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans12_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans12_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans12_PneumaticActuator_VIEW_1; \
	MENU trans12_PneumaticActuator_VIEW_1_page; \
	MENU trans12_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans12_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans12_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans12_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans12_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans12_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans12_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans12_PneumaticActuator_TAB_ENTRY; \
	MENU trans12_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans12_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans12_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans12_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans12_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans12_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans12_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans12_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans12_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans12_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans12_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans12_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans12_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans12_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans12_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans12_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans12_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans12_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans12_PneumaticActuator_DEADBAND; \
	MENU trans12_PneumaticActuator_DEADBAND_page; \
	COMMAND trans12_PneumaticActuator_DEADBAND_read; \
	COMMAND trans12_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans12_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans12_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans12_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans12_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans12_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans12_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans12_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans12_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans12_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans12_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans12_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans12_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans12_PneumaticActuator_SERVO_RATE_1; \
	MENU trans12_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans12_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans12_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans12_PneumaticActuator_SERVO_RESET_1; \
	MENU trans12_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans12_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans12_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans12_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans12_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans12_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans12_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans12_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans12_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans12_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans12_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans12_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans12_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans12_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans12_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans12_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans12_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans12_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans12_PneumaticActuator_SERVO_RATE_2; \
	MENU trans12_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans12_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans12_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans12_PneumaticActuator_SERVO_RESET_2; \
	MENU trans12_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans12_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans12_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans12_PneumaticActuator_TAB_OP_CODE; \
	MENU trans12_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans12_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans12_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans12_PneumaticActuator_TAB_STATUS; \
	MENU trans12_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans12_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans12_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans12_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans12_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans12_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans12_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans12_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans12_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans12_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans12_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans12_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans12_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans12_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans12_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans12_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans12_PneumaticActuator_VIEW_2; \
	MENU trans12_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans12_PneumaticActuator_VIEW_3; \
	MENU trans12_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans12_PneumaticActuator_VIEW_4; \
	MENU trans12_PneumaticActuator_VIEW_4_page

#define USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans12_PneumaticActuator_LIN_TYPE; \
	MENU trans12_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans12_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans12_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans12_PneumaticActuator_RATED_TRAVEL; \
	MENU trans12_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans12_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans12_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans12_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans12_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans12_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans12_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans12_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans12_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans12_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans12_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans12_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans12_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans12_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans12_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans12_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans12_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans12_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans12_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans12_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans12_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans12_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans12_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans12_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans12_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans12_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans12_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans12_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans12_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans12_PneumaticActuator_VALVE_MAN; \
	MENU trans12_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans12_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans12_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans12_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans12_PneumaticActuator_VALVE_TYPE; \
	MENU trans12_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans12_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans12_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans12_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans12_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans12_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans12_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans12_PneumaticActuator_VIEW_1; \
	MENU trans12_PneumaticActuator_VIEW_1_page; \
	MENU trans12_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans12_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans12_PneumaticActuator_)
#define USE_TRANS12_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans12_PneumaticActuator_)
#define USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans12_PneumaticActuator_)
#define USE_TRANS12_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans12_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans13_PneumaticActuator_block; \
	COLLECTION trans13_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans13_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans13_PneumaticActuator_ST_REV; \
	MENU trans13_PneumaticActuator_ST_REV_page; \
	COMMAND trans13_PneumaticActuator_ST_REV_read; \
	VARIABLE trans13_PneumaticActuator_TAG_DESC; \
	MENU trans13_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans13_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans13_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans13_PneumaticActuator_STRATEGY; \
	MENU trans13_PneumaticActuator_STRATEGY_page; \
	COMMAND trans13_PneumaticActuator_STRATEGY_read; \
	COMMAND trans13_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans13_PneumaticActuator_ALERT_KEY; \
	MENU trans13_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans13_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans13_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans13_PneumaticActuator_TARGET_MODE; \
	MENU trans13_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans13_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans13_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans13_PneumaticActuator_MODE_BLK; \
	VARIABLE trans13_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans13_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans13_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans13_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans13_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans13_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans13_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans13_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans13_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans13_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans13_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans13_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans13_PneumaticActuator_LIN_TYPE; \
	MENU trans13_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans13_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans13_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans13_PneumaticActuator_RATED_TRAVEL; \
	MENU trans13_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans13_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans13_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans13_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans13_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans13_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans13_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans13_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans13_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans13_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans13_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans13_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans13_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans13_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans13_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans13_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans13_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans13_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans13_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans13_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans13_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans13_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans13_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans13_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans13_PneumaticActuator_VALVE_MAN; \
	MENU trans13_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans13_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans13_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans13_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans13_PneumaticActuator_VALVE_TYPE; \
	MENU trans13_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans13_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans13_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans13_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans13_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans13_PneumaticActuator_VIEW_1; \
	MENU trans13_PneumaticActuator_VIEW_1_page; \
	MENU trans13_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans13_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans13_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans13_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans13_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans13_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans13_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans13_PneumaticActuator_TAB_ENTRY; \
	MENU trans13_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans13_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans13_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans13_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans13_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans13_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans13_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans13_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans13_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans13_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans13_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans13_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans13_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans13_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans13_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans13_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans13_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans13_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans13_PneumaticActuator_DEADBAND; \
	MENU trans13_PneumaticActuator_DEADBAND_page; \
	COMMAND trans13_PneumaticActuator_DEADBAND_read; \
	COMMAND trans13_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans13_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans13_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans13_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans13_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans13_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans13_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans13_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans13_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans13_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans13_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans13_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans13_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans13_PneumaticActuator_SERVO_RATE_1; \
	MENU trans13_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans13_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans13_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans13_PneumaticActuator_SERVO_RESET_1; \
	MENU trans13_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans13_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans13_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans13_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans13_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans13_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans13_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans13_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans13_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans13_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans13_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans13_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans13_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans13_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans13_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans13_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans13_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans13_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans13_PneumaticActuator_SERVO_RATE_2; \
	MENU trans13_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans13_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans13_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans13_PneumaticActuator_SERVO_RESET_2; \
	MENU trans13_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans13_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans13_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans13_PneumaticActuator_TAB_OP_CODE; \
	MENU trans13_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans13_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans13_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans13_PneumaticActuator_TAB_STATUS; \
	MENU trans13_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans13_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans13_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans13_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans13_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans13_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans13_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans13_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans13_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans13_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans13_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans13_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans13_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans13_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans13_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans13_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans13_PneumaticActuator_VIEW_2; \
	MENU trans13_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans13_PneumaticActuator_VIEW_3; \
	MENU trans13_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans13_PneumaticActuator_VIEW_4; \
	MENU trans13_PneumaticActuator_VIEW_4_page

#define USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans13_PneumaticActuator_LIN_TYPE; \
	MENU trans13_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans13_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans13_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans13_PneumaticActuator_RATED_TRAVEL; \
	MENU trans13_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans13_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans13_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans13_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans13_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans13_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans13_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans13_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans13_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans13_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans13_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans13_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans13_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans13_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans13_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans13_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans13_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans13_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans13_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans13_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans13_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans13_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans13_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans13_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans13_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans13_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans13_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans13_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans13_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans13_PneumaticActuator_VALVE_MAN; \
	MENU trans13_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans13_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans13_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans13_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans13_PneumaticActuator_VALVE_TYPE; \
	MENU trans13_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans13_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans13_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans13_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans13_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans13_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans13_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans13_PneumaticActuator_VIEW_1; \
	MENU trans13_PneumaticActuator_VIEW_1_page; \
	MENU trans13_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans13_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans13_PneumaticActuator_)
#define USE_TRANS13_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans13_PneumaticActuator_)
#define USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans13_PneumaticActuator_)
#define USE_TRANS13_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans13_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans14_PneumaticActuator_block; \
	COLLECTION trans14_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans14_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans14_PneumaticActuator_ST_REV; \
	MENU trans14_PneumaticActuator_ST_REV_page; \
	COMMAND trans14_PneumaticActuator_ST_REV_read; \
	VARIABLE trans14_PneumaticActuator_TAG_DESC; \
	MENU trans14_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans14_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans14_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans14_PneumaticActuator_STRATEGY; \
	MENU trans14_PneumaticActuator_STRATEGY_page; \
	COMMAND trans14_PneumaticActuator_STRATEGY_read; \
	COMMAND trans14_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans14_PneumaticActuator_ALERT_KEY; \
	MENU trans14_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans14_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans14_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans14_PneumaticActuator_TARGET_MODE; \
	MENU trans14_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans14_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans14_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans14_PneumaticActuator_MODE_BLK; \
	VARIABLE trans14_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans14_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans14_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans14_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans14_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans14_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans14_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans14_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans14_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans14_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans14_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans14_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans14_PneumaticActuator_LIN_TYPE; \
	MENU trans14_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans14_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans14_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans14_PneumaticActuator_RATED_TRAVEL; \
	MENU trans14_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans14_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans14_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans14_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans14_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans14_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans14_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans14_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans14_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans14_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans14_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans14_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans14_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans14_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans14_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans14_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans14_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans14_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans14_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans14_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans14_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans14_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans14_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans14_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans14_PneumaticActuator_VALVE_MAN; \
	MENU trans14_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans14_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans14_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans14_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans14_PneumaticActuator_VALVE_TYPE; \
	MENU trans14_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans14_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans14_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans14_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans14_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans14_PneumaticActuator_VIEW_1; \
	MENU trans14_PneumaticActuator_VIEW_1_page; \
	MENU trans14_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans14_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans14_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans14_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans14_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans14_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans14_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans14_PneumaticActuator_TAB_ENTRY; \
	MENU trans14_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans14_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans14_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans14_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans14_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans14_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans14_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans14_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans14_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans14_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans14_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans14_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans14_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans14_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans14_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans14_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans14_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans14_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans14_PneumaticActuator_DEADBAND; \
	MENU trans14_PneumaticActuator_DEADBAND_page; \
	COMMAND trans14_PneumaticActuator_DEADBAND_read; \
	COMMAND trans14_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans14_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans14_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans14_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans14_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans14_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans14_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans14_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans14_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans14_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans14_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans14_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans14_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans14_PneumaticActuator_SERVO_RATE_1; \
	MENU trans14_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans14_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans14_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans14_PneumaticActuator_SERVO_RESET_1; \
	MENU trans14_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans14_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans14_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans14_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans14_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans14_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans14_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans14_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans14_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans14_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans14_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans14_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans14_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans14_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans14_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans14_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans14_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans14_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans14_PneumaticActuator_SERVO_RATE_2; \
	MENU trans14_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans14_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans14_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans14_PneumaticActuator_SERVO_RESET_2; \
	MENU trans14_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans14_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans14_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans14_PneumaticActuator_TAB_OP_CODE; \
	MENU trans14_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans14_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans14_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans14_PneumaticActuator_TAB_STATUS; \
	MENU trans14_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans14_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans14_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans14_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans14_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans14_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans14_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans14_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans14_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans14_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans14_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans14_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans14_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans14_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans14_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans14_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans14_PneumaticActuator_VIEW_2; \
	MENU trans14_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans14_PneumaticActuator_VIEW_3; \
	MENU trans14_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans14_PneumaticActuator_VIEW_4; \
	MENU trans14_PneumaticActuator_VIEW_4_page

#define USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans14_PneumaticActuator_LIN_TYPE; \
	MENU trans14_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans14_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans14_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans14_PneumaticActuator_RATED_TRAVEL; \
	MENU trans14_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans14_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans14_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans14_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans14_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans14_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans14_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans14_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans14_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans14_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans14_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans14_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans14_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans14_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans14_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans14_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans14_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans14_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans14_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans14_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans14_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans14_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans14_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans14_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans14_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans14_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans14_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans14_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans14_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans14_PneumaticActuator_VALVE_MAN; \
	MENU trans14_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans14_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans14_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans14_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans14_PneumaticActuator_VALVE_TYPE; \
	MENU trans14_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans14_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans14_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans14_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans14_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans14_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans14_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans14_PneumaticActuator_VIEW_1; \
	MENU trans14_PneumaticActuator_VIEW_1_page; \
	MENU trans14_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans14_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans14_PneumaticActuator_)
#define USE_TRANS14_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans14_PneumaticActuator_)
#define USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans14_PneumaticActuator_)
#define USE_TRANS14_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans14_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_BOTH \
	BLOCK trans15_PneumaticActuator_block; \
	COLLECTION trans15_PneumaticActuator_BLOCK_OBJECT; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Class; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_PneumaticActuator_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_PneumaticActuator_BLOCK_OBJECT_page; \
	COMMAND trans15_PneumaticActuator_BLOCK_OBJECT_read; \
	VARIABLE trans15_PneumaticActuator_ST_REV; \
	MENU trans15_PneumaticActuator_ST_REV_page; \
	COMMAND trans15_PneumaticActuator_ST_REV_read; \
	VARIABLE trans15_PneumaticActuator_TAG_DESC; \
	MENU trans15_PneumaticActuator_TAG_DESC_page; \
	COMMAND trans15_PneumaticActuator_TAG_DESC_read; \
	COMMAND trans15_PneumaticActuator_TAG_DESC_write; \
	VARIABLE trans15_PneumaticActuator_STRATEGY; \
	MENU trans15_PneumaticActuator_STRATEGY_page; \
	COMMAND trans15_PneumaticActuator_STRATEGY_read; \
	COMMAND trans15_PneumaticActuator_STRATEGY_write; \
	VARIABLE trans15_PneumaticActuator_ALERT_KEY; \
	MENU trans15_PneumaticActuator_ALERT_KEY_page; \
	COMMAND trans15_PneumaticActuator_ALERT_KEY_read; \
	COMMAND trans15_PneumaticActuator_ALERT_KEY_write; \
	VARIABLE trans15_PneumaticActuator_TARGET_MODE; \
	MENU trans15_PneumaticActuator_TARGET_MODE_page; \
	COMMAND trans15_PneumaticActuator_TARGET_MODE_read; \
	COMMAND trans15_PneumaticActuator_TARGET_MODE_write; \
	COLLECTION trans15_PneumaticActuator_MODE_BLK; \
	VARIABLE trans15_PneumaticActuator_MODE_BLK_Actual; \
	VARIABLE trans15_PneumaticActuator_MODE_BLK_Permitted; \
	VARIABLE trans15_PneumaticActuator_MODE_BLK_Normal; \
	MENU trans15_PneumaticActuator_MODE_BLK_page; \
	COMMAND trans15_PneumaticActuator_MODE_BLK_read; \
	COLLECTION trans15_PneumaticActuator_ALARM_SUM; \
	VARIABLE trans15_PneumaticActuator_ALARM_SUM_Current; \
	VARIABLE trans15_PneumaticActuator_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_PneumaticActuator_ALARM_SUM_Unreported; \
	VARIABLE trans15_PneumaticActuator_ALARM_SUM_Disabled; \
	MENU trans15_PneumaticActuator_ALARM_SUM_page; \
	COMMAND trans15_PneumaticActuator_ALARM_SUM_read

#define USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_A \
	USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	MENU trans15_PneumaticActuator_Simple_Dialog_Mandatory_A

#define USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_B \
	USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_BOTH; \
	VARIABLE trans15_PneumaticActuator_LIN_TYPE; \
	MENU trans15_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans15_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans15_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans15_PneumaticActuator_RATED_TRAVEL; \
	MENU trans15_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans15_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans15_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans15_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans15_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans15_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans15_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans15_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans15_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans15_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans15_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans15_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans15_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans15_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans15_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans15_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans15_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans15_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans15_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans15_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans15_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans15_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans15_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans15_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans15_PneumaticActuator_VALVE_MAN; \
	MENU trans15_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans15_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans15_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans15_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans15_PneumaticActuator_VALVE_TYPE; \
	MENU trans15_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans15_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans15_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans15_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans15_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans15_PneumaticActuator_VIEW_1; \
	MENU trans15_PneumaticActuator_VIEW_1_page; \
	MENU trans15_PneumaticActuator_Simple_Dialog_Mandatory_B

#define USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_BOTH \
	VARIABLE trans15_PneumaticActuator_ACT_STROKE_TIME_DEC; \
	MENU trans15_PneumaticActuator_ACT_STROKE_TIME_DEC_page; \
	COMMAND trans15_PneumaticActuator_ACT_STROKE_TIME_DEC_read; \
	VARIABLE trans15_PneumaticActuator_ACT_STROKE_TIME_INC; \
	MENU trans15_PneumaticActuator_ACT_STROKE_TIME_INC_page; \
	COMMAND trans15_PneumaticActuator_ACT_STROKE_TIME_INC_read; \
	VARIABLE trans15_PneumaticActuator_TAB_ENTRY; \
	MENU trans15_PneumaticActuator_TAB_ENTRY_page; \
	COMMAND trans15_PneumaticActuator_TAB_ENTRY_read; \
	COMMAND trans15_PneumaticActuator_TAB_ENTRY_write; \
	COLLECTION trans15_PneumaticActuator_TAB_X_Y_VALUE; \
	VARIABLE trans15_PneumaticActuator_TAB_X_Y_VALUE_Upper_Value; \
	VARIABLE trans15_PneumaticActuator_TAB_X_Y_VALUE_Lower_Value; \
	MENU trans15_PneumaticActuator_TAB_X_Y_VALUE_page; \
	COMMAND trans15_PneumaticActuator_TAB_X_Y_VALUE_read; \
	COMMAND trans15_PneumaticActuator_TAB_X_Y_VALUE_write; \
	VARIABLE trans15_PneumaticActuator_TAB_MIN_NUMBER; \
	MENU trans15_PneumaticActuator_TAB_MIN_NUMBER_page; \
	COMMAND trans15_PneumaticActuator_TAB_MIN_NUMBER_read; \
	VARIABLE trans15_PneumaticActuator_TAB_MAX_NUMBER; \
	MENU trans15_PneumaticActuator_TAB_MAX_NUMBER_page; \
	COMMAND trans15_PneumaticActuator_TAB_MAX_NUMBER_read; \
	VARIABLE trans15_PneumaticActuator_TAB_ACTUAL_NUMBER; \
	MENU trans15_PneumaticActuator_TAB_ACTUAL_NUMBER_page; \
	COMMAND trans15_PneumaticActuator_TAB_ACTUAL_NUMBER_read; \
	VARIABLE trans15_PneumaticActuator_DEADBAND; \
	MENU trans15_PneumaticActuator_DEADBAND_page; \
	COMMAND trans15_PneumaticActuator_DEADBAND_read; \
	COMMAND trans15_PneumaticActuator_DEADBAND_write; \
	VARIABLE trans15_PneumaticActuator_DEVICE_CALIB_DATE; \
	MENU trans15_PneumaticActuator_DEVICE_CALIB_DATE_page; \
	COMMAND trans15_PneumaticActuator_DEVICE_CALIB_DATE_read; \
	COMMAND trans15_PneumaticActuator_DEVICE_CALIB_DATE_write; \
	VARIABLE trans15_PneumaticActuator_DEVICE_CONFIG_DATE; \
	MENU trans15_PneumaticActuator_DEVICE_CONFIG_DATE_page; \
	COMMAND trans15_PneumaticActuator_DEVICE_CONFIG_DATE_read; \
	COMMAND trans15_PneumaticActuator_DEVICE_CONFIG_DATE_write; \
	VARIABLE trans15_PneumaticActuator_SERVO_GAIN_1; \
	MENU trans15_PneumaticActuator_SERVO_GAIN_1_page; \
	COMMAND trans15_PneumaticActuator_SERVO_GAIN_1_read; \
	COMMAND trans15_PneumaticActuator_SERVO_GAIN_1_write; \
	VARIABLE trans15_PneumaticActuator_SERVO_RATE_1; \
	MENU trans15_PneumaticActuator_SERVO_RATE_1_page; \
	COMMAND trans15_PneumaticActuator_SERVO_RATE_1_read; \
	COMMAND trans15_PneumaticActuator_SERVO_RATE_1_write; \
	VARIABLE trans15_PneumaticActuator_SERVO_RESET_1; \
	MENU trans15_PneumaticActuator_SERVO_RESET_1_page; \
	COMMAND trans15_PneumaticActuator_SERVO_RESET_1_read; \
	COMMAND trans15_PneumaticActuator_SERVO_RESET_1_write; \
	VARIABLE trans15_PneumaticActuator_TOTAL_VALVE_TRAVEL; \
	MENU trans15_PneumaticActuator_TOTAL_VALVE_TRAVEL_page; \
	COMMAND trans15_PneumaticActuator_TOTAL_VALVE_TRAVEL_read; \
	VARIABLE trans15_PneumaticActuator_TOT_VALVE_TRAV_LIM; \
	MENU trans15_PneumaticActuator_TOT_VALVE_TRAV_LIM_page; \
	COMMAND trans15_PneumaticActuator_TOT_VALVE_TRAV_LIM_read; \
	COMMAND trans15_PneumaticActuator_TOT_VALVE_TRAV_LIM_write; \
	VARIABLE trans15_PneumaticActuator_VALVE_MAINT_DATE; \
	MENU trans15_PneumaticActuator_VALVE_MAINT_DATE_page; \
	COMMAND trans15_PneumaticActuator_VALVE_MAINT_DATE_read; \
	COMMAND trans15_PneumaticActuator_VALVE_MAINT_DATE_write; \
	VARIABLE trans15_PneumaticActuator_SERVO_GAIN_2; \
	MENU trans15_PneumaticActuator_SERVO_GAIN_2_page; \
	COMMAND trans15_PneumaticActuator_SERVO_GAIN_2_read; \
	COMMAND trans15_PneumaticActuator_SERVO_GAIN_2_write; \
	VARIABLE trans15_PneumaticActuator_SERVO_RATE_2; \
	MENU trans15_PneumaticActuator_SERVO_RATE_2_page; \
	COMMAND trans15_PneumaticActuator_SERVO_RATE_2_read; \
	COMMAND trans15_PneumaticActuator_SERVO_RATE_2_write; \
	VARIABLE trans15_PneumaticActuator_SERVO_RESET_2; \
	MENU trans15_PneumaticActuator_SERVO_RESET_2_page; \
	COMMAND trans15_PneumaticActuator_SERVO_RESET_2_read; \
	COMMAND trans15_PneumaticActuator_SERVO_RESET_2_write; \
	VARIABLE trans15_PneumaticActuator_TAB_OP_CODE; \
	MENU trans15_PneumaticActuator_TAB_OP_CODE_page; \
	COMMAND trans15_PneumaticActuator_TAB_OP_CODE_read; \
	COMMAND trans15_PneumaticActuator_TAB_OP_CODE_write; \
	VARIABLE trans15_PneumaticActuator_TAB_STATUS; \
	MENU trans15_PneumaticActuator_TAB_STATUS_page; \
	COMMAND trans15_PneumaticActuator_TAB_STATUS_read; \
	VARIABLE trans15_PneumaticActuator_VALVE_SER_NUM; \
	MENU trans15_PneumaticActuator_VALVE_SER_NUM_page; \
	COMMAND trans15_PneumaticActuator_VALVE_SER_NUM_read; \
	COMMAND trans15_PneumaticActuator_VALVE_SER_NUM_write; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_SER_NUM; \
	MENU trans15_PneumaticActuator_ACTUATOR_SER_NUM_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_SER_NUM_read; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_SER_NUM_write; \
	VARIABLE trans15_PneumaticActuator_ADD_GEAR_SER_NUM; \
	MENU trans15_PneumaticActuator_ADD_GEAR_SER_NUM_page; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_SER_NUM_read; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_SER_NUM_write; \
	VARIABLE trans15_PneumaticActuator_ADD_GEAR_MAN; \
	MENU trans15_PneumaticActuator_ADD_GEAR_MAN_page; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_MAN_read; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_MAN_write; \
	VARIABLE trans15_PneumaticActuator_ADD_GEAR_ID; \
	MENU trans15_PneumaticActuator_ADD_GEAR_ID_page; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_ID_read; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_ID_write; \
	VARIABLE trans15_PneumaticActuator_ADD_GEAR_INST_DATE; \
	MENU trans15_PneumaticActuator_ADD_GEAR_INST_DATE_page; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_INST_DATE_read; \
	COMMAND trans15_PneumaticActuator_ADD_GEAR_INST_DATE_write; \
	COLLECTION trans15_PneumaticActuator_VIEW_2; \
	MENU trans15_PneumaticActuator_VIEW_2_page; \
	COLLECTION trans15_PneumaticActuator_VIEW_3; \
	MENU trans15_PneumaticActuator_VIEW_3_page; \
	COLLECTION trans15_PneumaticActuator_VIEW_4; \
	MENU trans15_PneumaticActuator_VIEW_4_page

#define USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_A \
	USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	VARIABLE trans15_PneumaticActuator_LIN_TYPE; \
	MENU trans15_PneumaticActuator_LIN_TYPE_page; \
	COMMAND trans15_PneumaticActuator_LIN_TYPE_read; \
	COMMAND trans15_PneumaticActuator_LIN_TYPE_write; \
	VARIABLE trans15_PneumaticActuator_RATED_TRAVEL; \
	MENU trans15_PneumaticActuator_RATED_TRAVEL_page; \
	COMMAND trans15_PneumaticActuator_RATED_TRAVEL_read; \
	COMMAND trans15_PneumaticActuator_RATED_TRAVEL_write; \
	VARIABLE trans15_PneumaticActuator_SELF_CALIB_CMD; \
	MENU trans15_PneumaticActuator_SELF_CALIB_CMD_page; \
	COMMAND trans15_PneumaticActuator_SELF_CALIB_CMD_read; \
	COMMAND trans15_PneumaticActuator_SELF_CALIB_CMD_write; \
	VARIABLE trans15_PneumaticActuator_SELF_CALIB_STATUS; \
	MENU trans15_PneumaticActuator_SELF_CALIB_STATUS_page; \
	COMMAND trans15_PneumaticActuator_SELF_CALIB_STATUS_read; \
	VARIABLE trans15_PneumaticActuator_SETP_CUTOFF_DEC; \
	MENU trans15_PneumaticActuator_SETP_CUTOFF_DEC_page; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_DEC_read; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_DEC_write; \
	VARIABLE trans15_PneumaticActuator_SETP_CUTOFF_INC; \
	MENU trans15_PneumaticActuator_SETP_CUTOFF_INC_page; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_INC_read; \
	COMMAND trans15_PneumaticActuator_SETP_CUTOFF_INC_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_LIMIT_LOW; \
	MENU trans15_PneumaticActuator_TRAVEL_LIMIT_LOW_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_LOW_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_LOW_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_LIMIT_UP; \
	MENU trans15_PneumaticActuator_TRAVEL_LIMIT_UP_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_UP_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_LIMIT_UP_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_RATE_DEC; \
	MENU trans15_PneumaticActuator_TRAVEL_RATE_DEC_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_DEC_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_DEC_write; \
	VARIABLE trans15_PneumaticActuator_TRAVEL_RATE_INC; \
	MENU trans15_PneumaticActuator_TRAVEL_RATE_INC_page; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_INC_read; \
	COMMAND trans15_PneumaticActuator_TRAVEL_RATE_INC_write; \
	COLLECTION trans15_PneumaticActuator_POSITIONING_VALUE; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Value; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Status_Condensed; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Status_Quality; \
	VARIABLE trans15_PneumaticActuator_POSITIONING_VALUE_Status_Limit; \
	MENU trans15_PneumaticActuator_POSITIONING_VALUE_page; \
	COMMAND trans15_PneumaticActuator_POSITIONING_VALUE_read; \
	COLLECTION trans15_PneumaticActuator_FEEDBACK_VALUE; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Value; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Status_Condensed; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Status_Quality; \
	VARIABLE trans15_PneumaticActuator_FEEDBACK_VALUE_Status_Limit; \
	MENU trans15_PneumaticActuator_FEEDBACK_VALUE_page; \
	COMMAND trans15_PneumaticActuator_FEEDBACK_VALUE_read; \
	VARIABLE trans15_PneumaticActuator_VALVE_MAN; \
	MENU trans15_PneumaticActuator_VALVE_MAN_page; \
	COMMAND trans15_PneumaticActuator_VALVE_MAN_read; \
	COMMAND trans15_PneumaticActuator_VALVE_MAN_write; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_MAN; \
	MENU trans15_PneumaticActuator_ACTUATOR_MAN_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_MAN_read; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_MAN_write; \
	VARIABLE trans15_PneumaticActuator_VALVE_TYPE; \
	MENU trans15_PneumaticActuator_VALVE_TYPE_page; \
	COMMAND trans15_PneumaticActuator_VALVE_TYPE_read; \
	COMMAND trans15_PneumaticActuator_VALVE_TYPE_write; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_TYPE; \
	MENU trans15_PneumaticActuator_ACTUATOR_TYPE_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_TYPE_read; \
	VARIABLE trans15_PneumaticActuator_ACTUATOR_ACTION; \
	MENU trans15_PneumaticActuator_ACTUATOR_ACTION_page; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_ACTION_read; \
	COMMAND trans15_PneumaticActuator_ACTUATOR_ACTION_write; \
	COLLECTION trans15_PneumaticActuator_VIEW_1; \
	MENU trans15_PneumaticActuator_VIEW_1_page; \
	MENU trans15_PneumaticActuator_Simple_Dialog_Optional_A

#define USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_B \
	USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_BOTH; \
	MENU trans15_PneumaticActuator_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_A USE_TRANS_PNEUMATICACTUATOR_MANDATORY_A(trans15_PneumaticActuator_)
#define USE_TRANS15_PNEUMATICACTUATOR_MANDATORY_B USE_TRANS_PNEUMATICACTUATOR_MANDATORY_B(trans15_PneumaticActuator_)
#define USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_A  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_A(trans15_PneumaticActuator_)
#define USE_TRANS15_PNEUMATICACTUATOR_OPTIONAL_B  USE_TRANS_PNEUMATICACTUATOR_OPTIONAL_B(trans15_PneumaticActuator_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC1_AO_MANDATORY_BOTH \
	BLOCK func1_AO_block; \
	COLLECTION func1_AO_BLOCK_OBJECT; \
	VARIABLE func1_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func1_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func1_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func1_AO_BLOCK_OBJECT_Class; \
	VARIABLE func1_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func1_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func1_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func1_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func1_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func1_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func1_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func1_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func1_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func1_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func1_AO_BLOCK_OBJECT_page; \
	COMMAND func1_AO_BLOCK_OBJECT_read; \
	VARIABLE func1_AO_ST_REV; \
	MENU func1_AO_ST_REV_page; \
	COMMAND func1_AO_ST_REV_read; \
	VARIABLE func1_AO_TAG_DESC; \
	MENU func1_AO_TAG_DESC_page; \
	COMMAND func1_AO_TAG_DESC_read; \
	COMMAND func1_AO_TAG_DESC_write; \
	VARIABLE func1_AO_STRATEGY; \
	MENU func1_AO_STRATEGY_page; \
	COMMAND func1_AO_STRATEGY_read; \
	COMMAND func1_AO_STRATEGY_write; \
	VARIABLE func1_AO_ALERT_KEY; \
	MENU func1_AO_ALERT_KEY_page; \
	COMMAND func1_AO_ALERT_KEY_read; \
	COMMAND func1_AO_ALERT_KEY_write; \
	VARIABLE func1_AO_TARGET_MODE; \
	MENU func1_AO_TARGET_MODE_page; \
	COMMAND func1_AO_TARGET_MODE_read; \
	COMMAND func1_AO_TARGET_MODE_write; \
	COLLECTION func1_AO_MODE_BLK; \
	VARIABLE func1_AO_MODE_BLK_Actual; \
	VARIABLE func1_AO_MODE_BLK_Permitted; \
	VARIABLE func1_AO_MODE_BLK_Normal; \
	MENU func1_AO_MODE_BLK_page; \
	COMMAND func1_AO_MODE_BLK_read; \
	COLLECTION func1_AO_ALARM_SUM; \
	VARIABLE func1_AO_ALARM_SUM_Current; \
	VARIABLE func1_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func1_AO_ALARM_SUM_Unreported; \
	VARIABLE func1_AO_ALARM_SUM_Disabled; \
	MENU func1_AO_ALARM_SUM_page; \
	COMMAND func1_AO_ALARM_SUM_read; \
	COLLECTION func1_AO_BATCH; \
	VARIABLE func1_AO_BATCH_Batch_ID; \
	VARIABLE func1_AO_BATCH_Rup; \
	VARIABLE func1_AO_BATCH_Operation; \
	VARIABLE func1_AO_BATCH_Phase; \
	MENU func1_AO_BATCH_page; \
	COMMAND func1_AO_BATCH_read; \
	COMMAND func1_AO_BATCH_write; \
	COLLECTION func1_AO_SP; \
	VARIABLE func1_AO_SP_Value; \
	VARIABLE func1_AO_SP_Status_Condensed; \
	VARIABLE func1_AO_SP_Status_Quality; \
	VARIABLE func1_AO_SP_Status_Limit; \
	MENU func1_AO_SP_page; \
	COMMAND func1_AO_SP_read; \
	COMMAND func1_AO_SP_write; \
	COLLECTION func1_AO_PV_SCALE; \
	VARIABLE func1_AO_PV_SCALE_Upper_Value; \
	VARIABLE func1_AO_PV_SCALE_Lower_Value; \
	VARIABLE func1_AO_PV_SCALE_Units_Index; \
	VARIABLE func1_AO_PV_SCALE_Decimal_Point; \
	MENU func1_AO_PV_SCALE_page; \
	COMMAND func1_AO_PV_SCALE_read; \
	COMMAND func1_AO_PV_SCALE_write; \
	COLLECTION func1_AO_POS_D; \
	VARIABLE func1_AO_POS_D_Value; \
	VARIABLE func1_AO_POS_D_Status_Condensed; \
	VARIABLE func1_AO_POS_D_Status_Quality; \
	VARIABLE func1_AO_POS_D_Status_Limit; \
	MENU func1_AO_POS_D_page; \
	COMMAND func1_AO_POS_D_read; \
	COLLECTION func1_AO_OUT_SCALE; \
	VARIABLE func1_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func1_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func1_AO_OUT_SCALE_Units_Index; \
	VARIABLE func1_AO_OUT_SCALE_Decimal_Point; \
	MENU func1_AO_OUT_SCALE_page; \
	COMMAND func1_AO_OUT_SCALE_read; \
	COMMAND func1_AO_OUT_SCALE_write; \
	UNIT func1_AO_PV_SCALE_unit_1; \
	UNIT func1_AO_OUT_SCALE_unit_1

#define USE_FUNC1_AO_MANDATORY_A \
	USE_FUNC1_AO_MANDATORY_BOTH; \
	MENU func1_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC1_AO_MANDATORY_B \
	USE_FUNC1_AO_MANDATORY_BOTH; \
	COLLECTION func1_AO_READBACK; \
	VARIABLE func1_AO_READBACK_Value; \
	VARIABLE func1_AO_READBACK_Status_Condensed; \
	VARIABLE func1_AO_READBACK_Status_Quality; \
	VARIABLE func1_AO_READBACK_Status_Limit; \
	MENU func1_AO_READBACK_page; \
	COMMAND func1_AO_READBACK_read; \
	VARIABLE func1_AO_IN_CHANNEL; \
	MENU func1_AO_IN_CHANNEL_page; \
	COMMAND func1_AO_IN_CHANNEL_read; \
	COMMAND func1_AO_IN_CHANNEL_write; \
	VARIABLE func1_AO_OUT_CHANNEL; \
	MENU func1_AO_OUT_CHANNEL_page; \
	COMMAND func1_AO_OUT_CHANNEL_read; \
	COMMAND func1_AO_OUT_CHANNEL_write; \
	VARIABLE func1_AO_FSAFE_TIME; \
	MENU func1_AO_FSAFE_TIME_page; \
	COMMAND func1_AO_FSAFE_TIME_read; \
	COMMAND func1_AO_FSAFE_TIME_write; \
	VARIABLE func1_AO_FSAFE_TYPE; \
	MENU func1_AO_FSAFE_TYPE_page; \
	COMMAND func1_AO_FSAFE_TYPE_read; \
	COMMAND func1_AO_FSAFE_TYPE_write; \
	VARIABLE func1_AO_FSAFE_VALUE; \
	MENU func1_AO_FSAFE_VALUE_page; \
	COMMAND func1_AO_FSAFE_VALUE_read; \
	COMMAND func1_AO_FSAFE_VALUE_write; \
	VARIABLE func1_AO_CHECK_BACK; \
	MENU func1_AO_CHECK_BACK_page; \
	COMMAND func1_AO_CHECK_BACK_read; \
	VARIABLE func1_AO_CHECK_BACK_MASK; \
	MENU func1_AO_CHECK_BACK_MASK_page; \
	COMMAND func1_AO_CHECK_BACK_MASK_read; \
	COLLECTION func1_AO_SIMULATE; \
	VARIABLE func1_AO_SIMULATE_Status_Condensed; \
	VARIABLE func1_AO_SIMULATE_Value; \
	VARIABLE func1_AO_SIMULATE_Enabled; \
	VARIABLE func1_AO_SIMULATE_Status_Quality; \
	VARIABLE func1_AO_SIMULATE_Status_Limit; \
	MENU func1_AO_SIMULATE_page; \
	COMMAND func1_AO_SIMULATE_read; \
	COMMAND func1_AO_SIMULATE_write; \
	VARIABLE func1_AO_INCREASE_CLOSE; \
	MENU func1_AO_INCREASE_CLOSE_page; \
	COMMAND func1_AO_INCREASE_CLOSE_read; \
	COMMAND func1_AO_INCREASE_CLOSE_write; \
	COLLECTION func1_AO_OUT; \
	VARIABLE func1_AO_OUT_Value; \
	VARIABLE func1_AO_OUT_Status_Condensed; \
	VARIABLE func1_AO_OUT_Status_Quality; \
	VARIABLE func1_AO_OUT_Status_Limit; \
	MENU func1_AO_OUT_page; \
	COMMAND func1_AO_OUT_read; \
	COMMAND func1_AO_OUT_write; \
	COLLECTION func1_AO_VIEW_1; \
	MENU func1_AO_VIEW_1_page; \
	MENU func1_AO_Simple_Dialog_Mandatory_B; \
	UNIT func1_AO_PV_SCALE_unit_2; \
	UNIT func1_AO_OUT_SCALE_unit_2

#define USE_FUNC1_AO_OPTIONAL_BOTH \
	COLLECTION func1_AO_RCAS_IN; \
	VARIABLE func1_AO_RCAS_IN_Value; \
	VARIABLE func1_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func1_AO_RCAS_IN_Status_Quality; \
	VARIABLE func1_AO_RCAS_IN_Status_Limit; \
	MENU func1_AO_RCAS_IN_page; \
	COMMAND func1_AO_RCAS_IN_read; \
	COMMAND func1_AO_RCAS_IN_write; \
	COLLECTION func1_AO_RCAS_OUT; \
	VARIABLE func1_AO_RCAS_OUT_Value; \
	VARIABLE func1_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func1_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func1_AO_RCAS_OUT_Status_Limit; \
	MENU func1_AO_RCAS_OUT_page; \
	COMMAND func1_AO_RCAS_OUT_read; \
	VARIABLE func1_AO_SETP_DEVIATION; \
	MENU func1_AO_SETP_DEVIATION_page; \
	COMMAND func1_AO_SETP_DEVIATION_read; \
	COLLECTION func1_AO_VIEW_2; \
	MENU func1_AO_VIEW_2_page; \
	COLLECTION func1_AO_VIEW_3; \
	MENU func1_AO_VIEW_3_page; \
	UNIT func1_AO_PV_SCALE_unit_3

#define USE_FUNC1_AO_OPTIONAL_A \
	USE_FUNC1_AO_OPTIONAL_BOTH; \
	COLLECTION func1_AO_READBACK; \
	VARIABLE func1_AO_READBACK_Value; \
	VARIABLE func1_AO_READBACK_Status_Condensed; \
	VARIABLE func1_AO_READBACK_Status_Quality; \
	VARIABLE func1_AO_READBACK_Status_Limit; \
	MENU func1_AO_READBACK_page; \
	COMMAND func1_AO_READBACK_read; \
	VARIABLE func1_AO_IN_CHANNEL; \
	MENU func1_AO_IN_CHANNEL_page; \
	COMMAND func1_AO_IN_CHANNEL_read; \
	COMMAND func1_AO_IN_CHANNEL_write; \
	VARIABLE func1_AO_OUT_CHANNEL; \
	MENU func1_AO_OUT_CHANNEL_page; \
	COMMAND func1_AO_OUT_CHANNEL_read; \
	COMMAND func1_AO_OUT_CHANNEL_write; \
	VARIABLE func1_AO_FSAFE_TIME; \
	MENU func1_AO_FSAFE_TIME_page; \
	COMMAND func1_AO_FSAFE_TIME_read; \
	COMMAND func1_AO_FSAFE_TIME_write; \
	VARIABLE func1_AO_FSAFE_TYPE; \
	MENU func1_AO_FSAFE_TYPE_page; \
	COMMAND func1_AO_FSAFE_TYPE_read; \
	COMMAND func1_AO_FSAFE_TYPE_write; \
	VARIABLE func1_AO_FSAFE_VALUE; \
	MENU func1_AO_FSAFE_VALUE_page; \
	COMMAND func1_AO_FSAFE_VALUE_read; \
	COMMAND func1_AO_FSAFE_VALUE_write; \
	VARIABLE func1_AO_CHECK_BACK; \
	MENU func1_AO_CHECK_BACK_page; \
	COMMAND func1_AO_CHECK_BACK_read; \
	VARIABLE func1_AO_CHECK_BACK_MASK; \
	MENU func1_AO_CHECK_BACK_MASK_page; \
	COMMAND func1_AO_CHECK_BACK_MASK_read; \
	COLLECTION func1_AO_SIMULATE; \
	VARIABLE func1_AO_SIMULATE_Status_Condensed; \
	VARIABLE func1_AO_SIMULATE_Value; \
	VARIABLE func1_AO_SIMULATE_Enabled; \
	VARIABLE func1_AO_SIMULATE_Status_Quality; \
	VARIABLE func1_AO_SIMULATE_Status_Limit; \
	MENU func1_AO_SIMULATE_page; \
	COMMAND func1_AO_SIMULATE_read; \
	COMMAND func1_AO_SIMULATE_write; \
	VARIABLE func1_AO_INCREASE_CLOSE; \
	MENU func1_AO_INCREASE_CLOSE_page; \
	COMMAND func1_AO_INCREASE_CLOSE_read; \
	COMMAND func1_AO_INCREASE_CLOSE_write; \
	COLLECTION func1_AO_OUT; \
	VARIABLE func1_AO_OUT_Value; \
	VARIABLE func1_AO_OUT_Status_Condensed; \
	VARIABLE func1_AO_OUT_Status_Quality; \
	VARIABLE func1_AO_OUT_Status_Limit; \
	MENU func1_AO_OUT_page; \
	COMMAND func1_AO_OUT_read; \
	COMMAND func1_AO_OUT_write; \
	COLLECTION func1_AO_VIEW_1; \
	MENU func1_AO_VIEW_1_page; \
	MENU func1_AO_Simple_Dialog_Optional_A; \
	UNIT func1_AO_PV_SCALE_unit_2; \
	UNIT func1_AO_OUT_SCALE_unit_2

#define USE_FUNC1_AO_OPTIONAL_B \
	USE_FUNC1_AO_OPTIONAL_BOTH; \
	MENU func1_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC_AO_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## BATCH; \
	VARIABLE prefix ## BATCH_Batch_ID; \
	VARIABLE prefix ## BATCH_Rup; \
	VARIABLE prefix ## BATCH_Operation; \
	VARIABLE prefix ## BATCH_Phase; \
	MENU prefix ## BATCH_page; \
	COMMAND prefix ## BATCH_read; \
	COMMAND prefix ## BATCH_write; \
	COLLECTION prefix ## SP; \
	VARIABLE prefix ## SP_Value; \
	VARIABLE prefix ## SP_Status_Condensed; \
	VARIABLE prefix ## SP_Status_Quality; \
	VARIABLE prefix ## SP_Status_Limit; \
	MENU prefix ## SP_page; \
	COMMAND prefix ## SP_read; \
	COMMAND prefix ## SP_write; \
	COLLECTION prefix ## PV_SCALE; \
	VARIABLE prefix ## PV_SCALE_Upper_Value; \
	VARIABLE prefix ## PV_SCALE_Lower_Value; \
	VARIABLE prefix ## PV_SCALE_Units_Index; \
	VARIABLE prefix ## PV_SCALE_Decimal_Point; \
	MENU prefix ## PV_SCALE_page; \
	COMMAND prefix ## PV_SCALE_read; \
	COMMAND prefix ## PV_SCALE_write; \
	COLLECTION prefix ## POS_D; \
	VARIABLE prefix ## POS_D_Value; \
	VARIABLE prefix ## POS_D_Status_Condensed; \
	VARIABLE prefix ## POS_D_Status_Quality; \
	VARIABLE prefix ## POS_D_Status_Limit; \
	MENU prefix ## POS_D_page; \
	COMMAND prefix ## POS_D_read; \
	COLLECTION prefix ## OUT_SCALE; \
	VARIABLE prefix ## OUT_SCALE_Upper_Value; \
	VARIABLE prefix ## OUT_SCALE_Lower_Value; \
	VARIABLE prefix ## OUT_SCALE_Units_Index; \
	VARIABLE prefix ## OUT_SCALE_Decimal_Point; \
	MENU prefix ## OUT_SCALE_page; \
	COMMAND prefix ## OUT_SCALE_read; \
	COMMAND prefix ## OUT_SCALE_write; \
	UNIT prefix ## PV_SCALE_unit_1; \
	UNIT prefix ## OUT_SCALE_unit_1

#define USE_FUNC_AO_MANDATORY_A(prefix) \
	USE_FUNC_AO_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_FUNC_AO_MANDATORY_B(prefix) \
	USE_FUNC_AO_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## READBACK; \
	VARIABLE prefix ## READBACK_Value; \
	VARIABLE prefix ## READBACK_Status_Condensed; \
	VARIABLE prefix ## READBACK_Status_Quality; \
	VARIABLE prefix ## READBACK_Status_Limit; \
	MENU prefix ## READBACK_page; \
	COMMAND prefix ## READBACK_read; \
	VARIABLE prefix ## IN_CHANNEL; \
	MENU prefix ## IN_CHANNEL_page; \
	COMMAND prefix ## IN_CHANNEL_read; \
	COMMAND prefix ## IN_CHANNEL_write; \
	VARIABLE prefix ## OUT_CHANNEL; \
	MENU prefix ## OUT_CHANNEL_page; \
	COMMAND prefix ## OUT_CHANNEL_read; \
	COMMAND prefix ## OUT_CHANNEL_write; \
	VARIABLE prefix ## FSAFE_TIME; \
	MENU prefix ## FSAFE_TIME_page; \
	COMMAND prefix ## FSAFE_TIME_read; \
	COMMAND prefix ## FSAFE_TIME_write; \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	VARIABLE prefix ## FSAFE_VALUE; \
	MENU prefix ## FSAFE_VALUE_page; \
	COMMAND prefix ## FSAFE_VALUE_read; \
	COMMAND prefix ## FSAFE_VALUE_write; \
	VARIABLE prefix ## CHECK_BACK; \
	MENU prefix ## CHECK_BACK_page; \
	COMMAND prefix ## CHECK_BACK_read; \
	VARIABLE prefix ## CHECK_BACK_MASK; \
	MENU prefix ## CHECK_BACK_MASK_page; \
	COMMAND prefix ## CHECK_BACK_MASK_read; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	VARIABLE prefix ## INCREASE_CLOSE; \
	MENU prefix ## INCREASE_CLOSE_page; \
	COMMAND prefix ## INCREASE_CLOSE_read; \
	COMMAND prefix ## INCREASE_CLOSE_write; \
	COLLECTION prefix ## OUT; \
	VARIABLE prefix ## OUT_Value; \
	VARIABLE prefix ## OUT_Status_Condensed; \
	VARIABLE prefix ## OUT_Status_Quality; \
	VARIABLE prefix ## OUT_Status_Limit; \
	MENU prefix ## OUT_page; \
	COMMAND prefix ## OUT_read; \
	COMMAND prefix ## OUT_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B; \
	UNIT prefix ## PV_SCALE_unit_2; \
	UNIT prefix ## OUT_SCALE_unit_2

#define USE_FUNC_AO_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## RCAS_IN; \
	VARIABLE prefix ## RCAS_IN_Value; \
	VARIABLE prefix ## RCAS_IN_Status_Condensed; \
	VARIABLE prefix ## RCAS_IN_Status_Quality; \
	VARIABLE prefix ## RCAS_IN_Status_Limit; \
	MENU prefix ## RCAS_IN_page; \
	COMMAND prefix ## RCAS_IN_read; \
	COMMAND prefix ## RCAS_IN_write; \
	COLLECTION prefix ## RCAS_OUT; \
	VARIABLE prefix ## RCAS_OUT_Value; \
	VARIABLE prefix ## RCAS_OUT_Status_Condensed; \
	VARIABLE prefix ## RCAS_OUT_Status_Quality; \
	VARIABLE prefix ## RCAS_OUT_Status_Limit; \
	MENU prefix ## RCAS_OUT_page; \
	COMMAND prefix ## RCAS_OUT_read; \
	VARIABLE prefix ## SETP_DEVIATION; \
	MENU prefix ## SETP_DEVIATION_page; \
	COMMAND prefix ## SETP_DEVIATION_read; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	UNIT prefix ## PV_SCALE_unit_3

#define USE_FUNC_AO_OPTIONAL_A(prefix) \
	USE_FUNC_AO_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## READBACK; \
	VARIABLE prefix ## READBACK_Value; \
	VARIABLE prefix ## READBACK_Status_Condensed; \
	VARIABLE prefix ## READBACK_Status_Quality; \
	VARIABLE prefix ## READBACK_Status_Limit; \
	MENU prefix ## READBACK_page; \
	COMMAND prefix ## READBACK_read; \
	VARIABLE prefix ## IN_CHANNEL; \
	MENU prefix ## IN_CHANNEL_page; \
	COMMAND prefix ## IN_CHANNEL_read; \
	COMMAND prefix ## IN_CHANNEL_write; \
	VARIABLE prefix ## OUT_CHANNEL; \
	MENU prefix ## OUT_CHANNEL_page; \
	COMMAND prefix ## OUT_CHANNEL_read; \
	COMMAND prefix ## OUT_CHANNEL_write; \
	VARIABLE prefix ## FSAFE_TIME; \
	MENU prefix ## FSAFE_TIME_page; \
	COMMAND prefix ## FSAFE_TIME_read; \
	COMMAND prefix ## FSAFE_TIME_write; \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	VARIABLE prefix ## FSAFE_VALUE; \
	MENU prefix ## FSAFE_VALUE_page; \
	COMMAND prefix ## FSAFE_VALUE_read; \
	COMMAND prefix ## FSAFE_VALUE_write; \
	VARIABLE prefix ## CHECK_BACK; \
	MENU prefix ## CHECK_BACK_page; \
	COMMAND prefix ## CHECK_BACK_read; \
	VARIABLE prefix ## CHECK_BACK_MASK; \
	MENU prefix ## CHECK_BACK_MASK_page; \
	COMMAND prefix ## CHECK_BACK_MASK_read; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	VARIABLE prefix ## INCREASE_CLOSE; \
	MENU prefix ## INCREASE_CLOSE_page; \
	COMMAND prefix ## INCREASE_CLOSE_read; \
	COMMAND prefix ## INCREASE_CLOSE_write; \
	COLLECTION prefix ## OUT; \
	VARIABLE prefix ## OUT_Value; \
	VARIABLE prefix ## OUT_Status_Condensed; \
	VARIABLE prefix ## OUT_Status_Quality; \
	VARIABLE prefix ## OUT_Status_Limit; \
	MENU prefix ## OUT_page; \
	COMMAND prefix ## OUT_read; \
	COMMAND prefix ## OUT_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A; \
	UNIT prefix ## PV_SCALE_unit_2; \
	UNIT prefix ## OUT_SCALE_unit_2

#define USE_FUNC_AO_OPTIONAL_B(prefix) \
	USE_FUNC_AO_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_FUNC1_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func1_AO_)
#define USE_FUNC1_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func1_AO_)
#define USE_FUNC1_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func1_AO_)
#define USE_FUNC1_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func1_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC2_AO_MANDATORY_BOTH \
	BLOCK func2_AO_block; \
	COLLECTION func2_AO_BLOCK_OBJECT; \
	VARIABLE func2_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func2_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func2_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func2_AO_BLOCK_OBJECT_Class; \
	VARIABLE func2_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func2_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func2_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func2_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func2_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func2_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func2_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func2_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func2_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func2_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func2_AO_BLOCK_OBJECT_page; \
	COMMAND func2_AO_BLOCK_OBJECT_read; \
	VARIABLE func2_AO_ST_REV; \
	MENU func2_AO_ST_REV_page; \
	COMMAND func2_AO_ST_REV_read; \
	VARIABLE func2_AO_TAG_DESC; \
	MENU func2_AO_TAG_DESC_page; \
	COMMAND func2_AO_TAG_DESC_read; \
	COMMAND func2_AO_TAG_DESC_write; \
	VARIABLE func2_AO_STRATEGY; \
	MENU func2_AO_STRATEGY_page; \
	COMMAND func2_AO_STRATEGY_read; \
	COMMAND func2_AO_STRATEGY_write; \
	VARIABLE func2_AO_ALERT_KEY; \
	MENU func2_AO_ALERT_KEY_page; \
	COMMAND func2_AO_ALERT_KEY_read; \
	COMMAND func2_AO_ALERT_KEY_write; \
	VARIABLE func2_AO_TARGET_MODE; \
	MENU func2_AO_TARGET_MODE_page; \
	COMMAND func2_AO_TARGET_MODE_read; \
	COMMAND func2_AO_TARGET_MODE_write; \
	COLLECTION func2_AO_MODE_BLK; \
	VARIABLE func2_AO_MODE_BLK_Actual; \
	VARIABLE func2_AO_MODE_BLK_Permitted; \
	VARIABLE func2_AO_MODE_BLK_Normal; \
	MENU func2_AO_MODE_BLK_page; \
	COMMAND func2_AO_MODE_BLK_read; \
	COLLECTION func2_AO_ALARM_SUM; \
	VARIABLE func2_AO_ALARM_SUM_Current; \
	VARIABLE func2_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func2_AO_ALARM_SUM_Unreported; \
	VARIABLE func2_AO_ALARM_SUM_Disabled; \
	MENU func2_AO_ALARM_SUM_page; \
	COMMAND func2_AO_ALARM_SUM_read; \
	COLLECTION func2_AO_BATCH; \
	VARIABLE func2_AO_BATCH_Batch_ID; \
	VARIABLE func2_AO_BATCH_Rup; \
	VARIABLE func2_AO_BATCH_Operation; \
	VARIABLE func2_AO_BATCH_Phase; \
	MENU func2_AO_BATCH_page; \
	COMMAND func2_AO_BATCH_read; \
	COMMAND func2_AO_BATCH_write; \
	COLLECTION func2_AO_SP; \
	VARIABLE func2_AO_SP_Value; \
	VARIABLE func2_AO_SP_Status_Condensed; \
	VARIABLE func2_AO_SP_Status_Quality; \
	VARIABLE func2_AO_SP_Status_Limit; \
	MENU func2_AO_SP_page; \
	COMMAND func2_AO_SP_read; \
	COMMAND func2_AO_SP_write; \
	COLLECTION func2_AO_PV_SCALE; \
	VARIABLE func2_AO_PV_SCALE_Upper_Value; \
	VARIABLE func2_AO_PV_SCALE_Lower_Value; \
	VARIABLE func2_AO_PV_SCALE_Units_Index; \
	VARIABLE func2_AO_PV_SCALE_Decimal_Point; \
	MENU func2_AO_PV_SCALE_page; \
	COMMAND func2_AO_PV_SCALE_read; \
	COMMAND func2_AO_PV_SCALE_write; \
	COLLECTION func2_AO_POS_D; \
	VARIABLE func2_AO_POS_D_Value; \
	VARIABLE func2_AO_POS_D_Status_Condensed; \
	VARIABLE func2_AO_POS_D_Status_Quality; \
	VARIABLE func2_AO_POS_D_Status_Limit; \
	MENU func2_AO_POS_D_page; \
	COMMAND func2_AO_POS_D_read; \
	COLLECTION func2_AO_OUT_SCALE; \
	VARIABLE func2_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func2_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func2_AO_OUT_SCALE_Units_Index; \
	VARIABLE func2_AO_OUT_SCALE_Decimal_Point; \
	MENU func2_AO_OUT_SCALE_page; \
	COMMAND func2_AO_OUT_SCALE_read; \
	COMMAND func2_AO_OUT_SCALE_write; \
	UNIT func2_AO_PV_SCALE_unit_1; \
	UNIT func2_AO_OUT_SCALE_unit_1

#define USE_FUNC2_AO_MANDATORY_A \
	USE_FUNC2_AO_MANDATORY_BOTH; \
	MENU func2_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC2_AO_MANDATORY_B \
	USE_FUNC2_AO_MANDATORY_BOTH; \
	COLLECTION func2_AO_READBACK; \
	VARIABLE func2_AO_READBACK_Value; \
	VARIABLE func2_AO_READBACK_Status_Condensed; \
	VARIABLE func2_AO_READBACK_Status_Quality; \
	VARIABLE func2_AO_READBACK_Status_Limit; \
	MENU func2_AO_READBACK_page; \
	COMMAND func2_AO_READBACK_read; \
	VARIABLE func2_AO_IN_CHANNEL; \
	MENU func2_AO_IN_CHANNEL_page; \
	COMMAND func2_AO_IN_CHANNEL_read; \
	COMMAND func2_AO_IN_CHANNEL_write; \
	VARIABLE func2_AO_OUT_CHANNEL; \
	MENU func2_AO_OUT_CHANNEL_page; \
	COMMAND func2_AO_OUT_CHANNEL_read; \
	COMMAND func2_AO_OUT_CHANNEL_write; \
	VARIABLE func2_AO_FSAFE_TIME; \
	MENU func2_AO_FSAFE_TIME_page; \
	COMMAND func2_AO_FSAFE_TIME_read; \
	COMMAND func2_AO_FSAFE_TIME_write; \
	VARIABLE func2_AO_FSAFE_TYPE; \
	MENU func2_AO_FSAFE_TYPE_page; \
	COMMAND func2_AO_FSAFE_TYPE_read; \
	COMMAND func2_AO_FSAFE_TYPE_write; \
	VARIABLE func2_AO_FSAFE_VALUE; \
	MENU func2_AO_FSAFE_VALUE_page; \
	COMMAND func2_AO_FSAFE_VALUE_read; \
	COMMAND func2_AO_FSAFE_VALUE_write; \
	VARIABLE func2_AO_CHECK_BACK; \
	MENU func2_AO_CHECK_BACK_page; \
	COMMAND func2_AO_CHECK_BACK_read; \
	VARIABLE func2_AO_CHECK_BACK_MASK; \
	MENU func2_AO_CHECK_BACK_MASK_page; \
	COMMAND func2_AO_CHECK_BACK_MASK_read; \
	COLLECTION func2_AO_SIMULATE; \
	VARIABLE func2_AO_SIMULATE_Status_Condensed; \
	VARIABLE func2_AO_SIMULATE_Value; \
	VARIABLE func2_AO_SIMULATE_Enabled; \
	VARIABLE func2_AO_SIMULATE_Status_Quality; \
	VARIABLE func2_AO_SIMULATE_Status_Limit; \
	MENU func2_AO_SIMULATE_page; \
	COMMAND func2_AO_SIMULATE_read; \
	COMMAND func2_AO_SIMULATE_write; \
	VARIABLE func2_AO_INCREASE_CLOSE; \
	MENU func2_AO_INCREASE_CLOSE_page; \
	COMMAND func2_AO_INCREASE_CLOSE_read; \
	COMMAND func2_AO_INCREASE_CLOSE_write; \
	COLLECTION func2_AO_OUT; \
	VARIABLE func2_AO_OUT_Value; \
	VARIABLE func2_AO_OUT_Status_Condensed; \
	VARIABLE func2_AO_OUT_Status_Quality; \
	VARIABLE func2_AO_OUT_Status_Limit; \
	MENU func2_AO_OUT_page; \
	COMMAND func2_AO_OUT_read; \
	COMMAND func2_AO_OUT_write; \
	COLLECTION func2_AO_VIEW_1; \
	MENU func2_AO_VIEW_1_page; \
	MENU func2_AO_Simple_Dialog_Mandatory_B; \
	UNIT func2_AO_PV_SCALE_unit_2; \
	UNIT func2_AO_OUT_SCALE_unit_2

#define USE_FUNC2_AO_OPTIONAL_BOTH \
	COLLECTION func2_AO_RCAS_IN; \
	VARIABLE func2_AO_RCAS_IN_Value; \
	VARIABLE func2_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func2_AO_RCAS_IN_Status_Quality; \
	VARIABLE func2_AO_RCAS_IN_Status_Limit; \
	MENU func2_AO_RCAS_IN_page; \
	COMMAND func2_AO_RCAS_IN_read; \
	COMMAND func2_AO_RCAS_IN_write; \
	COLLECTION func2_AO_RCAS_OUT; \
	VARIABLE func2_AO_RCAS_OUT_Value; \
	VARIABLE func2_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func2_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func2_AO_RCAS_OUT_Status_Limit; \
	MENU func2_AO_RCAS_OUT_page; \
	COMMAND func2_AO_RCAS_OUT_read; \
	VARIABLE func2_AO_SETP_DEVIATION; \
	MENU func2_AO_SETP_DEVIATION_page; \
	COMMAND func2_AO_SETP_DEVIATION_read; \
	COLLECTION func2_AO_VIEW_2; \
	MENU func2_AO_VIEW_2_page; \
	COLLECTION func2_AO_VIEW_3; \
	MENU func2_AO_VIEW_3_page; \
	UNIT func2_AO_PV_SCALE_unit_3

#define USE_FUNC2_AO_OPTIONAL_A \
	USE_FUNC2_AO_OPTIONAL_BOTH; \
	COLLECTION func2_AO_READBACK; \
	VARIABLE func2_AO_READBACK_Value; \
	VARIABLE func2_AO_READBACK_Status_Condensed; \
	VARIABLE func2_AO_READBACK_Status_Quality; \
	VARIABLE func2_AO_READBACK_Status_Limit; \
	MENU func2_AO_READBACK_page; \
	COMMAND func2_AO_READBACK_read; \
	VARIABLE func2_AO_IN_CHANNEL; \
	MENU func2_AO_IN_CHANNEL_page; \
	COMMAND func2_AO_IN_CHANNEL_read; \
	COMMAND func2_AO_IN_CHANNEL_write; \
	VARIABLE func2_AO_OUT_CHANNEL; \
	MENU func2_AO_OUT_CHANNEL_page; \
	COMMAND func2_AO_OUT_CHANNEL_read; \
	COMMAND func2_AO_OUT_CHANNEL_write; \
	VARIABLE func2_AO_FSAFE_TIME; \
	MENU func2_AO_FSAFE_TIME_page; \
	COMMAND func2_AO_FSAFE_TIME_read; \
	COMMAND func2_AO_FSAFE_TIME_write; \
	VARIABLE func2_AO_FSAFE_TYPE; \
	MENU func2_AO_FSAFE_TYPE_page; \
	COMMAND func2_AO_FSAFE_TYPE_read; \
	COMMAND func2_AO_FSAFE_TYPE_write; \
	VARIABLE func2_AO_FSAFE_VALUE; \
	MENU func2_AO_FSAFE_VALUE_page; \
	COMMAND func2_AO_FSAFE_VALUE_read; \
	COMMAND func2_AO_FSAFE_VALUE_write; \
	VARIABLE func2_AO_CHECK_BACK; \
	MENU func2_AO_CHECK_BACK_page; \
	COMMAND func2_AO_CHECK_BACK_read; \
	VARIABLE func2_AO_CHECK_BACK_MASK; \
	MENU func2_AO_CHECK_BACK_MASK_page; \
	COMMAND func2_AO_CHECK_BACK_MASK_read; \
	COLLECTION func2_AO_SIMULATE; \
	VARIABLE func2_AO_SIMULATE_Status_Condensed; \
	VARIABLE func2_AO_SIMULATE_Value; \
	VARIABLE func2_AO_SIMULATE_Enabled; \
	VARIABLE func2_AO_SIMULATE_Status_Quality; \
	VARIABLE func2_AO_SIMULATE_Status_Limit; \
	MENU func2_AO_SIMULATE_page; \
	COMMAND func2_AO_SIMULATE_read; \
	COMMAND func2_AO_SIMULATE_write; \
	VARIABLE func2_AO_INCREASE_CLOSE; \
	MENU func2_AO_INCREASE_CLOSE_page; \
	COMMAND func2_AO_INCREASE_CLOSE_read; \
	COMMAND func2_AO_INCREASE_CLOSE_write; \
	COLLECTION func2_AO_OUT; \
	VARIABLE func2_AO_OUT_Value; \
	VARIABLE func2_AO_OUT_Status_Condensed; \
	VARIABLE func2_AO_OUT_Status_Quality; \
	VARIABLE func2_AO_OUT_Status_Limit; \
	MENU func2_AO_OUT_page; \
	COMMAND func2_AO_OUT_read; \
	COMMAND func2_AO_OUT_write; \
	COLLECTION func2_AO_VIEW_1; \
	MENU func2_AO_VIEW_1_page; \
	MENU func2_AO_Simple_Dialog_Optional_A; \
	UNIT func2_AO_PV_SCALE_unit_2; \
	UNIT func2_AO_OUT_SCALE_unit_2

#define USE_FUNC2_AO_OPTIONAL_B \
	USE_FUNC2_AO_OPTIONAL_BOTH; \
	MENU func2_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC2_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func2_AO_)
#define USE_FUNC2_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func2_AO_)
#define USE_FUNC2_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func2_AO_)
#define USE_FUNC2_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func2_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC3_AO_MANDATORY_BOTH \
	BLOCK func3_AO_block; \
	COLLECTION func3_AO_BLOCK_OBJECT; \
	VARIABLE func3_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func3_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func3_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func3_AO_BLOCK_OBJECT_Class; \
	VARIABLE func3_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func3_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func3_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func3_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func3_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func3_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func3_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func3_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func3_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func3_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func3_AO_BLOCK_OBJECT_page; \
	COMMAND func3_AO_BLOCK_OBJECT_read; \
	VARIABLE func3_AO_ST_REV; \
	MENU func3_AO_ST_REV_page; \
	COMMAND func3_AO_ST_REV_read; \
	VARIABLE func3_AO_TAG_DESC; \
	MENU func3_AO_TAG_DESC_page; \
	COMMAND func3_AO_TAG_DESC_read; \
	COMMAND func3_AO_TAG_DESC_write; \
	VARIABLE func3_AO_STRATEGY; \
	MENU func3_AO_STRATEGY_page; \
	COMMAND func3_AO_STRATEGY_read; \
	COMMAND func3_AO_STRATEGY_write; \
	VARIABLE func3_AO_ALERT_KEY; \
	MENU func3_AO_ALERT_KEY_page; \
	COMMAND func3_AO_ALERT_KEY_read; \
	COMMAND func3_AO_ALERT_KEY_write; \
	VARIABLE func3_AO_TARGET_MODE; \
	MENU func3_AO_TARGET_MODE_page; \
	COMMAND func3_AO_TARGET_MODE_read; \
	COMMAND func3_AO_TARGET_MODE_write; \
	COLLECTION func3_AO_MODE_BLK; \
	VARIABLE func3_AO_MODE_BLK_Actual; \
	VARIABLE func3_AO_MODE_BLK_Permitted; \
	VARIABLE func3_AO_MODE_BLK_Normal; \
	MENU func3_AO_MODE_BLK_page; \
	COMMAND func3_AO_MODE_BLK_read; \
	COLLECTION func3_AO_ALARM_SUM; \
	VARIABLE func3_AO_ALARM_SUM_Current; \
	VARIABLE func3_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func3_AO_ALARM_SUM_Unreported; \
	VARIABLE func3_AO_ALARM_SUM_Disabled; \
	MENU func3_AO_ALARM_SUM_page; \
	COMMAND func3_AO_ALARM_SUM_read; \
	COLLECTION func3_AO_BATCH; \
	VARIABLE func3_AO_BATCH_Batch_ID; \
	VARIABLE func3_AO_BATCH_Rup; \
	VARIABLE func3_AO_BATCH_Operation; \
	VARIABLE func3_AO_BATCH_Phase; \
	MENU func3_AO_BATCH_page; \
	COMMAND func3_AO_BATCH_read; \
	COMMAND func3_AO_BATCH_write; \
	COLLECTION func3_AO_SP; \
	VARIABLE func3_AO_SP_Value; \
	VARIABLE func3_AO_SP_Status_Condensed; \
	VARIABLE func3_AO_SP_Status_Quality; \
	VARIABLE func3_AO_SP_Status_Limit; \
	MENU func3_AO_SP_page; \
	COMMAND func3_AO_SP_read; \
	COMMAND func3_AO_SP_write; \
	COLLECTION func3_AO_PV_SCALE; \
	VARIABLE func3_AO_PV_SCALE_Upper_Value; \
	VARIABLE func3_AO_PV_SCALE_Lower_Value; \
	VARIABLE func3_AO_PV_SCALE_Units_Index; \
	VARIABLE func3_AO_PV_SCALE_Decimal_Point; \
	MENU func3_AO_PV_SCALE_page; \
	COMMAND func3_AO_PV_SCALE_read; \
	COMMAND func3_AO_PV_SCALE_write; \
	COLLECTION func3_AO_POS_D; \
	VARIABLE func3_AO_POS_D_Value; \
	VARIABLE func3_AO_POS_D_Status_Condensed; \
	VARIABLE func3_AO_POS_D_Status_Quality; \
	VARIABLE func3_AO_POS_D_Status_Limit; \
	MENU func3_AO_POS_D_page; \
	COMMAND func3_AO_POS_D_read; \
	COLLECTION func3_AO_OUT_SCALE; \
	VARIABLE func3_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func3_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func3_AO_OUT_SCALE_Units_Index; \
	VARIABLE func3_AO_OUT_SCALE_Decimal_Point; \
	MENU func3_AO_OUT_SCALE_page; \
	COMMAND func3_AO_OUT_SCALE_read; \
	COMMAND func3_AO_OUT_SCALE_write; \
	UNIT func3_AO_PV_SCALE_unit_1; \
	UNIT func3_AO_OUT_SCALE_unit_1

#define USE_FUNC3_AO_MANDATORY_A \
	USE_FUNC3_AO_MANDATORY_BOTH; \
	MENU func3_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC3_AO_MANDATORY_B \
	USE_FUNC3_AO_MANDATORY_BOTH; \
	COLLECTION func3_AO_READBACK; \
	VARIABLE func3_AO_READBACK_Value; \
	VARIABLE func3_AO_READBACK_Status_Condensed; \
	VARIABLE func3_AO_READBACK_Status_Quality; \
	VARIABLE func3_AO_READBACK_Status_Limit; \
	MENU func3_AO_READBACK_page; \
	COMMAND func3_AO_READBACK_read; \
	VARIABLE func3_AO_IN_CHANNEL; \
	MENU func3_AO_IN_CHANNEL_page; \
	COMMAND func3_AO_IN_CHANNEL_read; \
	COMMAND func3_AO_IN_CHANNEL_write; \
	VARIABLE func3_AO_OUT_CHANNEL; \
	MENU func3_AO_OUT_CHANNEL_page; \
	COMMAND func3_AO_OUT_CHANNEL_read; \
	COMMAND func3_AO_OUT_CHANNEL_write; \
	VARIABLE func3_AO_FSAFE_TIME; \
	MENU func3_AO_FSAFE_TIME_page; \
	COMMAND func3_AO_FSAFE_TIME_read; \
	COMMAND func3_AO_FSAFE_TIME_write; \
	VARIABLE func3_AO_FSAFE_TYPE; \
	MENU func3_AO_FSAFE_TYPE_page; \
	COMMAND func3_AO_FSAFE_TYPE_read; \
	COMMAND func3_AO_FSAFE_TYPE_write; \
	VARIABLE func3_AO_FSAFE_VALUE; \
	MENU func3_AO_FSAFE_VALUE_page; \
	COMMAND func3_AO_FSAFE_VALUE_read; \
	COMMAND func3_AO_FSAFE_VALUE_write; \
	VARIABLE func3_AO_CHECK_BACK; \
	MENU func3_AO_CHECK_BACK_page; \
	COMMAND func3_AO_CHECK_BACK_read; \
	VARIABLE func3_AO_CHECK_BACK_MASK; \
	MENU func3_AO_CHECK_BACK_MASK_page; \
	COMMAND func3_AO_CHECK_BACK_MASK_read; \
	COLLECTION func3_AO_SIMULATE; \
	VARIABLE func3_AO_SIMULATE_Status_Condensed; \
	VARIABLE func3_AO_SIMULATE_Value; \
	VARIABLE func3_AO_SIMULATE_Enabled; \
	VARIABLE func3_AO_SIMULATE_Status_Quality; \
	VARIABLE func3_AO_SIMULATE_Status_Limit; \
	MENU func3_AO_SIMULATE_page; \
	COMMAND func3_AO_SIMULATE_read; \
	COMMAND func3_AO_SIMULATE_write; \
	VARIABLE func3_AO_INCREASE_CLOSE; \
	MENU func3_AO_INCREASE_CLOSE_page; \
	COMMAND func3_AO_INCREASE_CLOSE_read; \
	COMMAND func3_AO_INCREASE_CLOSE_write; \
	COLLECTION func3_AO_OUT; \
	VARIABLE func3_AO_OUT_Value; \
	VARIABLE func3_AO_OUT_Status_Condensed; \
	VARIABLE func3_AO_OUT_Status_Quality; \
	VARIABLE func3_AO_OUT_Status_Limit; \
	MENU func3_AO_OUT_page; \
	COMMAND func3_AO_OUT_read; \
	COMMAND func3_AO_OUT_write; \
	COLLECTION func3_AO_VIEW_1; \
	MENU func3_AO_VIEW_1_page; \
	MENU func3_AO_Simple_Dialog_Mandatory_B; \
	UNIT func3_AO_PV_SCALE_unit_2; \
	UNIT func3_AO_OUT_SCALE_unit_2

#define USE_FUNC3_AO_OPTIONAL_BOTH \
	COLLECTION func3_AO_RCAS_IN; \
	VARIABLE func3_AO_RCAS_IN_Value; \
	VARIABLE func3_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func3_AO_RCAS_IN_Status_Quality; \
	VARIABLE func3_AO_RCAS_IN_Status_Limit; \
	MENU func3_AO_RCAS_IN_page; \
	COMMAND func3_AO_RCAS_IN_read; \
	COMMAND func3_AO_RCAS_IN_write; \
	COLLECTION func3_AO_RCAS_OUT; \
	VARIABLE func3_AO_RCAS_OUT_Value; \
	VARIABLE func3_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func3_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func3_AO_RCAS_OUT_Status_Limit; \
	MENU func3_AO_RCAS_OUT_page; \
	COMMAND func3_AO_RCAS_OUT_read; \
	VARIABLE func3_AO_SETP_DEVIATION; \
	MENU func3_AO_SETP_DEVIATION_page; \
	COMMAND func3_AO_SETP_DEVIATION_read; \
	COLLECTION func3_AO_VIEW_2; \
	MENU func3_AO_VIEW_2_page; \
	COLLECTION func3_AO_VIEW_3; \
	MENU func3_AO_VIEW_3_page; \
	UNIT func3_AO_PV_SCALE_unit_3

#define USE_FUNC3_AO_OPTIONAL_A \
	USE_FUNC3_AO_OPTIONAL_BOTH; \
	COLLECTION func3_AO_READBACK; \
	VARIABLE func3_AO_READBACK_Value; \
	VARIABLE func3_AO_READBACK_Status_Condensed; \
	VARIABLE func3_AO_READBACK_Status_Quality; \
	VARIABLE func3_AO_READBACK_Status_Limit; \
	MENU func3_AO_READBACK_page; \
	COMMAND func3_AO_READBACK_read; \
	VARIABLE func3_AO_IN_CHANNEL; \
	MENU func3_AO_IN_CHANNEL_page; \
	COMMAND func3_AO_IN_CHANNEL_read; \
	COMMAND func3_AO_IN_CHANNEL_write; \
	VARIABLE func3_AO_OUT_CHANNEL; \
	MENU func3_AO_OUT_CHANNEL_page; \
	COMMAND func3_AO_OUT_CHANNEL_read; \
	COMMAND func3_AO_OUT_CHANNEL_write; \
	VARIABLE func3_AO_FSAFE_TIME; \
	MENU func3_AO_FSAFE_TIME_page; \
	COMMAND func3_AO_FSAFE_TIME_read; \
	COMMAND func3_AO_FSAFE_TIME_write; \
	VARIABLE func3_AO_FSAFE_TYPE; \
	MENU func3_AO_FSAFE_TYPE_page; \
	COMMAND func3_AO_FSAFE_TYPE_read; \
	COMMAND func3_AO_FSAFE_TYPE_write; \
	VARIABLE func3_AO_FSAFE_VALUE; \
	MENU func3_AO_FSAFE_VALUE_page; \
	COMMAND func3_AO_FSAFE_VALUE_read; \
	COMMAND func3_AO_FSAFE_VALUE_write; \
	VARIABLE func3_AO_CHECK_BACK; \
	MENU func3_AO_CHECK_BACK_page; \
	COMMAND func3_AO_CHECK_BACK_read; \
	VARIABLE func3_AO_CHECK_BACK_MASK; \
	MENU func3_AO_CHECK_BACK_MASK_page; \
	COMMAND func3_AO_CHECK_BACK_MASK_read; \
	COLLECTION func3_AO_SIMULATE; \
	VARIABLE func3_AO_SIMULATE_Status_Condensed; \
	VARIABLE func3_AO_SIMULATE_Value; \
	VARIABLE func3_AO_SIMULATE_Enabled; \
	VARIABLE func3_AO_SIMULATE_Status_Quality; \
	VARIABLE func3_AO_SIMULATE_Status_Limit; \
	MENU func3_AO_SIMULATE_page; \
	COMMAND func3_AO_SIMULATE_read; \
	COMMAND func3_AO_SIMULATE_write; \
	VARIABLE func3_AO_INCREASE_CLOSE; \
	MENU func3_AO_INCREASE_CLOSE_page; \
	COMMAND func3_AO_INCREASE_CLOSE_read; \
	COMMAND func3_AO_INCREASE_CLOSE_write; \
	COLLECTION func3_AO_OUT; \
	VARIABLE func3_AO_OUT_Value; \
	VARIABLE func3_AO_OUT_Status_Condensed; \
	VARIABLE func3_AO_OUT_Status_Quality; \
	VARIABLE func3_AO_OUT_Status_Limit; \
	MENU func3_AO_OUT_page; \
	COMMAND func3_AO_OUT_read; \
	COMMAND func3_AO_OUT_write; \
	COLLECTION func3_AO_VIEW_1; \
	MENU func3_AO_VIEW_1_page; \
	MENU func3_AO_Simple_Dialog_Optional_A; \
	UNIT func3_AO_PV_SCALE_unit_2; \
	UNIT func3_AO_OUT_SCALE_unit_2

#define USE_FUNC3_AO_OPTIONAL_B \
	USE_FUNC3_AO_OPTIONAL_BOTH; \
	MENU func3_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC3_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func3_AO_)
#define USE_FUNC3_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func3_AO_)
#define USE_FUNC3_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func3_AO_)
#define USE_FUNC3_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func3_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC4_AO_MANDATORY_BOTH \
	BLOCK func4_AO_block; \
	COLLECTION func4_AO_BLOCK_OBJECT; \
	VARIABLE func4_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func4_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func4_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func4_AO_BLOCK_OBJECT_Class; \
	VARIABLE func4_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func4_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func4_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func4_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func4_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func4_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func4_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func4_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func4_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func4_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func4_AO_BLOCK_OBJECT_page; \
	COMMAND func4_AO_BLOCK_OBJECT_read; \
	VARIABLE func4_AO_ST_REV; \
	MENU func4_AO_ST_REV_page; \
	COMMAND func4_AO_ST_REV_read; \
	VARIABLE func4_AO_TAG_DESC; \
	MENU func4_AO_TAG_DESC_page; \
	COMMAND func4_AO_TAG_DESC_read; \
	COMMAND func4_AO_TAG_DESC_write; \
	VARIABLE func4_AO_STRATEGY; \
	MENU func4_AO_STRATEGY_page; \
	COMMAND func4_AO_STRATEGY_read; \
	COMMAND func4_AO_STRATEGY_write; \
	VARIABLE func4_AO_ALERT_KEY; \
	MENU func4_AO_ALERT_KEY_page; \
	COMMAND func4_AO_ALERT_KEY_read; \
	COMMAND func4_AO_ALERT_KEY_write; \
	VARIABLE func4_AO_TARGET_MODE; \
	MENU func4_AO_TARGET_MODE_page; \
	COMMAND func4_AO_TARGET_MODE_read; \
	COMMAND func4_AO_TARGET_MODE_write; \
	COLLECTION func4_AO_MODE_BLK; \
	VARIABLE func4_AO_MODE_BLK_Actual; \
	VARIABLE func4_AO_MODE_BLK_Permitted; \
	VARIABLE func4_AO_MODE_BLK_Normal; \
	MENU func4_AO_MODE_BLK_page; \
	COMMAND func4_AO_MODE_BLK_read; \
	COLLECTION func4_AO_ALARM_SUM; \
	VARIABLE func4_AO_ALARM_SUM_Current; \
	VARIABLE func4_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func4_AO_ALARM_SUM_Unreported; \
	VARIABLE func4_AO_ALARM_SUM_Disabled; \
	MENU func4_AO_ALARM_SUM_page; \
	COMMAND func4_AO_ALARM_SUM_read; \
	COLLECTION func4_AO_BATCH; \
	VARIABLE func4_AO_BATCH_Batch_ID; \
	VARIABLE func4_AO_BATCH_Rup; \
	VARIABLE func4_AO_BATCH_Operation; \
	VARIABLE func4_AO_BATCH_Phase; \
	MENU func4_AO_BATCH_page; \
	COMMAND func4_AO_BATCH_read; \
	COMMAND func4_AO_BATCH_write; \
	COLLECTION func4_AO_SP; \
	VARIABLE func4_AO_SP_Value; \
	VARIABLE func4_AO_SP_Status_Condensed; \
	VARIABLE func4_AO_SP_Status_Quality; \
	VARIABLE func4_AO_SP_Status_Limit; \
	MENU func4_AO_SP_page; \
	COMMAND func4_AO_SP_read; \
	COMMAND func4_AO_SP_write; \
	COLLECTION func4_AO_PV_SCALE; \
	VARIABLE func4_AO_PV_SCALE_Upper_Value; \
	VARIABLE func4_AO_PV_SCALE_Lower_Value; \
	VARIABLE func4_AO_PV_SCALE_Units_Index; \
	VARIABLE func4_AO_PV_SCALE_Decimal_Point; \
	MENU func4_AO_PV_SCALE_page; \
	COMMAND func4_AO_PV_SCALE_read; \
	COMMAND func4_AO_PV_SCALE_write; \
	COLLECTION func4_AO_POS_D; \
	VARIABLE func4_AO_POS_D_Value; \
	VARIABLE func4_AO_POS_D_Status_Condensed; \
	VARIABLE func4_AO_POS_D_Status_Quality; \
	VARIABLE func4_AO_POS_D_Status_Limit; \
	MENU func4_AO_POS_D_page; \
	COMMAND func4_AO_POS_D_read; \
	COLLECTION func4_AO_OUT_SCALE; \
	VARIABLE func4_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func4_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func4_AO_OUT_SCALE_Units_Index; \
	VARIABLE func4_AO_OUT_SCALE_Decimal_Point; \
	MENU func4_AO_OUT_SCALE_page; \
	COMMAND func4_AO_OUT_SCALE_read; \
	COMMAND func4_AO_OUT_SCALE_write; \
	UNIT func4_AO_PV_SCALE_unit_1; \
	UNIT func4_AO_OUT_SCALE_unit_1

#define USE_FUNC4_AO_MANDATORY_A \
	USE_FUNC4_AO_MANDATORY_BOTH; \
	MENU func4_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC4_AO_MANDATORY_B \
	USE_FUNC4_AO_MANDATORY_BOTH; \
	COLLECTION func4_AO_READBACK; \
	VARIABLE func4_AO_READBACK_Value; \
	VARIABLE func4_AO_READBACK_Status_Condensed; \
	VARIABLE func4_AO_READBACK_Status_Quality; \
	VARIABLE func4_AO_READBACK_Status_Limit; \
	MENU func4_AO_READBACK_page; \
	COMMAND func4_AO_READBACK_read; \
	VARIABLE func4_AO_IN_CHANNEL; \
	MENU func4_AO_IN_CHANNEL_page; \
	COMMAND func4_AO_IN_CHANNEL_read; \
	COMMAND func4_AO_IN_CHANNEL_write; \
	VARIABLE func4_AO_OUT_CHANNEL; \
	MENU func4_AO_OUT_CHANNEL_page; \
	COMMAND func4_AO_OUT_CHANNEL_read; \
	COMMAND func4_AO_OUT_CHANNEL_write; \
	VARIABLE func4_AO_FSAFE_TIME; \
	MENU func4_AO_FSAFE_TIME_page; \
	COMMAND func4_AO_FSAFE_TIME_read; \
	COMMAND func4_AO_FSAFE_TIME_write; \
	VARIABLE func4_AO_FSAFE_TYPE; \
	MENU func4_AO_FSAFE_TYPE_page; \
	COMMAND func4_AO_FSAFE_TYPE_read; \
	COMMAND func4_AO_FSAFE_TYPE_write; \
	VARIABLE func4_AO_FSAFE_VALUE; \
	MENU func4_AO_FSAFE_VALUE_page; \
	COMMAND func4_AO_FSAFE_VALUE_read; \
	COMMAND func4_AO_FSAFE_VALUE_write; \
	VARIABLE func4_AO_CHECK_BACK; \
	MENU func4_AO_CHECK_BACK_page; \
	COMMAND func4_AO_CHECK_BACK_read; \
	VARIABLE func4_AO_CHECK_BACK_MASK; \
	MENU func4_AO_CHECK_BACK_MASK_page; \
	COMMAND func4_AO_CHECK_BACK_MASK_read; \
	COLLECTION func4_AO_SIMULATE; \
	VARIABLE func4_AO_SIMULATE_Status_Condensed; \
	VARIABLE func4_AO_SIMULATE_Value; \
	VARIABLE func4_AO_SIMULATE_Enabled; \
	VARIABLE func4_AO_SIMULATE_Status_Quality; \
	VARIABLE func4_AO_SIMULATE_Status_Limit; \
	MENU func4_AO_SIMULATE_page; \
	COMMAND func4_AO_SIMULATE_read; \
	COMMAND func4_AO_SIMULATE_write; \
	VARIABLE func4_AO_INCREASE_CLOSE; \
	MENU func4_AO_INCREASE_CLOSE_page; \
	COMMAND func4_AO_INCREASE_CLOSE_read; \
	COMMAND func4_AO_INCREASE_CLOSE_write; \
	COLLECTION func4_AO_OUT; \
	VARIABLE func4_AO_OUT_Value; \
	VARIABLE func4_AO_OUT_Status_Condensed; \
	VARIABLE func4_AO_OUT_Status_Quality; \
	VARIABLE func4_AO_OUT_Status_Limit; \
	MENU func4_AO_OUT_page; \
	COMMAND func4_AO_OUT_read; \
	COMMAND func4_AO_OUT_write; \
	COLLECTION func4_AO_VIEW_1; \
	MENU func4_AO_VIEW_1_page; \
	MENU func4_AO_Simple_Dialog_Mandatory_B; \
	UNIT func4_AO_PV_SCALE_unit_2; \
	UNIT func4_AO_OUT_SCALE_unit_2

#define USE_FUNC4_AO_OPTIONAL_BOTH \
	COLLECTION func4_AO_RCAS_IN; \
	VARIABLE func4_AO_RCAS_IN_Value; \
	VARIABLE func4_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func4_AO_RCAS_IN_Status_Quality; \
	VARIABLE func4_AO_RCAS_IN_Status_Limit; \
	MENU func4_AO_RCAS_IN_page; \
	COMMAND func4_AO_RCAS_IN_read; \
	COMMAND func4_AO_RCAS_IN_write; \
	COLLECTION func4_AO_RCAS_OUT; \
	VARIABLE func4_AO_RCAS_OUT_Value; \
	VARIABLE func4_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func4_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func4_AO_RCAS_OUT_Status_Limit; \
	MENU func4_AO_RCAS_OUT_page; \
	COMMAND func4_AO_RCAS_OUT_read; \
	VARIABLE func4_AO_SETP_DEVIATION; \
	MENU func4_AO_SETP_DEVIATION_page; \
	COMMAND func4_AO_SETP_DEVIATION_read; \
	COLLECTION func4_AO_VIEW_2; \
	MENU func4_AO_VIEW_2_page; \
	COLLECTION func4_AO_VIEW_3; \
	MENU func4_AO_VIEW_3_page; \
	UNIT func4_AO_PV_SCALE_unit_3

#define USE_FUNC4_AO_OPTIONAL_A \
	USE_FUNC4_AO_OPTIONAL_BOTH; \
	COLLECTION func4_AO_READBACK; \
	VARIABLE func4_AO_READBACK_Value; \
	VARIABLE func4_AO_READBACK_Status_Condensed; \
	VARIABLE func4_AO_READBACK_Status_Quality; \
	VARIABLE func4_AO_READBACK_Status_Limit; \
	MENU func4_AO_READBACK_page; \
	COMMAND func4_AO_READBACK_read; \
	VARIABLE func4_AO_IN_CHANNEL; \
	MENU func4_AO_IN_CHANNEL_page; \
	COMMAND func4_AO_IN_CHANNEL_read; \
	COMMAND func4_AO_IN_CHANNEL_write; \
	VARIABLE func4_AO_OUT_CHANNEL; \
	MENU func4_AO_OUT_CHANNEL_page; \
	COMMAND func4_AO_OUT_CHANNEL_read; \
	COMMAND func4_AO_OUT_CHANNEL_write; \
	VARIABLE func4_AO_FSAFE_TIME; \
	MENU func4_AO_FSAFE_TIME_page; \
	COMMAND func4_AO_FSAFE_TIME_read; \
	COMMAND func4_AO_FSAFE_TIME_write; \
	VARIABLE func4_AO_FSAFE_TYPE; \
	MENU func4_AO_FSAFE_TYPE_page; \
	COMMAND func4_AO_FSAFE_TYPE_read; \
	COMMAND func4_AO_FSAFE_TYPE_write; \
	VARIABLE func4_AO_FSAFE_VALUE; \
	MENU func4_AO_FSAFE_VALUE_page; \
	COMMAND func4_AO_FSAFE_VALUE_read; \
	COMMAND func4_AO_FSAFE_VALUE_write; \
	VARIABLE func4_AO_CHECK_BACK; \
	MENU func4_AO_CHECK_BACK_page; \
	COMMAND func4_AO_CHECK_BACK_read; \
	VARIABLE func4_AO_CHECK_BACK_MASK; \
	MENU func4_AO_CHECK_BACK_MASK_page; \
	COMMAND func4_AO_CHECK_BACK_MASK_read; \
	COLLECTION func4_AO_SIMULATE; \
	VARIABLE func4_AO_SIMULATE_Status_Condensed; \
	VARIABLE func4_AO_SIMULATE_Value; \
	VARIABLE func4_AO_SIMULATE_Enabled; \
	VARIABLE func4_AO_SIMULATE_Status_Quality; \
	VARIABLE func4_AO_SIMULATE_Status_Limit; \
	MENU func4_AO_SIMULATE_page; \
	COMMAND func4_AO_SIMULATE_read; \
	COMMAND func4_AO_SIMULATE_write; \
	VARIABLE func4_AO_INCREASE_CLOSE; \
	MENU func4_AO_INCREASE_CLOSE_page; \
	COMMAND func4_AO_INCREASE_CLOSE_read; \
	COMMAND func4_AO_INCREASE_CLOSE_write; \
	COLLECTION func4_AO_OUT; \
	VARIABLE func4_AO_OUT_Value; \
	VARIABLE func4_AO_OUT_Status_Condensed; \
	VARIABLE func4_AO_OUT_Status_Quality; \
	VARIABLE func4_AO_OUT_Status_Limit; \
	MENU func4_AO_OUT_page; \
	COMMAND func4_AO_OUT_read; \
	COMMAND func4_AO_OUT_write; \
	COLLECTION func4_AO_VIEW_1; \
	MENU func4_AO_VIEW_1_page; \
	MENU func4_AO_Simple_Dialog_Optional_A; \
	UNIT func4_AO_PV_SCALE_unit_2; \
	UNIT func4_AO_OUT_SCALE_unit_2

#define USE_FUNC4_AO_OPTIONAL_B \
	USE_FUNC4_AO_OPTIONAL_BOTH; \
	MENU func4_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC4_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func4_AO_)
#define USE_FUNC4_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func4_AO_)
#define USE_FUNC4_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func4_AO_)
#define USE_FUNC4_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func4_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC5_AO_MANDATORY_BOTH \
	BLOCK func5_AO_block; \
	COLLECTION func5_AO_BLOCK_OBJECT; \
	VARIABLE func5_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func5_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func5_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func5_AO_BLOCK_OBJECT_Class; \
	VARIABLE func5_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func5_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func5_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func5_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func5_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func5_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func5_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func5_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func5_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func5_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func5_AO_BLOCK_OBJECT_page; \
	COMMAND func5_AO_BLOCK_OBJECT_read; \
	VARIABLE func5_AO_ST_REV; \
	MENU func5_AO_ST_REV_page; \
	COMMAND func5_AO_ST_REV_read; \
	VARIABLE func5_AO_TAG_DESC; \
	MENU func5_AO_TAG_DESC_page; \
	COMMAND func5_AO_TAG_DESC_read; \
	COMMAND func5_AO_TAG_DESC_write; \
	VARIABLE func5_AO_STRATEGY; \
	MENU func5_AO_STRATEGY_page; \
	COMMAND func5_AO_STRATEGY_read; \
	COMMAND func5_AO_STRATEGY_write; \
	VARIABLE func5_AO_ALERT_KEY; \
	MENU func5_AO_ALERT_KEY_page; \
	COMMAND func5_AO_ALERT_KEY_read; \
	COMMAND func5_AO_ALERT_KEY_write; \
	VARIABLE func5_AO_TARGET_MODE; \
	MENU func5_AO_TARGET_MODE_page; \
	COMMAND func5_AO_TARGET_MODE_read; \
	COMMAND func5_AO_TARGET_MODE_write; \
	COLLECTION func5_AO_MODE_BLK; \
	VARIABLE func5_AO_MODE_BLK_Actual; \
	VARIABLE func5_AO_MODE_BLK_Permitted; \
	VARIABLE func5_AO_MODE_BLK_Normal; \
	MENU func5_AO_MODE_BLK_page; \
	COMMAND func5_AO_MODE_BLK_read; \
	COLLECTION func5_AO_ALARM_SUM; \
	VARIABLE func5_AO_ALARM_SUM_Current; \
	VARIABLE func5_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func5_AO_ALARM_SUM_Unreported; \
	VARIABLE func5_AO_ALARM_SUM_Disabled; \
	MENU func5_AO_ALARM_SUM_page; \
	COMMAND func5_AO_ALARM_SUM_read; \
	COLLECTION func5_AO_BATCH; \
	VARIABLE func5_AO_BATCH_Batch_ID; \
	VARIABLE func5_AO_BATCH_Rup; \
	VARIABLE func5_AO_BATCH_Operation; \
	VARIABLE func5_AO_BATCH_Phase; \
	MENU func5_AO_BATCH_page; \
	COMMAND func5_AO_BATCH_read; \
	COMMAND func5_AO_BATCH_write; \
	COLLECTION func5_AO_SP; \
	VARIABLE func5_AO_SP_Value; \
	VARIABLE func5_AO_SP_Status_Condensed; \
	VARIABLE func5_AO_SP_Status_Quality; \
	VARIABLE func5_AO_SP_Status_Limit; \
	MENU func5_AO_SP_page; \
	COMMAND func5_AO_SP_read; \
	COMMAND func5_AO_SP_write; \
	COLLECTION func5_AO_PV_SCALE; \
	VARIABLE func5_AO_PV_SCALE_Upper_Value; \
	VARIABLE func5_AO_PV_SCALE_Lower_Value; \
	VARIABLE func5_AO_PV_SCALE_Units_Index; \
	VARIABLE func5_AO_PV_SCALE_Decimal_Point; \
	MENU func5_AO_PV_SCALE_page; \
	COMMAND func5_AO_PV_SCALE_read; \
	COMMAND func5_AO_PV_SCALE_write; \
	COLLECTION func5_AO_POS_D; \
	VARIABLE func5_AO_POS_D_Value; \
	VARIABLE func5_AO_POS_D_Status_Condensed; \
	VARIABLE func5_AO_POS_D_Status_Quality; \
	VARIABLE func5_AO_POS_D_Status_Limit; \
	MENU func5_AO_POS_D_page; \
	COMMAND func5_AO_POS_D_read; \
	COLLECTION func5_AO_OUT_SCALE; \
	VARIABLE func5_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func5_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func5_AO_OUT_SCALE_Units_Index; \
	VARIABLE func5_AO_OUT_SCALE_Decimal_Point; \
	MENU func5_AO_OUT_SCALE_page; \
	COMMAND func5_AO_OUT_SCALE_read; \
	COMMAND func5_AO_OUT_SCALE_write; \
	UNIT func5_AO_PV_SCALE_unit_1; \
	UNIT func5_AO_OUT_SCALE_unit_1

#define USE_FUNC5_AO_MANDATORY_A \
	USE_FUNC5_AO_MANDATORY_BOTH; \
	MENU func5_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC5_AO_MANDATORY_B \
	USE_FUNC5_AO_MANDATORY_BOTH; \
	COLLECTION func5_AO_READBACK; \
	VARIABLE func5_AO_READBACK_Value; \
	VARIABLE func5_AO_READBACK_Status_Condensed; \
	VARIABLE func5_AO_READBACK_Status_Quality; \
	VARIABLE func5_AO_READBACK_Status_Limit; \
	MENU func5_AO_READBACK_page; \
	COMMAND func5_AO_READBACK_read; \
	VARIABLE func5_AO_IN_CHANNEL; \
	MENU func5_AO_IN_CHANNEL_page; \
	COMMAND func5_AO_IN_CHANNEL_read; \
	COMMAND func5_AO_IN_CHANNEL_write; \
	VARIABLE func5_AO_OUT_CHANNEL; \
	MENU func5_AO_OUT_CHANNEL_page; \
	COMMAND func5_AO_OUT_CHANNEL_read; \
	COMMAND func5_AO_OUT_CHANNEL_write; \
	VARIABLE func5_AO_FSAFE_TIME; \
	MENU func5_AO_FSAFE_TIME_page; \
	COMMAND func5_AO_FSAFE_TIME_read; \
	COMMAND func5_AO_FSAFE_TIME_write; \
	VARIABLE func5_AO_FSAFE_TYPE; \
	MENU func5_AO_FSAFE_TYPE_page; \
	COMMAND func5_AO_FSAFE_TYPE_read; \
	COMMAND func5_AO_FSAFE_TYPE_write; \
	VARIABLE func5_AO_FSAFE_VALUE; \
	MENU func5_AO_FSAFE_VALUE_page; \
	COMMAND func5_AO_FSAFE_VALUE_read; \
	COMMAND func5_AO_FSAFE_VALUE_write; \
	VARIABLE func5_AO_CHECK_BACK; \
	MENU func5_AO_CHECK_BACK_page; \
	COMMAND func5_AO_CHECK_BACK_read; \
	VARIABLE func5_AO_CHECK_BACK_MASK; \
	MENU func5_AO_CHECK_BACK_MASK_page; \
	COMMAND func5_AO_CHECK_BACK_MASK_read; \
	COLLECTION func5_AO_SIMULATE; \
	VARIABLE func5_AO_SIMULATE_Status_Condensed; \
	VARIABLE func5_AO_SIMULATE_Value; \
	VARIABLE func5_AO_SIMULATE_Enabled; \
	VARIABLE func5_AO_SIMULATE_Status_Quality; \
	VARIABLE func5_AO_SIMULATE_Status_Limit; \
	MENU func5_AO_SIMULATE_page; \
	COMMAND func5_AO_SIMULATE_read; \
	COMMAND func5_AO_SIMULATE_write; \
	VARIABLE func5_AO_INCREASE_CLOSE; \
	MENU func5_AO_INCREASE_CLOSE_page; \
	COMMAND func5_AO_INCREASE_CLOSE_read; \
	COMMAND func5_AO_INCREASE_CLOSE_write; \
	COLLECTION func5_AO_OUT; \
	VARIABLE func5_AO_OUT_Value; \
	VARIABLE func5_AO_OUT_Status_Condensed; \
	VARIABLE func5_AO_OUT_Status_Quality; \
	VARIABLE func5_AO_OUT_Status_Limit; \
	MENU func5_AO_OUT_page; \
	COMMAND func5_AO_OUT_read; \
	COMMAND func5_AO_OUT_write; \
	COLLECTION func5_AO_VIEW_1; \
	MENU func5_AO_VIEW_1_page; \
	MENU func5_AO_Simple_Dialog_Mandatory_B; \
	UNIT func5_AO_PV_SCALE_unit_2; \
	UNIT func5_AO_OUT_SCALE_unit_2

#define USE_FUNC5_AO_OPTIONAL_BOTH \
	COLLECTION func5_AO_RCAS_IN; \
	VARIABLE func5_AO_RCAS_IN_Value; \
	VARIABLE func5_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func5_AO_RCAS_IN_Status_Quality; \
	VARIABLE func5_AO_RCAS_IN_Status_Limit; \
	MENU func5_AO_RCAS_IN_page; \
	COMMAND func5_AO_RCAS_IN_read; \
	COMMAND func5_AO_RCAS_IN_write; \
	COLLECTION func5_AO_RCAS_OUT; \
	VARIABLE func5_AO_RCAS_OUT_Value; \
	VARIABLE func5_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func5_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func5_AO_RCAS_OUT_Status_Limit; \
	MENU func5_AO_RCAS_OUT_page; \
	COMMAND func5_AO_RCAS_OUT_read; \
	VARIABLE func5_AO_SETP_DEVIATION; \
	MENU func5_AO_SETP_DEVIATION_page; \
	COMMAND func5_AO_SETP_DEVIATION_read; \
	COLLECTION func5_AO_VIEW_2; \
	MENU func5_AO_VIEW_2_page; \
	COLLECTION func5_AO_VIEW_3; \
	MENU func5_AO_VIEW_3_page; \
	UNIT func5_AO_PV_SCALE_unit_3

#define USE_FUNC5_AO_OPTIONAL_A \
	USE_FUNC5_AO_OPTIONAL_BOTH; \
	COLLECTION func5_AO_READBACK; \
	VARIABLE func5_AO_READBACK_Value; \
	VARIABLE func5_AO_READBACK_Status_Condensed; \
	VARIABLE func5_AO_READBACK_Status_Quality; \
	VARIABLE func5_AO_READBACK_Status_Limit; \
	MENU func5_AO_READBACK_page; \
	COMMAND func5_AO_READBACK_read; \
	VARIABLE func5_AO_IN_CHANNEL; \
	MENU func5_AO_IN_CHANNEL_page; \
	COMMAND func5_AO_IN_CHANNEL_read; \
	COMMAND func5_AO_IN_CHANNEL_write; \
	VARIABLE func5_AO_OUT_CHANNEL; \
	MENU func5_AO_OUT_CHANNEL_page; \
	COMMAND func5_AO_OUT_CHANNEL_read; \
	COMMAND func5_AO_OUT_CHANNEL_write; \
	VARIABLE func5_AO_FSAFE_TIME; \
	MENU func5_AO_FSAFE_TIME_page; \
	COMMAND func5_AO_FSAFE_TIME_read; \
	COMMAND func5_AO_FSAFE_TIME_write; \
	VARIABLE func5_AO_FSAFE_TYPE; \
	MENU func5_AO_FSAFE_TYPE_page; \
	COMMAND func5_AO_FSAFE_TYPE_read; \
	COMMAND func5_AO_FSAFE_TYPE_write; \
	VARIABLE func5_AO_FSAFE_VALUE; \
	MENU func5_AO_FSAFE_VALUE_page; \
	COMMAND func5_AO_FSAFE_VALUE_read; \
	COMMAND func5_AO_FSAFE_VALUE_write; \
	VARIABLE func5_AO_CHECK_BACK; \
	MENU func5_AO_CHECK_BACK_page; \
	COMMAND func5_AO_CHECK_BACK_read; \
	VARIABLE func5_AO_CHECK_BACK_MASK; \
	MENU func5_AO_CHECK_BACK_MASK_page; \
	COMMAND func5_AO_CHECK_BACK_MASK_read; \
	COLLECTION func5_AO_SIMULATE; \
	VARIABLE func5_AO_SIMULATE_Status_Condensed; \
	VARIABLE func5_AO_SIMULATE_Value; \
	VARIABLE func5_AO_SIMULATE_Enabled; \
	VARIABLE func5_AO_SIMULATE_Status_Quality; \
	VARIABLE func5_AO_SIMULATE_Status_Limit; \
	MENU func5_AO_SIMULATE_page; \
	COMMAND func5_AO_SIMULATE_read; \
	COMMAND func5_AO_SIMULATE_write; \
	VARIABLE func5_AO_INCREASE_CLOSE; \
	MENU func5_AO_INCREASE_CLOSE_page; \
	COMMAND func5_AO_INCREASE_CLOSE_read; \
	COMMAND func5_AO_INCREASE_CLOSE_write; \
	COLLECTION func5_AO_OUT; \
	VARIABLE func5_AO_OUT_Value; \
	VARIABLE func5_AO_OUT_Status_Condensed; \
	VARIABLE func5_AO_OUT_Status_Quality; \
	VARIABLE func5_AO_OUT_Status_Limit; \
	MENU func5_AO_OUT_page; \
	COMMAND func5_AO_OUT_read; \
	COMMAND func5_AO_OUT_write; \
	COLLECTION func5_AO_VIEW_1; \
	MENU func5_AO_VIEW_1_page; \
	MENU func5_AO_Simple_Dialog_Optional_A; \
	UNIT func5_AO_PV_SCALE_unit_2; \
	UNIT func5_AO_OUT_SCALE_unit_2

#define USE_FUNC5_AO_OPTIONAL_B \
	USE_FUNC5_AO_OPTIONAL_BOTH; \
	MENU func5_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC5_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func5_AO_)
#define USE_FUNC5_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func5_AO_)
#define USE_FUNC5_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func5_AO_)
#define USE_FUNC5_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func5_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC6_AO_MANDATORY_BOTH \
	BLOCK func6_AO_block; \
	COLLECTION func6_AO_BLOCK_OBJECT; \
	VARIABLE func6_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func6_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func6_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func6_AO_BLOCK_OBJECT_Class; \
	VARIABLE func6_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func6_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func6_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func6_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func6_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func6_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func6_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func6_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func6_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func6_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func6_AO_BLOCK_OBJECT_page; \
	COMMAND func6_AO_BLOCK_OBJECT_read; \
	VARIABLE func6_AO_ST_REV; \
	MENU func6_AO_ST_REV_page; \
	COMMAND func6_AO_ST_REV_read; \
	VARIABLE func6_AO_TAG_DESC; \
	MENU func6_AO_TAG_DESC_page; \
	COMMAND func6_AO_TAG_DESC_read; \
	COMMAND func6_AO_TAG_DESC_write; \
	VARIABLE func6_AO_STRATEGY; \
	MENU func6_AO_STRATEGY_page; \
	COMMAND func6_AO_STRATEGY_read; \
	COMMAND func6_AO_STRATEGY_write; \
	VARIABLE func6_AO_ALERT_KEY; \
	MENU func6_AO_ALERT_KEY_page; \
	COMMAND func6_AO_ALERT_KEY_read; \
	COMMAND func6_AO_ALERT_KEY_write; \
	VARIABLE func6_AO_TARGET_MODE; \
	MENU func6_AO_TARGET_MODE_page; \
	COMMAND func6_AO_TARGET_MODE_read; \
	COMMAND func6_AO_TARGET_MODE_write; \
	COLLECTION func6_AO_MODE_BLK; \
	VARIABLE func6_AO_MODE_BLK_Actual; \
	VARIABLE func6_AO_MODE_BLK_Permitted; \
	VARIABLE func6_AO_MODE_BLK_Normal; \
	MENU func6_AO_MODE_BLK_page; \
	COMMAND func6_AO_MODE_BLK_read; \
	COLLECTION func6_AO_ALARM_SUM; \
	VARIABLE func6_AO_ALARM_SUM_Current; \
	VARIABLE func6_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func6_AO_ALARM_SUM_Unreported; \
	VARIABLE func6_AO_ALARM_SUM_Disabled; \
	MENU func6_AO_ALARM_SUM_page; \
	COMMAND func6_AO_ALARM_SUM_read; \
	COLLECTION func6_AO_BATCH; \
	VARIABLE func6_AO_BATCH_Batch_ID; \
	VARIABLE func6_AO_BATCH_Rup; \
	VARIABLE func6_AO_BATCH_Operation; \
	VARIABLE func6_AO_BATCH_Phase; \
	MENU func6_AO_BATCH_page; \
	COMMAND func6_AO_BATCH_read; \
	COMMAND func6_AO_BATCH_write; \
	COLLECTION func6_AO_SP; \
	VARIABLE func6_AO_SP_Value; \
	VARIABLE func6_AO_SP_Status_Condensed; \
	VARIABLE func6_AO_SP_Status_Quality; \
	VARIABLE func6_AO_SP_Status_Limit; \
	MENU func6_AO_SP_page; \
	COMMAND func6_AO_SP_read; \
	COMMAND func6_AO_SP_write; \
	COLLECTION func6_AO_PV_SCALE; \
	VARIABLE func6_AO_PV_SCALE_Upper_Value; \
	VARIABLE func6_AO_PV_SCALE_Lower_Value; \
	VARIABLE func6_AO_PV_SCALE_Units_Index; \
	VARIABLE func6_AO_PV_SCALE_Decimal_Point; \
	MENU func6_AO_PV_SCALE_page; \
	COMMAND func6_AO_PV_SCALE_read; \
	COMMAND func6_AO_PV_SCALE_write; \
	COLLECTION func6_AO_POS_D; \
	VARIABLE func6_AO_POS_D_Value; \
	VARIABLE func6_AO_POS_D_Status_Condensed; \
	VARIABLE func6_AO_POS_D_Status_Quality; \
	VARIABLE func6_AO_POS_D_Status_Limit; \
	MENU func6_AO_POS_D_page; \
	COMMAND func6_AO_POS_D_read; \
	COLLECTION func6_AO_OUT_SCALE; \
	VARIABLE func6_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func6_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func6_AO_OUT_SCALE_Units_Index; \
	VARIABLE func6_AO_OUT_SCALE_Decimal_Point; \
	MENU func6_AO_OUT_SCALE_page; \
	COMMAND func6_AO_OUT_SCALE_read; \
	COMMAND func6_AO_OUT_SCALE_write; \
	UNIT func6_AO_PV_SCALE_unit_1; \
	UNIT func6_AO_OUT_SCALE_unit_1

#define USE_FUNC6_AO_MANDATORY_A \
	USE_FUNC6_AO_MANDATORY_BOTH; \
	MENU func6_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC6_AO_MANDATORY_B \
	USE_FUNC6_AO_MANDATORY_BOTH; \
	COLLECTION func6_AO_READBACK; \
	VARIABLE func6_AO_READBACK_Value; \
	VARIABLE func6_AO_READBACK_Status_Condensed; \
	VARIABLE func6_AO_READBACK_Status_Quality; \
	VARIABLE func6_AO_READBACK_Status_Limit; \
	MENU func6_AO_READBACK_page; \
	COMMAND func6_AO_READBACK_read; \
	VARIABLE func6_AO_IN_CHANNEL; \
	MENU func6_AO_IN_CHANNEL_page; \
	COMMAND func6_AO_IN_CHANNEL_read; \
	COMMAND func6_AO_IN_CHANNEL_write; \
	VARIABLE func6_AO_OUT_CHANNEL; \
	MENU func6_AO_OUT_CHANNEL_page; \
	COMMAND func6_AO_OUT_CHANNEL_read; \
	COMMAND func6_AO_OUT_CHANNEL_write; \
	VARIABLE func6_AO_FSAFE_TIME; \
	MENU func6_AO_FSAFE_TIME_page; \
	COMMAND func6_AO_FSAFE_TIME_read; \
	COMMAND func6_AO_FSAFE_TIME_write; \
	VARIABLE func6_AO_FSAFE_TYPE; \
	MENU func6_AO_FSAFE_TYPE_page; \
	COMMAND func6_AO_FSAFE_TYPE_read; \
	COMMAND func6_AO_FSAFE_TYPE_write; \
	VARIABLE func6_AO_FSAFE_VALUE; \
	MENU func6_AO_FSAFE_VALUE_page; \
	COMMAND func6_AO_FSAFE_VALUE_read; \
	COMMAND func6_AO_FSAFE_VALUE_write; \
	VARIABLE func6_AO_CHECK_BACK; \
	MENU func6_AO_CHECK_BACK_page; \
	COMMAND func6_AO_CHECK_BACK_read; \
	VARIABLE func6_AO_CHECK_BACK_MASK; \
	MENU func6_AO_CHECK_BACK_MASK_page; \
	COMMAND func6_AO_CHECK_BACK_MASK_read; \
	COLLECTION func6_AO_SIMULATE; \
	VARIABLE func6_AO_SIMULATE_Status_Condensed; \
	VARIABLE func6_AO_SIMULATE_Value; \
	VARIABLE func6_AO_SIMULATE_Enabled; \
	VARIABLE func6_AO_SIMULATE_Status_Quality; \
	VARIABLE func6_AO_SIMULATE_Status_Limit; \
	MENU func6_AO_SIMULATE_page; \
	COMMAND func6_AO_SIMULATE_read; \
	COMMAND func6_AO_SIMULATE_write; \
	VARIABLE func6_AO_INCREASE_CLOSE; \
	MENU func6_AO_INCREASE_CLOSE_page; \
	COMMAND func6_AO_INCREASE_CLOSE_read; \
	COMMAND func6_AO_INCREASE_CLOSE_write; \
	COLLECTION func6_AO_OUT; \
	VARIABLE func6_AO_OUT_Value; \
	VARIABLE func6_AO_OUT_Status_Condensed; \
	VARIABLE func6_AO_OUT_Status_Quality; \
	VARIABLE func6_AO_OUT_Status_Limit; \
	MENU func6_AO_OUT_page; \
	COMMAND func6_AO_OUT_read; \
	COMMAND func6_AO_OUT_write; \
	COLLECTION func6_AO_VIEW_1; \
	MENU func6_AO_VIEW_1_page; \
	MENU func6_AO_Simple_Dialog_Mandatory_B; \
	UNIT func6_AO_PV_SCALE_unit_2; \
	UNIT func6_AO_OUT_SCALE_unit_2

#define USE_FUNC6_AO_OPTIONAL_BOTH \
	COLLECTION func6_AO_RCAS_IN; \
	VARIABLE func6_AO_RCAS_IN_Value; \
	VARIABLE func6_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func6_AO_RCAS_IN_Status_Quality; \
	VARIABLE func6_AO_RCAS_IN_Status_Limit; \
	MENU func6_AO_RCAS_IN_page; \
	COMMAND func6_AO_RCAS_IN_read; \
	COMMAND func6_AO_RCAS_IN_write; \
	COLLECTION func6_AO_RCAS_OUT; \
	VARIABLE func6_AO_RCAS_OUT_Value; \
	VARIABLE func6_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func6_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func6_AO_RCAS_OUT_Status_Limit; \
	MENU func6_AO_RCAS_OUT_page; \
	COMMAND func6_AO_RCAS_OUT_read; \
	VARIABLE func6_AO_SETP_DEVIATION; \
	MENU func6_AO_SETP_DEVIATION_page; \
	COMMAND func6_AO_SETP_DEVIATION_read; \
	COLLECTION func6_AO_VIEW_2; \
	MENU func6_AO_VIEW_2_page; \
	COLLECTION func6_AO_VIEW_3; \
	MENU func6_AO_VIEW_3_page; \
	UNIT func6_AO_PV_SCALE_unit_3

#define USE_FUNC6_AO_OPTIONAL_A \
	USE_FUNC6_AO_OPTIONAL_BOTH; \
	COLLECTION func6_AO_READBACK; \
	VARIABLE func6_AO_READBACK_Value; \
	VARIABLE func6_AO_READBACK_Status_Condensed; \
	VARIABLE func6_AO_READBACK_Status_Quality; \
	VARIABLE func6_AO_READBACK_Status_Limit; \
	MENU func6_AO_READBACK_page; \
	COMMAND func6_AO_READBACK_read; \
	VARIABLE func6_AO_IN_CHANNEL; \
	MENU func6_AO_IN_CHANNEL_page; \
	COMMAND func6_AO_IN_CHANNEL_read; \
	COMMAND func6_AO_IN_CHANNEL_write; \
	VARIABLE func6_AO_OUT_CHANNEL; \
	MENU func6_AO_OUT_CHANNEL_page; \
	COMMAND func6_AO_OUT_CHANNEL_read; \
	COMMAND func6_AO_OUT_CHANNEL_write; \
	VARIABLE func6_AO_FSAFE_TIME; \
	MENU func6_AO_FSAFE_TIME_page; \
	COMMAND func6_AO_FSAFE_TIME_read; \
	COMMAND func6_AO_FSAFE_TIME_write; \
	VARIABLE func6_AO_FSAFE_TYPE; \
	MENU func6_AO_FSAFE_TYPE_page; \
	COMMAND func6_AO_FSAFE_TYPE_read; \
	COMMAND func6_AO_FSAFE_TYPE_write; \
	VARIABLE func6_AO_FSAFE_VALUE; \
	MENU func6_AO_FSAFE_VALUE_page; \
	COMMAND func6_AO_FSAFE_VALUE_read; \
	COMMAND func6_AO_FSAFE_VALUE_write; \
	VARIABLE func6_AO_CHECK_BACK; \
	MENU func6_AO_CHECK_BACK_page; \
	COMMAND func6_AO_CHECK_BACK_read; \
	VARIABLE func6_AO_CHECK_BACK_MASK; \
	MENU func6_AO_CHECK_BACK_MASK_page; \
	COMMAND func6_AO_CHECK_BACK_MASK_read; \
	COLLECTION func6_AO_SIMULATE; \
	VARIABLE func6_AO_SIMULATE_Status_Condensed; \
	VARIABLE func6_AO_SIMULATE_Value; \
	VARIABLE func6_AO_SIMULATE_Enabled; \
	VARIABLE func6_AO_SIMULATE_Status_Quality; \
	VARIABLE func6_AO_SIMULATE_Status_Limit; \
	MENU func6_AO_SIMULATE_page; \
	COMMAND func6_AO_SIMULATE_read; \
	COMMAND func6_AO_SIMULATE_write; \
	VARIABLE func6_AO_INCREASE_CLOSE; \
	MENU func6_AO_INCREASE_CLOSE_page; \
	COMMAND func6_AO_INCREASE_CLOSE_read; \
	COMMAND func6_AO_INCREASE_CLOSE_write; \
	COLLECTION func6_AO_OUT; \
	VARIABLE func6_AO_OUT_Value; \
	VARIABLE func6_AO_OUT_Status_Condensed; \
	VARIABLE func6_AO_OUT_Status_Quality; \
	VARIABLE func6_AO_OUT_Status_Limit; \
	MENU func6_AO_OUT_page; \
	COMMAND func6_AO_OUT_read; \
	COMMAND func6_AO_OUT_write; \
	COLLECTION func6_AO_VIEW_1; \
	MENU func6_AO_VIEW_1_page; \
	MENU func6_AO_Simple_Dialog_Optional_A; \
	UNIT func6_AO_PV_SCALE_unit_2; \
	UNIT func6_AO_OUT_SCALE_unit_2

#define USE_FUNC6_AO_OPTIONAL_B \
	USE_FUNC6_AO_OPTIONAL_BOTH; \
	MENU func6_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC6_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func6_AO_)
#define USE_FUNC6_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func6_AO_)
#define USE_FUNC6_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func6_AO_)
#define USE_FUNC6_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func6_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC7_AO_MANDATORY_BOTH \
	BLOCK func7_AO_block; \
	COLLECTION func7_AO_BLOCK_OBJECT; \
	VARIABLE func7_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func7_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func7_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func7_AO_BLOCK_OBJECT_Class; \
	VARIABLE func7_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func7_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func7_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func7_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func7_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func7_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func7_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func7_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func7_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func7_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func7_AO_BLOCK_OBJECT_page; \
	COMMAND func7_AO_BLOCK_OBJECT_read; \
	VARIABLE func7_AO_ST_REV; \
	MENU func7_AO_ST_REV_page; \
	COMMAND func7_AO_ST_REV_read; \
	VARIABLE func7_AO_TAG_DESC; \
	MENU func7_AO_TAG_DESC_page; \
	COMMAND func7_AO_TAG_DESC_read; \
	COMMAND func7_AO_TAG_DESC_write; \
	VARIABLE func7_AO_STRATEGY; \
	MENU func7_AO_STRATEGY_page; \
	COMMAND func7_AO_STRATEGY_read; \
	COMMAND func7_AO_STRATEGY_write; \
	VARIABLE func7_AO_ALERT_KEY; \
	MENU func7_AO_ALERT_KEY_page; \
	COMMAND func7_AO_ALERT_KEY_read; \
	COMMAND func7_AO_ALERT_KEY_write; \
	VARIABLE func7_AO_TARGET_MODE; \
	MENU func7_AO_TARGET_MODE_page; \
	COMMAND func7_AO_TARGET_MODE_read; \
	COMMAND func7_AO_TARGET_MODE_write; \
	COLLECTION func7_AO_MODE_BLK; \
	VARIABLE func7_AO_MODE_BLK_Actual; \
	VARIABLE func7_AO_MODE_BLK_Permitted; \
	VARIABLE func7_AO_MODE_BLK_Normal; \
	MENU func7_AO_MODE_BLK_page; \
	COMMAND func7_AO_MODE_BLK_read; \
	COLLECTION func7_AO_ALARM_SUM; \
	VARIABLE func7_AO_ALARM_SUM_Current; \
	VARIABLE func7_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func7_AO_ALARM_SUM_Unreported; \
	VARIABLE func7_AO_ALARM_SUM_Disabled; \
	MENU func7_AO_ALARM_SUM_page; \
	COMMAND func7_AO_ALARM_SUM_read; \
	COLLECTION func7_AO_BATCH; \
	VARIABLE func7_AO_BATCH_Batch_ID; \
	VARIABLE func7_AO_BATCH_Rup; \
	VARIABLE func7_AO_BATCH_Operation; \
	VARIABLE func7_AO_BATCH_Phase; \
	MENU func7_AO_BATCH_page; \
	COMMAND func7_AO_BATCH_read; \
	COMMAND func7_AO_BATCH_write; \
	COLLECTION func7_AO_SP; \
	VARIABLE func7_AO_SP_Value; \
	VARIABLE func7_AO_SP_Status_Condensed; \
	VARIABLE func7_AO_SP_Status_Quality; \
	VARIABLE func7_AO_SP_Status_Limit; \
	MENU func7_AO_SP_page; \
	COMMAND func7_AO_SP_read; \
	COMMAND func7_AO_SP_write; \
	COLLECTION func7_AO_PV_SCALE; \
	VARIABLE func7_AO_PV_SCALE_Upper_Value; \
	VARIABLE func7_AO_PV_SCALE_Lower_Value; \
	VARIABLE func7_AO_PV_SCALE_Units_Index; \
	VARIABLE func7_AO_PV_SCALE_Decimal_Point; \
	MENU func7_AO_PV_SCALE_page; \
	COMMAND func7_AO_PV_SCALE_read; \
	COMMAND func7_AO_PV_SCALE_write; \
	COLLECTION func7_AO_POS_D; \
	VARIABLE func7_AO_POS_D_Value; \
	VARIABLE func7_AO_POS_D_Status_Condensed; \
	VARIABLE func7_AO_POS_D_Status_Quality; \
	VARIABLE func7_AO_POS_D_Status_Limit; \
	MENU func7_AO_POS_D_page; \
	COMMAND func7_AO_POS_D_read; \
	COLLECTION func7_AO_OUT_SCALE; \
	VARIABLE func7_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func7_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func7_AO_OUT_SCALE_Units_Index; \
	VARIABLE func7_AO_OUT_SCALE_Decimal_Point; \
	MENU func7_AO_OUT_SCALE_page; \
	COMMAND func7_AO_OUT_SCALE_read; \
	COMMAND func7_AO_OUT_SCALE_write; \
	UNIT func7_AO_PV_SCALE_unit_1; \
	UNIT func7_AO_OUT_SCALE_unit_1

#define USE_FUNC7_AO_MANDATORY_A \
	USE_FUNC7_AO_MANDATORY_BOTH; \
	MENU func7_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC7_AO_MANDATORY_B \
	USE_FUNC7_AO_MANDATORY_BOTH; \
	COLLECTION func7_AO_READBACK; \
	VARIABLE func7_AO_READBACK_Value; \
	VARIABLE func7_AO_READBACK_Status_Condensed; \
	VARIABLE func7_AO_READBACK_Status_Quality; \
	VARIABLE func7_AO_READBACK_Status_Limit; \
	MENU func7_AO_READBACK_page; \
	COMMAND func7_AO_READBACK_read; \
	VARIABLE func7_AO_IN_CHANNEL; \
	MENU func7_AO_IN_CHANNEL_page; \
	COMMAND func7_AO_IN_CHANNEL_read; \
	COMMAND func7_AO_IN_CHANNEL_write; \
	VARIABLE func7_AO_OUT_CHANNEL; \
	MENU func7_AO_OUT_CHANNEL_page; \
	COMMAND func7_AO_OUT_CHANNEL_read; \
	COMMAND func7_AO_OUT_CHANNEL_write; \
	VARIABLE func7_AO_FSAFE_TIME; \
	MENU func7_AO_FSAFE_TIME_page; \
	COMMAND func7_AO_FSAFE_TIME_read; \
	COMMAND func7_AO_FSAFE_TIME_write; \
	VARIABLE func7_AO_FSAFE_TYPE; \
	MENU func7_AO_FSAFE_TYPE_page; \
	COMMAND func7_AO_FSAFE_TYPE_read; \
	COMMAND func7_AO_FSAFE_TYPE_write; \
	VARIABLE func7_AO_FSAFE_VALUE; \
	MENU func7_AO_FSAFE_VALUE_page; \
	COMMAND func7_AO_FSAFE_VALUE_read; \
	COMMAND func7_AO_FSAFE_VALUE_write; \
	VARIABLE func7_AO_CHECK_BACK; \
	MENU func7_AO_CHECK_BACK_page; \
	COMMAND func7_AO_CHECK_BACK_read; \
	VARIABLE func7_AO_CHECK_BACK_MASK; \
	MENU func7_AO_CHECK_BACK_MASK_page; \
	COMMAND func7_AO_CHECK_BACK_MASK_read; \
	COLLECTION func7_AO_SIMULATE; \
	VARIABLE func7_AO_SIMULATE_Status_Condensed; \
	VARIABLE func7_AO_SIMULATE_Value; \
	VARIABLE func7_AO_SIMULATE_Enabled; \
	VARIABLE func7_AO_SIMULATE_Status_Quality; \
	VARIABLE func7_AO_SIMULATE_Status_Limit; \
	MENU func7_AO_SIMULATE_page; \
	COMMAND func7_AO_SIMULATE_read; \
	COMMAND func7_AO_SIMULATE_write; \
	VARIABLE func7_AO_INCREASE_CLOSE; \
	MENU func7_AO_INCREASE_CLOSE_page; \
	COMMAND func7_AO_INCREASE_CLOSE_read; \
	COMMAND func7_AO_INCREASE_CLOSE_write; \
	COLLECTION func7_AO_OUT; \
	VARIABLE func7_AO_OUT_Value; \
	VARIABLE func7_AO_OUT_Status_Condensed; \
	VARIABLE func7_AO_OUT_Status_Quality; \
	VARIABLE func7_AO_OUT_Status_Limit; \
	MENU func7_AO_OUT_page; \
	COMMAND func7_AO_OUT_read; \
	COMMAND func7_AO_OUT_write; \
	COLLECTION func7_AO_VIEW_1; \
	MENU func7_AO_VIEW_1_page; \
	MENU func7_AO_Simple_Dialog_Mandatory_B; \
	UNIT func7_AO_PV_SCALE_unit_2; \
	UNIT func7_AO_OUT_SCALE_unit_2

#define USE_FUNC7_AO_OPTIONAL_BOTH \
	COLLECTION func7_AO_RCAS_IN; \
	VARIABLE func7_AO_RCAS_IN_Value; \
	VARIABLE func7_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func7_AO_RCAS_IN_Status_Quality; \
	VARIABLE func7_AO_RCAS_IN_Status_Limit; \
	MENU func7_AO_RCAS_IN_page; \
	COMMAND func7_AO_RCAS_IN_read; \
	COMMAND func7_AO_RCAS_IN_write; \
	COLLECTION func7_AO_RCAS_OUT; \
	VARIABLE func7_AO_RCAS_OUT_Value; \
	VARIABLE func7_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func7_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func7_AO_RCAS_OUT_Status_Limit; \
	MENU func7_AO_RCAS_OUT_page; \
	COMMAND func7_AO_RCAS_OUT_read; \
	VARIABLE func7_AO_SETP_DEVIATION; \
	MENU func7_AO_SETP_DEVIATION_page; \
	COMMAND func7_AO_SETP_DEVIATION_read; \
	COLLECTION func7_AO_VIEW_2; \
	MENU func7_AO_VIEW_2_page; \
	COLLECTION func7_AO_VIEW_3; \
	MENU func7_AO_VIEW_3_page; \
	UNIT func7_AO_PV_SCALE_unit_3

#define USE_FUNC7_AO_OPTIONAL_A \
	USE_FUNC7_AO_OPTIONAL_BOTH; \
	COLLECTION func7_AO_READBACK; \
	VARIABLE func7_AO_READBACK_Value; \
	VARIABLE func7_AO_READBACK_Status_Condensed; \
	VARIABLE func7_AO_READBACK_Status_Quality; \
	VARIABLE func7_AO_READBACK_Status_Limit; \
	MENU func7_AO_READBACK_page; \
	COMMAND func7_AO_READBACK_read; \
	VARIABLE func7_AO_IN_CHANNEL; \
	MENU func7_AO_IN_CHANNEL_page; \
	COMMAND func7_AO_IN_CHANNEL_read; \
	COMMAND func7_AO_IN_CHANNEL_write; \
	VARIABLE func7_AO_OUT_CHANNEL; \
	MENU func7_AO_OUT_CHANNEL_page; \
	COMMAND func7_AO_OUT_CHANNEL_read; \
	COMMAND func7_AO_OUT_CHANNEL_write; \
	VARIABLE func7_AO_FSAFE_TIME; \
	MENU func7_AO_FSAFE_TIME_page; \
	COMMAND func7_AO_FSAFE_TIME_read; \
	COMMAND func7_AO_FSAFE_TIME_write; \
	VARIABLE func7_AO_FSAFE_TYPE; \
	MENU func7_AO_FSAFE_TYPE_page; \
	COMMAND func7_AO_FSAFE_TYPE_read; \
	COMMAND func7_AO_FSAFE_TYPE_write; \
	VARIABLE func7_AO_FSAFE_VALUE; \
	MENU func7_AO_FSAFE_VALUE_page; \
	COMMAND func7_AO_FSAFE_VALUE_read; \
	COMMAND func7_AO_FSAFE_VALUE_write; \
	VARIABLE func7_AO_CHECK_BACK; \
	MENU func7_AO_CHECK_BACK_page; \
	COMMAND func7_AO_CHECK_BACK_read; \
	VARIABLE func7_AO_CHECK_BACK_MASK; \
	MENU func7_AO_CHECK_BACK_MASK_page; \
	COMMAND func7_AO_CHECK_BACK_MASK_read; \
	COLLECTION func7_AO_SIMULATE; \
	VARIABLE func7_AO_SIMULATE_Status_Condensed; \
	VARIABLE func7_AO_SIMULATE_Value; \
	VARIABLE func7_AO_SIMULATE_Enabled; \
	VARIABLE func7_AO_SIMULATE_Status_Quality; \
	VARIABLE func7_AO_SIMULATE_Status_Limit; \
	MENU func7_AO_SIMULATE_page; \
	COMMAND func7_AO_SIMULATE_read; \
	COMMAND func7_AO_SIMULATE_write; \
	VARIABLE func7_AO_INCREASE_CLOSE; \
	MENU func7_AO_INCREASE_CLOSE_page; \
	COMMAND func7_AO_INCREASE_CLOSE_read; \
	COMMAND func7_AO_INCREASE_CLOSE_write; \
	COLLECTION func7_AO_OUT; \
	VARIABLE func7_AO_OUT_Value; \
	VARIABLE func7_AO_OUT_Status_Condensed; \
	VARIABLE func7_AO_OUT_Status_Quality; \
	VARIABLE func7_AO_OUT_Status_Limit; \
	MENU func7_AO_OUT_page; \
	COMMAND func7_AO_OUT_read; \
	COMMAND func7_AO_OUT_write; \
	COLLECTION func7_AO_VIEW_1; \
	MENU func7_AO_VIEW_1_page; \
	MENU func7_AO_Simple_Dialog_Optional_A; \
	UNIT func7_AO_PV_SCALE_unit_2; \
	UNIT func7_AO_OUT_SCALE_unit_2

#define USE_FUNC7_AO_OPTIONAL_B \
	USE_FUNC7_AO_OPTIONAL_BOTH; \
	MENU func7_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC7_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func7_AO_)
#define USE_FUNC7_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func7_AO_)
#define USE_FUNC7_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func7_AO_)
#define USE_FUNC7_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func7_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC8_AO_MANDATORY_BOTH \
	BLOCK func8_AO_block; \
	COLLECTION func8_AO_BLOCK_OBJECT; \
	VARIABLE func8_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func8_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func8_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func8_AO_BLOCK_OBJECT_Class; \
	VARIABLE func8_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func8_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func8_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func8_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func8_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func8_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func8_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func8_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func8_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func8_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func8_AO_BLOCK_OBJECT_page; \
	COMMAND func8_AO_BLOCK_OBJECT_read; \
	VARIABLE func8_AO_ST_REV; \
	MENU func8_AO_ST_REV_page; \
	COMMAND func8_AO_ST_REV_read; \
	VARIABLE func8_AO_TAG_DESC; \
	MENU func8_AO_TAG_DESC_page; \
	COMMAND func8_AO_TAG_DESC_read; \
	COMMAND func8_AO_TAG_DESC_write; \
	VARIABLE func8_AO_STRATEGY; \
	MENU func8_AO_STRATEGY_page; \
	COMMAND func8_AO_STRATEGY_read; \
	COMMAND func8_AO_STRATEGY_write; \
	VARIABLE func8_AO_ALERT_KEY; \
	MENU func8_AO_ALERT_KEY_page; \
	COMMAND func8_AO_ALERT_KEY_read; \
	COMMAND func8_AO_ALERT_KEY_write; \
	VARIABLE func8_AO_TARGET_MODE; \
	MENU func8_AO_TARGET_MODE_page; \
	COMMAND func8_AO_TARGET_MODE_read; \
	COMMAND func8_AO_TARGET_MODE_write; \
	COLLECTION func8_AO_MODE_BLK; \
	VARIABLE func8_AO_MODE_BLK_Actual; \
	VARIABLE func8_AO_MODE_BLK_Permitted; \
	VARIABLE func8_AO_MODE_BLK_Normal; \
	MENU func8_AO_MODE_BLK_page; \
	COMMAND func8_AO_MODE_BLK_read; \
	COLLECTION func8_AO_ALARM_SUM; \
	VARIABLE func8_AO_ALARM_SUM_Current; \
	VARIABLE func8_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func8_AO_ALARM_SUM_Unreported; \
	VARIABLE func8_AO_ALARM_SUM_Disabled; \
	MENU func8_AO_ALARM_SUM_page; \
	COMMAND func8_AO_ALARM_SUM_read; \
	COLLECTION func8_AO_BATCH; \
	VARIABLE func8_AO_BATCH_Batch_ID; \
	VARIABLE func8_AO_BATCH_Rup; \
	VARIABLE func8_AO_BATCH_Operation; \
	VARIABLE func8_AO_BATCH_Phase; \
	MENU func8_AO_BATCH_page; \
	COMMAND func8_AO_BATCH_read; \
	COMMAND func8_AO_BATCH_write; \
	COLLECTION func8_AO_SP; \
	VARIABLE func8_AO_SP_Value; \
	VARIABLE func8_AO_SP_Status_Condensed; \
	VARIABLE func8_AO_SP_Status_Quality; \
	VARIABLE func8_AO_SP_Status_Limit; \
	MENU func8_AO_SP_page; \
	COMMAND func8_AO_SP_read; \
	COMMAND func8_AO_SP_write; \
	COLLECTION func8_AO_PV_SCALE; \
	VARIABLE func8_AO_PV_SCALE_Upper_Value; \
	VARIABLE func8_AO_PV_SCALE_Lower_Value; \
	VARIABLE func8_AO_PV_SCALE_Units_Index; \
	VARIABLE func8_AO_PV_SCALE_Decimal_Point; \
	MENU func8_AO_PV_SCALE_page; \
	COMMAND func8_AO_PV_SCALE_read; \
	COMMAND func8_AO_PV_SCALE_write; \
	COLLECTION func8_AO_POS_D; \
	VARIABLE func8_AO_POS_D_Value; \
	VARIABLE func8_AO_POS_D_Status_Condensed; \
	VARIABLE func8_AO_POS_D_Status_Quality; \
	VARIABLE func8_AO_POS_D_Status_Limit; \
	MENU func8_AO_POS_D_page; \
	COMMAND func8_AO_POS_D_read; \
	COLLECTION func8_AO_OUT_SCALE; \
	VARIABLE func8_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func8_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func8_AO_OUT_SCALE_Units_Index; \
	VARIABLE func8_AO_OUT_SCALE_Decimal_Point; \
	MENU func8_AO_OUT_SCALE_page; \
	COMMAND func8_AO_OUT_SCALE_read; \
	COMMAND func8_AO_OUT_SCALE_write; \
	UNIT func8_AO_PV_SCALE_unit_1; \
	UNIT func8_AO_OUT_SCALE_unit_1

#define USE_FUNC8_AO_MANDATORY_A \
	USE_FUNC8_AO_MANDATORY_BOTH; \
	MENU func8_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC8_AO_MANDATORY_B \
	USE_FUNC8_AO_MANDATORY_BOTH; \
	COLLECTION func8_AO_READBACK; \
	VARIABLE func8_AO_READBACK_Value; \
	VARIABLE func8_AO_READBACK_Status_Condensed; \
	VARIABLE func8_AO_READBACK_Status_Quality; \
	VARIABLE func8_AO_READBACK_Status_Limit; \
	MENU func8_AO_READBACK_page; \
	COMMAND func8_AO_READBACK_read; \
	VARIABLE func8_AO_IN_CHANNEL; \
	MENU func8_AO_IN_CHANNEL_page; \
	COMMAND func8_AO_IN_CHANNEL_read; \
	COMMAND func8_AO_IN_CHANNEL_write; \
	VARIABLE func8_AO_OUT_CHANNEL; \
	MENU func8_AO_OUT_CHANNEL_page; \
	COMMAND func8_AO_OUT_CHANNEL_read; \
	COMMAND func8_AO_OUT_CHANNEL_write; \
	VARIABLE func8_AO_FSAFE_TIME; \
	MENU func8_AO_FSAFE_TIME_page; \
	COMMAND func8_AO_FSAFE_TIME_read; \
	COMMAND func8_AO_FSAFE_TIME_write; \
	VARIABLE func8_AO_FSAFE_TYPE; \
	MENU func8_AO_FSAFE_TYPE_page; \
	COMMAND func8_AO_FSAFE_TYPE_read; \
	COMMAND func8_AO_FSAFE_TYPE_write; \
	VARIABLE func8_AO_FSAFE_VALUE; \
	MENU func8_AO_FSAFE_VALUE_page; \
	COMMAND func8_AO_FSAFE_VALUE_read; \
	COMMAND func8_AO_FSAFE_VALUE_write; \
	VARIABLE func8_AO_CHECK_BACK; \
	MENU func8_AO_CHECK_BACK_page; \
	COMMAND func8_AO_CHECK_BACK_read; \
	VARIABLE func8_AO_CHECK_BACK_MASK; \
	MENU func8_AO_CHECK_BACK_MASK_page; \
	COMMAND func8_AO_CHECK_BACK_MASK_read; \
	COLLECTION func8_AO_SIMULATE; \
	VARIABLE func8_AO_SIMULATE_Status_Condensed; \
	VARIABLE func8_AO_SIMULATE_Value; \
	VARIABLE func8_AO_SIMULATE_Enabled; \
	VARIABLE func8_AO_SIMULATE_Status_Quality; \
	VARIABLE func8_AO_SIMULATE_Status_Limit; \
	MENU func8_AO_SIMULATE_page; \
	COMMAND func8_AO_SIMULATE_read; \
	COMMAND func8_AO_SIMULATE_write; \
	VARIABLE func8_AO_INCREASE_CLOSE; \
	MENU func8_AO_INCREASE_CLOSE_page; \
	COMMAND func8_AO_INCREASE_CLOSE_read; \
	COMMAND func8_AO_INCREASE_CLOSE_write; \
	COLLECTION func8_AO_OUT; \
	VARIABLE func8_AO_OUT_Value; \
	VARIABLE func8_AO_OUT_Status_Condensed; \
	VARIABLE func8_AO_OUT_Status_Quality; \
	VARIABLE func8_AO_OUT_Status_Limit; \
	MENU func8_AO_OUT_page; \
	COMMAND func8_AO_OUT_read; \
	COMMAND func8_AO_OUT_write; \
	COLLECTION func8_AO_VIEW_1; \
	MENU func8_AO_VIEW_1_page; \
	MENU func8_AO_Simple_Dialog_Mandatory_B; \
	UNIT func8_AO_PV_SCALE_unit_2; \
	UNIT func8_AO_OUT_SCALE_unit_2

#define USE_FUNC8_AO_OPTIONAL_BOTH \
	COLLECTION func8_AO_RCAS_IN; \
	VARIABLE func8_AO_RCAS_IN_Value; \
	VARIABLE func8_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func8_AO_RCAS_IN_Status_Quality; \
	VARIABLE func8_AO_RCAS_IN_Status_Limit; \
	MENU func8_AO_RCAS_IN_page; \
	COMMAND func8_AO_RCAS_IN_read; \
	COMMAND func8_AO_RCAS_IN_write; \
	COLLECTION func8_AO_RCAS_OUT; \
	VARIABLE func8_AO_RCAS_OUT_Value; \
	VARIABLE func8_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func8_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func8_AO_RCAS_OUT_Status_Limit; \
	MENU func8_AO_RCAS_OUT_page; \
	COMMAND func8_AO_RCAS_OUT_read; \
	VARIABLE func8_AO_SETP_DEVIATION; \
	MENU func8_AO_SETP_DEVIATION_page; \
	COMMAND func8_AO_SETP_DEVIATION_read; \
	COLLECTION func8_AO_VIEW_2; \
	MENU func8_AO_VIEW_2_page; \
	COLLECTION func8_AO_VIEW_3; \
	MENU func8_AO_VIEW_3_page; \
	UNIT func8_AO_PV_SCALE_unit_3

#define USE_FUNC8_AO_OPTIONAL_A \
	USE_FUNC8_AO_OPTIONAL_BOTH; \
	COLLECTION func8_AO_READBACK; \
	VARIABLE func8_AO_READBACK_Value; \
	VARIABLE func8_AO_READBACK_Status_Condensed; \
	VARIABLE func8_AO_READBACK_Status_Quality; \
	VARIABLE func8_AO_READBACK_Status_Limit; \
	MENU func8_AO_READBACK_page; \
	COMMAND func8_AO_READBACK_read; \
	VARIABLE func8_AO_IN_CHANNEL; \
	MENU func8_AO_IN_CHANNEL_page; \
	COMMAND func8_AO_IN_CHANNEL_read; \
	COMMAND func8_AO_IN_CHANNEL_write; \
	VARIABLE func8_AO_OUT_CHANNEL; \
	MENU func8_AO_OUT_CHANNEL_page; \
	COMMAND func8_AO_OUT_CHANNEL_read; \
	COMMAND func8_AO_OUT_CHANNEL_write; \
	VARIABLE func8_AO_FSAFE_TIME; \
	MENU func8_AO_FSAFE_TIME_page; \
	COMMAND func8_AO_FSAFE_TIME_read; \
	COMMAND func8_AO_FSAFE_TIME_write; \
	VARIABLE func8_AO_FSAFE_TYPE; \
	MENU func8_AO_FSAFE_TYPE_page; \
	COMMAND func8_AO_FSAFE_TYPE_read; \
	COMMAND func8_AO_FSAFE_TYPE_write; \
	VARIABLE func8_AO_FSAFE_VALUE; \
	MENU func8_AO_FSAFE_VALUE_page; \
	COMMAND func8_AO_FSAFE_VALUE_read; \
	COMMAND func8_AO_FSAFE_VALUE_write; \
	VARIABLE func8_AO_CHECK_BACK; \
	MENU func8_AO_CHECK_BACK_page; \
	COMMAND func8_AO_CHECK_BACK_read; \
	VARIABLE func8_AO_CHECK_BACK_MASK; \
	MENU func8_AO_CHECK_BACK_MASK_page; \
	COMMAND func8_AO_CHECK_BACK_MASK_read; \
	COLLECTION func8_AO_SIMULATE; \
	VARIABLE func8_AO_SIMULATE_Status_Condensed; \
	VARIABLE func8_AO_SIMULATE_Value; \
	VARIABLE func8_AO_SIMULATE_Enabled; \
	VARIABLE func8_AO_SIMULATE_Status_Quality; \
	VARIABLE func8_AO_SIMULATE_Status_Limit; \
	MENU func8_AO_SIMULATE_page; \
	COMMAND func8_AO_SIMULATE_read; \
	COMMAND func8_AO_SIMULATE_write; \
	VARIABLE func8_AO_INCREASE_CLOSE; \
	MENU func8_AO_INCREASE_CLOSE_page; \
	COMMAND func8_AO_INCREASE_CLOSE_read; \
	COMMAND func8_AO_INCREASE_CLOSE_write; \
	COLLECTION func8_AO_OUT; \
	VARIABLE func8_AO_OUT_Value; \
	VARIABLE func8_AO_OUT_Status_Condensed; \
	VARIABLE func8_AO_OUT_Status_Quality; \
	VARIABLE func8_AO_OUT_Status_Limit; \
	MENU func8_AO_OUT_page; \
	COMMAND func8_AO_OUT_read; \
	COMMAND func8_AO_OUT_write; \
	COLLECTION func8_AO_VIEW_1; \
	MENU func8_AO_VIEW_1_page; \
	MENU func8_AO_Simple_Dialog_Optional_A; \
	UNIT func8_AO_PV_SCALE_unit_2; \
	UNIT func8_AO_OUT_SCALE_unit_2

#define USE_FUNC8_AO_OPTIONAL_B \
	USE_FUNC8_AO_OPTIONAL_BOTH; \
	MENU func8_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC8_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func8_AO_)
#define USE_FUNC8_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func8_AO_)
#define USE_FUNC8_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func8_AO_)
#define USE_FUNC8_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func8_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC9_AO_MANDATORY_BOTH \
	BLOCK func9_AO_block; \
	COLLECTION func9_AO_BLOCK_OBJECT; \
	VARIABLE func9_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func9_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func9_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func9_AO_BLOCK_OBJECT_Class; \
	VARIABLE func9_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func9_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func9_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func9_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func9_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func9_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func9_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func9_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func9_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func9_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func9_AO_BLOCK_OBJECT_page; \
	COMMAND func9_AO_BLOCK_OBJECT_read; \
	VARIABLE func9_AO_ST_REV; \
	MENU func9_AO_ST_REV_page; \
	COMMAND func9_AO_ST_REV_read; \
	VARIABLE func9_AO_TAG_DESC; \
	MENU func9_AO_TAG_DESC_page; \
	COMMAND func9_AO_TAG_DESC_read; \
	COMMAND func9_AO_TAG_DESC_write; \
	VARIABLE func9_AO_STRATEGY; \
	MENU func9_AO_STRATEGY_page; \
	COMMAND func9_AO_STRATEGY_read; \
	COMMAND func9_AO_STRATEGY_write; \
	VARIABLE func9_AO_ALERT_KEY; \
	MENU func9_AO_ALERT_KEY_page; \
	COMMAND func9_AO_ALERT_KEY_read; \
	COMMAND func9_AO_ALERT_KEY_write; \
	VARIABLE func9_AO_TARGET_MODE; \
	MENU func9_AO_TARGET_MODE_page; \
	COMMAND func9_AO_TARGET_MODE_read; \
	COMMAND func9_AO_TARGET_MODE_write; \
	COLLECTION func9_AO_MODE_BLK; \
	VARIABLE func9_AO_MODE_BLK_Actual; \
	VARIABLE func9_AO_MODE_BLK_Permitted; \
	VARIABLE func9_AO_MODE_BLK_Normal; \
	MENU func9_AO_MODE_BLK_page; \
	COMMAND func9_AO_MODE_BLK_read; \
	COLLECTION func9_AO_ALARM_SUM; \
	VARIABLE func9_AO_ALARM_SUM_Current; \
	VARIABLE func9_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func9_AO_ALARM_SUM_Unreported; \
	VARIABLE func9_AO_ALARM_SUM_Disabled; \
	MENU func9_AO_ALARM_SUM_page; \
	COMMAND func9_AO_ALARM_SUM_read; \
	COLLECTION func9_AO_BATCH; \
	VARIABLE func9_AO_BATCH_Batch_ID; \
	VARIABLE func9_AO_BATCH_Rup; \
	VARIABLE func9_AO_BATCH_Operation; \
	VARIABLE func9_AO_BATCH_Phase; \
	MENU func9_AO_BATCH_page; \
	COMMAND func9_AO_BATCH_read; \
	COMMAND func9_AO_BATCH_write; \
	COLLECTION func9_AO_SP; \
	VARIABLE func9_AO_SP_Value; \
	VARIABLE func9_AO_SP_Status_Condensed; \
	VARIABLE func9_AO_SP_Status_Quality; \
	VARIABLE func9_AO_SP_Status_Limit; \
	MENU func9_AO_SP_page; \
	COMMAND func9_AO_SP_read; \
	COMMAND func9_AO_SP_write; \
	COLLECTION func9_AO_PV_SCALE; \
	VARIABLE func9_AO_PV_SCALE_Upper_Value; \
	VARIABLE func9_AO_PV_SCALE_Lower_Value; \
	VARIABLE func9_AO_PV_SCALE_Units_Index; \
	VARIABLE func9_AO_PV_SCALE_Decimal_Point; \
	MENU func9_AO_PV_SCALE_page; \
	COMMAND func9_AO_PV_SCALE_read; \
	COMMAND func9_AO_PV_SCALE_write; \
	COLLECTION func9_AO_POS_D; \
	VARIABLE func9_AO_POS_D_Value; \
	VARIABLE func9_AO_POS_D_Status_Condensed; \
	VARIABLE func9_AO_POS_D_Status_Quality; \
	VARIABLE func9_AO_POS_D_Status_Limit; \
	MENU func9_AO_POS_D_page; \
	COMMAND func9_AO_POS_D_read; \
	COLLECTION func9_AO_OUT_SCALE; \
	VARIABLE func9_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func9_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func9_AO_OUT_SCALE_Units_Index; \
	VARIABLE func9_AO_OUT_SCALE_Decimal_Point; \
	MENU func9_AO_OUT_SCALE_page; \
	COMMAND func9_AO_OUT_SCALE_read; \
	COMMAND func9_AO_OUT_SCALE_write; \
	UNIT func9_AO_PV_SCALE_unit_1; \
	UNIT func9_AO_OUT_SCALE_unit_1

#define USE_FUNC9_AO_MANDATORY_A \
	USE_FUNC9_AO_MANDATORY_BOTH; \
	MENU func9_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC9_AO_MANDATORY_B \
	USE_FUNC9_AO_MANDATORY_BOTH; \
	COLLECTION func9_AO_READBACK; \
	VARIABLE func9_AO_READBACK_Value; \
	VARIABLE func9_AO_READBACK_Status_Condensed; \
	VARIABLE func9_AO_READBACK_Status_Quality; \
	VARIABLE func9_AO_READBACK_Status_Limit; \
	MENU func9_AO_READBACK_page; \
	COMMAND func9_AO_READBACK_read; \
	VARIABLE func9_AO_IN_CHANNEL; \
	MENU func9_AO_IN_CHANNEL_page; \
	COMMAND func9_AO_IN_CHANNEL_read; \
	COMMAND func9_AO_IN_CHANNEL_write; \
	VARIABLE func9_AO_OUT_CHANNEL; \
	MENU func9_AO_OUT_CHANNEL_page; \
	COMMAND func9_AO_OUT_CHANNEL_read; \
	COMMAND func9_AO_OUT_CHANNEL_write; \
	VARIABLE func9_AO_FSAFE_TIME; \
	MENU func9_AO_FSAFE_TIME_page; \
	COMMAND func9_AO_FSAFE_TIME_read; \
	COMMAND func9_AO_FSAFE_TIME_write; \
	VARIABLE func9_AO_FSAFE_TYPE; \
	MENU func9_AO_FSAFE_TYPE_page; \
	COMMAND func9_AO_FSAFE_TYPE_read; \
	COMMAND func9_AO_FSAFE_TYPE_write; \
	VARIABLE func9_AO_FSAFE_VALUE; \
	MENU func9_AO_FSAFE_VALUE_page; \
	COMMAND func9_AO_FSAFE_VALUE_read; \
	COMMAND func9_AO_FSAFE_VALUE_write; \
	VARIABLE func9_AO_CHECK_BACK; \
	MENU func9_AO_CHECK_BACK_page; \
	COMMAND func9_AO_CHECK_BACK_read; \
	VARIABLE func9_AO_CHECK_BACK_MASK; \
	MENU func9_AO_CHECK_BACK_MASK_page; \
	COMMAND func9_AO_CHECK_BACK_MASK_read; \
	COLLECTION func9_AO_SIMULATE; \
	VARIABLE func9_AO_SIMULATE_Status_Condensed; \
	VARIABLE func9_AO_SIMULATE_Value; \
	VARIABLE func9_AO_SIMULATE_Enabled; \
	VARIABLE func9_AO_SIMULATE_Status_Quality; \
	VARIABLE func9_AO_SIMULATE_Status_Limit; \
	MENU func9_AO_SIMULATE_page; \
	COMMAND func9_AO_SIMULATE_read; \
	COMMAND func9_AO_SIMULATE_write; \
	VARIABLE func9_AO_INCREASE_CLOSE; \
	MENU func9_AO_INCREASE_CLOSE_page; \
	COMMAND func9_AO_INCREASE_CLOSE_read; \
	COMMAND func9_AO_INCREASE_CLOSE_write; \
	COLLECTION func9_AO_OUT; \
	VARIABLE func9_AO_OUT_Value; \
	VARIABLE func9_AO_OUT_Status_Condensed; \
	VARIABLE func9_AO_OUT_Status_Quality; \
	VARIABLE func9_AO_OUT_Status_Limit; \
	MENU func9_AO_OUT_page; \
	COMMAND func9_AO_OUT_read; \
	COMMAND func9_AO_OUT_write; \
	COLLECTION func9_AO_VIEW_1; \
	MENU func9_AO_VIEW_1_page; \
	MENU func9_AO_Simple_Dialog_Mandatory_B; \
	UNIT func9_AO_PV_SCALE_unit_2; \
	UNIT func9_AO_OUT_SCALE_unit_2

#define USE_FUNC9_AO_OPTIONAL_BOTH \
	COLLECTION func9_AO_RCAS_IN; \
	VARIABLE func9_AO_RCAS_IN_Value; \
	VARIABLE func9_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func9_AO_RCAS_IN_Status_Quality; \
	VARIABLE func9_AO_RCAS_IN_Status_Limit; \
	MENU func9_AO_RCAS_IN_page; \
	COMMAND func9_AO_RCAS_IN_read; \
	COMMAND func9_AO_RCAS_IN_write; \
	COLLECTION func9_AO_RCAS_OUT; \
	VARIABLE func9_AO_RCAS_OUT_Value; \
	VARIABLE func9_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func9_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func9_AO_RCAS_OUT_Status_Limit; \
	MENU func9_AO_RCAS_OUT_page; \
	COMMAND func9_AO_RCAS_OUT_read; \
	VARIABLE func9_AO_SETP_DEVIATION; \
	MENU func9_AO_SETP_DEVIATION_page; \
	COMMAND func9_AO_SETP_DEVIATION_read; \
	COLLECTION func9_AO_VIEW_2; \
	MENU func9_AO_VIEW_2_page; \
	COLLECTION func9_AO_VIEW_3; \
	MENU func9_AO_VIEW_3_page; \
	UNIT func9_AO_PV_SCALE_unit_3

#define USE_FUNC9_AO_OPTIONAL_A \
	USE_FUNC9_AO_OPTIONAL_BOTH; \
	COLLECTION func9_AO_READBACK; \
	VARIABLE func9_AO_READBACK_Value; \
	VARIABLE func9_AO_READBACK_Status_Condensed; \
	VARIABLE func9_AO_READBACK_Status_Quality; \
	VARIABLE func9_AO_READBACK_Status_Limit; \
	MENU func9_AO_READBACK_page; \
	COMMAND func9_AO_READBACK_read; \
	VARIABLE func9_AO_IN_CHANNEL; \
	MENU func9_AO_IN_CHANNEL_page; \
	COMMAND func9_AO_IN_CHANNEL_read; \
	COMMAND func9_AO_IN_CHANNEL_write; \
	VARIABLE func9_AO_OUT_CHANNEL; \
	MENU func9_AO_OUT_CHANNEL_page; \
	COMMAND func9_AO_OUT_CHANNEL_read; \
	COMMAND func9_AO_OUT_CHANNEL_write; \
	VARIABLE func9_AO_FSAFE_TIME; \
	MENU func9_AO_FSAFE_TIME_page; \
	COMMAND func9_AO_FSAFE_TIME_read; \
	COMMAND func9_AO_FSAFE_TIME_write; \
	VARIABLE func9_AO_FSAFE_TYPE; \
	MENU func9_AO_FSAFE_TYPE_page; \
	COMMAND func9_AO_FSAFE_TYPE_read; \
	COMMAND func9_AO_FSAFE_TYPE_write; \
	VARIABLE func9_AO_FSAFE_VALUE; \
	MENU func9_AO_FSAFE_VALUE_page; \
	COMMAND func9_AO_FSAFE_VALUE_read; \
	COMMAND func9_AO_FSAFE_VALUE_write; \
	VARIABLE func9_AO_CHECK_BACK; \
	MENU func9_AO_CHECK_BACK_page; \
	COMMAND func9_AO_CHECK_BACK_read; \
	VARIABLE func9_AO_CHECK_BACK_MASK; \
	MENU func9_AO_CHECK_BACK_MASK_page; \
	COMMAND func9_AO_CHECK_BACK_MASK_read; \
	COLLECTION func9_AO_SIMULATE; \
	VARIABLE func9_AO_SIMULATE_Status_Condensed; \
	VARIABLE func9_AO_SIMULATE_Value; \
	VARIABLE func9_AO_SIMULATE_Enabled; \
	VARIABLE func9_AO_SIMULATE_Status_Quality; \
	VARIABLE func9_AO_SIMULATE_Status_Limit; \
	MENU func9_AO_SIMULATE_page; \
	COMMAND func9_AO_SIMULATE_read; \
	COMMAND func9_AO_SIMULATE_write; \
	VARIABLE func9_AO_INCREASE_CLOSE; \
	MENU func9_AO_INCREASE_CLOSE_page; \
	COMMAND func9_AO_INCREASE_CLOSE_read; \
	COMMAND func9_AO_INCREASE_CLOSE_write; \
	COLLECTION func9_AO_OUT; \
	VARIABLE func9_AO_OUT_Value; \
	VARIABLE func9_AO_OUT_Status_Condensed; \
	VARIABLE func9_AO_OUT_Status_Quality; \
	VARIABLE func9_AO_OUT_Status_Limit; \
	MENU func9_AO_OUT_page; \
	COMMAND func9_AO_OUT_read; \
	COMMAND func9_AO_OUT_write; \
	COLLECTION func9_AO_VIEW_1; \
	MENU func9_AO_VIEW_1_page; \
	MENU func9_AO_Simple_Dialog_Optional_A; \
	UNIT func9_AO_PV_SCALE_unit_2; \
	UNIT func9_AO_OUT_SCALE_unit_2

#define USE_FUNC9_AO_OPTIONAL_B \
	USE_FUNC9_AO_OPTIONAL_BOTH; \
	MENU func9_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC9_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func9_AO_)
#define USE_FUNC9_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func9_AO_)
#define USE_FUNC9_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func9_AO_)
#define USE_FUNC9_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func9_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC10_AO_MANDATORY_BOTH \
	BLOCK func10_AO_block; \
	COLLECTION func10_AO_BLOCK_OBJECT; \
	VARIABLE func10_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func10_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func10_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func10_AO_BLOCK_OBJECT_Class; \
	VARIABLE func10_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func10_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func10_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func10_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func10_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func10_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func10_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func10_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func10_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func10_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func10_AO_BLOCK_OBJECT_page; \
	COMMAND func10_AO_BLOCK_OBJECT_read; \
	VARIABLE func10_AO_ST_REV; \
	MENU func10_AO_ST_REV_page; \
	COMMAND func10_AO_ST_REV_read; \
	VARIABLE func10_AO_TAG_DESC; \
	MENU func10_AO_TAG_DESC_page; \
	COMMAND func10_AO_TAG_DESC_read; \
	COMMAND func10_AO_TAG_DESC_write; \
	VARIABLE func10_AO_STRATEGY; \
	MENU func10_AO_STRATEGY_page; \
	COMMAND func10_AO_STRATEGY_read; \
	COMMAND func10_AO_STRATEGY_write; \
	VARIABLE func10_AO_ALERT_KEY; \
	MENU func10_AO_ALERT_KEY_page; \
	COMMAND func10_AO_ALERT_KEY_read; \
	COMMAND func10_AO_ALERT_KEY_write; \
	VARIABLE func10_AO_TARGET_MODE; \
	MENU func10_AO_TARGET_MODE_page; \
	COMMAND func10_AO_TARGET_MODE_read; \
	COMMAND func10_AO_TARGET_MODE_write; \
	COLLECTION func10_AO_MODE_BLK; \
	VARIABLE func10_AO_MODE_BLK_Actual; \
	VARIABLE func10_AO_MODE_BLK_Permitted; \
	VARIABLE func10_AO_MODE_BLK_Normal; \
	MENU func10_AO_MODE_BLK_page; \
	COMMAND func10_AO_MODE_BLK_read; \
	COLLECTION func10_AO_ALARM_SUM; \
	VARIABLE func10_AO_ALARM_SUM_Current; \
	VARIABLE func10_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func10_AO_ALARM_SUM_Unreported; \
	VARIABLE func10_AO_ALARM_SUM_Disabled; \
	MENU func10_AO_ALARM_SUM_page; \
	COMMAND func10_AO_ALARM_SUM_read; \
	COLLECTION func10_AO_BATCH; \
	VARIABLE func10_AO_BATCH_Batch_ID; \
	VARIABLE func10_AO_BATCH_Rup; \
	VARIABLE func10_AO_BATCH_Operation; \
	VARIABLE func10_AO_BATCH_Phase; \
	MENU func10_AO_BATCH_page; \
	COMMAND func10_AO_BATCH_read; \
	COMMAND func10_AO_BATCH_write; \
	COLLECTION func10_AO_SP; \
	VARIABLE func10_AO_SP_Value; \
	VARIABLE func10_AO_SP_Status_Condensed; \
	VARIABLE func10_AO_SP_Status_Quality; \
	VARIABLE func10_AO_SP_Status_Limit; \
	MENU func10_AO_SP_page; \
	COMMAND func10_AO_SP_read; \
	COMMAND func10_AO_SP_write; \
	COLLECTION func10_AO_PV_SCALE; \
	VARIABLE func10_AO_PV_SCALE_Upper_Value; \
	VARIABLE func10_AO_PV_SCALE_Lower_Value; \
	VARIABLE func10_AO_PV_SCALE_Units_Index; \
	VARIABLE func10_AO_PV_SCALE_Decimal_Point; \
	MENU func10_AO_PV_SCALE_page; \
	COMMAND func10_AO_PV_SCALE_read; \
	COMMAND func10_AO_PV_SCALE_write; \
	COLLECTION func10_AO_POS_D; \
	VARIABLE func10_AO_POS_D_Value; \
	VARIABLE func10_AO_POS_D_Status_Condensed; \
	VARIABLE func10_AO_POS_D_Status_Quality; \
	VARIABLE func10_AO_POS_D_Status_Limit; \
	MENU func10_AO_POS_D_page; \
	COMMAND func10_AO_POS_D_read; \
	COLLECTION func10_AO_OUT_SCALE; \
	VARIABLE func10_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func10_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func10_AO_OUT_SCALE_Units_Index; \
	VARIABLE func10_AO_OUT_SCALE_Decimal_Point; \
	MENU func10_AO_OUT_SCALE_page; \
	COMMAND func10_AO_OUT_SCALE_read; \
	COMMAND func10_AO_OUT_SCALE_write; \
	UNIT func10_AO_PV_SCALE_unit_1; \
	UNIT func10_AO_OUT_SCALE_unit_1

#define USE_FUNC10_AO_MANDATORY_A \
	USE_FUNC10_AO_MANDATORY_BOTH; \
	MENU func10_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC10_AO_MANDATORY_B \
	USE_FUNC10_AO_MANDATORY_BOTH; \
	COLLECTION func10_AO_READBACK; \
	VARIABLE func10_AO_READBACK_Value; \
	VARIABLE func10_AO_READBACK_Status_Condensed; \
	VARIABLE func10_AO_READBACK_Status_Quality; \
	VARIABLE func10_AO_READBACK_Status_Limit; \
	MENU func10_AO_READBACK_page; \
	COMMAND func10_AO_READBACK_read; \
	VARIABLE func10_AO_IN_CHANNEL; \
	MENU func10_AO_IN_CHANNEL_page; \
	COMMAND func10_AO_IN_CHANNEL_read; \
	COMMAND func10_AO_IN_CHANNEL_write; \
	VARIABLE func10_AO_OUT_CHANNEL; \
	MENU func10_AO_OUT_CHANNEL_page; \
	COMMAND func10_AO_OUT_CHANNEL_read; \
	COMMAND func10_AO_OUT_CHANNEL_write; \
	VARIABLE func10_AO_FSAFE_TIME; \
	MENU func10_AO_FSAFE_TIME_page; \
	COMMAND func10_AO_FSAFE_TIME_read; \
	COMMAND func10_AO_FSAFE_TIME_write; \
	VARIABLE func10_AO_FSAFE_TYPE; \
	MENU func10_AO_FSAFE_TYPE_page; \
	COMMAND func10_AO_FSAFE_TYPE_read; \
	COMMAND func10_AO_FSAFE_TYPE_write; \
	VARIABLE func10_AO_FSAFE_VALUE; \
	MENU func10_AO_FSAFE_VALUE_page; \
	COMMAND func10_AO_FSAFE_VALUE_read; \
	COMMAND func10_AO_FSAFE_VALUE_write; \
	VARIABLE func10_AO_CHECK_BACK; \
	MENU func10_AO_CHECK_BACK_page; \
	COMMAND func10_AO_CHECK_BACK_read; \
	VARIABLE func10_AO_CHECK_BACK_MASK; \
	MENU func10_AO_CHECK_BACK_MASK_page; \
	COMMAND func10_AO_CHECK_BACK_MASK_read; \
	COLLECTION func10_AO_SIMULATE; \
	VARIABLE func10_AO_SIMULATE_Status_Condensed; \
	VARIABLE func10_AO_SIMULATE_Value; \
	VARIABLE func10_AO_SIMULATE_Enabled; \
	VARIABLE func10_AO_SIMULATE_Status_Quality; \
	VARIABLE func10_AO_SIMULATE_Status_Limit; \
	MENU func10_AO_SIMULATE_page; \
	COMMAND func10_AO_SIMULATE_read; \
	COMMAND func10_AO_SIMULATE_write; \
	VARIABLE func10_AO_INCREASE_CLOSE; \
	MENU func10_AO_INCREASE_CLOSE_page; \
	COMMAND func10_AO_INCREASE_CLOSE_read; \
	COMMAND func10_AO_INCREASE_CLOSE_write; \
	COLLECTION func10_AO_OUT; \
	VARIABLE func10_AO_OUT_Value; \
	VARIABLE func10_AO_OUT_Status_Condensed; \
	VARIABLE func10_AO_OUT_Status_Quality; \
	VARIABLE func10_AO_OUT_Status_Limit; \
	MENU func10_AO_OUT_page; \
	COMMAND func10_AO_OUT_read; \
	COMMAND func10_AO_OUT_write; \
	COLLECTION func10_AO_VIEW_1; \
	MENU func10_AO_VIEW_1_page; \
	MENU func10_AO_Simple_Dialog_Mandatory_B; \
	UNIT func10_AO_PV_SCALE_unit_2; \
	UNIT func10_AO_OUT_SCALE_unit_2

#define USE_FUNC10_AO_OPTIONAL_BOTH \
	COLLECTION func10_AO_RCAS_IN; \
	VARIABLE func10_AO_RCAS_IN_Value; \
	VARIABLE func10_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func10_AO_RCAS_IN_Status_Quality; \
	VARIABLE func10_AO_RCAS_IN_Status_Limit; \
	MENU func10_AO_RCAS_IN_page; \
	COMMAND func10_AO_RCAS_IN_read; \
	COMMAND func10_AO_RCAS_IN_write; \
	COLLECTION func10_AO_RCAS_OUT; \
	VARIABLE func10_AO_RCAS_OUT_Value; \
	VARIABLE func10_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func10_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func10_AO_RCAS_OUT_Status_Limit; \
	MENU func10_AO_RCAS_OUT_page; \
	COMMAND func10_AO_RCAS_OUT_read; \
	VARIABLE func10_AO_SETP_DEVIATION; \
	MENU func10_AO_SETP_DEVIATION_page; \
	COMMAND func10_AO_SETP_DEVIATION_read; \
	COLLECTION func10_AO_VIEW_2; \
	MENU func10_AO_VIEW_2_page; \
	COLLECTION func10_AO_VIEW_3; \
	MENU func10_AO_VIEW_3_page; \
	UNIT func10_AO_PV_SCALE_unit_3

#define USE_FUNC10_AO_OPTIONAL_A \
	USE_FUNC10_AO_OPTIONAL_BOTH; \
	COLLECTION func10_AO_READBACK; \
	VARIABLE func10_AO_READBACK_Value; \
	VARIABLE func10_AO_READBACK_Status_Condensed; \
	VARIABLE func10_AO_READBACK_Status_Quality; \
	VARIABLE func10_AO_READBACK_Status_Limit; \
	MENU func10_AO_READBACK_page; \
	COMMAND func10_AO_READBACK_read; \
	VARIABLE func10_AO_IN_CHANNEL; \
	MENU func10_AO_IN_CHANNEL_page; \
	COMMAND func10_AO_IN_CHANNEL_read; \
	COMMAND func10_AO_IN_CHANNEL_write; \
	VARIABLE func10_AO_OUT_CHANNEL; \
	MENU func10_AO_OUT_CHANNEL_page; \
	COMMAND func10_AO_OUT_CHANNEL_read; \
	COMMAND func10_AO_OUT_CHANNEL_write; \
	VARIABLE func10_AO_FSAFE_TIME; \
	MENU func10_AO_FSAFE_TIME_page; \
	COMMAND func10_AO_FSAFE_TIME_read; \
	COMMAND func10_AO_FSAFE_TIME_write; \
	VARIABLE func10_AO_FSAFE_TYPE; \
	MENU func10_AO_FSAFE_TYPE_page; \
	COMMAND func10_AO_FSAFE_TYPE_read; \
	COMMAND func10_AO_FSAFE_TYPE_write; \
	VARIABLE func10_AO_FSAFE_VALUE; \
	MENU func10_AO_FSAFE_VALUE_page; \
	COMMAND func10_AO_FSAFE_VALUE_read; \
	COMMAND func10_AO_FSAFE_VALUE_write; \
	VARIABLE func10_AO_CHECK_BACK; \
	MENU func10_AO_CHECK_BACK_page; \
	COMMAND func10_AO_CHECK_BACK_read; \
	VARIABLE func10_AO_CHECK_BACK_MASK; \
	MENU func10_AO_CHECK_BACK_MASK_page; \
	COMMAND func10_AO_CHECK_BACK_MASK_read; \
	COLLECTION func10_AO_SIMULATE; \
	VARIABLE func10_AO_SIMULATE_Status_Condensed; \
	VARIABLE func10_AO_SIMULATE_Value; \
	VARIABLE func10_AO_SIMULATE_Enabled; \
	VARIABLE func10_AO_SIMULATE_Status_Quality; \
	VARIABLE func10_AO_SIMULATE_Status_Limit; \
	MENU func10_AO_SIMULATE_page; \
	COMMAND func10_AO_SIMULATE_read; \
	COMMAND func10_AO_SIMULATE_write; \
	VARIABLE func10_AO_INCREASE_CLOSE; \
	MENU func10_AO_INCREASE_CLOSE_page; \
	COMMAND func10_AO_INCREASE_CLOSE_read; \
	COMMAND func10_AO_INCREASE_CLOSE_write; \
	COLLECTION func10_AO_OUT; \
	VARIABLE func10_AO_OUT_Value; \
	VARIABLE func10_AO_OUT_Status_Condensed; \
	VARIABLE func10_AO_OUT_Status_Quality; \
	VARIABLE func10_AO_OUT_Status_Limit; \
	MENU func10_AO_OUT_page; \
	COMMAND func10_AO_OUT_read; \
	COMMAND func10_AO_OUT_write; \
	COLLECTION func10_AO_VIEW_1; \
	MENU func10_AO_VIEW_1_page; \
	MENU func10_AO_Simple_Dialog_Optional_A; \
	UNIT func10_AO_PV_SCALE_unit_2; \
	UNIT func10_AO_OUT_SCALE_unit_2

#define USE_FUNC10_AO_OPTIONAL_B \
	USE_FUNC10_AO_OPTIONAL_BOTH; \
	MENU func10_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC10_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func10_AO_)
#define USE_FUNC10_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func10_AO_)
#define USE_FUNC10_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func10_AO_)
#define USE_FUNC10_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func10_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC11_AO_MANDATORY_BOTH \
	BLOCK func11_AO_block; \
	COLLECTION func11_AO_BLOCK_OBJECT; \
	VARIABLE func11_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func11_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func11_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func11_AO_BLOCK_OBJECT_Class; \
	VARIABLE func11_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func11_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func11_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func11_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func11_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func11_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func11_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func11_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func11_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func11_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func11_AO_BLOCK_OBJECT_page; \
	COMMAND func11_AO_BLOCK_OBJECT_read; \
	VARIABLE func11_AO_ST_REV; \
	MENU func11_AO_ST_REV_page; \
	COMMAND func11_AO_ST_REV_read; \
	VARIABLE func11_AO_TAG_DESC; \
	MENU func11_AO_TAG_DESC_page; \
	COMMAND func11_AO_TAG_DESC_read; \
	COMMAND func11_AO_TAG_DESC_write; \
	VARIABLE func11_AO_STRATEGY; \
	MENU func11_AO_STRATEGY_page; \
	COMMAND func11_AO_STRATEGY_read; \
	COMMAND func11_AO_STRATEGY_write; \
	VARIABLE func11_AO_ALERT_KEY; \
	MENU func11_AO_ALERT_KEY_page; \
	COMMAND func11_AO_ALERT_KEY_read; \
	COMMAND func11_AO_ALERT_KEY_write; \
	VARIABLE func11_AO_TARGET_MODE; \
	MENU func11_AO_TARGET_MODE_page; \
	COMMAND func11_AO_TARGET_MODE_read; \
	COMMAND func11_AO_TARGET_MODE_write; \
	COLLECTION func11_AO_MODE_BLK; \
	VARIABLE func11_AO_MODE_BLK_Actual; \
	VARIABLE func11_AO_MODE_BLK_Permitted; \
	VARIABLE func11_AO_MODE_BLK_Normal; \
	MENU func11_AO_MODE_BLK_page; \
	COMMAND func11_AO_MODE_BLK_read; \
	COLLECTION func11_AO_ALARM_SUM; \
	VARIABLE func11_AO_ALARM_SUM_Current; \
	VARIABLE func11_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func11_AO_ALARM_SUM_Unreported; \
	VARIABLE func11_AO_ALARM_SUM_Disabled; \
	MENU func11_AO_ALARM_SUM_page; \
	COMMAND func11_AO_ALARM_SUM_read; \
	COLLECTION func11_AO_BATCH; \
	VARIABLE func11_AO_BATCH_Batch_ID; \
	VARIABLE func11_AO_BATCH_Rup; \
	VARIABLE func11_AO_BATCH_Operation; \
	VARIABLE func11_AO_BATCH_Phase; \
	MENU func11_AO_BATCH_page; \
	COMMAND func11_AO_BATCH_read; \
	COMMAND func11_AO_BATCH_write; \
	COLLECTION func11_AO_SP; \
	VARIABLE func11_AO_SP_Value; \
	VARIABLE func11_AO_SP_Status_Condensed; \
	VARIABLE func11_AO_SP_Status_Quality; \
	VARIABLE func11_AO_SP_Status_Limit; \
	MENU func11_AO_SP_page; \
	COMMAND func11_AO_SP_read; \
	COMMAND func11_AO_SP_write; \
	COLLECTION func11_AO_PV_SCALE; \
	VARIABLE func11_AO_PV_SCALE_Upper_Value; \
	VARIABLE func11_AO_PV_SCALE_Lower_Value; \
	VARIABLE func11_AO_PV_SCALE_Units_Index; \
	VARIABLE func11_AO_PV_SCALE_Decimal_Point; \
	MENU func11_AO_PV_SCALE_page; \
	COMMAND func11_AO_PV_SCALE_read; \
	COMMAND func11_AO_PV_SCALE_write; \
	COLLECTION func11_AO_POS_D; \
	VARIABLE func11_AO_POS_D_Value; \
	VARIABLE func11_AO_POS_D_Status_Condensed; \
	VARIABLE func11_AO_POS_D_Status_Quality; \
	VARIABLE func11_AO_POS_D_Status_Limit; \
	MENU func11_AO_POS_D_page; \
	COMMAND func11_AO_POS_D_read; \
	COLLECTION func11_AO_OUT_SCALE; \
	VARIABLE func11_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func11_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func11_AO_OUT_SCALE_Units_Index; \
	VARIABLE func11_AO_OUT_SCALE_Decimal_Point; \
	MENU func11_AO_OUT_SCALE_page; \
	COMMAND func11_AO_OUT_SCALE_read; \
	COMMAND func11_AO_OUT_SCALE_write; \
	UNIT func11_AO_PV_SCALE_unit_1; \
	UNIT func11_AO_OUT_SCALE_unit_1

#define USE_FUNC11_AO_MANDATORY_A \
	USE_FUNC11_AO_MANDATORY_BOTH; \
	MENU func11_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC11_AO_MANDATORY_B \
	USE_FUNC11_AO_MANDATORY_BOTH; \
	COLLECTION func11_AO_READBACK; \
	VARIABLE func11_AO_READBACK_Value; \
	VARIABLE func11_AO_READBACK_Status_Condensed; \
	VARIABLE func11_AO_READBACK_Status_Quality; \
	VARIABLE func11_AO_READBACK_Status_Limit; \
	MENU func11_AO_READBACK_page; \
	COMMAND func11_AO_READBACK_read; \
	VARIABLE func11_AO_IN_CHANNEL; \
	MENU func11_AO_IN_CHANNEL_page; \
	COMMAND func11_AO_IN_CHANNEL_read; \
	COMMAND func11_AO_IN_CHANNEL_write; \
	VARIABLE func11_AO_OUT_CHANNEL; \
	MENU func11_AO_OUT_CHANNEL_page; \
	COMMAND func11_AO_OUT_CHANNEL_read; \
	COMMAND func11_AO_OUT_CHANNEL_write; \
	VARIABLE func11_AO_FSAFE_TIME; \
	MENU func11_AO_FSAFE_TIME_page; \
	COMMAND func11_AO_FSAFE_TIME_read; \
	COMMAND func11_AO_FSAFE_TIME_write; \
	VARIABLE func11_AO_FSAFE_TYPE; \
	MENU func11_AO_FSAFE_TYPE_page; \
	COMMAND func11_AO_FSAFE_TYPE_read; \
	COMMAND func11_AO_FSAFE_TYPE_write; \
	VARIABLE func11_AO_FSAFE_VALUE; \
	MENU func11_AO_FSAFE_VALUE_page; \
	COMMAND func11_AO_FSAFE_VALUE_read; \
	COMMAND func11_AO_FSAFE_VALUE_write; \
	VARIABLE func11_AO_CHECK_BACK; \
	MENU func11_AO_CHECK_BACK_page; \
	COMMAND func11_AO_CHECK_BACK_read; \
	VARIABLE func11_AO_CHECK_BACK_MASK; \
	MENU func11_AO_CHECK_BACK_MASK_page; \
	COMMAND func11_AO_CHECK_BACK_MASK_read; \
	COLLECTION func11_AO_SIMULATE; \
	VARIABLE func11_AO_SIMULATE_Status_Condensed; \
	VARIABLE func11_AO_SIMULATE_Value; \
	VARIABLE func11_AO_SIMULATE_Enabled; \
	VARIABLE func11_AO_SIMULATE_Status_Quality; \
	VARIABLE func11_AO_SIMULATE_Status_Limit; \
	MENU func11_AO_SIMULATE_page; \
	COMMAND func11_AO_SIMULATE_read; \
	COMMAND func11_AO_SIMULATE_write; \
	VARIABLE func11_AO_INCREASE_CLOSE; \
	MENU func11_AO_INCREASE_CLOSE_page; \
	COMMAND func11_AO_INCREASE_CLOSE_read; \
	COMMAND func11_AO_INCREASE_CLOSE_write; \
	COLLECTION func11_AO_OUT; \
	VARIABLE func11_AO_OUT_Value; \
	VARIABLE func11_AO_OUT_Status_Condensed; \
	VARIABLE func11_AO_OUT_Status_Quality; \
	VARIABLE func11_AO_OUT_Status_Limit; \
	MENU func11_AO_OUT_page; \
	COMMAND func11_AO_OUT_read; \
	COMMAND func11_AO_OUT_write; \
	COLLECTION func11_AO_VIEW_1; \
	MENU func11_AO_VIEW_1_page; \
	MENU func11_AO_Simple_Dialog_Mandatory_B; \
	UNIT func11_AO_PV_SCALE_unit_2; \
	UNIT func11_AO_OUT_SCALE_unit_2

#define USE_FUNC11_AO_OPTIONAL_BOTH \
	COLLECTION func11_AO_RCAS_IN; \
	VARIABLE func11_AO_RCAS_IN_Value; \
	VARIABLE func11_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func11_AO_RCAS_IN_Status_Quality; \
	VARIABLE func11_AO_RCAS_IN_Status_Limit; \
	MENU func11_AO_RCAS_IN_page; \
	COMMAND func11_AO_RCAS_IN_read; \
	COMMAND func11_AO_RCAS_IN_write; \
	COLLECTION func11_AO_RCAS_OUT; \
	VARIABLE func11_AO_RCAS_OUT_Value; \
	VARIABLE func11_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func11_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func11_AO_RCAS_OUT_Status_Limit; \
	MENU func11_AO_RCAS_OUT_page; \
	COMMAND func11_AO_RCAS_OUT_read; \
	VARIABLE func11_AO_SETP_DEVIATION; \
	MENU func11_AO_SETP_DEVIATION_page; \
	COMMAND func11_AO_SETP_DEVIATION_read; \
	COLLECTION func11_AO_VIEW_2; \
	MENU func11_AO_VIEW_2_page; \
	COLLECTION func11_AO_VIEW_3; \
	MENU func11_AO_VIEW_3_page; \
	UNIT func11_AO_PV_SCALE_unit_3

#define USE_FUNC11_AO_OPTIONAL_A \
	USE_FUNC11_AO_OPTIONAL_BOTH; \
	COLLECTION func11_AO_READBACK; \
	VARIABLE func11_AO_READBACK_Value; \
	VARIABLE func11_AO_READBACK_Status_Condensed; \
	VARIABLE func11_AO_READBACK_Status_Quality; \
	VARIABLE func11_AO_READBACK_Status_Limit; \
	MENU func11_AO_READBACK_page; \
	COMMAND func11_AO_READBACK_read; \
	VARIABLE func11_AO_IN_CHANNEL; \
	MENU func11_AO_IN_CHANNEL_page; \
	COMMAND func11_AO_IN_CHANNEL_read; \
	COMMAND func11_AO_IN_CHANNEL_write; \
	VARIABLE func11_AO_OUT_CHANNEL; \
	MENU func11_AO_OUT_CHANNEL_page; \
	COMMAND func11_AO_OUT_CHANNEL_read; \
	COMMAND func11_AO_OUT_CHANNEL_write; \
	VARIABLE func11_AO_FSAFE_TIME; \
	MENU func11_AO_FSAFE_TIME_page; \
	COMMAND func11_AO_FSAFE_TIME_read; \
	COMMAND func11_AO_FSAFE_TIME_write; \
	VARIABLE func11_AO_FSAFE_TYPE; \
	MENU func11_AO_FSAFE_TYPE_page; \
	COMMAND func11_AO_FSAFE_TYPE_read; \
	COMMAND func11_AO_FSAFE_TYPE_write; \
	VARIABLE func11_AO_FSAFE_VALUE; \
	MENU func11_AO_FSAFE_VALUE_page; \
	COMMAND func11_AO_FSAFE_VALUE_read; \
	COMMAND func11_AO_FSAFE_VALUE_write; \
	VARIABLE func11_AO_CHECK_BACK; \
	MENU func11_AO_CHECK_BACK_page; \
	COMMAND func11_AO_CHECK_BACK_read; \
	VARIABLE func11_AO_CHECK_BACK_MASK; \
	MENU func11_AO_CHECK_BACK_MASK_page; \
	COMMAND func11_AO_CHECK_BACK_MASK_read; \
	COLLECTION func11_AO_SIMULATE; \
	VARIABLE func11_AO_SIMULATE_Status_Condensed; \
	VARIABLE func11_AO_SIMULATE_Value; \
	VARIABLE func11_AO_SIMULATE_Enabled; \
	VARIABLE func11_AO_SIMULATE_Status_Quality; \
	VARIABLE func11_AO_SIMULATE_Status_Limit; \
	MENU func11_AO_SIMULATE_page; \
	COMMAND func11_AO_SIMULATE_read; \
	COMMAND func11_AO_SIMULATE_write; \
	VARIABLE func11_AO_INCREASE_CLOSE; \
	MENU func11_AO_INCREASE_CLOSE_page; \
	COMMAND func11_AO_INCREASE_CLOSE_read; \
	COMMAND func11_AO_INCREASE_CLOSE_write; \
	COLLECTION func11_AO_OUT; \
	VARIABLE func11_AO_OUT_Value; \
	VARIABLE func11_AO_OUT_Status_Condensed; \
	VARIABLE func11_AO_OUT_Status_Quality; \
	VARIABLE func11_AO_OUT_Status_Limit; \
	MENU func11_AO_OUT_page; \
	COMMAND func11_AO_OUT_read; \
	COMMAND func11_AO_OUT_write; \
	COLLECTION func11_AO_VIEW_1; \
	MENU func11_AO_VIEW_1_page; \
	MENU func11_AO_Simple_Dialog_Optional_A; \
	UNIT func11_AO_PV_SCALE_unit_2; \
	UNIT func11_AO_OUT_SCALE_unit_2

#define USE_FUNC11_AO_OPTIONAL_B \
	USE_FUNC11_AO_OPTIONAL_BOTH; \
	MENU func11_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC11_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func11_AO_)
#define USE_FUNC11_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func11_AO_)
#define USE_FUNC11_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func11_AO_)
#define USE_FUNC11_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func11_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC12_AO_MANDATORY_BOTH \
	BLOCK func12_AO_block; \
	COLLECTION func12_AO_BLOCK_OBJECT; \
	VARIABLE func12_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func12_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func12_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func12_AO_BLOCK_OBJECT_Class; \
	VARIABLE func12_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func12_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func12_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func12_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func12_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func12_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func12_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func12_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func12_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func12_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func12_AO_BLOCK_OBJECT_page; \
	COMMAND func12_AO_BLOCK_OBJECT_read; \
	VARIABLE func12_AO_ST_REV; \
	MENU func12_AO_ST_REV_page; \
	COMMAND func12_AO_ST_REV_read; \
	VARIABLE func12_AO_TAG_DESC; \
	MENU func12_AO_TAG_DESC_page; \
	COMMAND func12_AO_TAG_DESC_read; \
	COMMAND func12_AO_TAG_DESC_write; \
	VARIABLE func12_AO_STRATEGY; \
	MENU func12_AO_STRATEGY_page; \
	COMMAND func12_AO_STRATEGY_read; \
	COMMAND func12_AO_STRATEGY_write; \
	VARIABLE func12_AO_ALERT_KEY; \
	MENU func12_AO_ALERT_KEY_page; \
	COMMAND func12_AO_ALERT_KEY_read; \
	COMMAND func12_AO_ALERT_KEY_write; \
	VARIABLE func12_AO_TARGET_MODE; \
	MENU func12_AO_TARGET_MODE_page; \
	COMMAND func12_AO_TARGET_MODE_read; \
	COMMAND func12_AO_TARGET_MODE_write; \
	COLLECTION func12_AO_MODE_BLK; \
	VARIABLE func12_AO_MODE_BLK_Actual; \
	VARIABLE func12_AO_MODE_BLK_Permitted; \
	VARIABLE func12_AO_MODE_BLK_Normal; \
	MENU func12_AO_MODE_BLK_page; \
	COMMAND func12_AO_MODE_BLK_read; \
	COLLECTION func12_AO_ALARM_SUM; \
	VARIABLE func12_AO_ALARM_SUM_Current; \
	VARIABLE func12_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func12_AO_ALARM_SUM_Unreported; \
	VARIABLE func12_AO_ALARM_SUM_Disabled; \
	MENU func12_AO_ALARM_SUM_page; \
	COMMAND func12_AO_ALARM_SUM_read; \
	COLLECTION func12_AO_BATCH; \
	VARIABLE func12_AO_BATCH_Batch_ID; \
	VARIABLE func12_AO_BATCH_Rup; \
	VARIABLE func12_AO_BATCH_Operation; \
	VARIABLE func12_AO_BATCH_Phase; \
	MENU func12_AO_BATCH_page; \
	COMMAND func12_AO_BATCH_read; \
	COMMAND func12_AO_BATCH_write; \
	COLLECTION func12_AO_SP; \
	VARIABLE func12_AO_SP_Value; \
	VARIABLE func12_AO_SP_Status_Condensed; \
	VARIABLE func12_AO_SP_Status_Quality; \
	VARIABLE func12_AO_SP_Status_Limit; \
	MENU func12_AO_SP_page; \
	COMMAND func12_AO_SP_read; \
	COMMAND func12_AO_SP_write; \
	COLLECTION func12_AO_PV_SCALE; \
	VARIABLE func12_AO_PV_SCALE_Upper_Value; \
	VARIABLE func12_AO_PV_SCALE_Lower_Value; \
	VARIABLE func12_AO_PV_SCALE_Units_Index; \
	VARIABLE func12_AO_PV_SCALE_Decimal_Point; \
	MENU func12_AO_PV_SCALE_page; \
	COMMAND func12_AO_PV_SCALE_read; \
	COMMAND func12_AO_PV_SCALE_write; \
	COLLECTION func12_AO_POS_D; \
	VARIABLE func12_AO_POS_D_Value; \
	VARIABLE func12_AO_POS_D_Status_Condensed; \
	VARIABLE func12_AO_POS_D_Status_Quality; \
	VARIABLE func12_AO_POS_D_Status_Limit; \
	MENU func12_AO_POS_D_page; \
	COMMAND func12_AO_POS_D_read; \
	COLLECTION func12_AO_OUT_SCALE; \
	VARIABLE func12_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func12_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func12_AO_OUT_SCALE_Units_Index; \
	VARIABLE func12_AO_OUT_SCALE_Decimal_Point; \
	MENU func12_AO_OUT_SCALE_page; \
	COMMAND func12_AO_OUT_SCALE_read; \
	COMMAND func12_AO_OUT_SCALE_write; \
	UNIT func12_AO_PV_SCALE_unit_1; \
	UNIT func12_AO_OUT_SCALE_unit_1

#define USE_FUNC12_AO_MANDATORY_A \
	USE_FUNC12_AO_MANDATORY_BOTH; \
	MENU func12_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC12_AO_MANDATORY_B \
	USE_FUNC12_AO_MANDATORY_BOTH; \
	COLLECTION func12_AO_READBACK; \
	VARIABLE func12_AO_READBACK_Value; \
	VARIABLE func12_AO_READBACK_Status_Condensed; \
	VARIABLE func12_AO_READBACK_Status_Quality; \
	VARIABLE func12_AO_READBACK_Status_Limit; \
	MENU func12_AO_READBACK_page; \
	COMMAND func12_AO_READBACK_read; \
	VARIABLE func12_AO_IN_CHANNEL; \
	MENU func12_AO_IN_CHANNEL_page; \
	COMMAND func12_AO_IN_CHANNEL_read; \
	COMMAND func12_AO_IN_CHANNEL_write; \
	VARIABLE func12_AO_OUT_CHANNEL; \
	MENU func12_AO_OUT_CHANNEL_page; \
	COMMAND func12_AO_OUT_CHANNEL_read; \
	COMMAND func12_AO_OUT_CHANNEL_write; \
	VARIABLE func12_AO_FSAFE_TIME; \
	MENU func12_AO_FSAFE_TIME_page; \
	COMMAND func12_AO_FSAFE_TIME_read; \
	COMMAND func12_AO_FSAFE_TIME_write; \
	VARIABLE func12_AO_FSAFE_TYPE; \
	MENU func12_AO_FSAFE_TYPE_page; \
	COMMAND func12_AO_FSAFE_TYPE_read; \
	COMMAND func12_AO_FSAFE_TYPE_write; \
	VARIABLE func12_AO_FSAFE_VALUE; \
	MENU func12_AO_FSAFE_VALUE_page; \
	COMMAND func12_AO_FSAFE_VALUE_read; \
	COMMAND func12_AO_FSAFE_VALUE_write; \
	VARIABLE func12_AO_CHECK_BACK; \
	MENU func12_AO_CHECK_BACK_page; \
	COMMAND func12_AO_CHECK_BACK_read; \
	VARIABLE func12_AO_CHECK_BACK_MASK; \
	MENU func12_AO_CHECK_BACK_MASK_page; \
	COMMAND func12_AO_CHECK_BACK_MASK_read; \
	COLLECTION func12_AO_SIMULATE; \
	VARIABLE func12_AO_SIMULATE_Status_Condensed; \
	VARIABLE func12_AO_SIMULATE_Value; \
	VARIABLE func12_AO_SIMULATE_Enabled; \
	VARIABLE func12_AO_SIMULATE_Status_Quality; \
	VARIABLE func12_AO_SIMULATE_Status_Limit; \
	MENU func12_AO_SIMULATE_page; \
	COMMAND func12_AO_SIMULATE_read; \
	COMMAND func12_AO_SIMULATE_write; \
	VARIABLE func12_AO_INCREASE_CLOSE; \
	MENU func12_AO_INCREASE_CLOSE_page; \
	COMMAND func12_AO_INCREASE_CLOSE_read; \
	COMMAND func12_AO_INCREASE_CLOSE_write; \
	COLLECTION func12_AO_OUT; \
	VARIABLE func12_AO_OUT_Value; \
	VARIABLE func12_AO_OUT_Status_Condensed; \
	VARIABLE func12_AO_OUT_Status_Quality; \
	VARIABLE func12_AO_OUT_Status_Limit; \
	MENU func12_AO_OUT_page; \
	COMMAND func12_AO_OUT_read; \
	COMMAND func12_AO_OUT_write; \
	COLLECTION func12_AO_VIEW_1; \
	MENU func12_AO_VIEW_1_page; \
	MENU func12_AO_Simple_Dialog_Mandatory_B; \
	UNIT func12_AO_PV_SCALE_unit_2; \
	UNIT func12_AO_OUT_SCALE_unit_2

#define USE_FUNC12_AO_OPTIONAL_BOTH \
	COLLECTION func12_AO_RCAS_IN; \
	VARIABLE func12_AO_RCAS_IN_Value; \
	VARIABLE func12_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func12_AO_RCAS_IN_Status_Quality; \
	VARIABLE func12_AO_RCAS_IN_Status_Limit; \
	MENU func12_AO_RCAS_IN_page; \
	COMMAND func12_AO_RCAS_IN_read; \
	COMMAND func12_AO_RCAS_IN_write; \
	COLLECTION func12_AO_RCAS_OUT; \
	VARIABLE func12_AO_RCAS_OUT_Value; \
	VARIABLE func12_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func12_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func12_AO_RCAS_OUT_Status_Limit; \
	MENU func12_AO_RCAS_OUT_page; \
	COMMAND func12_AO_RCAS_OUT_read; \
	VARIABLE func12_AO_SETP_DEVIATION; \
	MENU func12_AO_SETP_DEVIATION_page; \
	COMMAND func12_AO_SETP_DEVIATION_read; \
	COLLECTION func12_AO_VIEW_2; \
	MENU func12_AO_VIEW_2_page; \
	COLLECTION func12_AO_VIEW_3; \
	MENU func12_AO_VIEW_3_page; \
	UNIT func12_AO_PV_SCALE_unit_3

#define USE_FUNC12_AO_OPTIONAL_A \
	USE_FUNC12_AO_OPTIONAL_BOTH; \
	COLLECTION func12_AO_READBACK; \
	VARIABLE func12_AO_READBACK_Value; \
	VARIABLE func12_AO_READBACK_Status_Condensed; \
	VARIABLE func12_AO_READBACK_Status_Quality; \
	VARIABLE func12_AO_READBACK_Status_Limit; \
	MENU func12_AO_READBACK_page; \
	COMMAND func12_AO_READBACK_read; \
	VARIABLE func12_AO_IN_CHANNEL; \
	MENU func12_AO_IN_CHANNEL_page; \
	COMMAND func12_AO_IN_CHANNEL_read; \
	COMMAND func12_AO_IN_CHANNEL_write; \
	VARIABLE func12_AO_OUT_CHANNEL; \
	MENU func12_AO_OUT_CHANNEL_page; \
	COMMAND func12_AO_OUT_CHANNEL_read; \
	COMMAND func12_AO_OUT_CHANNEL_write; \
	VARIABLE func12_AO_FSAFE_TIME; \
	MENU func12_AO_FSAFE_TIME_page; \
	COMMAND func12_AO_FSAFE_TIME_read; \
	COMMAND func12_AO_FSAFE_TIME_write; \
	VARIABLE func12_AO_FSAFE_TYPE; \
	MENU func12_AO_FSAFE_TYPE_page; \
	COMMAND func12_AO_FSAFE_TYPE_read; \
	COMMAND func12_AO_FSAFE_TYPE_write; \
	VARIABLE func12_AO_FSAFE_VALUE; \
	MENU func12_AO_FSAFE_VALUE_page; \
	COMMAND func12_AO_FSAFE_VALUE_read; \
	COMMAND func12_AO_FSAFE_VALUE_write; \
	VARIABLE func12_AO_CHECK_BACK; \
	MENU func12_AO_CHECK_BACK_page; \
	COMMAND func12_AO_CHECK_BACK_read; \
	VARIABLE func12_AO_CHECK_BACK_MASK; \
	MENU func12_AO_CHECK_BACK_MASK_page; \
	COMMAND func12_AO_CHECK_BACK_MASK_read; \
	COLLECTION func12_AO_SIMULATE; \
	VARIABLE func12_AO_SIMULATE_Status_Condensed; \
	VARIABLE func12_AO_SIMULATE_Value; \
	VARIABLE func12_AO_SIMULATE_Enabled; \
	VARIABLE func12_AO_SIMULATE_Status_Quality; \
	VARIABLE func12_AO_SIMULATE_Status_Limit; \
	MENU func12_AO_SIMULATE_page; \
	COMMAND func12_AO_SIMULATE_read; \
	COMMAND func12_AO_SIMULATE_write; \
	VARIABLE func12_AO_INCREASE_CLOSE; \
	MENU func12_AO_INCREASE_CLOSE_page; \
	COMMAND func12_AO_INCREASE_CLOSE_read; \
	COMMAND func12_AO_INCREASE_CLOSE_write; \
	COLLECTION func12_AO_OUT; \
	VARIABLE func12_AO_OUT_Value; \
	VARIABLE func12_AO_OUT_Status_Condensed; \
	VARIABLE func12_AO_OUT_Status_Quality; \
	VARIABLE func12_AO_OUT_Status_Limit; \
	MENU func12_AO_OUT_page; \
	COMMAND func12_AO_OUT_read; \
	COMMAND func12_AO_OUT_write; \
	COLLECTION func12_AO_VIEW_1; \
	MENU func12_AO_VIEW_1_page; \
	MENU func12_AO_Simple_Dialog_Optional_A; \
	UNIT func12_AO_PV_SCALE_unit_2; \
	UNIT func12_AO_OUT_SCALE_unit_2

#define USE_FUNC12_AO_OPTIONAL_B \
	USE_FUNC12_AO_OPTIONAL_BOTH; \
	MENU func12_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC12_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func12_AO_)
#define USE_FUNC12_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func12_AO_)
#define USE_FUNC12_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func12_AO_)
#define USE_FUNC12_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func12_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC13_AO_MANDATORY_BOTH \
	BLOCK func13_AO_block; \
	COLLECTION func13_AO_BLOCK_OBJECT; \
	VARIABLE func13_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func13_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func13_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func13_AO_BLOCK_OBJECT_Class; \
	VARIABLE func13_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func13_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func13_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func13_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func13_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func13_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func13_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func13_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func13_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func13_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func13_AO_BLOCK_OBJECT_page; \
	COMMAND func13_AO_BLOCK_OBJECT_read; \
	VARIABLE func13_AO_ST_REV; \
	MENU func13_AO_ST_REV_page; \
	COMMAND func13_AO_ST_REV_read; \
	VARIABLE func13_AO_TAG_DESC; \
	MENU func13_AO_TAG_DESC_page; \
	COMMAND func13_AO_TAG_DESC_read; \
	COMMAND func13_AO_TAG_DESC_write; \
	VARIABLE func13_AO_STRATEGY; \
	MENU func13_AO_STRATEGY_page; \
	COMMAND func13_AO_STRATEGY_read; \
	COMMAND func13_AO_STRATEGY_write; \
	VARIABLE func13_AO_ALERT_KEY; \
	MENU func13_AO_ALERT_KEY_page; \
	COMMAND func13_AO_ALERT_KEY_read; \
	COMMAND func13_AO_ALERT_KEY_write; \
	VARIABLE func13_AO_TARGET_MODE; \
	MENU func13_AO_TARGET_MODE_page; \
	COMMAND func13_AO_TARGET_MODE_read; \
	COMMAND func13_AO_TARGET_MODE_write; \
	COLLECTION func13_AO_MODE_BLK; \
	VARIABLE func13_AO_MODE_BLK_Actual; \
	VARIABLE func13_AO_MODE_BLK_Permitted; \
	VARIABLE func13_AO_MODE_BLK_Normal; \
	MENU func13_AO_MODE_BLK_page; \
	COMMAND func13_AO_MODE_BLK_read; \
	COLLECTION func13_AO_ALARM_SUM; \
	VARIABLE func13_AO_ALARM_SUM_Current; \
	VARIABLE func13_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func13_AO_ALARM_SUM_Unreported; \
	VARIABLE func13_AO_ALARM_SUM_Disabled; \
	MENU func13_AO_ALARM_SUM_page; \
	COMMAND func13_AO_ALARM_SUM_read; \
	COLLECTION func13_AO_BATCH; \
	VARIABLE func13_AO_BATCH_Batch_ID; \
	VARIABLE func13_AO_BATCH_Rup; \
	VARIABLE func13_AO_BATCH_Operation; \
	VARIABLE func13_AO_BATCH_Phase; \
	MENU func13_AO_BATCH_page; \
	COMMAND func13_AO_BATCH_read; \
	COMMAND func13_AO_BATCH_write; \
	COLLECTION func13_AO_SP; \
	VARIABLE func13_AO_SP_Value; \
	VARIABLE func13_AO_SP_Status_Condensed; \
	VARIABLE func13_AO_SP_Status_Quality; \
	VARIABLE func13_AO_SP_Status_Limit; \
	MENU func13_AO_SP_page; \
	COMMAND func13_AO_SP_read; \
	COMMAND func13_AO_SP_write; \
	COLLECTION func13_AO_PV_SCALE; \
	VARIABLE func13_AO_PV_SCALE_Upper_Value; \
	VARIABLE func13_AO_PV_SCALE_Lower_Value; \
	VARIABLE func13_AO_PV_SCALE_Units_Index; \
	VARIABLE func13_AO_PV_SCALE_Decimal_Point; \
	MENU func13_AO_PV_SCALE_page; \
	COMMAND func13_AO_PV_SCALE_read; \
	COMMAND func13_AO_PV_SCALE_write; \
	COLLECTION func13_AO_POS_D; \
	VARIABLE func13_AO_POS_D_Value; \
	VARIABLE func13_AO_POS_D_Status_Condensed; \
	VARIABLE func13_AO_POS_D_Status_Quality; \
	VARIABLE func13_AO_POS_D_Status_Limit; \
	MENU func13_AO_POS_D_page; \
	COMMAND func13_AO_POS_D_read; \
	COLLECTION func13_AO_OUT_SCALE; \
	VARIABLE func13_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func13_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func13_AO_OUT_SCALE_Units_Index; \
	VARIABLE func13_AO_OUT_SCALE_Decimal_Point; \
	MENU func13_AO_OUT_SCALE_page; \
	COMMAND func13_AO_OUT_SCALE_read; \
	COMMAND func13_AO_OUT_SCALE_write; \
	UNIT func13_AO_PV_SCALE_unit_1; \
	UNIT func13_AO_OUT_SCALE_unit_1

#define USE_FUNC13_AO_MANDATORY_A \
	USE_FUNC13_AO_MANDATORY_BOTH; \
	MENU func13_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC13_AO_MANDATORY_B \
	USE_FUNC13_AO_MANDATORY_BOTH; \
	COLLECTION func13_AO_READBACK; \
	VARIABLE func13_AO_READBACK_Value; \
	VARIABLE func13_AO_READBACK_Status_Condensed; \
	VARIABLE func13_AO_READBACK_Status_Quality; \
	VARIABLE func13_AO_READBACK_Status_Limit; \
	MENU func13_AO_READBACK_page; \
	COMMAND func13_AO_READBACK_read; \
	VARIABLE func13_AO_IN_CHANNEL; \
	MENU func13_AO_IN_CHANNEL_page; \
	COMMAND func13_AO_IN_CHANNEL_read; \
	COMMAND func13_AO_IN_CHANNEL_write; \
	VARIABLE func13_AO_OUT_CHANNEL; \
	MENU func13_AO_OUT_CHANNEL_page; \
	COMMAND func13_AO_OUT_CHANNEL_read; \
	COMMAND func13_AO_OUT_CHANNEL_write; \
	VARIABLE func13_AO_FSAFE_TIME; \
	MENU func13_AO_FSAFE_TIME_page; \
	COMMAND func13_AO_FSAFE_TIME_read; \
	COMMAND func13_AO_FSAFE_TIME_write; \
	VARIABLE func13_AO_FSAFE_TYPE; \
	MENU func13_AO_FSAFE_TYPE_page; \
	COMMAND func13_AO_FSAFE_TYPE_read; \
	COMMAND func13_AO_FSAFE_TYPE_write; \
	VARIABLE func13_AO_FSAFE_VALUE; \
	MENU func13_AO_FSAFE_VALUE_page; \
	COMMAND func13_AO_FSAFE_VALUE_read; \
	COMMAND func13_AO_FSAFE_VALUE_write; \
	VARIABLE func13_AO_CHECK_BACK; \
	MENU func13_AO_CHECK_BACK_page; \
	COMMAND func13_AO_CHECK_BACK_read; \
	VARIABLE func13_AO_CHECK_BACK_MASK; \
	MENU func13_AO_CHECK_BACK_MASK_page; \
	COMMAND func13_AO_CHECK_BACK_MASK_read; \
	COLLECTION func13_AO_SIMULATE; \
	VARIABLE func13_AO_SIMULATE_Status_Condensed; \
	VARIABLE func13_AO_SIMULATE_Value; \
	VARIABLE func13_AO_SIMULATE_Enabled; \
	VARIABLE func13_AO_SIMULATE_Status_Quality; \
	VARIABLE func13_AO_SIMULATE_Status_Limit; \
	MENU func13_AO_SIMULATE_page; \
	COMMAND func13_AO_SIMULATE_read; \
	COMMAND func13_AO_SIMULATE_write; \
	VARIABLE func13_AO_INCREASE_CLOSE; \
	MENU func13_AO_INCREASE_CLOSE_page; \
	COMMAND func13_AO_INCREASE_CLOSE_read; \
	COMMAND func13_AO_INCREASE_CLOSE_write; \
	COLLECTION func13_AO_OUT; \
	VARIABLE func13_AO_OUT_Value; \
	VARIABLE func13_AO_OUT_Status_Condensed; \
	VARIABLE func13_AO_OUT_Status_Quality; \
	VARIABLE func13_AO_OUT_Status_Limit; \
	MENU func13_AO_OUT_page; \
	COMMAND func13_AO_OUT_read; \
	COMMAND func13_AO_OUT_write; \
	COLLECTION func13_AO_VIEW_1; \
	MENU func13_AO_VIEW_1_page; \
	MENU func13_AO_Simple_Dialog_Mandatory_B; \
	UNIT func13_AO_PV_SCALE_unit_2; \
	UNIT func13_AO_OUT_SCALE_unit_2

#define USE_FUNC13_AO_OPTIONAL_BOTH \
	COLLECTION func13_AO_RCAS_IN; \
	VARIABLE func13_AO_RCAS_IN_Value; \
	VARIABLE func13_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func13_AO_RCAS_IN_Status_Quality; \
	VARIABLE func13_AO_RCAS_IN_Status_Limit; \
	MENU func13_AO_RCAS_IN_page; \
	COMMAND func13_AO_RCAS_IN_read; \
	COMMAND func13_AO_RCAS_IN_write; \
	COLLECTION func13_AO_RCAS_OUT; \
	VARIABLE func13_AO_RCAS_OUT_Value; \
	VARIABLE func13_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func13_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func13_AO_RCAS_OUT_Status_Limit; \
	MENU func13_AO_RCAS_OUT_page; \
	COMMAND func13_AO_RCAS_OUT_read; \
	VARIABLE func13_AO_SETP_DEVIATION; \
	MENU func13_AO_SETP_DEVIATION_page; \
	COMMAND func13_AO_SETP_DEVIATION_read; \
	COLLECTION func13_AO_VIEW_2; \
	MENU func13_AO_VIEW_2_page; \
	COLLECTION func13_AO_VIEW_3; \
	MENU func13_AO_VIEW_3_page; \
	UNIT func13_AO_PV_SCALE_unit_3

#define USE_FUNC13_AO_OPTIONAL_A \
	USE_FUNC13_AO_OPTIONAL_BOTH; \
	COLLECTION func13_AO_READBACK; \
	VARIABLE func13_AO_READBACK_Value; \
	VARIABLE func13_AO_READBACK_Status_Condensed; \
	VARIABLE func13_AO_READBACK_Status_Quality; \
	VARIABLE func13_AO_READBACK_Status_Limit; \
	MENU func13_AO_READBACK_page; \
	COMMAND func13_AO_READBACK_read; \
	VARIABLE func13_AO_IN_CHANNEL; \
	MENU func13_AO_IN_CHANNEL_page; \
	COMMAND func13_AO_IN_CHANNEL_read; \
	COMMAND func13_AO_IN_CHANNEL_write; \
	VARIABLE func13_AO_OUT_CHANNEL; \
	MENU func13_AO_OUT_CHANNEL_page; \
	COMMAND func13_AO_OUT_CHANNEL_read; \
	COMMAND func13_AO_OUT_CHANNEL_write; \
	VARIABLE func13_AO_FSAFE_TIME; \
	MENU func13_AO_FSAFE_TIME_page; \
	COMMAND func13_AO_FSAFE_TIME_read; \
	COMMAND func13_AO_FSAFE_TIME_write; \
	VARIABLE func13_AO_FSAFE_TYPE; \
	MENU func13_AO_FSAFE_TYPE_page; \
	COMMAND func13_AO_FSAFE_TYPE_read; \
	COMMAND func13_AO_FSAFE_TYPE_write; \
	VARIABLE func13_AO_FSAFE_VALUE; \
	MENU func13_AO_FSAFE_VALUE_page; \
	COMMAND func13_AO_FSAFE_VALUE_read; \
	COMMAND func13_AO_FSAFE_VALUE_write; \
	VARIABLE func13_AO_CHECK_BACK; \
	MENU func13_AO_CHECK_BACK_page; \
	COMMAND func13_AO_CHECK_BACK_read; \
	VARIABLE func13_AO_CHECK_BACK_MASK; \
	MENU func13_AO_CHECK_BACK_MASK_page; \
	COMMAND func13_AO_CHECK_BACK_MASK_read; \
	COLLECTION func13_AO_SIMULATE; \
	VARIABLE func13_AO_SIMULATE_Status_Condensed; \
	VARIABLE func13_AO_SIMULATE_Value; \
	VARIABLE func13_AO_SIMULATE_Enabled; \
	VARIABLE func13_AO_SIMULATE_Status_Quality; \
	VARIABLE func13_AO_SIMULATE_Status_Limit; \
	MENU func13_AO_SIMULATE_page; \
	COMMAND func13_AO_SIMULATE_read; \
	COMMAND func13_AO_SIMULATE_write; \
	VARIABLE func13_AO_INCREASE_CLOSE; \
	MENU func13_AO_INCREASE_CLOSE_page; \
	COMMAND func13_AO_INCREASE_CLOSE_read; \
	COMMAND func13_AO_INCREASE_CLOSE_write; \
	COLLECTION func13_AO_OUT; \
	VARIABLE func13_AO_OUT_Value; \
	VARIABLE func13_AO_OUT_Status_Condensed; \
	VARIABLE func13_AO_OUT_Status_Quality; \
	VARIABLE func13_AO_OUT_Status_Limit; \
	MENU func13_AO_OUT_page; \
	COMMAND func13_AO_OUT_read; \
	COMMAND func13_AO_OUT_write; \
	COLLECTION func13_AO_VIEW_1; \
	MENU func13_AO_VIEW_1_page; \
	MENU func13_AO_Simple_Dialog_Optional_A; \
	UNIT func13_AO_PV_SCALE_unit_2; \
	UNIT func13_AO_OUT_SCALE_unit_2

#define USE_FUNC13_AO_OPTIONAL_B \
	USE_FUNC13_AO_OPTIONAL_BOTH; \
	MENU func13_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC13_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func13_AO_)
#define USE_FUNC13_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func13_AO_)
#define USE_FUNC13_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func13_AO_)
#define USE_FUNC13_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func13_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC14_AO_MANDATORY_BOTH \
	BLOCK func14_AO_block; \
	COLLECTION func14_AO_BLOCK_OBJECT; \
	VARIABLE func14_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func14_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func14_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func14_AO_BLOCK_OBJECT_Class; \
	VARIABLE func14_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func14_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func14_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func14_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func14_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func14_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func14_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func14_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func14_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func14_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func14_AO_BLOCK_OBJECT_page; \
	COMMAND func14_AO_BLOCK_OBJECT_read; \
	VARIABLE func14_AO_ST_REV; \
	MENU func14_AO_ST_REV_page; \
	COMMAND func14_AO_ST_REV_read; \
	VARIABLE func14_AO_TAG_DESC; \
	MENU func14_AO_TAG_DESC_page; \
	COMMAND func14_AO_TAG_DESC_read; \
	COMMAND func14_AO_TAG_DESC_write; \
	VARIABLE func14_AO_STRATEGY; \
	MENU func14_AO_STRATEGY_page; \
	COMMAND func14_AO_STRATEGY_read; \
	COMMAND func14_AO_STRATEGY_write; \
	VARIABLE func14_AO_ALERT_KEY; \
	MENU func14_AO_ALERT_KEY_page; \
	COMMAND func14_AO_ALERT_KEY_read; \
	COMMAND func14_AO_ALERT_KEY_write; \
	VARIABLE func14_AO_TARGET_MODE; \
	MENU func14_AO_TARGET_MODE_page; \
	COMMAND func14_AO_TARGET_MODE_read; \
	COMMAND func14_AO_TARGET_MODE_write; \
	COLLECTION func14_AO_MODE_BLK; \
	VARIABLE func14_AO_MODE_BLK_Actual; \
	VARIABLE func14_AO_MODE_BLK_Permitted; \
	VARIABLE func14_AO_MODE_BLK_Normal; \
	MENU func14_AO_MODE_BLK_page; \
	COMMAND func14_AO_MODE_BLK_read; \
	COLLECTION func14_AO_ALARM_SUM; \
	VARIABLE func14_AO_ALARM_SUM_Current; \
	VARIABLE func14_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func14_AO_ALARM_SUM_Unreported; \
	VARIABLE func14_AO_ALARM_SUM_Disabled; \
	MENU func14_AO_ALARM_SUM_page; \
	COMMAND func14_AO_ALARM_SUM_read; \
	COLLECTION func14_AO_BATCH; \
	VARIABLE func14_AO_BATCH_Batch_ID; \
	VARIABLE func14_AO_BATCH_Rup; \
	VARIABLE func14_AO_BATCH_Operation; \
	VARIABLE func14_AO_BATCH_Phase; \
	MENU func14_AO_BATCH_page; \
	COMMAND func14_AO_BATCH_read; \
	COMMAND func14_AO_BATCH_write; \
	COLLECTION func14_AO_SP; \
	VARIABLE func14_AO_SP_Value; \
	VARIABLE func14_AO_SP_Status_Condensed; \
	VARIABLE func14_AO_SP_Status_Quality; \
	VARIABLE func14_AO_SP_Status_Limit; \
	MENU func14_AO_SP_page; \
	COMMAND func14_AO_SP_read; \
	COMMAND func14_AO_SP_write; \
	COLLECTION func14_AO_PV_SCALE; \
	VARIABLE func14_AO_PV_SCALE_Upper_Value; \
	VARIABLE func14_AO_PV_SCALE_Lower_Value; \
	VARIABLE func14_AO_PV_SCALE_Units_Index; \
	VARIABLE func14_AO_PV_SCALE_Decimal_Point; \
	MENU func14_AO_PV_SCALE_page; \
	COMMAND func14_AO_PV_SCALE_read; \
	COMMAND func14_AO_PV_SCALE_write; \
	COLLECTION func14_AO_POS_D; \
	VARIABLE func14_AO_POS_D_Value; \
	VARIABLE func14_AO_POS_D_Status_Condensed; \
	VARIABLE func14_AO_POS_D_Status_Quality; \
	VARIABLE func14_AO_POS_D_Status_Limit; \
	MENU func14_AO_POS_D_page; \
	COMMAND func14_AO_POS_D_read; \
	COLLECTION func14_AO_OUT_SCALE; \
	VARIABLE func14_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func14_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func14_AO_OUT_SCALE_Units_Index; \
	VARIABLE func14_AO_OUT_SCALE_Decimal_Point; \
	MENU func14_AO_OUT_SCALE_page; \
	COMMAND func14_AO_OUT_SCALE_read; \
	COMMAND func14_AO_OUT_SCALE_write; \
	UNIT func14_AO_PV_SCALE_unit_1; \
	UNIT func14_AO_OUT_SCALE_unit_1

#define USE_FUNC14_AO_MANDATORY_A \
	USE_FUNC14_AO_MANDATORY_BOTH; \
	MENU func14_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC14_AO_MANDATORY_B \
	USE_FUNC14_AO_MANDATORY_BOTH; \
	COLLECTION func14_AO_READBACK; \
	VARIABLE func14_AO_READBACK_Value; \
	VARIABLE func14_AO_READBACK_Status_Condensed; \
	VARIABLE func14_AO_READBACK_Status_Quality; \
	VARIABLE func14_AO_READBACK_Status_Limit; \
	MENU func14_AO_READBACK_page; \
	COMMAND func14_AO_READBACK_read; \
	VARIABLE func14_AO_IN_CHANNEL; \
	MENU func14_AO_IN_CHANNEL_page; \
	COMMAND func14_AO_IN_CHANNEL_read; \
	COMMAND func14_AO_IN_CHANNEL_write; \
	VARIABLE func14_AO_OUT_CHANNEL; \
	MENU func14_AO_OUT_CHANNEL_page; \
	COMMAND func14_AO_OUT_CHANNEL_read; \
	COMMAND func14_AO_OUT_CHANNEL_write; \
	VARIABLE func14_AO_FSAFE_TIME; \
	MENU func14_AO_FSAFE_TIME_page; \
	COMMAND func14_AO_FSAFE_TIME_read; \
	COMMAND func14_AO_FSAFE_TIME_write; \
	VARIABLE func14_AO_FSAFE_TYPE; \
	MENU func14_AO_FSAFE_TYPE_page; \
	COMMAND func14_AO_FSAFE_TYPE_read; \
	COMMAND func14_AO_FSAFE_TYPE_write; \
	VARIABLE func14_AO_FSAFE_VALUE; \
	MENU func14_AO_FSAFE_VALUE_page; \
	COMMAND func14_AO_FSAFE_VALUE_read; \
	COMMAND func14_AO_FSAFE_VALUE_write; \
	VARIABLE func14_AO_CHECK_BACK; \
	MENU func14_AO_CHECK_BACK_page; \
	COMMAND func14_AO_CHECK_BACK_read; \
	VARIABLE func14_AO_CHECK_BACK_MASK; \
	MENU func14_AO_CHECK_BACK_MASK_page; \
	COMMAND func14_AO_CHECK_BACK_MASK_read; \
	COLLECTION func14_AO_SIMULATE; \
	VARIABLE func14_AO_SIMULATE_Status_Condensed; \
	VARIABLE func14_AO_SIMULATE_Value; \
	VARIABLE func14_AO_SIMULATE_Enabled; \
	VARIABLE func14_AO_SIMULATE_Status_Quality; \
	VARIABLE func14_AO_SIMULATE_Status_Limit; \
	MENU func14_AO_SIMULATE_page; \
	COMMAND func14_AO_SIMULATE_read; \
	COMMAND func14_AO_SIMULATE_write; \
	VARIABLE func14_AO_INCREASE_CLOSE; \
	MENU func14_AO_INCREASE_CLOSE_page; \
	COMMAND func14_AO_INCREASE_CLOSE_read; \
	COMMAND func14_AO_INCREASE_CLOSE_write; \
	COLLECTION func14_AO_OUT; \
	VARIABLE func14_AO_OUT_Value; \
	VARIABLE func14_AO_OUT_Status_Condensed; \
	VARIABLE func14_AO_OUT_Status_Quality; \
	VARIABLE func14_AO_OUT_Status_Limit; \
	MENU func14_AO_OUT_page; \
	COMMAND func14_AO_OUT_read; \
	COMMAND func14_AO_OUT_write; \
	COLLECTION func14_AO_VIEW_1; \
	MENU func14_AO_VIEW_1_page; \
	MENU func14_AO_Simple_Dialog_Mandatory_B; \
	UNIT func14_AO_PV_SCALE_unit_2; \
	UNIT func14_AO_OUT_SCALE_unit_2

#define USE_FUNC14_AO_OPTIONAL_BOTH \
	COLLECTION func14_AO_RCAS_IN; \
	VARIABLE func14_AO_RCAS_IN_Value; \
	VARIABLE func14_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func14_AO_RCAS_IN_Status_Quality; \
	VARIABLE func14_AO_RCAS_IN_Status_Limit; \
	MENU func14_AO_RCAS_IN_page; \
	COMMAND func14_AO_RCAS_IN_read; \
	COMMAND func14_AO_RCAS_IN_write; \
	COLLECTION func14_AO_RCAS_OUT; \
	VARIABLE func14_AO_RCAS_OUT_Value; \
	VARIABLE func14_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func14_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func14_AO_RCAS_OUT_Status_Limit; \
	MENU func14_AO_RCAS_OUT_page; \
	COMMAND func14_AO_RCAS_OUT_read; \
	VARIABLE func14_AO_SETP_DEVIATION; \
	MENU func14_AO_SETP_DEVIATION_page; \
	COMMAND func14_AO_SETP_DEVIATION_read; \
	COLLECTION func14_AO_VIEW_2; \
	MENU func14_AO_VIEW_2_page; \
	COLLECTION func14_AO_VIEW_3; \
	MENU func14_AO_VIEW_3_page; \
	UNIT func14_AO_PV_SCALE_unit_3

#define USE_FUNC14_AO_OPTIONAL_A \
	USE_FUNC14_AO_OPTIONAL_BOTH; \
	COLLECTION func14_AO_READBACK; \
	VARIABLE func14_AO_READBACK_Value; \
	VARIABLE func14_AO_READBACK_Status_Condensed; \
	VARIABLE func14_AO_READBACK_Status_Quality; \
	VARIABLE func14_AO_READBACK_Status_Limit; \
	MENU func14_AO_READBACK_page; \
	COMMAND func14_AO_READBACK_read; \
	VARIABLE func14_AO_IN_CHANNEL; \
	MENU func14_AO_IN_CHANNEL_page; \
	COMMAND func14_AO_IN_CHANNEL_read; \
	COMMAND func14_AO_IN_CHANNEL_write; \
	VARIABLE func14_AO_OUT_CHANNEL; \
	MENU func14_AO_OUT_CHANNEL_page; \
	COMMAND func14_AO_OUT_CHANNEL_read; \
	COMMAND func14_AO_OUT_CHANNEL_write; \
	VARIABLE func14_AO_FSAFE_TIME; \
	MENU func14_AO_FSAFE_TIME_page; \
	COMMAND func14_AO_FSAFE_TIME_read; \
	COMMAND func14_AO_FSAFE_TIME_write; \
	VARIABLE func14_AO_FSAFE_TYPE; \
	MENU func14_AO_FSAFE_TYPE_page; \
	COMMAND func14_AO_FSAFE_TYPE_read; \
	COMMAND func14_AO_FSAFE_TYPE_write; \
	VARIABLE func14_AO_FSAFE_VALUE; \
	MENU func14_AO_FSAFE_VALUE_page; \
	COMMAND func14_AO_FSAFE_VALUE_read; \
	COMMAND func14_AO_FSAFE_VALUE_write; \
	VARIABLE func14_AO_CHECK_BACK; \
	MENU func14_AO_CHECK_BACK_page; \
	COMMAND func14_AO_CHECK_BACK_read; \
	VARIABLE func14_AO_CHECK_BACK_MASK; \
	MENU func14_AO_CHECK_BACK_MASK_page; \
	COMMAND func14_AO_CHECK_BACK_MASK_read; \
	COLLECTION func14_AO_SIMULATE; \
	VARIABLE func14_AO_SIMULATE_Status_Condensed; \
	VARIABLE func14_AO_SIMULATE_Value; \
	VARIABLE func14_AO_SIMULATE_Enabled; \
	VARIABLE func14_AO_SIMULATE_Status_Quality; \
	VARIABLE func14_AO_SIMULATE_Status_Limit; \
	MENU func14_AO_SIMULATE_page; \
	COMMAND func14_AO_SIMULATE_read; \
	COMMAND func14_AO_SIMULATE_write; \
	VARIABLE func14_AO_INCREASE_CLOSE; \
	MENU func14_AO_INCREASE_CLOSE_page; \
	COMMAND func14_AO_INCREASE_CLOSE_read; \
	COMMAND func14_AO_INCREASE_CLOSE_write; \
	COLLECTION func14_AO_OUT; \
	VARIABLE func14_AO_OUT_Value; \
	VARIABLE func14_AO_OUT_Status_Condensed; \
	VARIABLE func14_AO_OUT_Status_Quality; \
	VARIABLE func14_AO_OUT_Status_Limit; \
	MENU func14_AO_OUT_page; \
	COMMAND func14_AO_OUT_read; \
	COMMAND func14_AO_OUT_write; \
	COLLECTION func14_AO_VIEW_1; \
	MENU func14_AO_VIEW_1_page; \
	MENU func14_AO_Simple_Dialog_Optional_A; \
	UNIT func14_AO_PV_SCALE_unit_2; \
	UNIT func14_AO_OUT_SCALE_unit_2

#define USE_FUNC14_AO_OPTIONAL_B \
	USE_FUNC14_AO_OPTIONAL_BOTH; \
	MENU func14_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC14_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func14_AO_)
#define USE_FUNC14_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func14_AO_)
#define USE_FUNC14_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func14_AO_)
#define USE_FUNC14_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func14_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC15_AO_MANDATORY_BOTH \
	BLOCK func15_AO_block; \
	COLLECTION func15_AO_BLOCK_OBJECT; \
	VARIABLE func15_AO_BLOCK_OBJECT_Reserved; \
	VARIABLE func15_AO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func15_AO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func15_AO_BLOCK_OBJECT_Class; \
	VARIABLE func15_AO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func15_AO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func15_AO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func15_AO_BLOCK_OBJECT_Profile; \
	VARIABLE func15_AO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func15_AO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func15_AO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func15_AO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func15_AO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func15_AO_BLOCK_OBJECT_Number_of_Views; \
	MENU func15_AO_BLOCK_OBJECT_page; \
	COMMAND func15_AO_BLOCK_OBJECT_read; \
	VARIABLE func15_AO_ST_REV; \
	MENU func15_AO_ST_REV_page; \
	COMMAND func15_AO_ST_REV_read; \
	VARIABLE func15_AO_TAG_DESC; \
	MENU func15_AO_TAG_DESC_page; \
	COMMAND func15_AO_TAG_DESC_read; \
	COMMAND func15_AO_TAG_DESC_write; \
	VARIABLE func15_AO_STRATEGY; \
	MENU func15_AO_STRATEGY_page; \
	COMMAND func15_AO_STRATEGY_read; \
	COMMAND func15_AO_STRATEGY_write; \
	VARIABLE func15_AO_ALERT_KEY; \
	MENU func15_AO_ALERT_KEY_page; \
	COMMAND func15_AO_ALERT_KEY_read; \
	COMMAND func15_AO_ALERT_KEY_write; \
	VARIABLE func15_AO_TARGET_MODE; \
	MENU func15_AO_TARGET_MODE_page; \
	COMMAND func15_AO_TARGET_MODE_read; \
	COMMAND func15_AO_TARGET_MODE_write; \
	COLLECTION func15_AO_MODE_BLK; \
	VARIABLE func15_AO_MODE_BLK_Actual; \
	VARIABLE func15_AO_MODE_BLK_Permitted; \
	VARIABLE func15_AO_MODE_BLK_Normal; \
	MENU func15_AO_MODE_BLK_page; \
	COMMAND func15_AO_MODE_BLK_read; \
	COLLECTION func15_AO_ALARM_SUM; \
	VARIABLE func15_AO_ALARM_SUM_Current; \
	VARIABLE func15_AO_ALARM_SUM_Unacknowledged; \
	VARIABLE func15_AO_ALARM_SUM_Unreported; \
	VARIABLE func15_AO_ALARM_SUM_Disabled; \
	MENU func15_AO_ALARM_SUM_page; \
	COMMAND func15_AO_ALARM_SUM_read; \
	COLLECTION func15_AO_BATCH; \
	VARIABLE func15_AO_BATCH_Batch_ID; \
	VARIABLE func15_AO_BATCH_Rup; \
	VARIABLE func15_AO_BATCH_Operation; \
	VARIABLE func15_AO_BATCH_Phase; \
	MENU func15_AO_BATCH_page; \
	COMMAND func15_AO_BATCH_read; \
	COMMAND func15_AO_BATCH_write; \
	COLLECTION func15_AO_SP; \
	VARIABLE func15_AO_SP_Value; \
	VARIABLE func15_AO_SP_Status_Condensed; \
	VARIABLE func15_AO_SP_Status_Quality; \
	VARIABLE func15_AO_SP_Status_Limit; \
	MENU func15_AO_SP_page; \
	COMMAND func15_AO_SP_read; \
	COMMAND func15_AO_SP_write; \
	COLLECTION func15_AO_PV_SCALE; \
	VARIABLE func15_AO_PV_SCALE_Upper_Value; \
	VARIABLE func15_AO_PV_SCALE_Lower_Value; \
	VARIABLE func15_AO_PV_SCALE_Units_Index; \
	VARIABLE func15_AO_PV_SCALE_Decimal_Point; \
	MENU func15_AO_PV_SCALE_page; \
	COMMAND func15_AO_PV_SCALE_read; \
	COMMAND func15_AO_PV_SCALE_write; \
	COLLECTION func15_AO_POS_D; \
	VARIABLE func15_AO_POS_D_Value; \
	VARIABLE func15_AO_POS_D_Status_Condensed; \
	VARIABLE func15_AO_POS_D_Status_Quality; \
	VARIABLE func15_AO_POS_D_Status_Limit; \
	MENU func15_AO_POS_D_page; \
	COMMAND func15_AO_POS_D_read; \
	COLLECTION func15_AO_OUT_SCALE; \
	VARIABLE func15_AO_OUT_SCALE_Upper_Value; \
	VARIABLE func15_AO_OUT_SCALE_Lower_Value; \
	VARIABLE func15_AO_OUT_SCALE_Units_Index; \
	VARIABLE func15_AO_OUT_SCALE_Decimal_Point; \
	MENU func15_AO_OUT_SCALE_page; \
	COMMAND func15_AO_OUT_SCALE_read; \
	COMMAND func15_AO_OUT_SCALE_write; \
	UNIT func15_AO_PV_SCALE_unit_1; \
	UNIT func15_AO_OUT_SCALE_unit_1

#define USE_FUNC15_AO_MANDATORY_A \
	USE_FUNC15_AO_MANDATORY_BOTH; \
	MENU func15_AO_Simple_Dialog_Mandatory_A

#define USE_FUNC15_AO_MANDATORY_B \
	USE_FUNC15_AO_MANDATORY_BOTH; \
	COLLECTION func15_AO_READBACK; \
	VARIABLE func15_AO_READBACK_Value; \
	VARIABLE func15_AO_READBACK_Status_Condensed; \
	VARIABLE func15_AO_READBACK_Status_Quality; \
	VARIABLE func15_AO_READBACK_Status_Limit; \
	MENU func15_AO_READBACK_page; \
	COMMAND func15_AO_READBACK_read; \
	VARIABLE func15_AO_IN_CHANNEL; \
	MENU func15_AO_IN_CHANNEL_page; \
	COMMAND func15_AO_IN_CHANNEL_read; \
	COMMAND func15_AO_IN_CHANNEL_write; \
	VARIABLE func15_AO_OUT_CHANNEL; \
	MENU func15_AO_OUT_CHANNEL_page; \
	COMMAND func15_AO_OUT_CHANNEL_read; \
	COMMAND func15_AO_OUT_CHANNEL_write; \
	VARIABLE func15_AO_FSAFE_TIME; \
	MENU func15_AO_FSAFE_TIME_page; \
	COMMAND func15_AO_FSAFE_TIME_read; \
	COMMAND func15_AO_FSAFE_TIME_write; \
	VARIABLE func15_AO_FSAFE_TYPE; \
	MENU func15_AO_FSAFE_TYPE_page; \
	COMMAND func15_AO_FSAFE_TYPE_read; \
	COMMAND func15_AO_FSAFE_TYPE_write; \
	VARIABLE func15_AO_FSAFE_VALUE; \
	MENU func15_AO_FSAFE_VALUE_page; \
	COMMAND func15_AO_FSAFE_VALUE_read; \
	COMMAND func15_AO_FSAFE_VALUE_write; \
	VARIABLE func15_AO_CHECK_BACK; \
	MENU func15_AO_CHECK_BACK_page; \
	COMMAND func15_AO_CHECK_BACK_read; \
	VARIABLE func15_AO_CHECK_BACK_MASK; \
	MENU func15_AO_CHECK_BACK_MASK_page; \
	COMMAND func15_AO_CHECK_BACK_MASK_read; \
	COLLECTION func15_AO_SIMULATE; \
	VARIABLE func15_AO_SIMULATE_Status_Condensed; \
	VARIABLE func15_AO_SIMULATE_Value; \
	VARIABLE func15_AO_SIMULATE_Enabled; \
	VARIABLE func15_AO_SIMULATE_Status_Quality; \
	VARIABLE func15_AO_SIMULATE_Status_Limit; \
	MENU func15_AO_SIMULATE_page; \
	COMMAND func15_AO_SIMULATE_read; \
	COMMAND func15_AO_SIMULATE_write; \
	VARIABLE func15_AO_INCREASE_CLOSE; \
	MENU func15_AO_INCREASE_CLOSE_page; \
	COMMAND func15_AO_INCREASE_CLOSE_read; \
	COMMAND func15_AO_INCREASE_CLOSE_write; \
	COLLECTION func15_AO_OUT; \
	VARIABLE func15_AO_OUT_Value; \
	VARIABLE func15_AO_OUT_Status_Condensed; \
	VARIABLE func15_AO_OUT_Status_Quality; \
	VARIABLE func15_AO_OUT_Status_Limit; \
	MENU func15_AO_OUT_page; \
	COMMAND func15_AO_OUT_read; \
	COMMAND func15_AO_OUT_write; \
	COLLECTION func15_AO_VIEW_1; \
	MENU func15_AO_VIEW_1_page; \
	MENU func15_AO_Simple_Dialog_Mandatory_B; \
	UNIT func15_AO_PV_SCALE_unit_2; \
	UNIT func15_AO_OUT_SCALE_unit_2

#define USE_FUNC15_AO_OPTIONAL_BOTH \
	COLLECTION func15_AO_RCAS_IN; \
	VARIABLE func15_AO_RCAS_IN_Value; \
	VARIABLE func15_AO_RCAS_IN_Status_Condensed; \
	VARIABLE func15_AO_RCAS_IN_Status_Quality; \
	VARIABLE func15_AO_RCAS_IN_Status_Limit; \
	MENU func15_AO_RCAS_IN_page; \
	COMMAND func15_AO_RCAS_IN_read; \
	COMMAND func15_AO_RCAS_IN_write; \
	COLLECTION func15_AO_RCAS_OUT; \
	VARIABLE func15_AO_RCAS_OUT_Value; \
	VARIABLE func15_AO_RCAS_OUT_Status_Condensed; \
	VARIABLE func15_AO_RCAS_OUT_Status_Quality; \
	VARIABLE func15_AO_RCAS_OUT_Status_Limit; \
	MENU func15_AO_RCAS_OUT_page; \
	COMMAND func15_AO_RCAS_OUT_read; \
	VARIABLE func15_AO_SETP_DEVIATION; \
	MENU func15_AO_SETP_DEVIATION_page; \
	COMMAND func15_AO_SETP_DEVIATION_read; \
	COLLECTION func15_AO_VIEW_2; \
	MENU func15_AO_VIEW_2_page; \
	COLLECTION func15_AO_VIEW_3; \
	MENU func15_AO_VIEW_3_page; \
	UNIT func15_AO_PV_SCALE_unit_3

#define USE_FUNC15_AO_OPTIONAL_A \
	USE_FUNC15_AO_OPTIONAL_BOTH; \
	COLLECTION func15_AO_READBACK; \
	VARIABLE func15_AO_READBACK_Value; \
	VARIABLE func15_AO_READBACK_Status_Condensed; \
	VARIABLE func15_AO_READBACK_Status_Quality; \
	VARIABLE func15_AO_READBACK_Status_Limit; \
	MENU func15_AO_READBACK_page; \
	COMMAND func15_AO_READBACK_read; \
	VARIABLE func15_AO_IN_CHANNEL; \
	MENU func15_AO_IN_CHANNEL_page; \
	COMMAND func15_AO_IN_CHANNEL_read; \
	COMMAND func15_AO_IN_CHANNEL_write; \
	VARIABLE func15_AO_OUT_CHANNEL; \
	MENU func15_AO_OUT_CHANNEL_page; \
	COMMAND func15_AO_OUT_CHANNEL_read; \
	COMMAND func15_AO_OUT_CHANNEL_write; \
	VARIABLE func15_AO_FSAFE_TIME; \
	MENU func15_AO_FSAFE_TIME_page; \
	COMMAND func15_AO_FSAFE_TIME_read; \
	COMMAND func15_AO_FSAFE_TIME_write; \
	VARIABLE func15_AO_FSAFE_TYPE; \
	MENU func15_AO_FSAFE_TYPE_page; \
	COMMAND func15_AO_FSAFE_TYPE_read; \
	COMMAND func15_AO_FSAFE_TYPE_write; \
	VARIABLE func15_AO_FSAFE_VALUE; \
	MENU func15_AO_FSAFE_VALUE_page; \
	COMMAND func15_AO_FSAFE_VALUE_read; \
	COMMAND func15_AO_FSAFE_VALUE_write; \
	VARIABLE func15_AO_CHECK_BACK; \
	MENU func15_AO_CHECK_BACK_page; \
	COMMAND func15_AO_CHECK_BACK_read; \
	VARIABLE func15_AO_CHECK_BACK_MASK; \
	MENU func15_AO_CHECK_BACK_MASK_page; \
	COMMAND func15_AO_CHECK_BACK_MASK_read; \
	COLLECTION func15_AO_SIMULATE; \
	VARIABLE func15_AO_SIMULATE_Status_Condensed; \
	VARIABLE func15_AO_SIMULATE_Value; \
	VARIABLE func15_AO_SIMULATE_Enabled; \
	VARIABLE func15_AO_SIMULATE_Status_Quality; \
	VARIABLE func15_AO_SIMULATE_Status_Limit; \
	MENU func15_AO_SIMULATE_page; \
	COMMAND func15_AO_SIMULATE_read; \
	COMMAND func15_AO_SIMULATE_write; \
	VARIABLE func15_AO_INCREASE_CLOSE; \
	MENU func15_AO_INCREASE_CLOSE_page; \
	COMMAND func15_AO_INCREASE_CLOSE_read; \
	COMMAND func15_AO_INCREASE_CLOSE_write; \
	COLLECTION func15_AO_OUT; \
	VARIABLE func15_AO_OUT_Value; \
	VARIABLE func15_AO_OUT_Status_Condensed; \
	VARIABLE func15_AO_OUT_Status_Quality; \
	VARIABLE func15_AO_OUT_Status_Limit; \
	MENU func15_AO_OUT_page; \
	COMMAND func15_AO_OUT_read; \
	COMMAND func15_AO_OUT_write; \
	COLLECTION func15_AO_VIEW_1; \
	MENU func15_AO_VIEW_1_page; \
	MENU func15_AO_Simple_Dialog_Optional_A; \
	UNIT func15_AO_PV_SCALE_unit_2; \
	UNIT func15_AO_OUT_SCALE_unit_2

#define USE_FUNC15_AO_OPTIONAL_B \
	USE_FUNC15_AO_OPTIONAL_BOTH; \
	MENU func15_AO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC15_AO_MANDATORY_A USE_FUNC_AO_MANDATORY_A(func15_AO_)
#define USE_FUNC15_AO_MANDATORY_B USE_FUNC_AO_MANDATORY_B(func15_AO_)
#define USE_FUNC15_AO_OPTIONAL_A  USE_FUNC_AO_OPTIONAL_A(func15_AO_)
#define USE_FUNC15_AO_OPTIONAL_B  USE_FUNC_AO_OPTIONAL_B(func15_AO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_DI_MANDATORY_BOTH \
	BLOCK trans1_DI_block; \
	COLLECTION trans1_DI_BLOCK_OBJECT; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_DI_BLOCK_OBJECT_page; \
	COMMAND trans1_DI_BLOCK_OBJECT_read; \
	VARIABLE trans1_DI_ST_REV; \
	MENU trans1_DI_ST_REV_page; \
	COMMAND trans1_DI_ST_REV_read; \
	VARIABLE trans1_DI_TAG_DESC; \
	MENU trans1_DI_TAG_DESC_page; \
	COMMAND trans1_DI_TAG_DESC_read; \
	COMMAND trans1_DI_TAG_DESC_write; \
	VARIABLE trans1_DI_STRATEGY; \
	MENU trans1_DI_STRATEGY_page; \
	COMMAND trans1_DI_STRATEGY_read; \
	COMMAND trans1_DI_STRATEGY_write; \
	VARIABLE trans1_DI_ALERT_KEY; \
	MENU trans1_DI_ALERT_KEY_page; \
	COMMAND trans1_DI_ALERT_KEY_read; \
	COMMAND trans1_DI_ALERT_KEY_write; \
	VARIABLE trans1_DI_TARGET_MODE; \
	MENU trans1_DI_TARGET_MODE_page; \
	COMMAND trans1_DI_TARGET_MODE_read; \
	COMMAND trans1_DI_TARGET_MODE_write; \
	COLLECTION trans1_DI_MODE_BLK; \
	VARIABLE trans1_DI_MODE_BLK_Actual; \
	VARIABLE trans1_DI_MODE_BLK_Permitted; \
	VARIABLE trans1_DI_MODE_BLK_Normal; \
	MENU trans1_DI_MODE_BLK_page; \
	COMMAND trans1_DI_MODE_BLK_read; \
	COLLECTION trans1_DI_ALARM_SUM; \
	VARIABLE trans1_DI_ALARM_SUM_Current; \
	VARIABLE trans1_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_DI_ALARM_SUM_Unreported; \
	VARIABLE trans1_DI_ALARM_SUM_Disabled; \
	MENU trans1_DI_ALARM_SUM_page; \
	COMMAND trans1_DI_ALARM_SUM_read

#define USE_TRANS1_DI_MANDATORY_A \
	USE_TRANS1_DI_MANDATORY_BOTH; \
	MENU trans1_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS1_DI_MANDATORY_B \
	USE_TRANS1_DI_MANDATORY_BOTH; \
	COLLECTION trans1_DI_PV_D; \
	VARIABLE trans1_DI_PV_D_Value; \
	VARIABLE trans1_DI_PV_D_Status_Condensed; \
	VARIABLE trans1_DI_PV_D_Status_Quality; \
	VARIABLE trans1_DI_PV_D_Status_Limit; \
	MENU trans1_DI_PV_D_page; \
	COMMAND trans1_DI_PV_D_read; \
	COLLECTION trans1_DI_VIEW_1; \
	MENU trans1_DI_VIEW_1_page; \
	MENU trans1_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS1_DI_OPTIONAL_BOTH \
	VARIABLE trans1_DI_SENSOR_WIRE_CHECK; \
	MENU trans1_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans1_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans1_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans1_DI_SENSOR_ID; \
	MENU trans1_DI_SENSOR_ID_page; \
	COMMAND trans1_DI_SENSOR_ID_read; \
	COMMAND trans1_DI_SENSOR_ID_write; \
	VARIABLE trans1_DI_SENSOR_SER_NUM; \
	MENU trans1_DI_SENSOR_SER_NUM_page; \
	COMMAND trans1_DI_SENSOR_SER_NUM_read; \
	COMMAND trans1_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans1_DI_SENSOR_MAN; \
	MENU trans1_DI_SENSOR_MAN_page; \
	COMMAND trans1_DI_SENSOR_MAN_read; \
	COMMAND trans1_DI_SENSOR_MAN_write; \
	COLLECTION trans1_DI_VIEW_2; \
	MENU trans1_DI_VIEW_2_page; \
	COLLECTION trans1_DI_VIEW_3; \
	MENU trans1_DI_VIEW_3_page

#define USE_TRANS1_DI_OPTIONAL_A \
	USE_TRANS1_DI_OPTIONAL_BOTH; \
	COLLECTION trans1_DI_PV_D; \
	VARIABLE trans1_DI_PV_D_Value; \
	VARIABLE trans1_DI_PV_D_Status_Condensed; \
	VARIABLE trans1_DI_PV_D_Status_Quality; \
	VARIABLE trans1_DI_PV_D_Status_Limit; \
	MENU trans1_DI_PV_D_page; \
	COMMAND trans1_DI_PV_D_read; \
	COLLECTION trans1_DI_VIEW_1; \
	MENU trans1_DI_VIEW_1_page; \
	MENU trans1_DI_Simple_Dialog_Optional_A

#define USE_TRANS1_DI_OPTIONAL_B \
	USE_TRANS1_DI_OPTIONAL_BOTH; \
	MENU trans1_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_DI_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read

#define USE_TRANS_DI_MANDATORY_A(prefix) \
	USE_TRANS_DI_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_DI_MANDATORY_B(prefix) \
	USE_TRANS_DI_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## PV_D; \
	VARIABLE prefix ## PV_D_Value; \
	VARIABLE prefix ## PV_D_Status_Condensed; \
	VARIABLE prefix ## PV_D_Status_Quality; \
	VARIABLE prefix ## PV_D_Status_Limit; \
	MENU prefix ## PV_D_page; \
	COMMAND prefix ## PV_D_read; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_DI_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## SENSOR_WIRE_CHECK; \
	MENU prefix ## SENSOR_WIRE_CHECK_page; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_read; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_write; \
	VARIABLE prefix ## SENSOR_ID; \
	MENU prefix ## SENSOR_ID_page; \
	COMMAND prefix ## SENSOR_ID_read; \
	COMMAND prefix ## SENSOR_ID_write; \
	VARIABLE prefix ## SENSOR_SER_NUM; \
	MENU prefix ## SENSOR_SER_NUM_page; \
	COMMAND prefix ## SENSOR_SER_NUM_read; \
	COMMAND prefix ## SENSOR_SER_NUM_write; \
	VARIABLE prefix ## SENSOR_MAN; \
	MENU prefix ## SENSOR_MAN_page; \
	COMMAND prefix ## SENSOR_MAN_read; \
	COMMAND prefix ## SENSOR_MAN_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_DI_OPTIONAL_A(prefix) \
	USE_TRANS_DI_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## PV_D; \
	VARIABLE prefix ## PV_D_Value; \
	VARIABLE prefix ## PV_D_Status_Condensed; \
	VARIABLE prefix ## PV_D_Status_Quality; \
	VARIABLE prefix ## PV_D_Status_Limit; \
	MENU prefix ## PV_D_page; \
	COMMAND prefix ## PV_D_read; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_DI_OPTIONAL_B(prefix) \
	USE_TRANS_DI_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans1_DI_)
#define USE_TRANS1_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans1_DI_)
#define USE_TRANS1_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans1_DI_)
#define USE_TRANS1_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans1_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_DI_MANDATORY_BOTH \
	BLOCK trans2_DI_block; \
	COLLECTION trans2_DI_BLOCK_OBJECT; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_DI_BLOCK_OBJECT_page; \
	COMMAND trans2_DI_BLOCK_OBJECT_read; \
	VARIABLE trans2_DI_ST_REV; \
	MENU trans2_DI_ST_REV_page; \
	COMMAND trans2_DI_ST_REV_read; \
	VARIABLE trans2_DI_TAG_DESC; \
	MENU trans2_DI_TAG_DESC_page; \
	COMMAND trans2_DI_TAG_DESC_read; \
	COMMAND trans2_DI_TAG_DESC_write; \
	VARIABLE trans2_DI_STRATEGY; \
	MENU trans2_DI_STRATEGY_page; \
	COMMAND trans2_DI_STRATEGY_read; \
	COMMAND trans2_DI_STRATEGY_write; \
	VARIABLE trans2_DI_ALERT_KEY; \
	MENU trans2_DI_ALERT_KEY_page; \
	COMMAND trans2_DI_ALERT_KEY_read; \
	COMMAND trans2_DI_ALERT_KEY_write; \
	VARIABLE trans2_DI_TARGET_MODE; \
	MENU trans2_DI_TARGET_MODE_page; \
	COMMAND trans2_DI_TARGET_MODE_read; \
	COMMAND trans2_DI_TARGET_MODE_write; \
	COLLECTION trans2_DI_MODE_BLK; \
	VARIABLE trans2_DI_MODE_BLK_Actual; \
	VARIABLE trans2_DI_MODE_BLK_Permitted; \
	VARIABLE trans2_DI_MODE_BLK_Normal; \
	MENU trans2_DI_MODE_BLK_page; \
	COMMAND trans2_DI_MODE_BLK_read; \
	COLLECTION trans2_DI_ALARM_SUM; \
	VARIABLE trans2_DI_ALARM_SUM_Current; \
	VARIABLE trans2_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_DI_ALARM_SUM_Unreported; \
	VARIABLE trans2_DI_ALARM_SUM_Disabled; \
	MENU trans2_DI_ALARM_SUM_page; \
	COMMAND trans2_DI_ALARM_SUM_read

#define USE_TRANS2_DI_MANDATORY_A \
	USE_TRANS2_DI_MANDATORY_BOTH; \
	MENU trans2_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS2_DI_MANDATORY_B \
	USE_TRANS2_DI_MANDATORY_BOTH; \
	COLLECTION trans2_DI_PV_D; \
	VARIABLE trans2_DI_PV_D_Value; \
	VARIABLE trans2_DI_PV_D_Status_Condensed; \
	VARIABLE trans2_DI_PV_D_Status_Quality; \
	VARIABLE trans2_DI_PV_D_Status_Limit; \
	MENU trans2_DI_PV_D_page; \
	COMMAND trans2_DI_PV_D_read; \
	COLLECTION trans2_DI_VIEW_1; \
	MENU trans2_DI_VIEW_1_page; \
	MENU trans2_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS2_DI_OPTIONAL_BOTH \
	VARIABLE trans2_DI_SENSOR_WIRE_CHECK; \
	MENU trans2_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans2_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans2_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans2_DI_SENSOR_ID; \
	MENU trans2_DI_SENSOR_ID_page; \
	COMMAND trans2_DI_SENSOR_ID_read; \
	COMMAND trans2_DI_SENSOR_ID_write; \
	VARIABLE trans2_DI_SENSOR_SER_NUM; \
	MENU trans2_DI_SENSOR_SER_NUM_page; \
	COMMAND trans2_DI_SENSOR_SER_NUM_read; \
	COMMAND trans2_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans2_DI_SENSOR_MAN; \
	MENU trans2_DI_SENSOR_MAN_page; \
	COMMAND trans2_DI_SENSOR_MAN_read; \
	COMMAND trans2_DI_SENSOR_MAN_write; \
	COLLECTION trans2_DI_VIEW_2; \
	MENU trans2_DI_VIEW_2_page; \
	COLLECTION trans2_DI_VIEW_3; \
	MENU trans2_DI_VIEW_3_page

#define USE_TRANS2_DI_OPTIONAL_A \
	USE_TRANS2_DI_OPTIONAL_BOTH; \
	COLLECTION trans2_DI_PV_D; \
	VARIABLE trans2_DI_PV_D_Value; \
	VARIABLE trans2_DI_PV_D_Status_Condensed; \
	VARIABLE trans2_DI_PV_D_Status_Quality; \
	VARIABLE trans2_DI_PV_D_Status_Limit; \
	MENU trans2_DI_PV_D_page; \
	COMMAND trans2_DI_PV_D_read; \
	COLLECTION trans2_DI_VIEW_1; \
	MENU trans2_DI_VIEW_1_page; \
	MENU trans2_DI_Simple_Dialog_Optional_A

#define USE_TRANS2_DI_OPTIONAL_B \
	USE_TRANS2_DI_OPTIONAL_BOTH; \
	MENU trans2_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans2_DI_)
#define USE_TRANS2_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans2_DI_)
#define USE_TRANS2_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans2_DI_)
#define USE_TRANS2_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans2_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_DI_MANDATORY_BOTH \
	BLOCK trans3_DI_block; \
	COLLECTION trans3_DI_BLOCK_OBJECT; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_DI_BLOCK_OBJECT_page; \
	COMMAND trans3_DI_BLOCK_OBJECT_read; \
	VARIABLE trans3_DI_ST_REV; \
	MENU trans3_DI_ST_REV_page; \
	COMMAND trans3_DI_ST_REV_read; \
	VARIABLE trans3_DI_TAG_DESC; \
	MENU trans3_DI_TAG_DESC_page; \
	COMMAND trans3_DI_TAG_DESC_read; \
	COMMAND trans3_DI_TAG_DESC_write; \
	VARIABLE trans3_DI_STRATEGY; \
	MENU trans3_DI_STRATEGY_page; \
	COMMAND trans3_DI_STRATEGY_read; \
	COMMAND trans3_DI_STRATEGY_write; \
	VARIABLE trans3_DI_ALERT_KEY; \
	MENU trans3_DI_ALERT_KEY_page; \
	COMMAND trans3_DI_ALERT_KEY_read; \
	COMMAND trans3_DI_ALERT_KEY_write; \
	VARIABLE trans3_DI_TARGET_MODE; \
	MENU trans3_DI_TARGET_MODE_page; \
	COMMAND trans3_DI_TARGET_MODE_read; \
	COMMAND trans3_DI_TARGET_MODE_write; \
	COLLECTION trans3_DI_MODE_BLK; \
	VARIABLE trans3_DI_MODE_BLK_Actual; \
	VARIABLE trans3_DI_MODE_BLK_Permitted; \
	VARIABLE trans3_DI_MODE_BLK_Normal; \
	MENU trans3_DI_MODE_BLK_page; \
	COMMAND trans3_DI_MODE_BLK_read; \
	COLLECTION trans3_DI_ALARM_SUM; \
	VARIABLE trans3_DI_ALARM_SUM_Current; \
	VARIABLE trans3_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_DI_ALARM_SUM_Unreported; \
	VARIABLE trans3_DI_ALARM_SUM_Disabled; \
	MENU trans3_DI_ALARM_SUM_page; \
	COMMAND trans3_DI_ALARM_SUM_read

#define USE_TRANS3_DI_MANDATORY_A \
	USE_TRANS3_DI_MANDATORY_BOTH; \
	MENU trans3_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS3_DI_MANDATORY_B \
	USE_TRANS3_DI_MANDATORY_BOTH; \
	COLLECTION trans3_DI_PV_D; \
	VARIABLE trans3_DI_PV_D_Value; \
	VARIABLE trans3_DI_PV_D_Status_Condensed; \
	VARIABLE trans3_DI_PV_D_Status_Quality; \
	VARIABLE trans3_DI_PV_D_Status_Limit; \
	MENU trans3_DI_PV_D_page; \
	COMMAND trans3_DI_PV_D_read; \
	COLLECTION trans3_DI_VIEW_1; \
	MENU trans3_DI_VIEW_1_page; \
	MENU trans3_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS3_DI_OPTIONAL_BOTH \
	VARIABLE trans3_DI_SENSOR_WIRE_CHECK; \
	MENU trans3_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans3_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans3_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans3_DI_SENSOR_ID; \
	MENU trans3_DI_SENSOR_ID_page; \
	COMMAND trans3_DI_SENSOR_ID_read; \
	COMMAND trans3_DI_SENSOR_ID_write; \
	VARIABLE trans3_DI_SENSOR_SER_NUM; \
	MENU trans3_DI_SENSOR_SER_NUM_page; \
	COMMAND trans3_DI_SENSOR_SER_NUM_read; \
	COMMAND trans3_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans3_DI_SENSOR_MAN; \
	MENU trans3_DI_SENSOR_MAN_page; \
	COMMAND trans3_DI_SENSOR_MAN_read; \
	COMMAND trans3_DI_SENSOR_MAN_write; \
	COLLECTION trans3_DI_VIEW_2; \
	MENU trans3_DI_VIEW_2_page; \
	COLLECTION trans3_DI_VIEW_3; \
	MENU trans3_DI_VIEW_3_page

#define USE_TRANS3_DI_OPTIONAL_A \
	USE_TRANS3_DI_OPTIONAL_BOTH; \
	COLLECTION trans3_DI_PV_D; \
	VARIABLE trans3_DI_PV_D_Value; \
	VARIABLE trans3_DI_PV_D_Status_Condensed; \
	VARIABLE trans3_DI_PV_D_Status_Quality; \
	VARIABLE trans3_DI_PV_D_Status_Limit; \
	MENU trans3_DI_PV_D_page; \
	COMMAND trans3_DI_PV_D_read; \
	COLLECTION trans3_DI_VIEW_1; \
	MENU trans3_DI_VIEW_1_page; \
	MENU trans3_DI_Simple_Dialog_Optional_A

#define USE_TRANS3_DI_OPTIONAL_B \
	USE_TRANS3_DI_OPTIONAL_BOTH; \
	MENU trans3_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans3_DI_)
#define USE_TRANS3_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans3_DI_)
#define USE_TRANS3_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans3_DI_)
#define USE_TRANS3_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans3_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_DI_MANDATORY_BOTH \
	BLOCK trans4_DI_block; \
	COLLECTION trans4_DI_BLOCK_OBJECT; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_DI_BLOCK_OBJECT_page; \
	COMMAND trans4_DI_BLOCK_OBJECT_read; \
	VARIABLE trans4_DI_ST_REV; \
	MENU trans4_DI_ST_REV_page; \
	COMMAND trans4_DI_ST_REV_read; \
	VARIABLE trans4_DI_TAG_DESC; \
	MENU trans4_DI_TAG_DESC_page; \
	COMMAND trans4_DI_TAG_DESC_read; \
	COMMAND trans4_DI_TAG_DESC_write; \
	VARIABLE trans4_DI_STRATEGY; \
	MENU trans4_DI_STRATEGY_page; \
	COMMAND trans4_DI_STRATEGY_read; \
	COMMAND trans4_DI_STRATEGY_write; \
	VARIABLE trans4_DI_ALERT_KEY; \
	MENU trans4_DI_ALERT_KEY_page; \
	COMMAND trans4_DI_ALERT_KEY_read; \
	COMMAND trans4_DI_ALERT_KEY_write; \
	VARIABLE trans4_DI_TARGET_MODE; \
	MENU trans4_DI_TARGET_MODE_page; \
	COMMAND trans4_DI_TARGET_MODE_read; \
	COMMAND trans4_DI_TARGET_MODE_write; \
	COLLECTION trans4_DI_MODE_BLK; \
	VARIABLE trans4_DI_MODE_BLK_Actual; \
	VARIABLE trans4_DI_MODE_BLK_Permitted; \
	VARIABLE trans4_DI_MODE_BLK_Normal; \
	MENU trans4_DI_MODE_BLK_page; \
	COMMAND trans4_DI_MODE_BLK_read; \
	COLLECTION trans4_DI_ALARM_SUM; \
	VARIABLE trans4_DI_ALARM_SUM_Current; \
	VARIABLE trans4_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_DI_ALARM_SUM_Unreported; \
	VARIABLE trans4_DI_ALARM_SUM_Disabled; \
	MENU trans4_DI_ALARM_SUM_page; \
	COMMAND trans4_DI_ALARM_SUM_read

#define USE_TRANS4_DI_MANDATORY_A \
	USE_TRANS4_DI_MANDATORY_BOTH; \
	MENU trans4_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS4_DI_MANDATORY_B \
	USE_TRANS4_DI_MANDATORY_BOTH; \
	COLLECTION trans4_DI_PV_D; \
	VARIABLE trans4_DI_PV_D_Value; \
	VARIABLE trans4_DI_PV_D_Status_Condensed; \
	VARIABLE trans4_DI_PV_D_Status_Quality; \
	VARIABLE trans4_DI_PV_D_Status_Limit; \
	MENU trans4_DI_PV_D_page; \
	COMMAND trans4_DI_PV_D_read; \
	COLLECTION trans4_DI_VIEW_1; \
	MENU trans4_DI_VIEW_1_page; \
	MENU trans4_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS4_DI_OPTIONAL_BOTH \
	VARIABLE trans4_DI_SENSOR_WIRE_CHECK; \
	MENU trans4_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans4_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans4_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans4_DI_SENSOR_ID; \
	MENU trans4_DI_SENSOR_ID_page; \
	COMMAND trans4_DI_SENSOR_ID_read; \
	COMMAND trans4_DI_SENSOR_ID_write; \
	VARIABLE trans4_DI_SENSOR_SER_NUM; \
	MENU trans4_DI_SENSOR_SER_NUM_page; \
	COMMAND trans4_DI_SENSOR_SER_NUM_read; \
	COMMAND trans4_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans4_DI_SENSOR_MAN; \
	MENU trans4_DI_SENSOR_MAN_page; \
	COMMAND trans4_DI_SENSOR_MAN_read; \
	COMMAND trans4_DI_SENSOR_MAN_write; \
	COLLECTION trans4_DI_VIEW_2; \
	MENU trans4_DI_VIEW_2_page; \
	COLLECTION trans4_DI_VIEW_3; \
	MENU trans4_DI_VIEW_3_page

#define USE_TRANS4_DI_OPTIONAL_A \
	USE_TRANS4_DI_OPTIONAL_BOTH; \
	COLLECTION trans4_DI_PV_D; \
	VARIABLE trans4_DI_PV_D_Value; \
	VARIABLE trans4_DI_PV_D_Status_Condensed; \
	VARIABLE trans4_DI_PV_D_Status_Quality; \
	VARIABLE trans4_DI_PV_D_Status_Limit; \
	MENU trans4_DI_PV_D_page; \
	COMMAND trans4_DI_PV_D_read; \
	COLLECTION trans4_DI_VIEW_1; \
	MENU trans4_DI_VIEW_1_page; \
	MENU trans4_DI_Simple_Dialog_Optional_A

#define USE_TRANS4_DI_OPTIONAL_B \
	USE_TRANS4_DI_OPTIONAL_BOTH; \
	MENU trans4_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans4_DI_)
#define USE_TRANS4_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans4_DI_)
#define USE_TRANS4_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans4_DI_)
#define USE_TRANS4_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans4_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_DI_MANDATORY_BOTH \
	BLOCK trans5_DI_block; \
	COLLECTION trans5_DI_BLOCK_OBJECT; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_DI_BLOCK_OBJECT_page; \
	COMMAND trans5_DI_BLOCK_OBJECT_read; \
	VARIABLE trans5_DI_ST_REV; \
	MENU trans5_DI_ST_REV_page; \
	COMMAND trans5_DI_ST_REV_read; \
	VARIABLE trans5_DI_TAG_DESC; \
	MENU trans5_DI_TAG_DESC_page; \
	COMMAND trans5_DI_TAG_DESC_read; \
	COMMAND trans5_DI_TAG_DESC_write; \
	VARIABLE trans5_DI_STRATEGY; \
	MENU trans5_DI_STRATEGY_page; \
	COMMAND trans5_DI_STRATEGY_read; \
	COMMAND trans5_DI_STRATEGY_write; \
	VARIABLE trans5_DI_ALERT_KEY; \
	MENU trans5_DI_ALERT_KEY_page; \
	COMMAND trans5_DI_ALERT_KEY_read; \
	COMMAND trans5_DI_ALERT_KEY_write; \
	VARIABLE trans5_DI_TARGET_MODE; \
	MENU trans5_DI_TARGET_MODE_page; \
	COMMAND trans5_DI_TARGET_MODE_read; \
	COMMAND trans5_DI_TARGET_MODE_write; \
	COLLECTION trans5_DI_MODE_BLK; \
	VARIABLE trans5_DI_MODE_BLK_Actual; \
	VARIABLE trans5_DI_MODE_BLK_Permitted; \
	VARIABLE trans5_DI_MODE_BLK_Normal; \
	MENU trans5_DI_MODE_BLK_page; \
	COMMAND trans5_DI_MODE_BLK_read; \
	COLLECTION trans5_DI_ALARM_SUM; \
	VARIABLE trans5_DI_ALARM_SUM_Current; \
	VARIABLE trans5_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_DI_ALARM_SUM_Unreported; \
	VARIABLE trans5_DI_ALARM_SUM_Disabled; \
	MENU trans5_DI_ALARM_SUM_page; \
	COMMAND trans5_DI_ALARM_SUM_read

#define USE_TRANS5_DI_MANDATORY_A \
	USE_TRANS5_DI_MANDATORY_BOTH; \
	MENU trans5_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS5_DI_MANDATORY_B \
	USE_TRANS5_DI_MANDATORY_BOTH; \
	COLLECTION trans5_DI_PV_D; \
	VARIABLE trans5_DI_PV_D_Value; \
	VARIABLE trans5_DI_PV_D_Status_Condensed; \
	VARIABLE trans5_DI_PV_D_Status_Quality; \
	VARIABLE trans5_DI_PV_D_Status_Limit; \
	MENU trans5_DI_PV_D_page; \
	COMMAND trans5_DI_PV_D_read; \
	COLLECTION trans5_DI_VIEW_1; \
	MENU trans5_DI_VIEW_1_page; \
	MENU trans5_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS5_DI_OPTIONAL_BOTH \
	VARIABLE trans5_DI_SENSOR_WIRE_CHECK; \
	MENU trans5_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans5_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans5_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans5_DI_SENSOR_ID; \
	MENU trans5_DI_SENSOR_ID_page; \
	COMMAND trans5_DI_SENSOR_ID_read; \
	COMMAND trans5_DI_SENSOR_ID_write; \
	VARIABLE trans5_DI_SENSOR_SER_NUM; \
	MENU trans5_DI_SENSOR_SER_NUM_page; \
	COMMAND trans5_DI_SENSOR_SER_NUM_read; \
	COMMAND trans5_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans5_DI_SENSOR_MAN; \
	MENU trans5_DI_SENSOR_MAN_page; \
	COMMAND trans5_DI_SENSOR_MAN_read; \
	COMMAND trans5_DI_SENSOR_MAN_write; \
	COLLECTION trans5_DI_VIEW_2; \
	MENU trans5_DI_VIEW_2_page; \
	COLLECTION trans5_DI_VIEW_3; \
	MENU trans5_DI_VIEW_3_page

#define USE_TRANS5_DI_OPTIONAL_A \
	USE_TRANS5_DI_OPTIONAL_BOTH; \
	COLLECTION trans5_DI_PV_D; \
	VARIABLE trans5_DI_PV_D_Value; \
	VARIABLE trans5_DI_PV_D_Status_Condensed; \
	VARIABLE trans5_DI_PV_D_Status_Quality; \
	VARIABLE trans5_DI_PV_D_Status_Limit; \
	MENU trans5_DI_PV_D_page; \
	COMMAND trans5_DI_PV_D_read; \
	COLLECTION trans5_DI_VIEW_1; \
	MENU trans5_DI_VIEW_1_page; \
	MENU trans5_DI_Simple_Dialog_Optional_A

#define USE_TRANS5_DI_OPTIONAL_B \
	USE_TRANS5_DI_OPTIONAL_BOTH; \
	MENU trans5_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans5_DI_)
#define USE_TRANS5_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans5_DI_)
#define USE_TRANS5_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans5_DI_)
#define USE_TRANS5_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans5_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_DI_MANDATORY_BOTH \
	BLOCK trans6_DI_block; \
	COLLECTION trans6_DI_BLOCK_OBJECT; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_DI_BLOCK_OBJECT_page; \
	COMMAND trans6_DI_BLOCK_OBJECT_read; \
	VARIABLE trans6_DI_ST_REV; \
	MENU trans6_DI_ST_REV_page; \
	COMMAND trans6_DI_ST_REV_read; \
	VARIABLE trans6_DI_TAG_DESC; \
	MENU trans6_DI_TAG_DESC_page; \
	COMMAND trans6_DI_TAG_DESC_read; \
	COMMAND trans6_DI_TAG_DESC_write; \
	VARIABLE trans6_DI_STRATEGY; \
	MENU trans6_DI_STRATEGY_page; \
	COMMAND trans6_DI_STRATEGY_read; \
	COMMAND trans6_DI_STRATEGY_write; \
	VARIABLE trans6_DI_ALERT_KEY; \
	MENU trans6_DI_ALERT_KEY_page; \
	COMMAND trans6_DI_ALERT_KEY_read; \
	COMMAND trans6_DI_ALERT_KEY_write; \
	VARIABLE trans6_DI_TARGET_MODE; \
	MENU trans6_DI_TARGET_MODE_page; \
	COMMAND trans6_DI_TARGET_MODE_read; \
	COMMAND trans6_DI_TARGET_MODE_write; \
	COLLECTION trans6_DI_MODE_BLK; \
	VARIABLE trans6_DI_MODE_BLK_Actual; \
	VARIABLE trans6_DI_MODE_BLK_Permitted; \
	VARIABLE trans6_DI_MODE_BLK_Normal; \
	MENU trans6_DI_MODE_BLK_page; \
	COMMAND trans6_DI_MODE_BLK_read; \
	COLLECTION trans6_DI_ALARM_SUM; \
	VARIABLE trans6_DI_ALARM_SUM_Current; \
	VARIABLE trans6_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_DI_ALARM_SUM_Unreported; \
	VARIABLE trans6_DI_ALARM_SUM_Disabled; \
	MENU trans6_DI_ALARM_SUM_page; \
	COMMAND trans6_DI_ALARM_SUM_read

#define USE_TRANS6_DI_MANDATORY_A \
	USE_TRANS6_DI_MANDATORY_BOTH; \
	MENU trans6_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS6_DI_MANDATORY_B \
	USE_TRANS6_DI_MANDATORY_BOTH; \
	COLLECTION trans6_DI_PV_D; \
	VARIABLE trans6_DI_PV_D_Value; \
	VARIABLE trans6_DI_PV_D_Status_Condensed; \
	VARIABLE trans6_DI_PV_D_Status_Quality; \
	VARIABLE trans6_DI_PV_D_Status_Limit; \
	MENU trans6_DI_PV_D_page; \
	COMMAND trans6_DI_PV_D_read; \
	COLLECTION trans6_DI_VIEW_1; \
	MENU trans6_DI_VIEW_1_page; \
	MENU trans6_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS6_DI_OPTIONAL_BOTH \
	VARIABLE trans6_DI_SENSOR_WIRE_CHECK; \
	MENU trans6_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans6_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans6_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans6_DI_SENSOR_ID; \
	MENU trans6_DI_SENSOR_ID_page; \
	COMMAND trans6_DI_SENSOR_ID_read; \
	COMMAND trans6_DI_SENSOR_ID_write; \
	VARIABLE trans6_DI_SENSOR_SER_NUM; \
	MENU trans6_DI_SENSOR_SER_NUM_page; \
	COMMAND trans6_DI_SENSOR_SER_NUM_read; \
	COMMAND trans6_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans6_DI_SENSOR_MAN; \
	MENU trans6_DI_SENSOR_MAN_page; \
	COMMAND trans6_DI_SENSOR_MAN_read; \
	COMMAND trans6_DI_SENSOR_MAN_write; \
	COLLECTION trans6_DI_VIEW_2; \
	MENU trans6_DI_VIEW_2_page; \
	COLLECTION trans6_DI_VIEW_3; \
	MENU trans6_DI_VIEW_3_page

#define USE_TRANS6_DI_OPTIONAL_A \
	USE_TRANS6_DI_OPTIONAL_BOTH; \
	COLLECTION trans6_DI_PV_D; \
	VARIABLE trans6_DI_PV_D_Value; \
	VARIABLE trans6_DI_PV_D_Status_Condensed; \
	VARIABLE trans6_DI_PV_D_Status_Quality; \
	VARIABLE trans6_DI_PV_D_Status_Limit; \
	MENU trans6_DI_PV_D_page; \
	COMMAND trans6_DI_PV_D_read; \
	COLLECTION trans6_DI_VIEW_1; \
	MENU trans6_DI_VIEW_1_page; \
	MENU trans6_DI_Simple_Dialog_Optional_A

#define USE_TRANS6_DI_OPTIONAL_B \
	USE_TRANS6_DI_OPTIONAL_BOTH; \
	MENU trans6_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans6_DI_)
#define USE_TRANS6_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans6_DI_)
#define USE_TRANS6_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans6_DI_)
#define USE_TRANS6_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans6_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_DI_MANDATORY_BOTH \
	BLOCK trans7_DI_block; \
	COLLECTION trans7_DI_BLOCK_OBJECT; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_DI_BLOCK_OBJECT_page; \
	COMMAND trans7_DI_BLOCK_OBJECT_read; \
	VARIABLE trans7_DI_ST_REV; \
	MENU trans7_DI_ST_REV_page; \
	COMMAND trans7_DI_ST_REV_read; \
	VARIABLE trans7_DI_TAG_DESC; \
	MENU trans7_DI_TAG_DESC_page; \
	COMMAND trans7_DI_TAG_DESC_read; \
	COMMAND trans7_DI_TAG_DESC_write; \
	VARIABLE trans7_DI_STRATEGY; \
	MENU trans7_DI_STRATEGY_page; \
	COMMAND trans7_DI_STRATEGY_read; \
	COMMAND trans7_DI_STRATEGY_write; \
	VARIABLE trans7_DI_ALERT_KEY; \
	MENU trans7_DI_ALERT_KEY_page; \
	COMMAND trans7_DI_ALERT_KEY_read; \
	COMMAND trans7_DI_ALERT_KEY_write; \
	VARIABLE trans7_DI_TARGET_MODE; \
	MENU trans7_DI_TARGET_MODE_page; \
	COMMAND trans7_DI_TARGET_MODE_read; \
	COMMAND trans7_DI_TARGET_MODE_write; \
	COLLECTION trans7_DI_MODE_BLK; \
	VARIABLE trans7_DI_MODE_BLK_Actual; \
	VARIABLE trans7_DI_MODE_BLK_Permitted; \
	VARIABLE trans7_DI_MODE_BLK_Normal; \
	MENU trans7_DI_MODE_BLK_page; \
	COMMAND trans7_DI_MODE_BLK_read; \
	COLLECTION trans7_DI_ALARM_SUM; \
	VARIABLE trans7_DI_ALARM_SUM_Current; \
	VARIABLE trans7_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_DI_ALARM_SUM_Unreported; \
	VARIABLE trans7_DI_ALARM_SUM_Disabled; \
	MENU trans7_DI_ALARM_SUM_page; \
	COMMAND trans7_DI_ALARM_SUM_read

#define USE_TRANS7_DI_MANDATORY_A \
	USE_TRANS7_DI_MANDATORY_BOTH; \
	MENU trans7_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS7_DI_MANDATORY_B \
	USE_TRANS7_DI_MANDATORY_BOTH; \
	COLLECTION trans7_DI_PV_D; \
	VARIABLE trans7_DI_PV_D_Value; \
	VARIABLE trans7_DI_PV_D_Status_Condensed; \
	VARIABLE trans7_DI_PV_D_Status_Quality; \
	VARIABLE trans7_DI_PV_D_Status_Limit; \
	MENU trans7_DI_PV_D_page; \
	COMMAND trans7_DI_PV_D_read; \
	COLLECTION trans7_DI_VIEW_1; \
	MENU trans7_DI_VIEW_1_page; \
	MENU trans7_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS7_DI_OPTIONAL_BOTH \
	VARIABLE trans7_DI_SENSOR_WIRE_CHECK; \
	MENU trans7_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans7_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans7_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans7_DI_SENSOR_ID; \
	MENU trans7_DI_SENSOR_ID_page; \
	COMMAND trans7_DI_SENSOR_ID_read; \
	COMMAND trans7_DI_SENSOR_ID_write; \
	VARIABLE trans7_DI_SENSOR_SER_NUM; \
	MENU trans7_DI_SENSOR_SER_NUM_page; \
	COMMAND trans7_DI_SENSOR_SER_NUM_read; \
	COMMAND trans7_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans7_DI_SENSOR_MAN; \
	MENU trans7_DI_SENSOR_MAN_page; \
	COMMAND trans7_DI_SENSOR_MAN_read; \
	COMMAND trans7_DI_SENSOR_MAN_write; \
	COLLECTION trans7_DI_VIEW_2; \
	MENU trans7_DI_VIEW_2_page; \
	COLLECTION trans7_DI_VIEW_3; \
	MENU trans7_DI_VIEW_3_page

#define USE_TRANS7_DI_OPTIONAL_A \
	USE_TRANS7_DI_OPTIONAL_BOTH; \
	COLLECTION trans7_DI_PV_D; \
	VARIABLE trans7_DI_PV_D_Value; \
	VARIABLE trans7_DI_PV_D_Status_Condensed; \
	VARIABLE trans7_DI_PV_D_Status_Quality; \
	VARIABLE trans7_DI_PV_D_Status_Limit; \
	MENU trans7_DI_PV_D_page; \
	COMMAND trans7_DI_PV_D_read; \
	COLLECTION trans7_DI_VIEW_1; \
	MENU trans7_DI_VIEW_1_page; \
	MENU trans7_DI_Simple_Dialog_Optional_A

#define USE_TRANS7_DI_OPTIONAL_B \
	USE_TRANS7_DI_OPTIONAL_BOTH; \
	MENU trans7_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans7_DI_)
#define USE_TRANS7_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans7_DI_)
#define USE_TRANS7_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans7_DI_)
#define USE_TRANS7_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans7_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_DI_MANDATORY_BOTH \
	BLOCK trans8_DI_block; \
	COLLECTION trans8_DI_BLOCK_OBJECT; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_DI_BLOCK_OBJECT_page; \
	COMMAND trans8_DI_BLOCK_OBJECT_read; \
	VARIABLE trans8_DI_ST_REV; \
	MENU trans8_DI_ST_REV_page; \
	COMMAND trans8_DI_ST_REV_read; \
	VARIABLE trans8_DI_TAG_DESC; \
	MENU trans8_DI_TAG_DESC_page; \
	COMMAND trans8_DI_TAG_DESC_read; \
	COMMAND trans8_DI_TAG_DESC_write; \
	VARIABLE trans8_DI_STRATEGY; \
	MENU trans8_DI_STRATEGY_page; \
	COMMAND trans8_DI_STRATEGY_read; \
	COMMAND trans8_DI_STRATEGY_write; \
	VARIABLE trans8_DI_ALERT_KEY; \
	MENU trans8_DI_ALERT_KEY_page; \
	COMMAND trans8_DI_ALERT_KEY_read; \
	COMMAND trans8_DI_ALERT_KEY_write; \
	VARIABLE trans8_DI_TARGET_MODE; \
	MENU trans8_DI_TARGET_MODE_page; \
	COMMAND trans8_DI_TARGET_MODE_read; \
	COMMAND trans8_DI_TARGET_MODE_write; \
	COLLECTION trans8_DI_MODE_BLK; \
	VARIABLE trans8_DI_MODE_BLK_Actual; \
	VARIABLE trans8_DI_MODE_BLK_Permitted; \
	VARIABLE trans8_DI_MODE_BLK_Normal; \
	MENU trans8_DI_MODE_BLK_page; \
	COMMAND trans8_DI_MODE_BLK_read; \
	COLLECTION trans8_DI_ALARM_SUM; \
	VARIABLE trans8_DI_ALARM_SUM_Current; \
	VARIABLE trans8_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_DI_ALARM_SUM_Unreported; \
	VARIABLE trans8_DI_ALARM_SUM_Disabled; \
	MENU trans8_DI_ALARM_SUM_page; \
	COMMAND trans8_DI_ALARM_SUM_read

#define USE_TRANS8_DI_MANDATORY_A \
	USE_TRANS8_DI_MANDATORY_BOTH; \
	MENU trans8_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS8_DI_MANDATORY_B \
	USE_TRANS8_DI_MANDATORY_BOTH; \
	COLLECTION trans8_DI_PV_D; \
	VARIABLE trans8_DI_PV_D_Value; \
	VARIABLE trans8_DI_PV_D_Status_Condensed; \
	VARIABLE trans8_DI_PV_D_Status_Quality; \
	VARIABLE trans8_DI_PV_D_Status_Limit; \
	MENU trans8_DI_PV_D_page; \
	COMMAND trans8_DI_PV_D_read; \
	COLLECTION trans8_DI_VIEW_1; \
	MENU trans8_DI_VIEW_1_page; \
	MENU trans8_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS8_DI_OPTIONAL_BOTH \
	VARIABLE trans8_DI_SENSOR_WIRE_CHECK; \
	MENU trans8_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans8_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans8_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans8_DI_SENSOR_ID; \
	MENU trans8_DI_SENSOR_ID_page; \
	COMMAND trans8_DI_SENSOR_ID_read; \
	COMMAND trans8_DI_SENSOR_ID_write; \
	VARIABLE trans8_DI_SENSOR_SER_NUM; \
	MENU trans8_DI_SENSOR_SER_NUM_page; \
	COMMAND trans8_DI_SENSOR_SER_NUM_read; \
	COMMAND trans8_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans8_DI_SENSOR_MAN; \
	MENU trans8_DI_SENSOR_MAN_page; \
	COMMAND trans8_DI_SENSOR_MAN_read; \
	COMMAND trans8_DI_SENSOR_MAN_write; \
	COLLECTION trans8_DI_VIEW_2; \
	MENU trans8_DI_VIEW_2_page; \
	COLLECTION trans8_DI_VIEW_3; \
	MENU trans8_DI_VIEW_3_page

#define USE_TRANS8_DI_OPTIONAL_A \
	USE_TRANS8_DI_OPTIONAL_BOTH; \
	COLLECTION trans8_DI_PV_D; \
	VARIABLE trans8_DI_PV_D_Value; \
	VARIABLE trans8_DI_PV_D_Status_Condensed; \
	VARIABLE trans8_DI_PV_D_Status_Quality; \
	VARIABLE trans8_DI_PV_D_Status_Limit; \
	MENU trans8_DI_PV_D_page; \
	COMMAND trans8_DI_PV_D_read; \
	COLLECTION trans8_DI_VIEW_1; \
	MENU trans8_DI_VIEW_1_page; \
	MENU trans8_DI_Simple_Dialog_Optional_A

#define USE_TRANS8_DI_OPTIONAL_B \
	USE_TRANS8_DI_OPTIONAL_BOTH; \
	MENU trans8_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans8_DI_)
#define USE_TRANS8_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans8_DI_)
#define USE_TRANS8_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans8_DI_)
#define USE_TRANS8_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans8_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_DI_MANDATORY_BOTH \
	BLOCK trans9_DI_block; \
	COLLECTION trans9_DI_BLOCK_OBJECT; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_DI_BLOCK_OBJECT_page; \
	COMMAND trans9_DI_BLOCK_OBJECT_read; \
	VARIABLE trans9_DI_ST_REV; \
	MENU trans9_DI_ST_REV_page; \
	COMMAND trans9_DI_ST_REV_read; \
	VARIABLE trans9_DI_TAG_DESC; \
	MENU trans9_DI_TAG_DESC_page; \
	COMMAND trans9_DI_TAG_DESC_read; \
	COMMAND trans9_DI_TAG_DESC_write; \
	VARIABLE trans9_DI_STRATEGY; \
	MENU trans9_DI_STRATEGY_page; \
	COMMAND trans9_DI_STRATEGY_read; \
	COMMAND trans9_DI_STRATEGY_write; \
	VARIABLE trans9_DI_ALERT_KEY; \
	MENU trans9_DI_ALERT_KEY_page; \
	COMMAND trans9_DI_ALERT_KEY_read; \
	COMMAND trans9_DI_ALERT_KEY_write; \
	VARIABLE trans9_DI_TARGET_MODE; \
	MENU trans9_DI_TARGET_MODE_page; \
	COMMAND trans9_DI_TARGET_MODE_read; \
	COMMAND trans9_DI_TARGET_MODE_write; \
	COLLECTION trans9_DI_MODE_BLK; \
	VARIABLE trans9_DI_MODE_BLK_Actual; \
	VARIABLE trans9_DI_MODE_BLK_Permitted; \
	VARIABLE trans9_DI_MODE_BLK_Normal; \
	MENU trans9_DI_MODE_BLK_page; \
	COMMAND trans9_DI_MODE_BLK_read; \
	COLLECTION trans9_DI_ALARM_SUM; \
	VARIABLE trans9_DI_ALARM_SUM_Current; \
	VARIABLE trans9_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_DI_ALARM_SUM_Unreported; \
	VARIABLE trans9_DI_ALARM_SUM_Disabled; \
	MENU trans9_DI_ALARM_SUM_page; \
	COMMAND trans9_DI_ALARM_SUM_read

#define USE_TRANS9_DI_MANDATORY_A \
	USE_TRANS9_DI_MANDATORY_BOTH; \
	MENU trans9_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS9_DI_MANDATORY_B \
	USE_TRANS9_DI_MANDATORY_BOTH; \
	COLLECTION trans9_DI_PV_D; \
	VARIABLE trans9_DI_PV_D_Value; \
	VARIABLE trans9_DI_PV_D_Status_Condensed; \
	VARIABLE trans9_DI_PV_D_Status_Quality; \
	VARIABLE trans9_DI_PV_D_Status_Limit; \
	MENU trans9_DI_PV_D_page; \
	COMMAND trans9_DI_PV_D_read; \
	COLLECTION trans9_DI_VIEW_1; \
	MENU trans9_DI_VIEW_1_page; \
	MENU trans9_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS9_DI_OPTIONAL_BOTH \
	VARIABLE trans9_DI_SENSOR_WIRE_CHECK; \
	MENU trans9_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans9_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans9_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans9_DI_SENSOR_ID; \
	MENU trans9_DI_SENSOR_ID_page; \
	COMMAND trans9_DI_SENSOR_ID_read; \
	COMMAND trans9_DI_SENSOR_ID_write; \
	VARIABLE trans9_DI_SENSOR_SER_NUM; \
	MENU trans9_DI_SENSOR_SER_NUM_page; \
	COMMAND trans9_DI_SENSOR_SER_NUM_read; \
	COMMAND trans9_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans9_DI_SENSOR_MAN; \
	MENU trans9_DI_SENSOR_MAN_page; \
	COMMAND trans9_DI_SENSOR_MAN_read; \
	COMMAND trans9_DI_SENSOR_MAN_write; \
	COLLECTION trans9_DI_VIEW_2; \
	MENU trans9_DI_VIEW_2_page; \
	COLLECTION trans9_DI_VIEW_3; \
	MENU trans9_DI_VIEW_3_page

#define USE_TRANS9_DI_OPTIONAL_A \
	USE_TRANS9_DI_OPTIONAL_BOTH; \
	COLLECTION trans9_DI_PV_D; \
	VARIABLE trans9_DI_PV_D_Value; \
	VARIABLE trans9_DI_PV_D_Status_Condensed; \
	VARIABLE trans9_DI_PV_D_Status_Quality; \
	VARIABLE trans9_DI_PV_D_Status_Limit; \
	MENU trans9_DI_PV_D_page; \
	COMMAND trans9_DI_PV_D_read; \
	COLLECTION trans9_DI_VIEW_1; \
	MENU trans9_DI_VIEW_1_page; \
	MENU trans9_DI_Simple_Dialog_Optional_A

#define USE_TRANS9_DI_OPTIONAL_B \
	USE_TRANS9_DI_OPTIONAL_BOTH; \
	MENU trans9_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans9_DI_)
#define USE_TRANS9_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans9_DI_)
#define USE_TRANS9_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans9_DI_)
#define USE_TRANS9_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans9_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_DI_MANDATORY_BOTH \
	BLOCK trans10_DI_block; \
	COLLECTION trans10_DI_BLOCK_OBJECT; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_DI_BLOCK_OBJECT_page; \
	COMMAND trans10_DI_BLOCK_OBJECT_read; \
	VARIABLE trans10_DI_ST_REV; \
	MENU trans10_DI_ST_REV_page; \
	COMMAND trans10_DI_ST_REV_read; \
	VARIABLE trans10_DI_TAG_DESC; \
	MENU trans10_DI_TAG_DESC_page; \
	COMMAND trans10_DI_TAG_DESC_read; \
	COMMAND trans10_DI_TAG_DESC_write; \
	VARIABLE trans10_DI_STRATEGY; \
	MENU trans10_DI_STRATEGY_page; \
	COMMAND trans10_DI_STRATEGY_read; \
	COMMAND trans10_DI_STRATEGY_write; \
	VARIABLE trans10_DI_ALERT_KEY; \
	MENU trans10_DI_ALERT_KEY_page; \
	COMMAND trans10_DI_ALERT_KEY_read; \
	COMMAND trans10_DI_ALERT_KEY_write; \
	VARIABLE trans10_DI_TARGET_MODE; \
	MENU trans10_DI_TARGET_MODE_page; \
	COMMAND trans10_DI_TARGET_MODE_read; \
	COMMAND trans10_DI_TARGET_MODE_write; \
	COLLECTION trans10_DI_MODE_BLK; \
	VARIABLE trans10_DI_MODE_BLK_Actual; \
	VARIABLE trans10_DI_MODE_BLK_Permitted; \
	VARIABLE trans10_DI_MODE_BLK_Normal; \
	MENU trans10_DI_MODE_BLK_page; \
	COMMAND trans10_DI_MODE_BLK_read; \
	COLLECTION trans10_DI_ALARM_SUM; \
	VARIABLE trans10_DI_ALARM_SUM_Current; \
	VARIABLE trans10_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_DI_ALARM_SUM_Unreported; \
	VARIABLE trans10_DI_ALARM_SUM_Disabled; \
	MENU trans10_DI_ALARM_SUM_page; \
	COMMAND trans10_DI_ALARM_SUM_read

#define USE_TRANS10_DI_MANDATORY_A \
	USE_TRANS10_DI_MANDATORY_BOTH; \
	MENU trans10_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS10_DI_MANDATORY_B \
	USE_TRANS10_DI_MANDATORY_BOTH; \
	COLLECTION trans10_DI_PV_D; \
	VARIABLE trans10_DI_PV_D_Value; \
	VARIABLE trans10_DI_PV_D_Status_Condensed; \
	VARIABLE trans10_DI_PV_D_Status_Quality; \
	VARIABLE trans10_DI_PV_D_Status_Limit; \
	MENU trans10_DI_PV_D_page; \
	COMMAND trans10_DI_PV_D_read; \
	COLLECTION trans10_DI_VIEW_1; \
	MENU trans10_DI_VIEW_1_page; \
	MENU trans10_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS10_DI_OPTIONAL_BOTH \
	VARIABLE trans10_DI_SENSOR_WIRE_CHECK; \
	MENU trans10_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans10_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans10_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans10_DI_SENSOR_ID; \
	MENU trans10_DI_SENSOR_ID_page; \
	COMMAND trans10_DI_SENSOR_ID_read; \
	COMMAND trans10_DI_SENSOR_ID_write; \
	VARIABLE trans10_DI_SENSOR_SER_NUM; \
	MENU trans10_DI_SENSOR_SER_NUM_page; \
	COMMAND trans10_DI_SENSOR_SER_NUM_read; \
	COMMAND trans10_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans10_DI_SENSOR_MAN; \
	MENU trans10_DI_SENSOR_MAN_page; \
	COMMAND trans10_DI_SENSOR_MAN_read; \
	COMMAND trans10_DI_SENSOR_MAN_write; \
	COLLECTION trans10_DI_VIEW_2; \
	MENU trans10_DI_VIEW_2_page; \
	COLLECTION trans10_DI_VIEW_3; \
	MENU trans10_DI_VIEW_3_page

#define USE_TRANS10_DI_OPTIONAL_A \
	USE_TRANS10_DI_OPTIONAL_BOTH; \
	COLLECTION trans10_DI_PV_D; \
	VARIABLE trans10_DI_PV_D_Value; \
	VARIABLE trans10_DI_PV_D_Status_Condensed; \
	VARIABLE trans10_DI_PV_D_Status_Quality; \
	VARIABLE trans10_DI_PV_D_Status_Limit; \
	MENU trans10_DI_PV_D_page; \
	COMMAND trans10_DI_PV_D_read; \
	COLLECTION trans10_DI_VIEW_1; \
	MENU trans10_DI_VIEW_1_page; \
	MENU trans10_DI_Simple_Dialog_Optional_A

#define USE_TRANS10_DI_OPTIONAL_B \
	USE_TRANS10_DI_OPTIONAL_BOTH; \
	MENU trans10_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans10_DI_)
#define USE_TRANS10_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans10_DI_)
#define USE_TRANS10_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans10_DI_)
#define USE_TRANS10_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans10_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_DI_MANDATORY_BOTH \
	BLOCK trans11_DI_block; \
	COLLECTION trans11_DI_BLOCK_OBJECT; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_DI_BLOCK_OBJECT_page; \
	COMMAND trans11_DI_BLOCK_OBJECT_read; \
	VARIABLE trans11_DI_ST_REV; \
	MENU trans11_DI_ST_REV_page; \
	COMMAND trans11_DI_ST_REV_read; \
	VARIABLE trans11_DI_TAG_DESC; \
	MENU trans11_DI_TAG_DESC_page; \
	COMMAND trans11_DI_TAG_DESC_read; \
	COMMAND trans11_DI_TAG_DESC_write; \
	VARIABLE trans11_DI_STRATEGY; \
	MENU trans11_DI_STRATEGY_page; \
	COMMAND trans11_DI_STRATEGY_read; \
	COMMAND trans11_DI_STRATEGY_write; \
	VARIABLE trans11_DI_ALERT_KEY; \
	MENU trans11_DI_ALERT_KEY_page; \
	COMMAND trans11_DI_ALERT_KEY_read; \
	COMMAND trans11_DI_ALERT_KEY_write; \
	VARIABLE trans11_DI_TARGET_MODE; \
	MENU trans11_DI_TARGET_MODE_page; \
	COMMAND trans11_DI_TARGET_MODE_read; \
	COMMAND trans11_DI_TARGET_MODE_write; \
	COLLECTION trans11_DI_MODE_BLK; \
	VARIABLE trans11_DI_MODE_BLK_Actual; \
	VARIABLE trans11_DI_MODE_BLK_Permitted; \
	VARIABLE trans11_DI_MODE_BLK_Normal; \
	MENU trans11_DI_MODE_BLK_page; \
	COMMAND trans11_DI_MODE_BLK_read; \
	COLLECTION trans11_DI_ALARM_SUM; \
	VARIABLE trans11_DI_ALARM_SUM_Current; \
	VARIABLE trans11_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_DI_ALARM_SUM_Unreported; \
	VARIABLE trans11_DI_ALARM_SUM_Disabled; \
	MENU trans11_DI_ALARM_SUM_page; \
	COMMAND trans11_DI_ALARM_SUM_read

#define USE_TRANS11_DI_MANDATORY_A \
	USE_TRANS11_DI_MANDATORY_BOTH; \
	MENU trans11_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS11_DI_MANDATORY_B \
	USE_TRANS11_DI_MANDATORY_BOTH; \
	COLLECTION trans11_DI_PV_D; \
	VARIABLE trans11_DI_PV_D_Value; \
	VARIABLE trans11_DI_PV_D_Status_Condensed; \
	VARIABLE trans11_DI_PV_D_Status_Quality; \
	VARIABLE trans11_DI_PV_D_Status_Limit; \
	MENU trans11_DI_PV_D_page; \
	COMMAND trans11_DI_PV_D_read; \
	COLLECTION trans11_DI_VIEW_1; \
	MENU trans11_DI_VIEW_1_page; \
	MENU trans11_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS11_DI_OPTIONAL_BOTH \
	VARIABLE trans11_DI_SENSOR_WIRE_CHECK; \
	MENU trans11_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans11_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans11_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans11_DI_SENSOR_ID; \
	MENU trans11_DI_SENSOR_ID_page; \
	COMMAND trans11_DI_SENSOR_ID_read; \
	COMMAND trans11_DI_SENSOR_ID_write; \
	VARIABLE trans11_DI_SENSOR_SER_NUM; \
	MENU trans11_DI_SENSOR_SER_NUM_page; \
	COMMAND trans11_DI_SENSOR_SER_NUM_read; \
	COMMAND trans11_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans11_DI_SENSOR_MAN; \
	MENU trans11_DI_SENSOR_MAN_page; \
	COMMAND trans11_DI_SENSOR_MAN_read; \
	COMMAND trans11_DI_SENSOR_MAN_write; \
	COLLECTION trans11_DI_VIEW_2; \
	MENU trans11_DI_VIEW_2_page; \
	COLLECTION trans11_DI_VIEW_3; \
	MENU trans11_DI_VIEW_3_page

#define USE_TRANS11_DI_OPTIONAL_A \
	USE_TRANS11_DI_OPTIONAL_BOTH; \
	COLLECTION trans11_DI_PV_D; \
	VARIABLE trans11_DI_PV_D_Value; \
	VARIABLE trans11_DI_PV_D_Status_Condensed; \
	VARIABLE trans11_DI_PV_D_Status_Quality; \
	VARIABLE trans11_DI_PV_D_Status_Limit; \
	MENU trans11_DI_PV_D_page; \
	COMMAND trans11_DI_PV_D_read; \
	COLLECTION trans11_DI_VIEW_1; \
	MENU trans11_DI_VIEW_1_page; \
	MENU trans11_DI_Simple_Dialog_Optional_A

#define USE_TRANS11_DI_OPTIONAL_B \
	USE_TRANS11_DI_OPTIONAL_BOTH; \
	MENU trans11_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans11_DI_)
#define USE_TRANS11_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans11_DI_)
#define USE_TRANS11_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans11_DI_)
#define USE_TRANS11_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans11_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_DI_MANDATORY_BOTH \
	BLOCK trans12_DI_block; \
	COLLECTION trans12_DI_BLOCK_OBJECT; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_DI_BLOCK_OBJECT_page; \
	COMMAND trans12_DI_BLOCK_OBJECT_read; \
	VARIABLE trans12_DI_ST_REV; \
	MENU trans12_DI_ST_REV_page; \
	COMMAND trans12_DI_ST_REV_read; \
	VARIABLE trans12_DI_TAG_DESC; \
	MENU trans12_DI_TAG_DESC_page; \
	COMMAND trans12_DI_TAG_DESC_read; \
	COMMAND trans12_DI_TAG_DESC_write; \
	VARIABLE trans12_DI_STRATEGY; \
	MENU trans12_DI_STRATEGY_page; \
	COMMAND trans12_DI_STRATEGY_read; \
	COMMAND trans12_DI_STRATEGY_write; \
	VARIABLE trans12_DI_ALERT_KEY; \
	MENU trans12_DI_ALERT_KEY_page; \
	COMMAND trans12_DI_ALERT_KEY_read; \
	COMMAND trans12_DI_ALERT_KEY_write; \
	VARIABLE trans12_DI_TARGET_MODE; \
	MENU trans12_DI_TARGET_MODE_page; \
	COMMAND trans12_DI_TARGET_MODE_read; \
	COMMAND trans12_DI_TARGET_MODE_write; \
	COLLECTION trans12_DI_MODE_BLK; \
	VARIABLE trans12_DI_MODE_BLK_Actual; \
	VARIABLE trans12_DI_MODE_BLK_Permitted; \
	VARIABLE trans12_DI_MODE_BLK_Normal; \
	MENU trans12_DI_MODE_BLK_page; \
	COMMAND trans12_DI_MODE_BLK_read; \
	COLLECTION trans12_DI_ALARM_SUM; \
	VARIABLE trans12_DI_ALARM_SUM_Current; \
	VARIABLE trans12_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_DI_ALARM_SUM_Unreported; \
	VARIABLE trans12_DI_ALARM_SUM_Disabled; \
	MENU trans12_DI_ALARM_SUM_page; \
	COMMAND trans12_DI_ALARM_SUM_read

#define USE_TRANS12_DI_MANDATORY_A \
	USE_TRANS12_DI_MANDATORY_BOTH; \
	MENU trans12_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS12_DI_MANDATORY_B \
	USE_TRANS12_DI_MANDATORY_BOTH; \
	COLLECTION trans12_DI_PV_D; \
	VARIABLE trans12_DI_PV_D_Value; \
	VARIABLE trans12_DI_PV_D_Status_Condensed; \
	VARIABLE trans12_DI_PV_D_Status_Quality; \
	VARIABLE trans12_DI_PV_D_Status_Limit; \
	MENU trans12_DI_PV_D_page; \
	COMMAND trans12_DI_PV_D_read; \
	COLLECTION trans12_DI_VIEW_1; \
	MENU trans12_DI_VIEW_1_page; \
	MENU trans12_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS12_DI_OPTIONAL_BOTH \
	VARIABLE trans12_DI_SENSOR_WIRE_CHECK; \
	MENU trans12_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans12_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans12_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans12_DI_SENSOR_ID; \
	MENU trans12_DI_SENSOR_ID_page; \
	COMMAND trans12_DI_SENSOR_ID_read; \
	COMMAND trans12_DI_SENSOR_ID_write; \
	VARIABLE trans12_DI_SENSOR_SER_NUM; \
	MENU trans12_DI_SENSOR_SER_NUM_page; \
	COMMAND trans12_DI_SENSOR_SER_NUM_read; \
	COMMAND trans12_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans12_DI_SENSOR_MAN; \
	MENU trans12_DI_SENSOR_MAN_page; \
	COMMAND trans12_DI_SENSOR_MAN_read; \
	COMMAND trans12_DI_SENSOR_MAN_write; \
	COLLECTION trans12_DI_VIEW_2; \
	MENU trans12_DI_VIEW_2_page; \
	COLLECTION trans12_DI_VIEW_3; \
	MENU trans12_DI_VIEW_3_page

#define USE_TRANS12_DI_OPTIONAL_A \
	USE_TRANS12_DI_OPTIONAL_BOTH; \
	COLLECTION trans12_DI_PV_D; \
	VARIABLE trans12_DI_PV_D_Value; \
	VARIABLE trans12_DI_PV_D_Status_Condensed; \
	VARIABLE trans12_DI_PV_D_Status_Quality; \
	VARIABLE trans12_DI_PV_D_Status_Limit; \
	MENU trans12_DI_PV_D_page; \
	COMMAND trans12_DI_PV_D_read; \
	COLLECTION trans12_DI_VIEW_1; \
	MENU trans12_DI_VIEW_1_page; \
	MENU trans12_DI_Simple_Dialog_Optional_A

#define USE_TRANS12_DI_OPTIONAL_B \
	USE_TRANS12_DI_OPTIONAL_BOTH; \
	MENU trans12_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans12_DI_)
#define USE_TRANS12_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans12_DI_)
#define USE_TRANS12_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans12_DI_)
#define USE_TRANS12_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans12_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_DI_MANDATORY_BOTH \
	BLOCK trans13_DI_block; \
	COLLECTION trans13_DI_BLOCK_OBJECT; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_DI_BLOCK_OBJECT_page; \
	COMMAND trans13_DI_BLOCK_OBJECT_read; \
	VARIABLE trans13_DI_ST_REV; \
	MENU trans13_DI_ST_REV_page; \
	COMMAND trans13_DI_ST_REV_read; \
	VARIABLE trans13_DI_TAG_DESC; \
	MENU trans13_DI_TAG_DESC_page; \
	COMMAND trans13_DI_TAG_DESC_read; \
	COMMAND trans13_DI_TAG_DESC_write; \
	VARIABLE trans13_DI_STRATEGY; \
	MENU trans13_DI_STRATEGY_page; \
	COMMAND trans13_DI_STRATEGY_read; \
	COMMAND trans13_DI_STRATEGY_write; \
	VARIABLE trans13_DI_ALERT_KEY; \
	MENU trans13_DI_ALERT_KEY_page; \
	COMMAND trans13_DI_ALERT_KEY_read; \
	COMMAND trans13_DI_ALERT_KEY_write; \
	VARIABLE trans13_DI_TARGET_MODE; \
	MENU trans13_DI_TARGET_MODE_page; \
	COMMAND trans13_DI_TARGET_MODE_read; \
	COMMAND trans13_DI_TARGET_MODE_write; \
	COLLECTION trans13_DI_MODE_BLK; \
	VARIABLE trans13_DI_MODE_BLK_Actual; \
	VARIABLE trans13_DI_MODE_BLK_Permitted; \
	VARIABLE trans13_DI_MODE_BLK_Normal; \
	MENU trans13_DI_MODE_BLK_page; \
	COMMAND trans13_DI_MODE_BLK_read; \
	COLLECTION trans13_DI_ALARM_SUM; \
	VARIABLE trans13_DI_ALARM_SUM_Current; \
	VARIABLE trans13_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_DI_ALARM_SUM_Unreported; \
	VARIABLE trans13_DI_ALARM_SUM_Disabled; \
	MENU trans13_DI_ALARM_SUM_page; \
	COMMAND trans13_DI_ALARM_SUM_read

#define USE_TRANS13_DI_MANDATORY_A \
	USE_TRANS13_DI_MANDATORY_BOTH; \
	MENU trans13_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS13_DI_MANDATORY_B \
	USE_TRANS13_DI_MANDATORY_BOTH; \
	COLLECTION trans13_DI_PV_D; \
	VARIABLE trans13_DI_PV_D_Value; \
	VARIABLE trans13_DI_PV_D_Status_Condensed; \
	VARIABLE trans13_DI_PV_D_Status_Quality; \
	VARIABLE trans13_DI_PV_D_Status_Limit; \
	MENU trans13_DI_PV_D_page; \
	COMMAND trans13_DI_PV_D_read; \
	COLLECTION trans13_DI_VIEW_1; \
	MENU trans13_DI_VIEW_1_page; \
	MENU trans13_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS13_DI_OPTIONAL_BOTH \
	VARIABLE trans13_DI_SENSOR_WIRE_CHECK; \
	MENU trans13_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans13_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans13_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans13_DI_SENSOR_ID; \
	MENU trans13_DI_SENSOR_ID_page; \
	COMMAND trans13_DI_SENSOR_ID_read; \
	COMMAND trans13_DI_SENSOR_ID_write; \
	VARIABLE trans13_DI_SENSOR_SER_NUM; \
	MENU trans13_DI_SENSOR_SER_NUM_page; \
	COMMAND trans13_DI_SENSOR_SER_NUM_read; \
	COMMAND trans13_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans13_DI_SENSOR_MAN; \
	MENU trans13_DI_SENSOR_MAN_page; \
	COMMAND trans13_DI_SENSOR_MAN_read; \
	COMMAND trans13_DI_SENSOR_MAN_write; \
	COLLECTION trans13_DI_VIEW_2; \
	MENU trans13_DI_VIEW_2_page; \
	COLLECTION trans13_DI_VIEW_3; \
	MENU trans13_DI_VIEW_3_page

#define USE_TRANS13_DI_OPTIONAL_A \
	USE_TRANS13_DI_OPTIONAL_BOTH; \
	COLLECTION trans13_DI_PV_D; \
	VARIABLE trans13_DI_PV_D_Value; \
	VARIABLE trans13_DI_PV_D_Status_Condensed; \
	VARIABLE trans13_DI_PV_D_Status_Quality; \
	VARIABLE trans13_DI_PV_D_Status_Limit; \
	MENU trans13_DI_PV_D_page; \
	COMMAND trans13_DI_PV_D_read; \
	COLLECTION trans13_DI_VIEW_1; \
	MENU trans13_DI_VIEW_1_page; \
	MENU trans13_DI_Simple_Dialog_Optional_A

#define USE_TRANS13_DI_OPTIONAL_B \
	USE_TRANS13_DI_OPTIONAL_BOTH; \
	MENU trans13_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans13_DI_)
#define USE_TRANS13_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans13_DI_)
#define USE_TRANS13_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans13_DI_)
#define USE_TRANS13_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans13_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_DI_MANDATORY_BOTH \
	BLOCK trans14_DI_block; \
	COLLECTION trans14_DI_BLOCK_OBJECT; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_DI_BLOCK_OBJECT_page; \
	COMMAND trans14_DI_BLOCK_OBJECT_read; \
	VARIABLE trans14_DI_ST_REV; \
	MENU trans14_DI_ST_REV_page; \
	COMMAND trans14_DI_ST_REV_read; \
	VARIABLE trans14_DI_TAG_DESC; \
	MENU trans14_DI_TAG_DESC_page; \
	COMMAND trans14_DI_TAG_DESC_read; \
	COMMAND trans14_DI_TAG_DESC_write; \
	VARIABLE trans14_DI_STRATEGY; \
	MENU trans14_DI_STRATEGY_page; \
	COMMAND trans14_DI_STRATEGY_read; \
	COMMAND trans14_DI_STRATEGY_write; \
	VARIABLE trans14_DI_ALERT_KEY; \
	MENU trans14_DI_ALERT_KEY_page; \
	COMMAND trans14_DI_ALERT_KEY_read; \
	COMMAND trans14_DI_ALERT_KEY_write; \
	VARIABLE trans14_DI_TARGET_MODE; \
	MENU trans14_DI_TARGET_MODE_page; \
	COMMAND trans14_DI_TARGET_MODE_read; \
	COMMAND trans14_DI_TARGET_MODE_write; \
	COLLECTION trans14_DI_MODE_BLK; \
	VARIABLE trans14_DI_MODE_BLK_Actual; \
	VARIABLE trans14_DI_MODE_BLK_Permitted; \
	VARIABLE trans14_DI_MODE_BLK_Normal; \
	MENU trans14_DI_MODE_BLK_page; \
	COMMAND trans14_DI_MODE_BLK_read; \
	COLLECTION trans14_DI_ALARM_SUM; \
	VARIABLE trans14_DI_ALARM_SUM_Current; \
	VARIABLE trans14_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_DI_ALARM_SUM_Unreported; \
	VARIABLE trans14_DI_ALARM_SUM_Disabled; \
	MENU trans14_DI_ALARM_SUM_page; \
	COMMAND trans14_DI_ALARM_SUM_read

#define USE_TRANS14_DI_MANDATORY_A \
	USE_TRANS14_DI_MANDATORY_BOTH; \
	MENU trans14_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS14_DI_MANDATORY_B \
	USE_TRANS14_DI_MANDATORY_BOTH; \
	COLLECTION trans14_DI_PV_D; \
	VARIABLE trans14_DI_PV_D_Value; \
	VARIABLE trans14_DI_PV_D_Status_Condensed; \
	VARIABLE trans14_DI_PV_D_Status_Quality; \
	VARIABLE trans14_DI_PV_D_Status_Limit; \
	MENU trans14_DI_PV_D_page; \
	COMMAND trans14_DI_PV_D_read; \
	COLLECTION trans14_DI_VIEW_1; \
	MENU trans14_DI_VIEW_1_page; \
	MENU trans14_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS14_DI_OPTIONAL_BOTH \
	VARIABLE trans14_DI_SENSOR_WIRE_CHECK; \
	MENU trans14_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans14_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans14_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans14_DI_SENSOR_ID; \
	MENU trans14_DI_SENSOR_ID_page; \
	COMMAND trans14_DI_SENSOR_ID_read; \
	COMMAND trans14_DI_SENSOR_ID_write; \
	VARIABLE trans14_DI_SENSOR_SER_NUM; \
	MENU trans14_DI_SENSOR_SER_NUM_page; \
	COMMAND trans14_DI_SENSOR_SER_NUM_read; \
	COMMAND trans14_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans14_DI_SENSOR_MAN; \
	MENU trans14_DI_SENSOR_MAN_page; \
	COMMAND trans14_DI_SENSOR_MAN_read; \
	COMMAND trans14_DI_SENSOR_MAN_write; \
	COLLECTION trans14_DI_VIEW_2; \
	MENU trans14_DI_VIEW_2_page; \
	COLLECTION trans14_DI_VIEW_3; \
	MENU trans14_DI_VIEW_3_page

#define USE_TRANS14_DI_OPTIONAL_A \
	USE_TRANS14_DI_OPTIONAL_BOTH; \
	COLLECTION trans14_DI_PV_D; \
	VARIABLE trans14_DI_PV_D_Value; \
	VARIABLE trans14_DI_PV_D_Status_Condensed; \
	VARIABLE trans14_DI_PV_D_Status_Quality; \
	VARIABLE trans14_DI_PV_D_Status_Limit; \
	MENU trans14_DI_PV_D_page; \
	COMMAND trans14_DI_PV_D_read; \
	COLLECTION trans14_DI_VIEW_1; \
	MENU trans14_DI_VIEW_1_page; \
	MENU trans14_DI_Simple_Dialog_Optional_A

#define USE_TRANS14_DI_OPTIONAL_B \
	USE_TRANS14_DI_OPTIONAL_BOTH; \
	MENU trans14_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans14_DI_)
#define USE_TRANS14_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans14_DI_)
#define USE_TRANS14_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans14_DI_)
#define USE_TRANS14_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans14_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_DI_MANDATORY_BOTH \
	BLOCK trans15_DI_block; \
	COLLECTION trans15_DI_BLOCK_OBJECT; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Class; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_DI_BLOCK_OBJECT_page; \
	COMMAND trans15_DI_BLOCK_OBJECT_read; \
	VARIABLE trans15_DI_ST_REV; \
	MENU trans15_DI_ST_REV_page; \
	COMMAND trans15_DI_ST_REV_read; \
	VARIABLE trans15_DI_TAG_DESC; \
	MENU trans15_DI_TAG_DESC_page; \
	COMMAND trans15_DI_TAG_DESC_read; \
	COMMAND trans15_DI_TAG_DESC_write; \
	VARIABLE trans15_DI_STRATEGY; \
	MENU trans15_DI_STRATEGY_page; \
	COMMAND trans15_DI_STRATEGY_read; \
	COMMAND trans15_DI_STRATEGY_write; \
	VARIABLE trans15_DI_ALERT_KEY; \
	MENU trans15_DI_ALERT_KEY_page; \
	COMMAND trans15_DI_ALERT_KEY_read; \
	COMMAND trans15_DI_ALERT_KEY_write; \
	VARIABLE trans15_DI_TARGET_MODE; \
	MENU trans15_DI_TARGET_MODE_page; \
	COMMAND trans15_DI_TARGET_MODE_read; \
	COMMAND trans15_DI_TARGET_MODE_write; \
	COLLECTION trans15_DI_MODE_BLK; \
	VARIABLE trans15_DI_MODE_BLK_Actual; \
	VARIABLE trans15_DI_MODE_BLK_Permitted; \
	VARIABLE trans15_DI_MODE_BLK_Normal; \
	MENU trans15_DI_MODE_BLK_page; \
	COMMAND trans15_DI_MODE_BLK_read; \
	COLLECTION trans15_DI_ALARM_SUM; \
	VARIABLE trans15_DI_ALARM_SUM_Current; \
	VARIABLE trans15_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_DI_ALARM_SUM_Unreported; \
	VARIABLE trans15_DI_ALARM_SUM_Disabled; \
	MENU trans15_DI_ALARM_SUM_page; \
	COMMAND trans15_DI_ALARM_SUM_read

#define USE_TRANS15_DI_MANDATORY_A \
	USE_TRANS15_DI_MANDATORY_BOTH; \
	MENU trans15_DI_Simple_Dialog_Mandatory_A

#define USE_TRANS15_DI_MANDATORY_B \
	USE_TRANS15_DI_MANDATORY_BOTH; \
	COLLECTION trans15_DI_PV_D; \
	VARIABLE trans15_DI_PV_D_Value; \
	VARIABLE trans15_DI_PV_D_Status_Condensed; \
	VARIABLE trans15_DI_PV_D_Status_Quality; \
	VARIABLE trans15_DI_PV_D_Status_Limit; \
	MENU trans15_DI_PV_D_page; \
	COMMAND trans15_DI_PV_D_read; \
	COLLECTION trans15_DI_VIEW_1; \
	MENU trans15_DI_VIEW_1_page; \
	MENU trans15_DI_Simple_Dialog_Mandatory_B

#define USE_TRANS15_DI_OPTIONAL_BOTH \
	VARIABLE trans15_DI_SENSOR_WIRE_CHECK; \
	MENU trans15_DI_SENSOR_WIRE_CHECK_page; \
	COMMAND trans15_DI_SENSOR_WIRE_CHECK_read; \
	COMMAND trans15_DI_SENSOR_WIRE_CHECK_write; \
	VARIABLE trans15_DI_SENSOR_ID; \
	MENU trans15_DI_SENSOR_ID_page; \
	COMMAND trans15_DI_SENSOR_ID_read; \
	COMMAND trans15_DI_SENSOR_ID_write; \
	VARIABLE trans15_DI_SENSOR_SER_NUM; \
	MENU trans15_DI_SENSOR_SER_NUM_page; \
	COMMAND trans15_DI_SENSOR_SER_NUM_read; \
	COMMAND trans15_DI_SENSOR_SER_NUM_write; \
	VARIABLE trans15_DI_SENSOR_MAN; \
	MENU trans15_DI_SENSOR_MAN_page; \
	COMMAND trans15_DI_SENSOR_MAN_read; \
	COMMAND trans15_DI_SENSOR_MAN_write; \
	COLLECTION trans15_DI_VIEW_2; \
	MENU trans15_DI_VIEW_2_page; \
	COLLECTION trans15_DI_VIEW_3; \
	MENU trans15_DI_VIEW_3_page

#define USE_TRANS15_DI_OPTIONAL_A \
	USE_TRANS15_DI_OPTIONAL_BOTH; \
	COLLECTION trans15_DI_PV_D; \
	VARIABLE trans15_DI_PV_D_Value; \
	VARIABLE trans15_DI_PV_D_Status_Condensed; \
	VARIABLE trans15_DI_PV_D_Status_Quality; \
	VARIABLE trans15_DI_PV_D_Status_Limit; \
	MENU trans15_DI_PV_D_page; \
	COMMAND trans15_DI_PV_D_read; \
	COLLECTION trans15_DI_VIEW_1; \
	MENU trans15_DI_VIEW_1_page; \
	MENU trans15_DI_Simple_Dialog_Optional_A

#define USE_TRANS15_DI_OPTIONAL_B \
	USE_TRANS15_DI_OPTIONAL_BOTH; \
	MENU trans15_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_DI_MANDATORY_A USE_TRANS_DI_MANDATORY_A(trans15_DI_)
#define USE_TRANS15_DI_MANDATORY_B USE_TRANS_DI_MANDATORY_B(trans15_DI_)
#define USE_TRANS15_DI_OPTIONAL_A  USE_TRANS_DI_OPTIONAL_A(trans15_DI_)
#define USE_TRANS15_DI_OPTIONAL_B  USE_TRANS_DI_OPTIONAL_B(trans15_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_DO_MANDATORY_BOTH \
	BLOCK trans1_DO_block; \
	COLLECTION trans1_DO_BLOCK_OBJECT; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_DO_BLOCK_OBJECT_page; \
	COMMAND trans1_DO_BLOCK_OBJECT_read; \
	VARIABLE trans1_DO_ST_REV; \
	MENU trans1_DO_ST_REV_page; \
	COMMAND trans1_DO_ST_REV_read; \
	VARIABLE trans1_DO_TAG_DESC; \
	MENU trans1_DO_TAG_DESC_page; \
	COMMAND trans1_DO_TAG_DESC_read; \
	COMMAND trans1_DO_TAG_DESC_write; \
	VARIABLE trans1_DO_STRATEGY; \
	MENU trans1_DO_STRATEGY_page; \
	COMMAND trans1_DO_STRATEGY_read; \
	COMMAND trans1_DO_STRATEGY_write; \
	VARIABLE trans1_DO_ALERT_KEY; \
	MENU trans1_DO_ALERT_KEY_page; \
	COMMAND trans1_DO_ALERT_KEY_read; \
	COMMAND trans1_DO_ALERT_KEY_write; \
	VARIABLE trans1_DO_TARGET_MODE; \
	MENU trans1_DO_TARGET_MODE_page; \
	COMMAND trans1_DO_TARGET_MODE_read; \
	COMMAND trans1_DO_TARGET_MODE_write; \
	COLLECTION trans1_DO_MODE_BLK; \
	VARIABLE trans1_DO_MODE_BLK_Actual; \
	VARIABLE trans1_DO_MODE_BLK_Permitted; \
	VARIABLE trans1_DO_MODE_BLK_Normal; \
	MENU trans1_DO_MODE_BLK_page; \
	COMMAND trans1_DO_MODE_BLK_read; \
	COLLECTION trans1_DO_ALARM_SUM; \
	VARIABLE trans1_DO_ALARM_SUM_Current; \
	VARIABLE trans1_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_DO_ALARM_SUM_Unreported; \
	VARIABLE trans1_DO_ALARM_SUM_Disabled; \
	MENU trans1_DO_ALARM_SUM_page; \
	COMMAND trans1_DO_ALARM_SUM_read

#define USE_TRANS1_DO_MANDATORY_A \
	USE_TRANS1_DO_MANDATORY_BOTH; \
	MENU trans1_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS1_DO_MANDATORY_B \
	USE_TRANS1_DO_MANDATORY_BOTH; \
	VARIABLE trans1_DO_ACTUATOR_ACTION; \
	MENU trans1_DO_ACTUATOR_ACTION_page; \
	COMMAND trans1_DO_ACTUATOR_ACTION_read; \
	COMMAND trans1_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans1_DO_SELF_CALIB_CMD; \
	MENU trans1_DO_SELF_CALIB_CMD_page; \
	COMMAND trans1_DO_SELF_CALIB_CMD_read; \
	COMMAND trans1_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans1_DO_SELF_CALIB_STATUS; \
	MENU trans1_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans1_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans1_DO_VIEW_1; \
	MENU trans1_DO_VIEW_1_page; \
	MENU trans1_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS1_DO_OPTIONAL_BOTH \
	VARIABLE trans1_DO_VALVE_MAN; \
	MENU trans1_DO_VALVE_MAN_page; \
	COMMAND trans1_DO_VALVE_MAN_read; \
	COMMAND trans1_DO_VALVE_MAN_write; \
	VARIABLE trans1_DO_ACTUATOR_MAN; \
	MENU trans1_DO_ACTUATOR_MAN_page; \
	COMMAND trans1_DO_ACTUATOR_MAN_read; \
	COMMAND trans1_DO_ACTUATOR_MAN_write; \
	VARIABLE trans1_DO_VALVE_SER_NUM; \
	MENU trans1_DO_VALVE_SER_NUM_page; \
	COMMAND trans1_DO_VALVE_SER_NUM_read; \
	COMMAND trans1_DO_VALVE_SER_NUM_write; \
	VARIABLE trans1_DO_ACTUATOR_SER_NUM; \
	MENU trans1_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans1_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans1_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans1_DO_VALVE_ID; \
	MENU trans1_DO_VALVE_ID_page; \
	COMMAND trans1_DO_VALVE_ID_read; \
	COMMAND trans1_DO_VALVE_ID_write; \
	VARIABLE trans1_DO_ACTUATOR_ID; \
	MENU trans1_DO_ACTUATOR_ID_page; \
	COMMAND trans1_DO_ACTUATOR_ID_read; \
	COMMAND trans1_DO_ACTUATOR_ID_write; \
	VARIABLE trans1_DO_TRAVEL_COUNT; \
	MENU trans1_DO_TRAVEL_COUNT_page; \
	COMMAND trans1_DO_TRAVEL_COUNT_read; \
	COMMAND trans1_DO_TRAVEL_COUNT_write; \
	VARIABLE trans1_DO_TRAVEL_COUNT_LIM; \
	MENU trans1_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans1_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans1_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans1_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans1_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans1_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans1_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans1_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans1_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans1_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans1_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans1_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans1_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans1_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans1_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans1_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans1_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans1_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans1_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans1_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans1_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans1_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans1_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans1_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans1_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans1_DO_CYCLE_TEST_CMD; \
	MENU trans1_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans1_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans1_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans1_DO_CYCLE_TEST_TIME; \
	MENU trans1_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans1_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans1_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans1_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans1_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans1_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans1_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans1_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans1_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans1_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans1_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans1_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans1_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans1_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans1_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans1_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans1_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans1_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans1_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans1_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans1_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans1_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans1_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans1_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans1_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans1_DO_SENSOR_WIRE_CHECK; \
	MENU trans1_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans1_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans1_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans1_DO_POSITIONING_VALUE_D; \
	VARIABLE trans1_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans1_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans1_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans1_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans1_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans1_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans1_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans1_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans1_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans1_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans1_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans1_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans1_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans1_DO_VIEW_2; \
	MENU trans1_DO_VIEW_2_page; \
	COLLECTION trans1_DO_VIEW_3; \
	MENU trans1_DO_VIEW_3_page; \
	COLLECTION trans1_DO_VIEW_4; \
	MENU trans1_DO_VIEW_4_page

#define USE_TRANS1_DO_OPTIONAL_A \
	USE_TRANS1_DO_OPTIONAL_BOTH; \
	VARIABLE trans1_DO_ACTUATOR_ACTION; \
	MENU trans1_DO_ACTUATOR_ACTION_page; \
	COMMAND trans1_DO_ACTUATOR_ACTION_read; \
	COMMAND trans1_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans1_DO_SELF_CALIB_CMD; \
	MENU trans1_DO_SELF_CALIB_CMD_page; \
	COMMAND trans1_DO_SELF_CALIB_CMD_read; \
	COMMAND trans1_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans1_DO_SELF_CALIB_STATUS; \
	MENU trans1_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans1_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans1_DO_VIEW_1; \
	MENU trans1_DO_VIEW_1_page; \
	MENU trans1_DO_Simple_Dialog_Optional_A

#define USE_TRANS1_DO_OPTIONAL_B \
	USE_TRANS1_DO_OPTIONAL_BOTH; \
	MENU trans1_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_DO_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read

#define USE_TRANS_DO_MANDATORY_A(prefix) \
	USE_TRANS_DO_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_DO_MANDATORY_B(prefix) \
	USE_TRANS_DO_MANDATORY_BOTH(prefix); \
	VARIABLE prefix ## ACTUATOR_ACTION; \
	MENU prefix ## ACTUATOR_ACTION_page; \
	COMMAND prefix ## ACTUATOR_ACTION_read; \
	COMMAND prefix ## ACTUATOR_ACTION_write; \
	VARIABLE prefix ## SELF_CALIB_CMD; \
	MENU prefix ## SELF_CALIB_CMD_page; \
	COMMAND prefix ## SELF_CALIB_CMD_read; \
	COMMAND prefix ## SELF_CALIB_CMD_write; \
	VARIABLE prefix ## SELF_CALIB_STATUS; \
	MENU prefix ## SELF_CALIB_STATUS_page; \
	COMMAND prefix ## SELF_CALIB_STATUS_read; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_DO_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## VALVE_MAN; \
	MENU prefix ## VALVE_MAN_page; \
	COMMAND prefix ## VALVE_MAN_read; \
	COMMAND prefix ## VALVE_MAN_write; \
	VARIABLE prefix ## ACTUATOR_MAN; \
	MENU prefix ## ACTUATOR_MAN_page; \
	COMMAND prefix ## ACTUATOR_MAN_read; \
	COMMAND prefix ## ACTUATOR_MAN_write; \
	VARIABLE prefix ## VALVE_SER_NUM; \
	MENU prefix ## VALVE_SER_NUM_page; \
	COMMAND prefix ## VALVE_SER_NUM_read; \
	COMMAND prefix ## VALVE_SER_NUM_write; \
	VARIABLE prefix ## ACTUATOR_SER_NUM; \
	MENU prefix ## ACTUATOR_SER_NUM_page; \
	COMMAND prefix ## ACTUATOR_SER_NUM_read; \
	COMMAND prefix ## ACTUATOR_SER_NUM_write; \
	VARIABLE prefix ## VALVE_ID; \
	MENU prefix ## VALVE_ID_page; \
	COMMAND prefix ## VALVE_ID_read; \
	COMMAND prefix ## VALVE_ID_write; \
	VARIABLE prefix ## ACTUATOR_ID; \
	MENU prefix ## ACTUATOR_ID_page; \
	COMMAND prefix ## ACTUATOR_ID_read; \
	COMMAND prefix ## ACTUATOR_ID_write; \
	VARIABLE prefix ## TRAVEL_COUNT; \
	MENU prefix ## TRAVEL_COUNT_page; \
	COMMAND prefix ## TRAVEL_COUNT_read; \
	COMMAND prefix ## TRAVEL_COUNT_write; \
	VARIABLE prefix ## TRAVEL_COUNT_LIM; \
	MENU prefix ## TRAVEL_COUNT_LIM_page; \
	COMMAND prefix ## TRAVEL_COUNT_LIM_read; \
	COMMAND prefix ## TRAVEL_COUNT_LIM_write; \
	VARIABLE prefix ## BREAK_TIME_OPEN_CLOSE; \
	MENU prefix ## BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND prefix ## BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND prefix ## BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE prefix ## BREAK_TIME_CLOSE_OPEN; \
	MENU prefix ## BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND prefix ## BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND prefix ## BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE prefix ## BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU prefix ## BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND prefix ## BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE prefix ## BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU prefix ## BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND prefix ## BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE prefix ## BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU prefix ## BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND prefix ## BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND prefix ## BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE prefix ## BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU prefix ## BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND prefix ## BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND prefix ## BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE prefix ## CYCLE_TEST_CMD; \
	MENU prefix ## CYCLE_TEST_CMD_page; \
	COMMAND prefix ## CYCLE_TEST_CMD_read; \
	COMMAND prefix ## CYCLE_TEST_CMD_write; \
	VARIABLE prefix ## CYCLE_TEST_TIME; \
	MENU prefix ## CYCLE_TEST_TIME_page; \
	COMMAND prefix ## CYCLE_TEST_TIME_read; \
	COMMAND prefix ## CYCLE_TEST_TIME_write; \
	VARIABLE prefix ## TRAVEL_TIME_CLOSE_OPEN; \
	MENU prefix ## TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND prefix ## TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND prefix ## TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE prefix ## TRAVEL_TIME_OPEN_CLOSE; \
	MENU prefix ## TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND prefix ## TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND prefix ## TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE prefix ## TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU prefix ## TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND prefix ## TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE prefix ## TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU prefix ## TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND prefix ## TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE prefix ## TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU prefix ## TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND prefix ## TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND prefix ## TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE prefix ## TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU prefix ## TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND prefix ## TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND prefix ## TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE prefix ## SENSOR_WIRE_CHECK; \
	MENU prefix ## SENSOR_WIRE_CHECK_page; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_read; \
	COMMAND prefix ## SENSOR_WIRE_CHECK_write; \
	COLLECTION prefix ## POSITIONING_VALUE_D; \
	VARIABLE prefix ## POSITIONING_VALUE_D_Value; \
	VARIABLE prefix ## POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE prefix ## POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE prefix ## POSITIONING_VALUE_D_Status_Limit; \
	MENU prefix ## POSITIONING_VALUE_D_page; \
	COMMAND prefix ## POSITIONING_VALUE_D_read; \
	COLLECTION prefix ## FEEDBACK_VALUE_D; \
	VARIABLE prefix ## FEEDBACK_VALUE_D_Value; \
	VARIABLE prefix ## FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE prefix ## FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE prefix ## FEEDBACK_VALUE_D_Status_Limit; \
	MENU prefix ## FEEDBACK_VALUE_D_page; \
	COMMAND prefix ## FEEDBACK_VALUE_D_read; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page; \
	COLLECTION prefix ## VIEW_4; \
	MENU prefix ## VIEW_4_page

#define USE_TRANS_DO_OPTIONAL_A(prefix) \
	USE_TRANS_DO_OPTIONAL_BOTH(prefix); \
	VARIABLE prefix ## ACTUATOR_ACTION; \
	MENU prefix ## ACTUATOR_ACTION_page; \
	COMMAND prefix ## ACTUATOR_ACTION_read; \
	COMMAND prefix ## ACTUATOR_ACTION_write; \
	VARIABLE prefix ## SELF_CALIB_CMD; \
	MENU prefix ## SELF_CALIB_CMD_page; \
	COMMAND prefix ## SELF_CALIB_CMD_read; \
	COMMAND prefix ## SELF_CALIB_CMD_write; \
	VARIABLE prefix ## SELF_CALIB_STATUS; \
	MENU prefix ## SELF_CALIB_STATUS_page; \
	COMMAND prefix ## SELF_CALIB_STATUS_read; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_DO_OPTIONAL_B(prefix) \
	USE_TRANS_DO_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans1_DO_)
#define USE_TRANS1_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans1_DO_)
#define USE_TRANS1_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans1_DO_)
#define USE_TRANS1_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans1_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_DO_MANDATORY_BOTH \
	BLOCK trans2_DO_block; \
	COLLECTION trans2_DO_BLOCK_OBJECT; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_DO_BLOCK_OBJECT_page; \
	COMMAND trans2_DO_BLOCK_OBJECT_read; \
	VARIABLE trans2_DO_ST_REV; \
	MENU trans2_DO_ST_REV_page; \
	COMMAND trans2_DO_ST_REV_read; \
	VARIABLE trans2_DO_TAG_DESC; \
	MENU trans2_DO_TAG_DESC_page; \
	COMMAND trans2_DO_TAG_DESC_read; \
	COMMAND trans2_DO_TAG_DESC_write; \
	VARIABLE trans2_DO_STRATEGY; \
	MENU trans2_DO_STRATEGY_page; \
	COMMAND trans2_DO_STRATEGY_read; \
	COMMAND trans2_DO_STRATEGY_write; \
	VARIABLE trans2_DO_ALERT_KEY; \
	MENU trans2_DO_ALERT_KEY_page; \
	COMMAND trans2_DO_ALERT_KEY_read; \
	COMMAND trans2_DO_ALERT_KEY_write; \
	VARIABLE trans2_DO_TARGET_MODE; \
	MENU trans2_DO_TARGET_MODE_page; \
	COMMAND trans2_DO_TARGET_MODE_read; \
	COMMAND trans2_DO_TARGET_MODE_write; \
	COLLECTION trans2_DO_MODE_BLK; \
	VARIABLE trans2_DO_MODE_BLK_Actual; \
	VARIABLE trans2_DO_MODE_BLK_Permitted; \
	VARIABLE trans2_DO_MODE_BLK_Normal; \
	MENU trans2_DO_MODE_BLK_page; \
	COMMAND trans2_DO_MODE_BLK_read; \
	COLLECTION trans2_DO_ALARM_SUM; \
	VARIABLE trans2_DO_ALARM_SUM_Current; \
	VARIABLE trans2_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_DO_ALARM_SUM_Unreported; \
	VARIABLE trans2_DO_ALARM_SUM_Disabled; \
	MENU trans2_DO_ALARM_SUM_page; \
	COMMAND trans2_DO_ALARM_SUM_read

#define USE_TRANS2_DO_MANDATORY_A \
	USE_TRANS2_DO_MANDATORY_BOTH; \
	MENU trans2_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS2_DO_MANDATORY_B \
	USE_TRANS2_DO_MANDATORY_BOTH; \
	VARIABLE trans2_DO_ACTUATOR_ACTION; \
	MENU trans2_DO_ACTUATOR_ACTION_page; \
	COMMAND trans2_DO_ACTUATOR_ACTION_read; \
	COMMAND trans2_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans2_DO_SELF_CALIB_CMD; \
	MENU trans2_DO_SELF_CALIB_CMD_page; \
	COMMAND trans2_DO_SELF_CALIB_CMD_read; \
	COMMAND trans2_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans2_DO_SELF_CALIB_STATUS; \
	MENU trans2_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans2_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans2_DO_VIEW_1; \
	MENU trans2_DO_VIEW_1_page; \
	MENU trans2_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS2_DO_OPTIONAL_BOTH \
	VARIABLE trans2_DO_VALVE_MAN; \
	MENU trans2_DO_VALVE_MAN_page; \
	COMMAND trans2_DO_VALVE_MAN_read; \
	COMMAND trans2_DO_VALVE_MAN_write; \
	VARIABLE trans2_DO_ACTUATOR_MAN; \
	MENU trans2_DO_ACTUATOR_MAN_page; \
	COMMAND trans2_DO_ACTUATOR_MAN_read; \
	COMMAND trans2_DO_ACTUATOR_MAN_write; \
	VARIABLE trans2_DO_VALVE_SER_NUM; \
	MENU trans2_DO_VALVE_SER_NUM_page; \
	COMMAND trans2_DO_VALVE_SER_NUM_read; \
	COMMAND trans2_DO_VALVE_SER_NUM_write; \
	VARIABLE trans2_DO_ACTUATOR_SER_NUM; \
	MENU trans2_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans2_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans2_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans2_DO_VALVE_ID; \
	MENU trans2_DO_VALVE_ID_page; \
	COMMAND trans2_DO_VALVE_ID_read; \
	COMMAND trans2_DO_VALVE_ID_write; \
	VARIABLE trans2_DO_ACTUATOR_ID; \
	MENU trans2_DO_ACTUATOR_ID_page; \
	COMMAND trans2_DO_ACTUATOR_ID_read; \
	COMMAND trans2_DO_ACTUATOR_ID_write; \
	VARIABLE trans2_DO_TRAVEL_COUNT; \
	MENU trans2_DO_TRAVEL_COUNT_page; \
	COMMAND trans2_DO_TRAVEL_COUNT_read; \
	COMMAND trans2_DO_TRAVEL_COUNT_write; \
	VARIABLE trans2_DO_TRAVEL_COUNT_LIM; \
	MENU trans2_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans2_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans2_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans2_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans2_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans2_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans2_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans2_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans2_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans2_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans2_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans2_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans2_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans2_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans2_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans2_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans2_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans2_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans2_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans2_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans2_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans2_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans2_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans2_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans2_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans2_DO_CYCLE_TEST_CMD; \
	MENU trans2_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans2_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans2_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans2_DO_CYCLE_TEST_TIME; \
	MENU trans2_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans2_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans2_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans2_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans2_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans2_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans2_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans2_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans2_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans2_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans2_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans2_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans2_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans2_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans2_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans2_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans2_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans2_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans2_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans2_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans2_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans2_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans2_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans2_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans2_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans2_DO_SENSOR_WIRE_CHECK; \
	MENU trans2_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans2_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans2_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans2_DO_POSITIONING_VALUE_D; \
	VARIABLE trans2_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans2_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans2_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans2_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans2_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans2_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans2_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans2_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans2_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans2_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans2_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans2_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans2_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans2_DO_VIEW_2; \
	MENU trans2_DO_VIEW_2_page; \
	COLLECTION trans2_DO_VIEW_3; \
	MENU trans2_DO_VIEW_3_page; \
	COLLECTION trans2_DO_VIEW_4; \
	MENU trans2_DO_VIEW_4_page

#define USE_TRANS2_DO_OPTIONAL_A \
	USE_TRANS2_DO_OPTIONAL_BOTH; \
	VARIABLE trans2_DO_ACTUATOR_ACTION; \
	MENU trans2_DO_ACTUATOR_ACTION_page; \
	COMMAND trans2_DO_ACTUATOR_ACTION_read; \
	COMMAND trans2_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans2_DO_SELF_CALIB_CMD; \
	MENU trans2_DO_SELF_CALIB_CMD_page; \
	COMMAND trans2_DO_SELF_CALIB_CMD_read; \
	COMMAND trans2_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans2_DO_SELF_CALIB_STATUS; \
	MENU trans2_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans2_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans2_DO_VIEW_1; \
	MENU trans2_DO_VIEW_1_page; \
	MENU trans2_DO_Simple_Dialog_Optional_A

#define USE_TRANS2_DO_OPTIONAL_B \
	USE_TRANS2_DO_OPTIONAL_BOTH; \
	MENU trans2_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans2_DO_)
#define USE_TRANS2_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans2_DO_)
#define USE_TRANS2_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans2_DO_)
#define USE_TRANS2_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans2_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_DO_MANDATORY_BOTH \
	BLOCK trans3_DO_block; \
	COLLECTION trans3_DO_BLOCK_OBJECT; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_DO_BLOCK_OBJECT_page; \
	COMMAND trans3_DO_BLOCK_OBJECT_read; \
	VARIABLE trans3_DO_ST_REV; \
	MENU trans3_DO_ST_REV_page; \
	COMMAND trans3_DO_ST_REV_read; \
	VARIABLE trans3_DO_TAG_DESC; \
	MENU trans3_DO_TAG_DESC_page; \
	COMMAND trans3_DO_TAG_DESC_read; \
	COMMAND trans3_DO_TAG_DESC_write; \
	VARIABLE trans3_DO_STRATEGY; \
	MENU trans3_DO_STRATEGY_page; \
	COMMAND trans3_DO_STRATEGY_read; \
	COMMAND trans3_DO_STRATEGY_write; \
	VARIABLE trans3_DO_ALERT_KEY; \
	MENU trans3_DO_ALERT_KEY_page; \
	COMMAND trans3_DO_ALERT_KEY_read; \
	COMMAND trans3_DO_ALERT_KEY_write; \
	VARIABLE trans3_DO_TARGET_MODE; \
	MENU trans3_DO_TARGET_MODE_page; \
	COMMAND trans3_DO_TARGET_MODE_read; \
	COMMAND trans3_DO_TARGET_MODE_write; \
	COLLECTION trans3_DO_MODE_BLK; \
	VARIABLE trans3_DO_MODE_BLK_Actual; \
	VARIABLE trans3_DO_MODE_BLK_Permitted; \
	VARIABLE trans3_DO_MODE_BLK_Normal; \
	MENU trans3_DO_MODE_BLK_page; \
	COMMAND trans3_DO_MODE_BLK_read; \
	COLLECTION trans3_DO_ALARM_SUM; \
	VARIABLE trans3_DO_ALARM_SUM_Current; \
	VARIABLE trans3_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_DO_ALARM_SUM_Unreported; \
	VARIABLE trans3_DO_ALARM_SUM_Disabled; \
	MENU trans3_DO_ALARM_SUM_page; \
	COMMAND trans3_DO_ALARM_SUM_read

#define USE_TRANS3_DO_MANDATORY_A \
	USE_TRANS3_DO_MANDATORY_BOTH; \
	MENU trans3_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS3_DO_MANDATORY_B \
	USE_TRANS3_DO_MANDATORY_BOTH; \
	VARIABLE trans3_DO_ACTUATOR_ACTION; \
	MENU trans3_DO_ACTUATOR_ACTION_page; \
	COMMAND trans3_DO_ACTUATOR_ACTION_read; \
	COMMAND trans3_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans3_DO_SELF_CALIB_CMD; \
	MENU trans3_DO_SELF_CALIB_CMD_page; \
	COMMAND trans3_DO_SELF_CALIB_CMD_read; \
	COMMAND trans3_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans3_DO_SELF_CALIB_STATUS; \
	MENU trans3_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans3_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans3_DO_VIEW_1; \
	MENU trans3_DO_VIEW_1_page; \
	MENU trans3_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS3_DO_OPTIONAL_BOTH \
	VARIABLE trans3_DO_VALVE_MAN; \
	MENU trans3_DO_VALVE_MAN_page; \
	COMMAND trans3_DO_VALVE_MAN_read; \
	COMMAND trans3_DO_VALVE_MAN_write; \
	VARIABLE trans3_DO_ACTUATOR_MAN; \
	MENU trans3_DO_ACTUATOR_MAN_page; \
	COMMAND trans3_DO_ACTUATOR_MAN_read; \
	COMMAND trans3_DO_ACTUATOR_MAN_write; \
	VARIABLE trans3_DO_VALVE_SER_NUM; \
	MENU trans3_DO_VALVE_SER_NUM_page; \
	COMMAND trans3_DO_VALVE_SER_NUM_read; \
	COMMAND trans3_DO_VALVE_SER_NUM_write; \
	VARIABLE trans3_DO_ACTUATOR_SER_NUM; \
	MENU trans3_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans3_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans3_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans3_DO_VALVE_ID; \
	MENU trans3_DO_VALVE_ID_page; \
	COMMAND trans3_DO_VALVE_ID_read; \
	COMMAND trans3_DO_VALVE_ID_write; \
	VARIABLE trans3_DO_ACTUATOR_ID; \
	MENU trans3_DO_ACTUATOR_ID_page; \
	COMMAND trans3_DO_ACTUATOR_ID_read; \
	COMMAND trans3_DO_ACTUATOR_ID_write; \
	VARIABLE trans3_DO_TRAVEL_COUNT; \
	MENU trans3_DO_TRAVEL_COUNT_page; \
	COMMAND trans3_DO_TRAVEL_COUNT_read; \
	COMMAND trans3_DO_TRAVEL_COUNT_write; \
	VARIABLE trans3_DO_TRAVEL_COUNT_LIM; \
	MENU trans3_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans3_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans3_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans3_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans3_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans3_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans3_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans3_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans3_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans3_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans3_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans3_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans3_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans3_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans3_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans3_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans3_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans3_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans3_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans3_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans3_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans3_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans3_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans3_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans3_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans3_DO_CYCLE_TEST_CMD; \
	MENU trans3_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans3_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans3_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans3_DO_CYCLE_TEST_TIME; \
	MENU trans3_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans3_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans3_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans3_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans3_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans3_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans3_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans3_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans3_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans3_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans3_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans3_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans3_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans3_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans3_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans3_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans3_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans3_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans3_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans3_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans3_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans3_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans3_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans3_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans3_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans3_DO_SENSOR_WIRE_CHECK; \
	MENU trans3_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans3_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans3_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans3_DO_POSITIONING_VALUE_D; \
	VARIABLE trans3_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans3_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans3_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans3_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans3_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans3_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans3_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans3_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans3_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans3_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans3_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans3_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans3_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans3_DO_VIEW_2; \
	MENU trans3_DO_VIEW_2_page; \
	COLLECTION trans3_DO_VIEW_3; \
	MENU trans3_DO_VIEW_3_page; \
	COLLECTION trans3_DO_VIEW_4; \
	MENU trans3_DO_VIEW_4_page

#define USE_TRANS3_DO_OPTIONAL_A \
	USE_TRANS3_DO_OPTIONAL_BOTH; \
	VARIABLE trans3_DO_ACTUATOR_ACTION; \
	MENU trans3_DO_ACTUATOR_ACTION_page; \
	COMMAND trans3_DO_ACTUATOR_ACTION_read; \
	COMMAND trans3_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans3_DO_SELF_CALIB_CMD; \
	MENU trans3_DO_SELF_CALIB_CMD_page; \
	COMMAND trans3_DO_SELF_CALIB_CMD_read; \
	COMMAND trans3_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans3_DO_SELF_CALIB_STATUS; \
	MENU trans3_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans3_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans3_DO_VIEW_1; \
	MENU trans3_DO_VIEW_1_page; \
	MENU trans3_DO_Simple_Dialog_Optional_A

#define USE_TRANS3_DO_OPTIONAL_B \
	USE_TRANS3_DO_OPTIONAL_BOTH; \
	MENU trans3_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans3_DO_)
#define USE_TRANS3_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans3_DO_)
#define USE_TRANS3_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans3_DO_)
#define USE_TRANS3_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans3_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_DO_MANDATORY_BOTH \
	BLOCK trans4_DO_block; \
	COLLECTION trans4_DO_BLOCK_OBJECT; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_DO_BLOCK_OBJECT_page; \
	COMMAND trans4_DO_BLOCK_OBJECT_read; \
	VARIABLE trans4_DO_ST_REV; \
	MENU trans4_DO_ST_REV_page; \
	COMMAND trans4_DO_ST_REV_read; \
	VARIABLE trans4_DO_TAG_DESC; \
	MENU trans4_DO_TAG_DESC_page; \
	COMMAND trans4_DO_TAG_DESC_read; \
	COMMAND trans4_DO_TAG_DESC_write; \
	VARIABLE trans4_DO_STRATEGY; \
	MENU trans4_DO_STRATEGY_page; \
	COMMAND trans4_DO_STRATEGY_read; \
	COMMAND trans4_DO_STRATEGY_write; \
	VARIABLE trans4_DO_ALERT_KEY; \
	MENU trans4_DO_ALERT_KEY_page; \
	COMMAND trans4_DO_ALERT_KEY_read; \
	COMMAND trans4_DO_ALERT_KEY_write; \
	VARIABLE trans4_DO_TARGET_MODE; \
	MENU trans4_DO_TARGET_MODE_page; \
	COMMAND trans4_DO_TARGET_MODE_read; \
	COMMAND trans4_DO_TARGET_MODE_write; \
	COLLECTION trans4_DO_MODE_BLK; \
	VARIABLE trans4_DO_MODE_BLK_Actual; \
	VARIABLE trans4_DO_MODE_BLK_Permitted; \
	VARIABLE trans4_DO_MODE_BLK_Normal; \
	MENU trans4_DO_MODE_BLK_page; \
	COMMAND trans4_DO_MODE_BLK_read; \
	COLLECTION trans4_DO_ALARM_SUM; \
	VARIABLE trans4_DO_ALARM_SUM_Current; \
	VARIABLE trans4_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_DO_ALARM_SUM_Unreported; \
	VARIABLE trans4_DO_ALARM_SUM_Disabled; \
	MENU trans4_DO_ALARM_SUM_page; \
	COMMAND trans4_DO_ALARM_SUM_read

#define USE_TRANS4_DO_MANDATORY_A \
	USE_TRANS4_DO_MANDATORY_BOTH; \
	MENU trans4_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS4_DO_MANDATORY_B \
	USE_TRANS4_DO_MANDATORY_BOTH; \
	VARIABLE trans4_DO_ACTUATOR_ACTION; \
	MENU trans4_DO_ACTUATOR_ACTION_page; \
	COMMAND trans4_DO_ACTUATOR_ACTION_read; \
	COMMAND trans4_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans4_DO_SELF_CALIB_CMD; \
	MENU trans4_DO_SELF_CALIB_CMD_page; \
	COMMAND trans4_DO_SELF_CALIB_CMD_read; \
	COMMAND trans4_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans4_DO_SELF_CALIB_STATUS; \
	MENU trans4_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans4_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans4_DO_VIEW_1; \
	MENU trans4_DO_VIEW_1_page; \
	MENU trans4_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS4_DO_OPTIONAL_BOTH \
	VARIABLE trans4_DO_VALVE_MAN; \
	MENU trans4_DO_VALVE_MAN_page; \
	COMMAND trans4_DO_VALVE_MAN_read; \
	COMMAND trans4_DO_VALVE_MAN_write; \
	VARIABLE trans4_DO_ACTUATOR_MAN; \
	MENU trans4_DO_ACTUATOR_MAN_page; \
	COMMAND trans4_DO_ACTUATOR_MAN_read; \
	COMMAND trans4_DO_ACTUATOR_MAN_write; \
	VARIABLE trans4_DO_VALVE_SER_NUM; \
	MENU trans4_DO_VALVE_SER_NUM_page; \
	COMMAND trans4_DO_VALVE_SER_NUM_read; \
	COMMAND trans4_DO_VALVE_SER_NUM_write; \
	VARIABLE trans4_DO_ACTUATOR_SER_NUM; \
	MENU trans4_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans4_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans4_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans4_DO_VALVE_ID; \
	MENU trans4_DO_VALVE_ID_page; \
	COMMAND trans4_DO_VALVE_ID_read; \
	COMMAND trans4_DO_VALVE_ID_write; \
	VARIABLE trans4_DO_ACTUATOR_ID; \
	MENU trans4_DO_ACTUATOR_ID_page; \
	COMMAND trans4_DO_ACTUATOR_ID_read; \
	COMMAND trans4_DO_ACTUATOR_ID_write; \
	VARIABLE trans4_DO_TRAVEL_COUNT; \
	MENU trans4_DO_TRAVEL_COUNT_page; \
	COMMAND trans4_DO_TRAVEL_COUNT_read; \
	COMMAND trans4_DO_TRAVEL_COUNT_write; \
	VARIABLE trans4_DO_TRAVEL_COUNT_LIM; \
	MENU trans4_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans4_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans4_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans4_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans4_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans4_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans4_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans4_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans4_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans4_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans4_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans4_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans4_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans4_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans4_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans4_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans4_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans4_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans4_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans4_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans4_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans4_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans4_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans4_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans4_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans4_DO_CYCLE_TEST_CMD; \
	MENU trans4_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans4_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans4_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans4_DO_CYCLE_TEST_TIME; \
	MENU trans4_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans4_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans4_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans4_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans4_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans4_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans4_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans4_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans4_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans4_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans4_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans4_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans4_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans4_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans4_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans4_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans4_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans4_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans4_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans4_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans4_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans4_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans4_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans4_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans4_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans4_DO_SENSOR_WIRE_CHECK; \
	MENU trans4_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans4_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans4_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans4_DO_POSITIONING_VALUE_D; \
	VARIABLE trans4_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans4_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans4_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans4_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans4_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans4_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans4_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans4_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans4_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans4_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans4_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans4_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans4_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans4_DO_VIEW_2; \
	MENU trans4_DO_VIEW_2_page; \
	COLLECTION trans4_DO_VIEW_3; \
	MENU trans4_DO_VIEW_3_page; \
	COLLECTION trans4_DO_VIEW_4; \
	MENU trans4_DO_VIEW_4_page

#define USE_TRANS4_DO_OPTIONAL_A \
	USE_TRANS4_DO_OPTIONAL_BOTH; \
	VARIABLE trans4_DO_ACTUATOR_ACTION; \
	MENU trans4_DO_ACTUATOR_ACTION_page; \
	COMMAND trans4_DO_ACTUATOR_ACTION_read; \
	COMMAND trans4_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans4_DO_SELF_CALIB_CMD; \
	MENU trans4_DO_SELF_CALIB_CMD_page; \
	COMMAND trans4_DO_SELF_CALIB_CMD_read; \
	COMMAND trans4_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans4_DO_SELF_CALIB_STATUS; \
	MENU trans4_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans4_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans4_DO_VIEW_1; \
	MENU trans4_DO_VIEW_1_page; \
	MENU trans4_DO_Simple_Dialog_Optional_A

#define USE_TRANS4_DO_OPTIONAL_B \
	USE_TRANS4_DO_OPTIONAL_BOTH; \
	MENU trans4_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans4_DO_)
#define USE_TRANS4_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans4_DO_)
#define USE_TRANS4_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans4_DO_)
#define USE_TRANS4_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans4_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_DO_MANDATORY_BOTH \
	BLOCK trans5_DO_block; \
	COLLECTION trans5_DO_BLOCK_OBJECT; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_DO_BLOCK_OBJECT_page; \
	COMMAND trans5_DO_BLOCK_OBJECT_read; \
	VARIABLE trans5_DO_ST_REV; \
	MENU trans5_DO_ST_REV_page; \
	COMMAND trans5_DO_ST_REV_read; \
	VARIABLE trans5_DO_TAG_DESC; \
	MENU trans5_DO_TAG_DESC_page; \
	COMMAND trans5_DO_TAG_DESC_read; \
	COMMAND trans5_DO_TAG_DESC_write; \
	VARIABLE trans5_DO_STRATEGY; \
	MENU trans5_DO_STRATEGY_page; \
	COMMAND trans5_DO_STRATEGY_read; \
	COMMAND trans5_DO_STRATEGY_write; \
	VARIABLE trans5_DO_ALERT_KEY; \
	MENU trans5_DO_ALERT_KEY_page; \
	COMMAND trans5_DO_ALERT_KEY_read; \
	COMMAND trans5_DO_ALERT_KEY_write; \
	VARIABLE trans5_DO_TARGET_MODE; \
	MENU trans5_DO_TARGET_MODE_page; \
	COMMAND trans5_DO_TARGET_MODE_read; \
	COMMAND trans5_DO_TARGET_MODE_write; \
	COLLECTION trans5_DO_MODE_BLK; \
	VARIABLE trans5_DO_MODE_BLK_Actual; \
	VARIABLE trans5_DO_MODE_BLK_Permitted; \
	VARIABLE trans5_DO_MODE_BLK_Normal; \
	MENU trans5_DO_MODE_BLK_page; \
	COMMAND trans5_DO_MODE_BLK_read; \
	COLLECTION trans5_DO_ALARM_SUM; \
	VARIABLE trans5_DO_ALARM_SUM_Current; \
	VARIABLE trans5_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_DO_ALARM_SUM_Unreported; \
	VARIABLE trans5_DO_ALARM_SUM_Disabled; \
	MENU trans5_DO_ALARM_SUM_page; \
	COMMAND trans5_DO_ALARM_SUM_read

#define USE_TRANS5_DO_MANDATORY_A \
	USE_TRANS5_DO_MANDATORY_BOTH; \
	MENU trans5_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS5_DO_MANDATORY_B \
	USE_TRANS5_DO_MANDATORY_BOTH; \
	VARIABLE trans5_DO_ACTUATOR_ACTION; \
	MENU trans5_DO_ACTUATOR_ACTION_page; \
	COMMAND trans5_DO_ACTUATOR_ACTION_read; \
	COMMAND trans5_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans5_DO_SELF_CALIB_CMD; \
	MENU trans5_DO_SELF_CALIB_CMD_page; \
	COMMAND trans5_DO_SELF_CALIB_CMD_read; \
	COMMAND trans5_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans5_DO_SELF_CALIB_STATUS; \
	MENU trans5_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans5_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans5_DO_VIEW_1; \
	MENU trans5_DO_VIEW_1_page; \
	MENU trans5_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS5_DO_OPTIONAL_BOTH \
	VARIABLE trans5_DO_VALVE_MAN; \
	MENU trans5_DO_VALVE_MAN_page; \
	COMMAND trans5_DO_VALVE_MAN_read; \
	COMMAND trans5_DO_VALVE_MAN_write; \
	VARIABLE trans5_DO_ACTUATOR_MAN; \
	MENU trans5_DO_ACTUATOR_MAN_page; \
	COMMAND trans5_DO_ACTUATOR_MAN_read; \
	COMMAND trans5_DO_ACTUATOR_MAN_write; \
	VARIABLE trans5_DO_VALVE_SER_NUM; \
	MENU trans5_DO_VALVE_SER_NUM_page; \
	COMMAND trans5_DO_VALVE_SER_NUM_read; \
	COMMAND trans5_DO_VALVE_SER_NUM_write; \
	VARIABLE trans5_DO_ACTUATOR_SER_NUM; \
	MENU trans5_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans5_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans5_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans5_DO_VALVE_ID; \
	MENU trans5_DO_VALVE_ID_page; \
	COMMAND trans5_DO_VALVE_ID_read; \
	COMMAND trans5_DO_VALVE_ID_write; \
	VARIABLE trans5_DO_ACTUATOR_ID; \
	MENU trans5_DO_ACTUATOR_ID_page; \
	COMMAND trans5_DO_ACTUATOR_ID_read; \
	COMMAND trans5_DO_ACTUATOR_ID_write; \
	VARIABLE trans5_DO_TRAVEL_COUNT; \
	MENU trans5_DO_TRAVEL_COUNT_page; \
	COMMAND trans5_DO_TRAVEL_COUNT_read; \
	COMMAND trans5_DO_TRAVEL_COUNT_write; \
	VARIABLE trans5_DO_TRAVEL_COUNT_LIM; \
	MENU trans5_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans5_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans5_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans5_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans5_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans5_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans5_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans5_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans5_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans5_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans5_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans5_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans5_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans5_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans5_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans5_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans5_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans5_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans5_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans5_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans5_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans5_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans5_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans5_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans5_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans5_DO_CYCLE_TEST_CMD; \
	MENU trans5_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans5_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans5_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans5_DO_CYCLE_TEST_TIME; \
	MENU trans5_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans5_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans5_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans5_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans5_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans5_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans5_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans5_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans5_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans5_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans5_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans5_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans5_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans5_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans5_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans5_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans5_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans5_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans5_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans5_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans5_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans5_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans5_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans5_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans5_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans5_DO_SENSOR_WIRE_CHECK; \
	MENU trans5_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans5_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans5_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans5_DO_POSITIONING_VALUE_D; \
	VARIABLE trans5_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans5_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans5_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans5_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans5_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans5_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans5_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans5_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans5_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans5_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans5_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans5_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans5_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans5_DO_VIEW_2; \
	MENU trans5_DO_VIEW_2_page; \
	COLLECTION trans5_DO_VIEW_3; \
	MENU trans5_DO_VIEW_3_page; \
	COLLECTION trans5_DO_VIEW_4; \
	MENU trans5_DO_VIEW_4_page

#define USE_TRANS5_DO_OPTIONAL_A \
	USE_TRANS5_DO_OPTIONAL_BOTH; \
	VARIABLE trans5_DO_ACTUATOR_ACTION; \
	MENU trans5_DO_ACTUATOR_ACTION_page; \
	COMMAND trans5_DO_ACTUATOR_ACTION_read; \
	COMMAND trans5_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans5_DO_SELF_CALIB_CMD; \
	MENU trans5_DO_SELF_CALIB_CMD_page; \
	COMMAND trans5_DO_SELF_CALIB_CMD_read; \
	COMMAND trans5_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans5_DO_SELF_CALIB_STATUS; \
	MENU trans5_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans5_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans5_DO_VIEW_1; \
	MENU trans5_DO_VIEW_1_page; \
	MENU trans5_DO_Simple_Dialog_Optional_A

#define USE_TRANS5_DO_OPTIONAL_B \
	USE_TRANS5_DO_OPTIONAL_BOTH; \
	MENU trans5_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans5_DO_)
#define USE_TRANS5_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans5_DO_)
#define USE_TRANS5_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans5_DO_)
#define USE_TRANS5_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans5_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_DO_MANDATORY_BOTH \
	BLOCK trans6_DO_block; \
	COLLECTION trans6_DO_BLOCK_OBJECT; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_DO_BLOCK_OBJECT_page; \
	COMMAND trans6_DO_BLOCK_OBJECT_read; \
	VARIABLE trans6_DO_ST_REV; \
	MENU trans6_DO_ST_REV_page; \
	COMMAND trans6_DO_ST_REV_read; \
	VARIABLE trans6_DO_TAG_DESC; \
	MENU trans6_DO_TAG_DESC_page; \
	COMMAND trans6_DO_TAG_DESC_read; \
	COMMAND trans6_DO_TAG_DESC_write; \
	VARIABLE trans6_DO_STRATEGY; \
	MENU trans6_DO_STRATEGY_page; \
	COMMAND trans6_DO_STRATEGY_read; \
	COMMAND trans6_DO_STRATEGY_write; \
	VARIABLE trans6_DO_ALERT_KEY; \
	MENU trans6_DO_ALERT_KEY_page; \
	COMMAND trans6_DO_ALERT_KEY_read; \
	COMMAND trans6_DO_ALERT_KEY_write; \
	VARIABLE trans6_DO_TARGET_MODE; \
	MENU trans6_DO_TARGET_MODE_page; \
	COMMAND trans6_DO_TARGET_MODE_read; \
	COMMAND trans6_DO_TARGET_MODE_write; \
	COLLECTION trans6_DO_MODE_BLK; \
	VARIABLE trans6_DO_MODE_BLK_Actual; \
	VARIABLE trans6_DO_MODE_BLK_Permitted; \
	VARIABLE trans6_DO_MODE_BLK_Normal; \
	MENU trans6_DO_MODE_BLK_page; \
	COMMAND trans6_DO_MODE_BLK_read; \
	COLLECTION trans6_DO_ALARM_SUM; \
	VARIABLE trans6_DO_ALARM_SUM_Current; \
	VARIABLE trans6_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_DO_ALARM_SUM_Unreported; \
	VARIABLE trans6_DO_ALARM_SUM_Disabled; \
	MENU trans6_DO_ALARM_SUM_page; \
	COMMAND trans6_DO_ALARM_SUM_read

#define USE_TRANS6_DO_MANDATORY_A \
	USE_TRANS6_DO_MANDATORY_BOTH; \
	MENU trans6_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS6_DO_MANDATORY_B \
	USE_TRANS6_DO_MANDATORY_BOTH; \
	VARIABLE trans6_DO_ACTUATOR_ACTION; \
	MENU trans6_DO_ACTUATOR_ACTION_page; \
	COMMAND trans6_DO_ACTUATOR_ACTION_read; \
	COMMAND trans6_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans6_DO_SELF_CALIB_CMD; \
	MENU trans6_DO_SELF_CALIB_CMD_page; \
	COMMAND trans6_DO_SELF_CALIB_CMD_read; \
	COMMAND trans6_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans6_DO_SELF_CALIB_STATUS; \
	MENU trans6_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans6_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans6_DO_VIEW_1; \
	MENU trans6_DO_VIEW_1_page; \
	MENU trans6_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS6_DO_OPTIONAL_BOTH \
	VARIABLE trans6_DO_VALVE_MAN; \
	MENU trans6_DO_VALVE_MAN_page; \
	COMMAND trans6_DO_VALVE_MAN_read; \
	COMMAND trans6_DO_VALVE_MAN_write; \
	VARIABLE trans6_DO_ACTUATOR_MAN; \
	MENU trans6_DO_ACTUATOR_MAN_page; \
	COMMAND trans6_DO_ACTUATOR_MAN_read; \
	COMMAND trans6_DO_ACTUATOR_MAN_write; \
	VARIABLE trans6_DO_VALVE_SER_NUM; \
	MENU trans6_DO_VALVE_SER_NUM_page; \
	COMMAND trans6_DO_VALVE_SER_NUM_read; \
	COMMAND trans6_DO_VALVE_SER_NUM_write; \
	VARIABLE trans6_DO_ACTUATOR_SER_NUM; \
	MENU trans6_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans6_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans6_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans6_DO_VALVE_ID; \
	MENU trans6_DO_VALVE_ID_page; \
	COMMAND trans6_DO_VALVE_ID_read; \
	COMMAND trans6_DO_VALVE_ID_write; \
	VARIABLE trans6_DO_ACTUATOR_ID; \
	MENU trans6_DO_ACTUATOR_ID_page; \
	COMMAND trans6_DO_ACTUATOR_ID_read; \
	COMMAND trans6_DO_ACTUATOR_ID_write; \
	VARIABLE trans6_DO_TRAVEL_COUNT; \
	MENU trans6_DO_TRAVEL_COUNT_page; \
	COMMAND trans6_DO_TRAVEL_COUNT_read; \
	COMMAND trans6_DO_TRAVEL_COUNT_write; \
	VARIABLE trans6_DO_TRAVEL_COUNT_LIM; \
	MENU trans6_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans6_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans6_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans6_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans6_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans6_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans6_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans6_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans6_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans6_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans6_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans6_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans6_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans6_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans6_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans6_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans6_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans6_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans6_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans6_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans6_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans6_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans6_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans6_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans6_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans6_DO_CYCLE_TEST_CMD; \
	MENU trans6_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans6_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans6_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans6_DO_CYCLE_TEST_TIME; \
	MENU trans6_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans6_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans6_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans6_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans6_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans6_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans6_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans6_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans6_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans6_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans6_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans6_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans6_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans6_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans6_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans6_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans6_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans6_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans6_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans6_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans6_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans6_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans6_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans6_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans6_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans6_DO_SENSOR_WIRE_CHECK; \
	MENU trans6_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans6_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans6_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans6_DO_POSITIONING_VALUE_D; \
	VARIABLE trans6_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans6_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans6_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans6_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans6_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans6_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans6_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans6_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans6_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans6_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans6_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans6_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans6_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans6_DO_VIEW_2; \
	MENU trans6_DO_VIEW_2_page; \
	COLLECTION trans6_DO_VIEW_3; \
	MENU trans6_DO_VIEW_3_page; \
	COLLECTION trans6_DO_VIEW_4; \
	MENU trans6_DO_VIEW_4_page

#define USE_TRANS6_DO_OPTIONAL_A \
	USE_TRANS6_DO_OPTIONAL_BOTH; \
	VARIABLE trans6_DO_ACTUATOR_ACTION; \
	MENU trans6_DO_ACTUATOR_ACTION_page; \
	COMMAND trans6_DO_ACTUATOR_ACTION_read; \
	COMMAND trans6_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans6_DO_SELF_CALIB_CMD; \
	MENU trans6_DO_SELF_CALIB_CMD_page; \
	COMMAND trans6_DO_SELF_CALIB_CMD_read; \
	COMMAND trans6_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans6_DO_SELF_CALIB_STATUS; \
	MENU trans6_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans6_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans6_DO_VIEW_1; \
	MENU trans6_DO_VIEW_1_page; \
	MENU trans6_DO_Simple_Dialog_Optional_A

#define USE_TRANS6_DO_OPTIONAL_B \
	USE_TRANS6_DO_OPTIONAL_BOTH; \
	MENU trans6_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans6_DO_)
#define USE_TRANS6_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans6_DO_)
#define USE_TRANS6_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans6_DO_)
#define USE_TRANS6_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans6_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_DO_MANDATORY_BOTH \
	BLOCK trans7_DO_block; \
	COLLECTION trans7_DO_BLOCK_OBJECT; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_DO_BLOCK_OBJECT_page; \
	COMMAND trans7_DO_BLOCK_OBJECT_read; \
	VARIABLE trans7_DO_ST_REV; \
	MENU trans7_DO_ST_REV_page; \
	COMMAND trans7_DO_ST_REV_read; \
	VARIABLE trans7_DO_TAG_DESC; \
	MENU trans7_DO_TAG_DESC_page; \
	COMMAND trans7_DO_TAG_DESC_read; \
	COMMAND trans7_DO_TAG_DESC_write; \
	VARIABLE trans7_DO_STRATEGY; \
	MENU trans7_DO_STRATEGY_page; \
	COMMAND trans7_DO_STRATEGY_read; \
	COMMAND trans7_DO_STRATEGY_write; \
	VARIABLE trans7_DO_ALERT_KEY; \
	MENU trans7_DO_ALERT_KEY_page; \
	COMMAND trans7_DO_ALERT_KEY_read; \
	COMMAND trans7_DO_ALERT_KEY_write; \
	VARIABLE trans7_DO_TARGET_MODE; \
	MENU trans7_DO_TARGET_MODE_page; \
	COMMAND trans7_DO_TARGET_MODE_read; \
	COMMAND trans7_DO_TARGET_MODE_write; \
	COLLECTION trans7_DO_MODE_BLK; \
	VARIABLE trans7_DO_MODE_BLK_Actual; \
	VARIABLE trans7_DO_MODE_BLK_Permitted; \
	VARIABLE trans7_DO_MODE_BLK_Normal; \
	MENU trans7_DO_MODE_BLK_page; \
	COMMAND trans7_DO_MODE_BLK_read; \
	COLLECTION trans7_DO_ALARM_SUM; \
	VARIABLE trans7_DO_ALARM_SUM_Current; \
	VARIABLE trans7_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_DO_ALARM_SUM_Unreported; \
	VARIABLE trans7_DO_ALARM_SUM_Disabled; \
	MENU trans7_DO_ALARM_SUM_page; \
	COMMAND trans7_DO_ALARM_SUM_read

#define USE_TRANS7_DO_MANDATORY_A \
	USE_TRANS7_DO_MANDATORY_BOTH; \
	MENU trans7_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS7_DO_MANDATORY_B \
	USE_TRANS7_DO_MANDATORY_BOTH; \
	VARIABLE trans7_DO_ACTUATOR_ACTION; \
	MENU trans7_DO_ACTUATOR_ACTION_page; \
	COMMAND trans7_DO_ACTUATOR_ACTION_read; \
	COMMAND trans7_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans7_DO_SELF_CALIB_CMD; \
	MENU trans7_DO_SELF_CALIB_CMD_page; \
	COMMAND trans7_DO_SELF_CALIB_CMD_read; \
	COMMAND trans7_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans7_DO_SELF_CALIB_STATUS; \
	MENU trans7_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans7_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans7_DO_VIEW_1; \
	MENU trans7_DO_VIEW_1_page; \
	MENU trans7_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS7_DO_OPTIONAL_BOTH \
	VARIABLE trans7_DO_VALVE_MAN; \
	MENU trans7_DO_VALVE_MAN_page; \
	COMMAND trans7_DO_VALVE_MAN_read; \
	COMMAND trans7_DO_VALVE_MAN_write; \
	VARIABLE trans7_DO_ACTUATOR_MAN; \
	MENU trans7_DO_ACTUATOR_MAN_page; \
	COMMAND trans7_DO_ACTUATOR_MAN_read; \
	COMMAND trans7_DO_ACTUATOR_MAN_write; \
	VARIABLE trans7_DO_VALVE_SER_NUM; \
	MENU trans7_DO_VALVE_SER_NUM_page; \
	COMMAND trans7_DO_VALVE_SER_NUM_read; \
	COMMAND trans7_DO_VALVE_SER_NUM_write; \
	VARIABLE trans7_DO_ACTUATOR_SER_NUM; \
	MENU trans7_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans7_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans7_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans7_DO_VALVE_ID; \
	MENU trans7_DO_VALVE_ID_page; \
	COMMAND trans7_DO_VALVE_ID_read; \
	COMMAND trans7_DO_VALVE_ID_write; \
	VARIABLE trans7_DO_ACTUATOR_ID; \
	MENU trans7_DO_ACTUATOR_ID_page; \
	COMMAND trans7_DO_ACTUATOR_ID_read; \
	COMMAND trans7_DO_ACTUATOR_ID_write; \
	VARIABLE trans7_DO_TRAVEL_COUNT; \
	MENU trans7_DO_TRAVEL_COUNT_page; \
	COMMAND trans7_DO_TRAVEL_COUNT_read; \
	COMMAND trans7_DO_TRAVEL_COUNT_write; \
	VARIABLE trans7_DO_TRAVEL_COUNT_LIM; \
	MENU trans7_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans7_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans7_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans7_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans7_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans7_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans7_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans7_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans7_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans7_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans7_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans7_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans7_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans7_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans7_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans7_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans7_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans7_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans7_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans7_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans7_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans7_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans7_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans7_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans7_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans7_DO_CYCLE_TEST_CMD; \
	MENU trans7_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans7_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans7_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans7_DO_CYCLE_TEST_TIME; \
	MENU trans7_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans7_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans7_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans7_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans7_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans7_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans7_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans7_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans7_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans7_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans7_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans7_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans7_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans7_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans7_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans7_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans7_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans7_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans7_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans7_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans7_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans7_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans7_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans7_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans7_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans7_DO_SENSOR_WIRE_CHECK; \
	MENU trans7_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans7_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans7_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans7_DO_POSITIONING_VALUE_D; \
	VARIABLE trans7_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans7_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans7_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans7_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans7_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans7_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans7_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans7_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans7_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans7_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans7_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans7_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans7_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans7_DO_VIEW_2; \
	MENU trans7_DO_VIEW_2_page; \
	COLLECTION trans7_DO_VIEW_3; \
	MENU trans7_DO_VIEW_3_page; \
	COLLECTION trans7_DO_VIEW_4; \
	MENU trans7_DO_VIEW_4_page

#define USE_TRANS7_DO_OPTIONAL_A \
	USE_TRANS7_DO_OPTIONAL_BOTH; \
	VARIABLE trans7_DO_ACTUATOR_ACTION; \
	MENU trans7_DO_ACTUATOR_ACTION_page; \
	COMMAND trans7_DO_ACTUATOR_ACTION_read; \
	COMMAND trans7_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans7_DO_SELF_CALIB_CMD; \
	MENU trans7_DO_SELF_CALIB_CMD_page; \
	COMMAND trans7_DO_SELF_CALIB_CMD_read; \
	COMMAND trans7_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans7_DO_SELF_CALIB_STATUS; \
	MENU trans7_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans7_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans7_DO_VIEW_1; \
	MENU trans7_DO_VIEW_1_page; \
	MENU trans7_DO_Simple_Dialog_Optional_A

#define USE_TRANS7_DO_OPTIONAL_B \
	USE_TRANS7_DO_OPTIONAL_BOTH; \
	MENU trans7_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans7_DO_)
#define USE_TRANS7_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans7_DO_)
#define USE_TRANS7_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans7_DO_)
#define USE_TRANS7_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans7_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_DO_MANDATORY_BOTH \
	BLOCK trans8_DO_block; \
	COLLECTION trans8_DO_BLOCK_OBJECT; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_DO_BLOCK_OBJECT_page; \
	COMMAND trans8_DO_BLOCK_OBJECT_read; \
	VARIABLE trans8_DO_ST_REV; \
	MENU trans8_DO_ST_REV_page; \
	COMMAND trans8_DO_ST_REV_read; \
	VARIABLE trans8_DO_TAG_DESC; \
	MENU trans8_DO_TAG_DESC_page; \
	COMMAND trans8_DO_TAG_DESC_read; \
	COMMAND trans8_DO_TAG_DESC_write; \
	VARIABLE trans8_DO_STRATEGY; \
	MENU trans8_DO_STRATEGY_page; \
	COMMAND trans8_DO_STRATEGY_read; \
	COMMAND trans8_DO_STRATEGY_write; \
	VARIABLE trans8_DO_ALERT_KEY; \
	MENU trans8_DO_ALERT_KEY_page; \
	COMMAND trans8_DO_ALERT_KEY_read; \
	COMMAND trans8_DO_ALERT_KEY_write; \
	VARIABLE trans8_DO_TARGET_MODE; \
	MENU trans8_DO_TARGET_MODE_page; \
	COMMAND trans8_DO_TARGET_MODE_read; \
	COMMAND trans8_DO_TARGET_MODE_write; \
	COLLECTION trans8_DO_MODE_BLK; \
	VARIABLE trans8_DO_MODE_BLK_Actual; \
	VARIABLE trans8_DO_MODE_BLK_Permitted; \
	VARIABLE trans8_DO_MODE_BLK_Normal; \
	MENU trans8_DO_MODE_BLK_page; \
	COMMAND trans8_DO_MODE_BLK_read; \
	COLLECTION trans8_DO_ALARM_SUM; \
	VARIABLE trans8_DO_ALARM_SUM_Current; \
	VARIABLE trans8_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_DO_ALARM_SUM_Unreported; \
	VARIABLE trans8_DO_ALARM_SUM_Disabled; \
	MENU trans8_DO_ALARM_SUM_page; \
	COMMAND trans8_DO_ALARM_SUM_read

#define USE_TRANS8_DO_MANDATORY_A \
	USE_TRANS8_DO_MANDATORY_BOTH; \
	MENU trans8_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS8_DO_MANDATORY_B \
	USE_TRANS8_DO_MANDATORY_BOTH; \
	VARIABLE trans8_DO_ACTUATOR_ACTION; \
	MENU trans8_DO_ACTUATOR_ACTION_page; \
	COMMAND trans8_DO_ACTUATOR_ACTION_read; \
	COMMAND trans8_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans8_DO_SELF_CALIB_CMD; \
	MENU trans8_DO_SELF_CALIB_CMD_page; \
	COMMAND trans8_DO_SELF_CALIB_CMD_read; \
	COMMAND trans8_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans8_DO_SELF_CALIB_STATUS; \
	MENU trans8_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans8_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans8_DO_VIEW_1; \
	MENU trans8_DO_VIEW_1_page; \
	MENU trans8_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS8_DO_OPTIONAL_BOTH \
	VARIABLE trans8_DO_VALVE_MAN; \
	MENU trans8_DO_VALVE_MAN_page; \
	COMMAND trans8_DO_VALVE_MAN_read; \
	COMMAND trans8_DO_VALVE_MAN_write; \
	VARIABLE trans8_DO_ACTUATOR_MAN; \
	MENU trans8_DO_ACTUATOR_MAN_page; \
	COMMAND trans8_DO_ACTUATOR_MAN_read; \
	COMMAND trans8_DO_ACTUATOR_MAN_write; \
	VARIABLE trans8_DO_VALVE_SER_NUM; \
	MENU trans8_DO_VALVE_SER_NUM_page; \
	COMMAND trans8_DO_VALVE_SER_NUM_read; \
	COMMAND trans8_DO_VALVE_SER_NUM_write; \
	VARIABLE trans8_DO_ACTUATOR_SER_NUM; \
	MENU trans8_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans8_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans8_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans8_DO_VALVE_ID; \
	MENU trans8_DO_VALVE_ID_page; \
	COMMAND trans8_DO_VALVE_ID_read; \
	COMMAND trans8_DO_VALVE_ID_write; \
	VARIABLE trans8_DO_ACTUATOR_ID; \
	MENU trans8_DO_ACTUATOR_ID_page; \
	COMMAND trans8_DO_ACTUATOR_ID_read; \
	COMMAND trans8_DO_ACTUATOR_ID_write; \
	VARIABLE trans8_DO_TRAVEL_COUNT; \
	MENU trans8_DO_TRAVEL_COUNT_page; \
	COMMAND trans8_DO_TRAVEL_COUNT_read; \
	COMMAND trans8_DO_TRAVEL_COUNT_write; \
	VARIABLE trans8_DO_TRAVEL_COUNT_LIM; \
	MENU trans8_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans8_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans8_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans8_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans8_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans8_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans8_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans8_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans8_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans8_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans8_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans8_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans8_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans8_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans8_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans8_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans8_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans8_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans8_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans8_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans8_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans8_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans8_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans8_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans8_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans8_DO_CYCLE_TEST_CMD; \
	MENU trans8_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans8_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans8_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans8_DO_CYCLE_TEST_TIME; \
	MENU trans8_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans8_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans8_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans8_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans8_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans8_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans8_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans8_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans8_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans8_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans8_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans8_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans8_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans8_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans8_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans8_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans8_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans8_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans8_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans8_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans8_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans8_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans8_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans8_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans8_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans8_DO_SENSOR_WIRE_CHECK; \
	MENU trans8_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans8_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans8_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans8_DO_POSITIONING_VALUE_D; \
	VARIABLE trans8_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans8_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans8_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans8_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans8_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans8_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans8_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans8_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans8_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans8_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans8_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans8_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans8_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans8_DO_VIEW_2; \
	MENU trans8_DO_VIEW_2_page; \
	COLLECTION trans8_DO_VIEW_3; \
	MENU trans8_DO_VIEW_3_page; \
	COLLECTION trans8_DO_VIEW_4; \
	MENU trans8_DO_VIEW_4_page

#define USE_TRANS8_DO_OPTIONAL_A \
	USE_TRANS8_DO_OPTIONAL_BOTH; \
	VARIABLE trans8_DO_ACTUATOR_ACTION; \
	MENU trans8_DO_ACTUATOR_ACTION_page; \
	COMMAND trans8_DO_ACTUATOR_ACTION_read; \
	COMMAND trans8_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans8_DO_SELF_CALIB_CMD; \
	MENU trans8_DO_SELF_CALIB_CMD_page; \
	COMMAND trans8_DO_SELF_CALIB_CMD_read; \
	COMMAND trans8_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans8_DO_SELF_CALIB_STATUS; \
	MENU trans8_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans8_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans8_DO_VIEW_1; \
	MENU trans8_DO_VIEW_1_page; \
	MENU trans8_DO_Simple_Dialog_Optional_A

#define USE_TRANS8_DO_OPTIONAL_B \
	USE_TRANS8_DO_OPTIONAL_BOTH; \
	MENU trans8_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans8_DO_)
#define USE_TRANS8_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans8_DO_)
#define USE_TRANS8_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans8_DO_)
#define USE_TRANS8_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans8_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_DO_MANDATORY_BOTH \
	BLOCK trans9_DO_block; \
	COLLECTION trans9_DO_BLOCK_OBJECT; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_DO_BLOCK_OBJECT_page; \
	COMMAND trans9_DO_BLOCK_OBJECT_read; \
	VARIABLE trans9_DO_ST_REV; \
	MENU trans9_DO_ST_REV_page; \
	COMMAND trans9_DO_ST_REV_read; \
	VARIABLE trans9_DO_TAG_DESC; \
	MENU trans9_DO_TAG_DESC_page; \
	COMMAND trans9_DO_TAG_DESC_read; \
	COMMAND trans9_DO_TAG_DESC_write; \
	VARIABLE trans9_DO_STRATEGY; \
	MENU trans9_DO_STRATEGY_page; \
	COMMAND trans9_DO_STRATEGY_read; \
	COMMAND trans9_DO_STRATEGY_write; \
	VARIABLE trans9_DO_ALERT_KEY; \
	MENU trans9_DO_ALERT_KEY_page; \
	COMMAND trans9_DO_ALERT_KEY_read; \
	COMMAND trans9_DO_ALERT_KEY_write; \
	VARIABLE trans9_DO_TARGET_MODE; \
	MENU trans9_DO_TARGET_MODE_page; \
	COMMAND trans9_DO_TARGET_MODE_read; \
	COMMAND trans9_DO_TARGET_MODE_write; \
	COLLECTION trans9_DO_MODE_BLK; \
	VARIABLE trans9_DO_MODE_BLK_Actual; \
	VARIABLE trans9_DO_MODE_BLK_Permitted; \
	VARIABLE trans9_DO_MODE_BLK_Normal; \
	MENU trans9_DO_MODE_BLK_page; \
	COMMAND trans9_DO_MODE_BLK_read; \
	COLLECTION trans9_DO_ALARM_SUM; \
	VARIABLE trans9_DO_ALARM_SUM_Current; \
	VARIABLE trans9_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_DO_ALARM_SUM_Unreported; \
	VARIABLE trans9_DO_ALARM_SUM_Disabled; \
	MENU trans9_DO_ALARM_SUM_page; \
	COMMAND trans9_DO_ALARM_SUM_read

#define USE_TRANS9_DO_MANDATORY_A \
	USE_TRANS9_DO_MANDATORY_BOTH; \
	MENU trans9_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS9_DO_MANDATORY_B \
	USE_TRANS9_DO_MANDATORY_BOTH; \
	VARIABLE trans9_DO_ACTUATOR_ACTION; \
	MENU trans9_DO_ACTUATOR_ACTION_page; \
	COMMAND trans9_DO_ACTUATOR_ACTION_read; \
	COMMAND trans9_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans9_DO_SELF_CALIB_CMD; \
	MENU trans9_DO_SELF_CALIB_CMD_page; \
	COMMAND trans9_DO_SELF_CALIB_CMD_read; \
	COMMAND trans9_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans9_DO_SELF_CALIB_STATUS; \
	MENU trans9_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans9_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans9_DO_VIEW_1; \
	MENU trans9_DO_VIEW_1_page; \
	MENU trans9_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS9_DO_OPTIONAL_BOTH \
	VARIABLE trans9_DO_VALVE_MAN; \
	MENU trans9_DO_VALVE_MAN_page; \
	COMMAND trans9_DO_VALVE_MAN_read; \
	COMMAND trans9_DO_VALVE_MAN_write; \
	VARIABLE trans9_DO_ACTUATOR_MAN; \
	MENU trans9_DO_ACTUATOR_MAN_page; \
	COMMAND trans9_DO_ACTUATOR_MAN_read; \
	COMMAND trans9_DO_ACTUATOR_MAN_write; \
	VARIABLE trans9_DO_VALVE_SER_NUM; \
	MENU trans9_DO_VALVE_SER_NUM_page; \
	COMMAND trans9_DO_VALVE_SER_NUM_read; \
	COMMAND trans9_DO_VALVE_SER_NUM_write; \
	VARIABLE trans9_DO_ACTUATOR_SER_NUM; \
	MENU trans9_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans9_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans9_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans9_DO_VALVE_ID; \
	MENU trans9_DO_VALVE_ID_page; \
	COMMAND trans9_DO_VALVE_ID_read; \
	COMMAND trans9_DO_VALVE_ID_write; \
	VARIABLE trans9_DO_ACTUATOR_ID; \
	MENU trans9_DO_ACTUATOR_ID_page; \
	COMMAND trans9_DO_ACTUATOR_ID_read; \
	COMMAND trans9_DO_ACTUATOR_ID_write; \
	VARIABLE trans9_DO_TRAVEL_COUNT; \
	MENU trans9_DO_TRAVEL_COUNT_page; \
	COMMAND trans9_DO_TRAVEL_COUNT_read; \
	COMMAND trans9_DO_TRAVEL_COUNT_write; \
	VARIABLE trans9_DO_TRAVEL_COUNT_LIM; \
	MENU trans9_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans9_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans9_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans9_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans9_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans9_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans9_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans9_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans9_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans9_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans9_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans9_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans9_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans9_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans9_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans9_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans9_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans9_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans9_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans9_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans9_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans9_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans9_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans9_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans9_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans9_DO_CYCLE_TEST_CMD; \
	MENU trans9_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans9_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans9_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans9_DO_CYCLE_TEST_TIME; \
	MENU trans9_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans9_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans9_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans9_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans9_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans9_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans9_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans9_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans9_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans9_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans9_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans9_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans9_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans9_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans9_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans9_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans9_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans9_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans9_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans9_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans9_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans9_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans9_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans9_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans9_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans9_DO_SENSOR_WIRE_CHECK; \
	MENU trans9_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans9_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans9_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans9_DO_POSITIONING_VALUE_D; \
	VARIABLE trans9_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans9_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans9_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans9_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans9_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans9_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans9_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans9_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans9_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans9_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans9_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans9_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans9_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans9_DO_VIEW_2; \
	MENU trans9_DO_VIEW_2_page; \
	COLLECTION trans9_DO_VIEW_3; \
	MENU trans9_DO_VIEW_3_page; \
	COLLECTION trans9_DO_VIEW_4; \
	MENU trans9_DO_VIEW_4_page

#define USE_TRANS9_DO_OPTIONAL_A \
	USE_TRANS9_DO_OPTIONAL_BOTH; \
	VARIABLE trans9_DO_ACTUATOR_ACTION; \
	MENU trans9_DO_ACTUATOR_ACTION_page; \
	COMMAND trans9_DO_ACTUATOR_ACTION_read; \
	COMMAND trans9_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans9_DO_SELF_CALIB_CMD; \
	MENU trans9_DO_SELF_CALIB_CMD_page; \
	COMMAND trans9_DO_SELF_CALIB_CMD_read; \
	COMMAND trans9_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans9_DO_SELF_CALIB_STATUS; \
	MENU trans9_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans9_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans9_DO_VIEW_1; \
	MENU trans9_DO_VIEW_1_page; \
	MENU trans9_DO_Simple_Dialog_Optional_A

#define USE_TRANS9_DO_OPTIONAL_B \
	USE_TRANS9_DO_OPTIONAL_BOTH; \
	MENU trans9_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans9_DO_)
#define USE_TRANS9_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans9_DO_)
#define USE_TRANS9_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans9_DO_)
#define USE_TRANS9_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans9_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_DO_MANDATORY_BOTH \
	BLOCK trans10_DO_block; \
	COLLECTION trans10_DO_BLOCK_OBJECT; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_DO_BLOCK_OBJECT_page; \
	COMMAND trans10_DO_BLOCK_OBJECT_read; \
	VARIABLE trans10_DO_ST_REV; \
	MENU trans10_DO_ST_REV_page; \
	COMMAND trans10_DO_ST_REV_read; \
	VARIABLE trans10_DO_TAG_DESC; \
	MENU trans10_DO_TAG_DESC_page; \
	COMMAND trans10_DO_TAG_DESC_read; \
	COMMAND trans10_DO_TAG_DESC_write; \
	VARIABLE trans10_DO_STRATEGY; \
	MENU trans10_DO_STRATEGY_page; \
	COMMAND trans10_DO_STRATEGY_read; \
	COMMAND trans10_DO_STRATEGY_write; \
	VARIABLE trans10_DO_ALERT_KEY; \
	MENU trans10_DO_ALERT_KEY_page; \
	COMMAND trans10_DO_ALERT_KEY_read; \
	COMMAND trans10_DO_ALERT_KEY_write; \
	VARIABLE trans10_DO_TARGET_MODE; \
	MENU trans10_DO_TARGET_MODE_page; \
	COMMAND trans10_DO_TARGET_MODE_read; \
	COMMAND trans10_DO_TARGET_MODE_write; \
	COLLECTION trans10_DO_MODE_BLK; \
	VARIABLE trans10_DO_MODE_BLK_Actual; \
	VARIABLE trans10_DO_MODE_BLK_Permitted; \
	VARIABLE trans10_DO_MODE_BLK_Normal; \
	MENU trans10_DO_MODE_BLK_page; \
	COMMAND trans10_DO_MODE_BLK_read; \
	COLLECTION trans10_DO_ALARM_SUM; \
	VARIABLE trans10_DO_ALARM_SUM_Current; \
	VARIABLE trans10_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_DO_ALARM_SUM_Unreported; \
	VARIABLE trans10_DO_ALARM_SUM_Disabled; \
	MENU trans10_DO_ALARM_SUM_page; \
	COMMAND trans10_DO_ALARM_SUM_read

#define USE_TRANS10_DO_MANDATORY_A \
	USE_TRANS10_DO_MANDATORY_BOTH; \
	MENU trans10_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS10_DO_MANDATORY_B \
	USE_TRANS10_DO_MANDATORY_BOTH; \
	VARIABLE trans10_DO_ACTUATOR_ACTION; \
	MENU trans10_DO_ACTUATOR_ACTION_page; \
	COMMAND trans10_DO_ACTUATOR_ACTION_read; \
	COMMAND trans10_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans10_DO_SELF_CALIB_CMD; \
	MENU trans10_DO_SELF_CALIB_CMD_page; \
	COMMAND trans10_DO_SELF_CALIB_CMD_read; \
	COMMAND trans10_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans10_DO_SELF_CALIB_STATUS; \
	MENU trans10_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans10_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans10_DO_VIEW_1; \
	MENU trans10_DO_VIEW_1_page; \
	MENU trans10_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS10_DO_OPTIONAL_BOTH \
	VARIABLE trans10_DO_VALVE_MAN; \
	MENU trans10_DO_VALVE_MAN_page; \
	COMMAND trans10_DO_VALVE_MAN_read; \
	COMMAND trans10_DO_VALVE_MAN_write; \
	VARIABLE trans10_DO_ACTUATOR_MAN; \
	MENU trans10_DO_ACTUATOR_MAN_page; \
	COMMAND trans10_DO_ACTUATOR_MAN_read; \
	COMMAND trans10_DO_ACTUATOR_MAN_write; \
	VARIABLE trans10_DO_VALVE_SER_NUM; \
	MENU trans10_DO_VALVE_SER_NUM_page; \
	COMMAND trans10_DO_VALVE_SER_NUM_read; \
	COMMAND trans10_DO_VALVE_SER_NUM_write; \
	VARIABLE trans10_DO_ACTUATOR_SER_NUM; \
	MENU trans10_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans10_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans10_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans10_DO_VALVE_ID; \
	MENU trans10_DO_VALVE_ID_page; \
	COMMAND trans10_DO_VALVE_ID_read; \
	COMMAND trans10_DO_VALVE_ID_write; \
	VARIABLE trans10_DO_ACTUATOR_ID; \
	MENU trans10_DO_ACTUATOR_ID_page; \
	COMMAND trans10_DO_ACTUATOR_ID_read; \
	COMMAND trans10_DO_ACTUATOR_ID_write; \
	VARIABLE trans10_DO_TRAVEL_COUNT; \
	MENU trans10_DO_TRAVEL_COUNT_page; \
	COMMAND trans10_DO_TRAVEL_COUNT_read; \
	COMMAND trans10_DO_TRAVEL_COUNT_write; \
	VARIABLE trans10_DO_TRAVEL_COUNT_LIM; \
	MENU trans10_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans10_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans10_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans10_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans10_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans10_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans10_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans10_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans10_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans10_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans10_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans10_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans10_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans10_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans10_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans10_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans10_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans10_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans10_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans10_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans10_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans10_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans10_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans10_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans10_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans10_DO_CYCLE_TEST_CMD; \
	MENU trans10_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans10_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans10_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans10_DO_CYCLE_TEST_TIME; \
	MENU trans10_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans10_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans10_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans10_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans10_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans10_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans10_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans10_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans10_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans10_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans10_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans10_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans10_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans10_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans10_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans10_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans10_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans10_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans10_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans10_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans10_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans10_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans10_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans10_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans10_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans10_DO_SENSOR_WIRE_CHECK; \
	MENU trans10_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans10_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans10_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans10_DO_POSITIONING_VALUE_D; \
	VARIABLE trans10_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans10_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans10_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans10_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans10_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans10_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans10_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans10_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans10_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans10_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans10_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans10_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans10_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans10_DO_VIEW_2; \
	MENU trans10_DO_VIEW_2_page; \
	COLLECTION trans10_DO_VIEW_3; \
	MENU trans10_DO_VIEW_3_page; \
	COLLECTION trans10_DO_VIEW_4; \
	MENU trans10_DO_VIEW_4_page

#define USE_TRANS10_DO_OPTIONAL_A \
	USE_TRANS10_DO_OPTIONAL_BOTH; \
	VARIABLE trans10_DO_ACTUATOR_ACTION; \
	MENU trans10_DO_ACTUATOR_ACTION_page; \
	COMMAND trans10_DO_ACTUATOR_ACTION_read; \
	COMMAND trans10_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans10_DO_SELF_CALIB_CMD; \
	MENU trans10_DO_SELF_CALIB_CMD_page; \
	COMMAND trans10_DO_SELF_CALIB_CMD_read; \
	COMMAND trans10_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans10_DO_SELF_CALIB_STATUS; \
	MENU trans10_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans10_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans10_DO_VIEW_1; \
	MENU trans10_DO_VIEW_1_page; \
	MENU trans10_DO_Simple_Dialog_Optional_A

#define USE_TRANS10_DO_OPTIONAL_B \
	USE_TRANS10_DO_OPTIONAL_BOTH; \
	MENU trans10_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans10_DO_)
#define USE_TRANS10_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans10_DO_)
#define USE_TRANS10_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans10_DO_)
#define USE_TRANS10_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans10_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_DO_MANDATORY_BOTH \
	BLOCK trans11_DO_block; \
	COLLECTION trans11_DO_BLOCK_OBJECT; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_DO_BLOCK_OBJECT_page; \
	COMMAND trans11_DO_BLOCK_OBJECT_read; \
	VARIABLE trans11_DO_ST_REV; \
	MENU trans11_DO_ST_REV_page; \
	COMMAND trans11_DO_ST_REV_read; \
	VARIABLE trans11_DO_TAG_DESC; \
	MENU trans11_DO_TAG_DESC_page; \
	COMMAND trans11_DO_TAG_DESC_read; \
	COMMAND trans11_DO_TAG_DESC_write; \
	VARIABLE trans11_DO_STRATEGY; \
	MENU trans11_DO_STRATEGY_page; \
	COMMAND trans11_DO_STRATEGY_read; \
	COMMAND trans11_DO_STRATEGY_write; \
	VARIABLE trans11_DO_ALERT_KEY; \
	MENU trans11_DO_ALERT_KEY_page; \
	COMMAND trans11_DO_ALERT_KEY_read; \
	COMMAND trans11_DO_ALERT_KEY_write; \
	VARIABLE trans11_DO_TARGET_MODE; \
	MENU trans11_DO_TARGET_MODE_page; \
	COMMAND trans11_DO_TARGET_MODE_read; \
	COMMAND trans11_DO_TARGET_MODE_write; \
	COLLECTION trans11_DO_MODE_BLK; \
	VARIABLE trans11_DO_MODE_BLK_Actual; \
	VARIABLE trans11_DO_MODE_BLK_Permitted; \
	VARIABLE trans11_DO_MODE_BLK_Normal; \
	MENU trans11_DO_MODE_BLK_page; \
	COMMAND trans11_DO_MODE_BLK_read; \
	COLLECTION trans11_DO_ALARM_SUM; \
	VARIABLE trans11_DO_ALARM_SUM_Current; \
	VARIABLE trans11_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_DO_ALARM_SUM_Unreported; \
	VARIABLE trans11_DO_ALARM_SUM_Disabled; \
	MENU trans11_DO_ALARM_SUM_page; \
	COMMAND trans11_DO_ALARM_SUM_read

#define USE_TRANS11_DO_MANDATORY_A \
	USE_TRANS11_DO_MANDATORY_BOTH; \
	MENU trans11_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS11_DO_MANDATORY_B \
	USE_TRANS11_DO_MANDATORY_BOTH; \
	VARIABLE trans11_DO_ACTUATOR_ACTION; \
	MENU trans11_DO_ACTUATOR_ACTION_page; \
	COMMAND trans11_DO_ACTUATOR_ACTION_read; \
	COMMAND trans11_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans11_DO_SELF_CALIB_CMD; \
	MENU trans11_DO_SELF_CALIB_CMD_page; \
	COMMAND trans11_DO_SELF_CALIB_CMD_read; \
	COMMAND trans11_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans11_DO_SELF_CALIB_STATUS; \
	MENU trans11_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans11_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans11_DO_VIEW_1; \
	MENU trans11_DO_VIEW_1_page; \
	MENU trans11_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS11_DO_OPTIONAL_BOTH \
	VARIABLE trans11_DO_VALVE_MAN; \
	MENU trans11_DO_VALVE_MAN_page; \
	COMMAND trans11_DO_VALVE_MAN_read; \
	COMMAND trans11_DO_VALVE_MAN_write; \
	VARIABLE trans11_DO_ACTUATOR_MAN; \
	MENU trans11_DO_ACTUATOR_MAN_page; \
	COMMAND trans11_DO_ACTUATOR_MAN_read; \
	COMMAND trans11_DO_ACTUATOR_MAN_write; \
	VARIABLE trans11_DO_VALVE_SER_NUM; \
	MENU trans11_DO_VALVE_SER_NUM_page; \
	COMMAND trans11_DO_VALVE_SER_NUM_read; \
	COMMAND trans11_DO_VALVE_SER_NUM_write; \
	VARIABLE trans11_DO_ACTUATOR_SER_NUM; \
	MENU trans11_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans11_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans11_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans11_DO_VALVE_ID; \
	MENU trans11_DO_VALVE_ID_page; \
	COMMAND trans11_DO_VALVE_ID_read; \
	COMMAND trans11_DO_VALVE_ID_write; \
	VARIABLE trans11_DO_ACTUATOR_ID; \
	MENU trans11_DO_ACTUATOR_ID_page; \
	COMMAND trans11_DO_ACTUATOR_ID_read; \
	COMMAND trans11_DO_ACTUATOR_ID_write; \
	VARIABLE trans11_DO_TRAVEL_COUNT; \
	MENU trans11_DO_TRAVEL_COUNT_page; \
	COMMAND trans11_DO_TRAVEL_COUNT_read; \
	COMMAND trans11_DO_TRAVEL_COUNT_write; \
	VARIABLE trans11_DO_TRAVEL_COUNT_LIM; \
	MENU trans11_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans11_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans11_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans11_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans11_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans11_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans11_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans11_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans11_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans11_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans11_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans11_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans11_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans11_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans11_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans11_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans11_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans11_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans11_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans11_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans11_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans11_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans11_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans11_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans11_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans11_DO_CYCLE_TEST_CMD; \
	MENU trans11_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans11_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans11_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans11_DO_CYCLE_TEST_TIME; \
	MENU trans11_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans11_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans11_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans11_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans11_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans11_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans11_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans11_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans11_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans11_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans11_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans11_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans11_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans11_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans11_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans11_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans11_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans11_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans11_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans11_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans11_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans11_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans11_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans11_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans11_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans11_DO_SENSOR_WIRE_CHECK; \
	MENU trans11_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans11_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans11_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans11_DO_POSITIONING_VALUE_D; \
	VARIABLE trans11_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans11_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans11_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans11_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans11_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans11_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans11_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans11_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans11_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans11_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans11_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans11_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans11_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans11_DO_VIEW_2; \
	MENU trans11_DO_VIEW_2_page; \
	COLLECTION trans11_DO_VIEW_3; \
	MENU trans11_DO_VIEW_3_page; \
	COLLECTION trans11_DO_VIEW_4; \
	MENU trans11_DO_VIEW_4_page

#define USE_TRANS11_DO_OPTIONAL_A \
	USE_TRANS11_DO_OPTIONAL_BOTH; \
	VARIABLE trans11_DO_ACTUATOR_ACTION; \
	MENU trans11_DO_ACTUATOR_ACTION_page; \
	COMMAND trans11_DO_ACTUATOR_ACTION_read; \
	COMMAND trans11_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans11_DO_SELF_CALIB_CMD; \
	MENU trans11_DO_SELF_CALIB_CMD_page; \
	COMMAND trans11_DO_SELF_CALIB_CMD_read; \
	COMMAND trans11_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans11_DO_SELF_CALIB_STATUS; \
	MENU trans11_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans11_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans11_DO_VIEW_1; \
	MENU trans11_DO_VIEW_1_page; \
	MENU trans11_DO_Simple_Dialog_Optional_A

#define USE_TRANS11_DO_OPTIONAL_B \
	USE_TRANS11_DO_OPTIONAL_BOTH; \
	MENU trans11_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans11_DO_)
#define USE_TRANS11_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans11_DO_)
#define USE_TRANS11_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans11_DO_)
#define USE_TRANS11_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans11_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_DO_MANDATORY_BOTH \
	BLOCK trans12_DO_block; \
	COLLECTION trans12_DO_BLOCK_OBJECT; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_DO_BLOCK_OBJECT_page; \
	COMMAND trans12_DO_BLOCK_OBJECT_read; \
	VARIABLE trans12_DO_ST_REV; \
	MENU trans12_DO_ST_REV_page; \
	COMMAND trans12_DO_ST_REV_read; \
	VARIABLE trans12_DO_TAG_DESC; \
	MENU trans12_DO_TAG_DESC_page; \
	COMMAND trans12_DO_TAG_DESC_read; \
	COMMAND trans12_DO_TAG_DESC_write; \
	VARIABLE trans12_DO_STRATEGY; \
	MENU trans12_DO_STRATEGY_page; \
	COMMAND trans12_DO_STRATEGY_read; \
	COMMAND trans12_DO_STRATEGY_write; \
	VARIABLE trans12_DO_ALERT_KEY; \
	MENU trans12_DO_ALERT_KEY_page; \
	COMMAND trans12_DO_ALERT_KEY_read; \
	COMMAND trans12_DO_ALERT_KEY_write; \
	VARIABLE trans12_DO_TARGET_MODE; \
	MENU trans12_DO_TARGET_MODE_page; \
	COMMAND trans12_DO_TARGET_MODE_read; \
	COMMAND trans12_DO_TARGET_MODE_write; \
	COLLECTION trans12_DO_MODE_BLK; \
	VARIABLE trans12_DO_MODE_BLK_Actual; \
	VARIABLE trans12_DO_MODE_BLK_Permitted; \
	VARIABLE trans12_DO_MODE_BLK_Normal; \
	MENU trans12_DO_MODE_BLK_page; \
	COMMAND trans12_DO_MODE_BLK_read; \
	COLLECTION trans12_DO_ALARM_SUM; \
	VARIABLE trans12_DO_ALARM_SUM_Current; \
	VARIABLE trans12_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_DO_ALARM_SUM_Unreported; \
	VARIABLE trans12_DO_ALARM_SUM_Disabled; \
	MENU trans12_DO_ALARM_SUM_page; \
	COMMAND trans12_DO_ALARM_SUM_read

#define USE_TRANS12_DO_MANDATORY_A \
	USE_TRANS12_DO_MANDATORY_BOTH; \
	MENU trans12_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS12_DO_MANDATORY_B \
	USE_TRANS12_DO_MANDATORY_BOTH; \
	VARIABLE trans12_DO_ACTUATOR_ACTION; \
	MENU trans12_DO_ACTUATOR_ACTION_page; \
	COMMAND trans12_DO_ACTUATOR_ACTION_read; \
	COMMAND trans12_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans12_DO_SELF_CALIB_CMD; \
	MENU trans12_DO_SELF_CALIB_CMD_page; \
	COMMAND trans12_DO_SELF_CALIB_CMD_read; \
	COMMAND trans12_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans12_DO_SELF_CALIB_STATUS; \
	MENU trans12_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans12_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans12_DO_VIEW_1; \
	MENU trans12_DO_VIEW_1_page; \
	MENU trans12_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS12_DO_OPTIONAL_BOTH \
	VARIABLE trans12_DO_VALVE_MAN; \
	MENU trans12_DO_VALVE_MAN_page; \
	COMMAND trans12_DO_VALVE_MAN_read; \
	COMMAND trans12_DO_VALVE_MAN_write; \
	VARIABLE trans12_DO_ACTUATOR_MAN; \
	MENU trans12_DO_ACTUATOR_MAN_page; \
	COMMAND trans12_DO_ACTUATOR_MAN_read; \
	COMMAND trans12_DO_ACTUATOR_MAN_write; \
	VARIABLE trans12_DO_VALVE_SER_NUM; \
	MENU trans12_DO_VALVE_SER_NUM_page; \
	COMMAND trans12_DO_VALVE_SER_NUM_read; \
	COMMAND trans12_DO_VALVE_SER_NUM_write; \
	VARIABLE trans12_DO_ACTUATOR_SER_NUM; \
	MENU trans12_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans12_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans12_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans12_DO_VALVE_ID; \
	MENU trans12_DO_VALVE_ID_page; \
	COMMAND trans12_DO_VALVE_ID_read; \
	COMMAND trans12_DO_VALVE_ID_write; \
	VARIABLE trans12_DO_ACTUATOR_ID; \
	MENU trans12_DO_ACTUATOR_ID_page; \
	COMMAND trans12_DO_ACTUATOR_ID_read; \
	COMMAND trans12_DO_ACTUATOR_ID_write; \
	VARIABLE trans12_DO_TRAVEL_COUNT; \
	MENU trans12_DO_TRAVEL_COUNT_page; \
	COMMAND trans12_DO_TRAVEL_COUNT_read; \
	COMMAND trans12_DO_TRAVEL_COUNT_write; \
	VARIABLE trans12_DO_TRAVEL_COUNT_LIM; \
	MENU trans12_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans12_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans12_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans12_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans12_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans12_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans12_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans12_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans12_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans12_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans12_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans12_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans12_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans12_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans12_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans12_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans12_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans12_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans12_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans12_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans12_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans12_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans12_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans12_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans12_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans12_DO_CYCLE_TEST_CMD; \
	MENU trans12_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans12_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans12_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans12_DO_CYCLE_TEST_TIME; \
	MENU trans12_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans12_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans12_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans12_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans12_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans12_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans12_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans12_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans12_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans12_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans12_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans12_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans12_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans12_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans12_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans12_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans12_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans12_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans12_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans12_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans12_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans12_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans12_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans12_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans12_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans12_DO_SENSOR_WIRE_CHECK; \
	MENU trans12_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans12_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans12_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans12_DO_POSITIONING_VALUE_D; \
	VARIABLE trans12_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans12_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans12_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans12_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans12_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans12_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans12_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans12_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans12_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans12_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans12_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans12_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans12_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans12_DO_VIEW_2; \
	MENU trans12_DO_VIEW_2_page; \
	COLLECTION trans12_DO_VIEW_3; \
	MENU trans12_DO_VIEW_3_page; \
	COLLECTION trans12_DO_VIEW_4; \
	MENU trans12_DO_VIEW_4_page

#define USE_TRANS12_DO_OPTIONAL_A \
	USE_TRANS12_DO_OPTIONAL_BOTH; \
	VARIABLE trans12_DO_ACTUATOR_ACTION; \
	MENU trans12_DO_ACTUATOR_ACTION_page; \
	COMMAND trans12_DO_ACTUATOR_ACTION_read; \
	COMMAND trans12_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans12_DO_SELF_CALIB_CMD; \
	MENU trans12_DO_SELF_CALIB_CMD_page; \
	COMMAND trans12_DO_SELF_CALIB_CMD_read; \
	COMMAND trans12_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans12_DO_SELF_CALIB_STATUS; \
	MENU trans12_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans12_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans12_DO_VIEW_1; \
	MENU trans12_DO_VIEW_1_page; \
	MENU trans12_DO_Simple_Dialog_Optional_A

#define USE_TRANS12_DO_OPTIONAL_B \
	USE_TRANS12_DO_OPTIONAL_BOTH; \
	MENU trans12_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans12_DO_)
#define USE_TRANS12_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans12_DO_)
#define USE_TRANS12_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans12_DO_)
#define USE_TRANS12_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans12_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_DO_MANDATORY_BOTH \
	BLOCK trans13_DO_block; \
	COLLECTION trans13_DO_BLOCK_OBJECT; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_DO_BLOCK_OBJECT_page; \
	COMMAND trans13_DO_BLOCK_OBJECT_read; \
	VARIABLE trans13_DO_ST_REV; \
	MENU trans13_DO_ST_REV_page; \
	COMMAND trans13_DO_ST_REV_read; \
	VARIABLE trans13_DO_TAG_DESC; \
	MENU trans13_DO_TAG_DESC_page; \
	COMMAND trans13_DO_TAG_DESC_read; \
	COMMAND trans13_DO_TAG_DESC_write; \
	VARIABLE trans13_DO_STRATEGY; \
	MENU trans13_DO_STRATEGY_page; \
	COMMAND trans13_DO_STRATEGY_read; \
	COMMAND trans13_DO_STRATEGY_write; \
	VARIABLE trans13_DO_ALERT_KEY; \
	MENU trans13_DO_ALERT_KEY_page; \
	COMMAND trans13_DO_ALERT_KEY_read; \
	COMMAND trans13_DO_ALERT_KEY_write; \
	VARIABLE trans13_DO_TARGET_MODE; \
	MENU trans13_DO_TARGET_MODE_page; \
	COMMAND trans13_DO_TARGET_MODE_read; \
	COMMAND trans13_DO_TARGET_MODE_write; \
	COLLECTION trans13_DO_MODE_BLK; \
	VARIABLE trans13_DO_MODE_BLK_Actual; \
	VARIABLE trans13_DO_MODE_BLK_Permitted; \
	VARIABLE trans13_DO_MODE_BLK_Normal; \
	MENU trans13_DO_MODE_BLK_page; \
	COMMAND trans13_DO_MODE_BLK_read; \
	COLLECTION trans13_DO_ALARM_SUM; \
	VARIABLE trans13_DO_ALARM_SUM_Current; \
	VARIABLE trans13_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_DO_ALARM_SUM_Unreported; \
	VARIABLE trans13_DO_ALARM_SUM_Disabled; \
	MENU trans13_DO_ALARM_SUM_page; \
	COMMAND trans13_DO_ALARM_SUM_read

#define USE_TRANS13_DO_MANDATORY_A \
	USE_TRANS13_DO_MANDATORY_BOTH; \
	MENU trans13_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS13_DO_MANDATORY_B \
	USE_TRANS13_DO_MANDATORY_BOTH; \
	VARIABLE trans13_DO_ACTUATOR_ACTION; \
	MENU trans13_DO_ACTUATOR_ACTION_page; \
	COMMAND trans13_DO_ACTUATOR_ACTION_read; \
	COMMAND trans13_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans13_DO_SELF_CALIB_CMD; \
	MENU trans13_DO_SELF_CALIB_CMD_page; \
	COMMAND trans13_DO_SELF_CALIB_CMD_read; \
	COMMAND trans13_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans13_DO_SELF_CALIB_STATUS; \
	MENU trans13_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans13_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans13_DO_VIEW_1; \
	MENU trans13_DO_VIEW_1_page; \
	MENU trans13_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS13_DO_OPTIONAL_BOTH \
	VARIABLE trans13_DO_VALVE_MAN; \
	MENU trans13_DO_VALVE_MAN_page; \
	COMMAND trans13_DO_VALVE_MAN_read; \
	COMMAND trans13_DO_VALVE_MAN_write; \
	VARIABLE trans13_DO_ACTUATOR_MAN; \
	MENU trans13_DO_ACTUATOR_MAN_page; \
	COMMAND trans13_DO_ACTUATOR_MAN_read; \
	COMMAND trans13_DO_ACTUATOR_MAN_write; \
	VARIABLE trans13_DO_VALVE_SER_NUM; \
	MENU trans13_DO_VALVE_SER_NUM_page; \
	COMMAND trans13_DO_VALVE_SER_NUM_read; \
	COMMAND trans13_DO_VALVE_SER_NUM_write; \
	VARIABLE trans13_DO_ACTUATOR_SER_NUM; \
	MENU trans13_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans13_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans13_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans13_DO_VALVE_ID; \
	MENU trans13_DO_VALVE_ID_page; \
	COMMAND trans13_DO_VALVE_ID_read; \
	COMMAND trans13_DO_VALVE_ID_write; \
	VARIABLE trans13_DO_ACTUATOR_ID; \
	MENU trans13_DO_ACTUATOR_ID_page; \
	COMMAND trans13_DO_ACTUATOR_ID_read; \
	COMMAND trans13_DO_ACTUATOR_ID_write; \
	VARIABLE trans13_DO_TRAVEL_COUNT; \
	MENU trans13_DO_TRAVEL_COUNT_page; \
	COMMAND trans13_DO_TRAVEL_COUNT_read; \
	COMMAND trans13_DO_TRAVEL_COUNT_write; \
	VARIABLE trans13_DO_TRAVEL_COUNT_LIM; \
	MENU trans13_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans13_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans13_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans13_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans13_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans13_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans13_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans13_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans13_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans13_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans13_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans13_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans13_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans13_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans13_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans13_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans13_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans13_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans13_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans13_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans13_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans13_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans13_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans13_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans13_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans13_DO_CYCLE_TEST_CMD; \
	MENU trans13_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans13_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans13_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans13_DO_CYCLE_TEST_TIME; \
	MENU trans13_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans13_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans13_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans13_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans13_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans13_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans13_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans13_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans13_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans13_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans13_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans13_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans13_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans13_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans13_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans13_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans13_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans13_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans13_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans13_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans13_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans13_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans13_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans13_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans13_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans13_DO_SENSOR_WIRE_CHECK; \
	MENU trans13_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans13_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans13_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans13_DO_POSITIONING_VALUE_D; \
	VARIABLE trans13_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans13_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans13_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans13_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans13_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans13_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans13_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans13_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans13_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans13_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans13_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans13_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans13_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans13_DO_VIEW_2; \
	MENU trans13_DO_VIEW_2_page; \
	COLLECTION trans13_DO_VIEW_3; \
	MENU trans13_DO_VIEW_3_page; \
	COLLECTION trans13_DO_VIEW_4; \
	MENU trans13_DO_VIEW_4_page

#define USE_TRANS13_DO_OPTIONAL_A \
	USE_TRANS13_DO_OPTIONAL_BOTH; \
	VARIABLE trans13_DO_ACTUATOR_ACTION; \
	MENU trans13_DO_ACTUATOR_ACTION_page; \
	COMMAND trans13_DO_ACTUATOR_ACTION_read; \
	COMMAND trans13_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans13_DO_SELF_CALIB_CMD; \
	MENU trans13_DO_SELF_CALIB_CMD_page; \
	COMMAND trans13_DO_SELF_CALIB_CMD_read; \
	COMMAND trans13_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans13_DO_SELF_CALIB_STATUS; \
	MENU trans13_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans13_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans13_DO_VIEW_1; \
	MENU trans13_DO_VIEW_1_page; \
	MENU trans13_DO_Simple_Dialog_Optional_A

#define USE_TRANS13_DO_OPTIONAL_B \
	USE_TRANS13_DO_OPTIONAL_BOTH; \
	MENU trans13_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans13_DO_)
#define USE_TRANS13_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans13_DO_)
#define USE_TRANS13_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans13_DO_)
#define USE_TRANS13_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans13_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_DO_MANDATORY_BOTH \
	BLOCK trans14_DO_block; \
	COLLECTION trans14_DO_BLOCK_OBJECT; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_DO_BLOCK_OBJECT_page; \
	COMMAND trans14_DO_BLOCK_OBJECT_read; \
	VARIABLE trans14_DO_ST_REV; \
	MENU trans14_DO_ST_REV_page; \
	COMMAND trans14_DO_ST_REV_read; \
	VARIABLE trans14_DO_TAG_DESC; \
	MENU trans14_DO_TAG_DESC_page; \
	COMMAND trans14_DO_TAG_DESC_read; \
	COMMAND trans14_DO_TAG_DESC_write; \
	VARIABLE trans14_DO_STRATEGY; \
	MENU trans14_DO_STRATEGY_page; \
	COMMAND trans14_DO_STRATEGY_read; \
	COMMAND trans14_DO_STRATEGY_write; \
	VARIABLE trans14_DO_ALERT_KEY; \
	MENU trans14_DO_ALERT_KEY_page; \
	COMMAND trans14_DO_ALERT_KEY_read; \
	COMMAND trans14_DO_ALERT_KEY_write; \
	VARIABLE trans14_DO_TARGET_MODE; \
	MENU trans14_DO_TARGET_MODE_page; \
	COMMAND trans14_DO_TARGET_MODE_read; \
	COMMAND trans14_DO_TARGET_MODE_write; \
	COLLECTION trans14_DO_MODE_BLK; \
	VARIABLE trans14_DO_MODE_BLK_Actual; \
	VARIABLE trans14_DO_MODE_BLK_Permitted; \
	VARIABLE trans14_DO_MODE_BLK_Normal; \
	MENU trans14_DO_MODE_BLK_page; \
	COMMAND trans14_DO_MODE_BLK_read; \
	COLLECTION trans14_DO_ALARM_SUM; \
	VARIABLE trans14_DO_ALARM_SUM_Current; \
	VARIABLE trans14_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_DO_ALARM_SUM_Unreported; \
	VARIABLE trans14_DO_ALARM_SUM_Disabled; \
	MENU trans14_DO_ALARM_SUM_page; \
	COMMAND trans14_DO_ALARM_SUM_read

#define USE_TRANS14_DO_MANDATORY_A \
	USE_TRANS14_DO_MANDATORY_BOTH; \
	MENU trans14_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS14_DO_MANDATORY_B \
	USE_TRANS14_DO_MANDATORY_BOTH; \
	VARIABLE trans14_DO_ACTUATOR_ACTION; \
	MENU trans14_DO_ACTUATOR_ACTION_page; \
	COMMAND trans14_DO_ACTUATOR_ACTION_read; \
	COMMAND trans14_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans14_DO_SELF_CALIB_CMD; \
	MENU trans14_DO_SELF_CALIB_CMD_page; \
	COMMAND trans14_DO_SELF_CALIB_CMD_read; \
	COMMAND trans14_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans14_DO_SELF_CALIB_STATUS; \
	MENU trans14_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans14_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans14_DO_VIEW_1; \
	MENU trans14_DO_VIEW_1_page; \
	MENU trans14_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS14_DO_OPTIONAL_BOTH \
	VARIABLE trans14_DO_VALVE_MAN; \
	MENU trans14_DO_VALVE_MAN_page; \
	COMMAND trans14_DO_VALVE_MAN_read; \
	COMMAND trans14_DO_VALVE_MAN_write; \
	VARIABLE trans14_DO_ACTUATOR_MAN; \
	MENU trans14_DO_ACTUATOR_MAN_page; \
	COMMAND trans14_DO_ACTUATOR_MAN_read; \
	COMMAND trans14_DO_ACTUATOR_MAN_write; \
	VARIABLE trans14_DO_VALVE_SER_NUM; \
	MENU trans14_DO_VALVE_SER_NUM_page; \
	COMMAND trans14_DO_VALVE_SER_NUM_read; \
	COMMAND trans14_DO_VALVE_SER_NUM_write; \
	VARIABLE trans14_DO_ACTUATOR_SER_NUM; \
	MENU trans14_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans14_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans14_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans14_DO_VALVE_ID; \
	MENU trans14_DO_VALVE_ID_page; \
	COMMAND trans14_DO_VALVE_ID_read; \
	COMMAND trans14_DO_VALVE_ID_write; \
	VARIABLE trans14_DO_ACTUATOR_ID; \
	MENU trans14_DO_ACTUATOR_ID_page; \
	COMMAND trans14_DO_ACTUATOR_ID_read; \
	COMMAND trans14_DO_ACTUATOR_ID_write; \
	VARIABLE trans14_DO_TRAVEL_COUNT; \
	MENU trans14_DO_TRAVEL_COUNT_page; \
	COMMAND trans14_DO_TRAVEL_COUNT_read; \
	COMMAND trans14_DO_TRAVEL_COUNT_write; \
	VARIABLE trans14_DO_TRAVEL_COUNT_LIM; \
	MENU trans14_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans14_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans14_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans14_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans14_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans14_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans14_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans14_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans14_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans14_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans14_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans14_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans14_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans14_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans14_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans14_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans14_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans14_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans14_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans14_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans14_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans14_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans14_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans14_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans14_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans14_DO_CYCLE_TEST_CMD; \
	MENU trans14_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans14_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans14_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans14_DO_CYCLE_TEST_TIME; \
	MENU trans14_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans14_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans14_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans14_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans14_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans14_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans14_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans14_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans14_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans14_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans14_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans14_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans14_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans14_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans14_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans14_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans14_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans14_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans14_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans14_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans14_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans14_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans14_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans14_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans14_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans14_DO_SENSOR_WIRE_CHECK; \
	MENU trans14_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans14_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans14_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans14_DO_POSITIONING_VALUE_D; \
	VARIABLE trans14_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans14_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans14_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans14_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans14_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans14_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans14_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans14_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans14_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans14_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans14_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans14_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans14_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans14_DO_VIEW_2; \
	MENU trans14_DO_VIEW_2_page; \
	COLLECTION trans14_DO_VIEW_3; \
	MENU trans14_DO_VIEW_3_page; \
	COLLECTION trans14_DO_VIEW_4; \
	MENU trans14_DO_VIEW_4_page

#define USE_TRANS14_DO_OPTIONAL_A \
	USE_TRANS14_DO_OPTIONAL_BOTH; \
	VARIABLE trans14_DO_ACTUATOR_ACTION; \
	MENU trans14_DO_ACTUATOR_ACTION_page; \
	COMMAND trans14_DO_ACTUATOR_ACTION_read; \
	COMMAND trans14_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans14_DO_SELF_CALIB_CMD; \
	MENU trans14_DO_SELF_CALIB_CMD_page; \
	COMMAND trans14_DO_SELF_CALIB_CMD_read; \
	COMMAND trans14_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans14_DO_SELF_CALIB_STATUS; \
	MENU trans14_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans14_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans14_DO_VIEW_1; \
	MENU trans14_DO_VIEW_1_page; \
	MENU trans14_DO_Simple_Dialog_Optional_A

#define USE_TRANS14_DO_OPTIONAL_B \
	USE_TRANS14_DO_OPTIONAL_BOTH; \
	MENU trans14_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans14_DO_)
#define USE_TRANS14_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans14_DO_)
#define USE_TRANS14_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans14_DO_)
#define USE_TRANS14_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans14_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_DO_MANDATORY_BOTH \
	BLOCK trans15_DO_block; \
	COLLECTION trans15_DO_BLOCK_OBJECT; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Class; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_DO_BLOCK_OBJECT_page; \
	COMMAND trans15_DO_BLOCK_OBJECT_read; \
	VARIABLE trans15_DO_ST_REV; \
	MENU trans15_DO_ST_REV_page; \
	COMMAND trans15_DO_ST_REV_read; \
	VARIABLE trans15_DO_TAG_DESC; \
	MENU trans15_DO_TAG_DESC_page; \
	COMMAND trans15_DO_TAG_DESC_read; \
	COMMAND trans15_DO_TAG_DESC_write; \
	VARIABLE trans15_DO_STRATEGY; \
	MENU trans15_DO_STRATEGY_page; \
	COMMAND trans15_DO_STRATEGY_read; \
	COMMAND trans15_DO_STRATEGY_write; \
	VARIABLE trans15_DO_ALERT_KEY; \
	MENU trans15_DO_ALERT_KEY_page; \
	COMMAND trans15_DO_ALERT_KEY_read; \
	COMMAND trans15_DO_ALERT_KEY_write; \
	VARIABLE trans15_DO_TARGET_MODE; \
	MENU trans15_DO_TARGET_MODE_page; \
	COMMAND trans15_DO_TARGET_MODE_read; \
	COMMAND trans15_DO_TARGET_MODE_write; \
	COLLECTION trans15_DO_MODE_BLK; \
	VARIABLE trans15_DO_MODE_BLK_Actual; \
	VARIABLE trans15_DO_MODE_BLK_Permitted; \
	VARIABLE trans15_DO_MODE_BLK_Normal; \
	MENU trans15_DO_MODE_BLK_page; \
	COMMAND trans15_DO_MODE_BLK_read; \
	COLLECTION trans15_DO_ALARM_SUM; \
	VARIABLE trans15_DO_ALARM_SUM_Current; \
	VARIABLE trans15_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_DO_ALARM_SUM_Unreported; \
	VARIABLE trans15_DO_ALARM_SUM_Disabled; \
	MENU trans15_DO_ALARM_SUM_page; \
	COMMAND trans15_DO_ALARM_SUM_read

#define USE_TRANS15_DO_MANDATORY_A \
	USE_TRANS15_DO_MANDATORY_BOTH; \
	MENU trans15_DO_Simple_Dialog_Mandatory_A

#define USE_TRANS15_DO_MANDATORY_B \
	USE_TRANS15_DO_MANDATORY_BOTH; \
	VARIABLE trans15_DO_ACTUATOR_ACTION; \
	MENU trans15_DO_ACTUATOR_ACTION_page; \
	COMMAND trans15_DO_ACTUATOR_ACTION_read; \
	COMMAND trans15_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans15_DO_SELF_CALIB_CMD; \
	MENU trans15_DO_SELF_CALIB_CMD_page; \
	COMMAND trans15_DO_SELF_CALIB_CMD_read; \
	COMMAND trans15_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans15_DO_SELF_CALIB_STATUS; \
	MENU trans15_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans15_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans15_DO_VIEW_1; \
	MENU trans15_DO_VIEW_1_page; \
	MENU trans15_DO_Simple_Dialog_Mandatory_B

#define USE_TRANS15_DO_OPTIONAL_BOTH \
	VARIABLE trans15_DO_VALVE_MAN; \
	MENU trans15_DO_VALVE_MAN_page; \
	COMMAND trans15_DO_VALVE_MAN_read; \
	COMMAND trans15_DO_VALVE_MAN_write; \
	VARIABLE trans15_DO_ACTUATOR_MAN; \
	MENU trans15_DO_ACTUATOR_MAN_page; \
	COMMAND trans15_DO_ACTUATOR_MAN_read; \
	COMMAND trans15_DO_ACTUATOR_MAN_write; \
	VARIABLE trans15_DO_VALVE_SER_NUM; \
	MENU trans15_DO_VALVE_SER_NUM_page; \
	COMMAND trans15_DO_VALVE_SER_NUM_read; \
	COMMAND trans15_DO_VALVE_SER_NUM_write; \
	VARIABLE trans15_DO_ACTUATOR_SER_NUM; \
	MENU trans15_DO_ACTUATOR_SER_NUM_page; \
	COMMAND trans15_DO_ACTUATOR_SER_NUM_read; \
	COMMAND trans15_DO_ACTUATOR_SER_NUM_write; \
	VARIABLE trans15_DO_VALVE_ID; \
	MENU trans15_DO_VALVE_ID_page; \
	COMMAND trans15_DO_VALVE_ID_read; \
	COMMAND trans15_DO_VALVE_ID_write; \
	VARIABLE trans15_DO_ACTUATOR_ID; \
	MENU trans15_DO_ACTUATOR_ID_page; \
	COMMAND trans15_DO_ACTUATOR_ID_read; \
	COMMAND trans15_DO_ACTUATOR_ID_write; \
	VARIABLE trans15_DO_TRAVEL_COUNT; \
	MENU trans15_DO_TRAVEL_COUNT_page; \
	COMMAND trans15_DO_TRAVEL_COUNT_read; \
	COMMAND trans15_DO_TRAVEL_COUNT_write; \
	VARIABLE trans15_DO_TRAVEL_COUNT_LIM; \
	MENU trans15_DO_TRAVEL_COUNT_LIM_page; \
	COMMAND trans15_DO_TRAVEL_COUNT_LIM_read; \
	COMMAND trans15_DO_TRAVEL_COUNT_LIM_write; \
	VARIABLE trans15_DO_BREAK_TIME_OPEN_CLOSE; \
	MENU trans15_DO_BREAK_TIME_OPEN_CLOSE_page; \
	COMMAND trans15_DO_BREAK_TIME_OPEN_CLOSE_read; \
	COMMAND trans15_DO_BREAK_TIME_OPEN_CLOSE_write; \
	VARIABLE trans15_DO_BREAK_TIME_CLOSE_OPEN; \
	MENU trans15_DO_BREAK_TIME_CLOSE_OPEN_page; \
	COMMAND trans15_DO_BREAK_TIME_CLOSE_OPEN_read; \
	COMMAND trans15_DO_BREAK_TIME_CLOSE_OPEN_write; \
	VARIABLE trans15_DO_BREAK_TIME_OPEN_CLOSE_ACT; \
	MENU trans15_DO_BREAK_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans15_DO_BREAK_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans15_DO_BREAK_TIME_CLOSE_OPEN_ACT; \
	MENU trans15_DO_BREAK_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans15_DO_BREAK_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans15_DO_BREAK_TIME_OPEN_CLOSE_TOL; \
	MENU trans15_DO_BREAK_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans15_DO_BREAK_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans15_DO_BREAK_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans15_DO_BREAK_TIME_CLOSE_OPEN_TOL; \
	MENU trans15_DO_BREAK_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans15_DO_BREAK_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans15_DO_BREAK_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans15_DO_CYCLE_TEST_CMD; \
	MENU trans15_DO_CYCLE_TEST_CMD_page; \
	COMMAND trans15_DO_CYCLE_TEST_CMD_read; \
	COMMAND trans15_DO_CYCLE_TEST_CMD_write; \
	VARIABLE trans15_DO_CYCLE_TEST_TIME; \
	MENU trans15_DO_CYCLE_TEST_TIME_page; \
	COMMAND trans15_DO_CYCLE_TEST_TIME_read; \
	COMMAND trans15_DO_CYCLE_TEST_TIME_write; \
	VARIABLE trans15_DO_TRAVEL_TIME_CLOSE_OPEN; \
	MENU trans15_DO_TRAVEL_TIME_CLOSE_OPEN_page; \
	COMMAND trans15_DO_TRAVEL_TIME_CLOSE_OPEN_read; \
	COMMAND trans15_DO_TRAVEL_TIME_CLOSE_OPEN_write; \
	VARIABLE trans15_DO_TRAVEL_TIME_OPEN_CLOSE; \
	MENU trans15_DO_TRAVEL_TIME_OPEN_CLOSE_page; \
	COMMAND trans15_DO_TRAVEL_TIME_OPEN_CLOSE_read; \
	COMMAND trans15_DO_TRAVEL_TIME_OPEN_CLOSE_write; \
	VARIABLE trans15_DO_TRAVEL_TIME_CLOSE_OPEN_ACT; \
	MENU trans15_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_page; \
	COMMAND trans15_DO_TRAVEL_TIME_CLOSE_OPEN_ACT_read; \
	VARIABLE trans15_DO_TRAVEL_TIME_OPEN_CLOSE_ACT; \
	MENU trans15_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_page; \
	COMMAND trans15_DO_TRAVEL_TIME_OPEN_CLOSE_ACT_read; \
	VARIABLE trans15_DO_TRAVEL_TIME_CLOSE_OPEN_TOL; \
	MENU trans15_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_page; \
	COMMAND trans15_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_read; \
	COMMAND trans15_DO_TRAVEL_TIME_CLOSE_OPEN_TOL_write; \
	VARIABLE trans15_DO_TRAVEL_TIME_OPEN_CLOSE_TOL; \
	MENU trans15_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_page; \
	COMMAND trans15_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_read; \
	COMMAND trans15_DO_TRAVEL_TIME_OPEN_CLOSE_TOL_write; \
	VARIABLE trans15_DO_SENSOR_WIRE_CHECK; \
	MENU trans15_DO_SENSOR_WIRE_CHECK_page; \
	COMMAND trans15_DO_SENSOR_WIRE_CHECK_read; \
	COMMAND trans15_DO_SENSOR_WIRE_CHECK_write; \
	COLLECTION trans15_DO_POSITIONING_VALUE_D; \
	VARIABLE trans15_DO_POSITIONING_VALUE_D_Value; \
	VARIABLE trans15_DO_POSITIONING_VALUE_D_Status_Condensed; \
	VARIABLE trans15_DO_POSITIONING_VALUE_D_Status_Quality; \
	VARIABLE trans15_DO_POSITIONING_VALUE_D_Status_Limit; \
	MENU trans15_DO_POSITIONING_VALUE_D_page; \
	COMMAND trans15_DO_POSITIONING_VALUE_D_read; \
	COLLECTION trans15_DO_FEEDBACK_VALUE_D; \
	VARIABLE trans15_DO_FEEDBACK_VALUE_D_Value; \
	VARIABLE trans15_DO_FEEDBACK_VALUE_D_Status_Condensed; \
	VARIABLE trans15_DO_FEEDBACK_VALUE_D_Status_Quality; \
	VARIABLE trans15_DO_FEEDBACK_VALUE_D_Status_Limit; \
	MENU trans15_DO_FEEDBACK_VALUE_D_page; \
	COMMAND trans15_DO_FEEDBACK_VALUE_D_read; \
	COLLECTION trans15_DO_VIEW_2; \
	MENU trans15_DO_VIEW_2_page; \
	COLLECTION trans15_DO_VIEW_3; \
	MENU trans15_DO_VIEW_3_page; \
	COLLECTION trans15_DO_VIEW_4; \
	MENU trans15_DO_VIEW_4_page

#define USE_TRANS15_DO_OPTIONAL_A \
	USE_TRANS15_DO_OPTIONAL_BOTH; \
	VARIABLE trans15_DO_ACTUATOR_ACTION; \
	MENU trans15_DO_ACTUATOR_ACTION_page; \
	COMMAND trans15_DO_ACTUATOR_ACTION_read; \
	COMMAND trans15_DO_ACTUATOR_ACTION_write; \
	VARIABLE trans15_DO_SELF_CALIB_CMD; \
	MENU trans15_DO_SELF_CALIB_CMD_page; \
	COMMAND trans15_DO_SELF_CALIB_CMD_read; \
	COMMAND trans15_DO_SELF_CALIB_CMD_write; \
	VARIABLE trans15_DO_SELF_CALIB_STATUS; \
	MENU trans15_DO_SELF_CALIB_STATUS_page; \
	COMMAND trans15_DO_SELF_CALIB_STATUS_read; \
	COLLECTION trans15_DO_VIEW_1; \
	MENU trans15_DO_VIEW_1_page; \
	MENU trans15_DO_Simple_Dialog_Optional_A

#define USE_TRANS15_DO_OPTIONAL_B \
	USE_TRANS15_DO_OPTIONAL_BOTH; \
	MENU trans15_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_DO_MANDATORY_A USE_TRANS_DO_MANDATORY_A(trans15_DO_)
#define USE_TRANS15_DO_MANDATORY_B USE_TRANS_DO_MANDATORY_B(trans15_DO_)
#define USE_TRANS15_DO_OPTIONAL_A  USE_TRANS_DO_OPTIONAL_A(trans15_DO_)
#define USE_TRANS15_DO_OPTIONAL_B  USE_TRANS_DO_OPTIONAL_B(trans15_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans1_analysis_block; \
	COLLECTION trans1_analysis_BLOCK_OBJECT; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_analysis_BLOCK_OBJECT_page; \
	COMMAND trans1_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans1_analysis_ST_REV; \
	MENU trans1_analysis_ST_REV_page; \
	COMMAND trans1_analysis_ST_REV_read; \
	VARIABLE trans1_analysis_TAG_DESC; \
	MENU trans1_analysis_TAG_DESC_page; \
	COMMAND trans1_analysis_TAG_DESC_read; \
	COMMAND trans1_analysis_TAG_DESC_write; \
	VARIABLE trans1_analysis_STRATEGY; \
	MENU trans1_analysis_STRATEGY_page; \
	COMMAND trans1_analysis_STRATEGY_read; \
	COMMAND trans1_analysis_STRATEGY_write; \
	VARIABLE trans1_analysis_ALERT_KEY; \
	MENU trans1_analysis_ALERT_KEY_page; \
	COMMAND trans1_analysis_ALERT_KEY_read; \
	COMMAND trans1_analysis_ALERT_KEY_write; \
	VARIABLE trans1_analysis_TARGET_MODE; \
	MENU trans1_analysis_TARGET_MODE_page; \
	COMMAND trans1_analysis_TARGET_MODE_read; \
	COMMAND trans1_analysis_TARGET_MODE_write; \
	COLLECTION trans1_analysis_MODE_BLK; \
	VARIABLE trans1_analysis_MODE_BLK_Actual; \
	VARIABLE trans1_analysis_MODE_BLK_Permitted; \
	VARIABLE trans1_analysis_MODE_BLK_Normal; \
	MENU trans1_analysis_MODE_BLK_page; \
	COMMAND trans1_analysis_MODE_BLK_read; \
	COLLECTION trans1_analysis_ALARM_SUM; \
	VARIABLE trans1_analysis_ALARM_SUM_Current; \
	VARIABLE trans1_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans1_analysis_ALARM_SUM_Disabled; \
	MENU trans1_analysis_ALARM_SUM_page; \
	COMMAND trans1_analysis_ALARM_SUM_read; \
	VARIABLE trans1_analysis_COMPONENT_NAME; \
	MENU trans1_analysis_COMPONENT_NAME_page; \
	COMMAND trans1_analysis_COMPONENT_NAME_read; \
	COMMAND trans1_analysis_COMPONENT_NAME_write; \
	COLLECTION trans1_analysis_PV; \
	VARIABLE trans1_analysis_PV_PV; \
	VARIABLE trans1_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans1_analysis_PV_PV_Time; \
	VARIABLE trans1_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans1_analysis_PV_Measurement_Status_Limit; \
	MENU trans1_analysis_PV_page; \
	COMMAND trans1_analysis_PV_read; \
	VARIABLE trans1_analysis_PV_UNIT; \
	MENU trans1_analysis_PV_UNIT_page; \
	COMMAND trans1_analysis_PV_UNIT_read; \
	COMMAND trans1_analysis_PV_UNIT_write; \
	VARIABLE trans1_analysis_PV_UNIT_TEXT; \
	MENU trans1_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans1_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans1_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans1_analysis_ACTIVE_RANGE; \
	MENU trans1_analysis_ACTIVE_RANGE_page; \
	COMMAND trans1_analysis_ACTIVE_RANGE_read; \
	COMMAND trans1_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans1_analysis_AUTORANGE_ON; \
	MENU trans1_analysis_AUTORANGE_ON_page; \
	COMMAND trans1_analysis_AUTORANGE_ON_read; \
	COMMAND trans1_analysis_AUTORANGE_ON_write; \
	VARIABLE trans1_analysis_SAMPLING_RATE; \
	MENU trans1_analysis_SAMPLING_RATE_page; \
	COMMAND trans1_analysis_SAMPLING_RATE_read; \
	COMMAND trans1_analysis_SAMPLING_RATE_write; \
	VARIABLE trans1_analysis_NUMBER_OF_RANGES; \
	MENU trans1_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans1_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans1_analysis_RANGE_1; \
	VARIABLE trans1_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans1_analysis_RANGE_1_End_of_Range; \
	MENU trans1_analysis_RANGE_1_page; \
	COMMAND trans1_analysis_RANGE_1_read; \
	COMMAND trans1_analysis_RANGE_1_write; \
	UNIT trans1_analysis_unit_1; \
	METHOD trans1_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans1_analysis_SAMPLING_RATE_Visible

#define USE_TRANS1_ANALYSIS_MANDATORY_A \
	USE_TRANS1_ANALYSIS_MANDATORY_BOTH; \
	MENU trans1_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS1_ANALYSIS_MANDATORY_B \
	USE_TRANS1_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans1_analysis_VIEW_1; \
	MENU trans1_analysis_VIEW_1_page; \
	MENU trans1_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS1_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans1_analysis_VIEW_2; \
	MENU trans1_analysis_VIEW_2_page; \
	COLLECTION trans1_analysis_VIEW_3; \
	MENU trans1_analysis_VIEW_3_page

#define USE_TRANS1_ANALYSIS_OPTIONAL_A \
	USE_TRANS1_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans1_analysis_VIEW_1; \
	MENU trans1_analysis_VIEW_1_page; \
	MENU trans1_analysis_Simple_Dialog_Optional_A

#define USE_TRANS1_ANALYSIS_OPTIONAL_B \
	USE_TRANS1_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans1_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_ANALYSIS_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## COMPONENT_NAME; \
	MENU prefix ## COMPONENT_NAME_page; \
	COMMAND prefix ## COMPONENT_NAME_read; \
	COMMAND prefix ## COMPONENT_NAME_write; \
	COLLECTION prefix ## PV; \
	VARIABLE prefix ## PV_PV; \
	VARIABLE prefix ## PV_Measurement_Status_Condensed; \
	VARIABLE prefix ## PV_PV_Time; \
	VARIABLE prefix ## PV_Measurement_Status_Quality; \
	VARIABLE prefix ## PV_Measurement_Status_Limit; \
	MENU prefix ## PV_page; \
	COMMAND prefix ## PV_read; \
	VARIABLE prefix ## PV_UNIT; \
	MENU prefix ## PV_UNIT_page; \
	COMMAND prefix ## PV_UNIT_read; \
	COMMAND prefix ## PV_UNIT_write; \
	VARIABLE prefix ## PV_UNIT_TEXT; \
	MENU prefix ## PV_UNIT_TEXT_page; \
	COMMAND prefix ## PV_UNIT_TEXT_read; \
	COMMAND prefix ## PV_UNIT_TEXT_write; \
	VARIABLE prefix ## ACTIVE_RANGE; \
	MENU prefix ## ACTIVE_RANGE_page; \
	COMMAND prefix ## ACTIVE_RANGE_read; \
	COMMAND prefix ## ACTIVE_RANGE_write; \
	VARIABLE prefix ## AUTORANGE_ON; \
	MENU prefix ## AUTORANGE_ON_page; \
	COMMAND prefix ## AUTORANGE_ON_read; \
	COMMAND prefix ## AUTORANGE_ON_write; \
	VARIABLE prefix ## SAMPLING_RATE; \
	MENU prefix ## SAMPLING_RATE_page; \
	COMMAND prefix ## SAMPLING_RATE_read; \
	COMMAND prefix ## SAMPLING_RATE_write; \
	VARIABLE prefix ## NUMBER_OF_RANGES; \
	MENU prefix ## NUMBER_OF_RANGES_page; \
	COMMAND prefix ## NUMBER_OF_RANGES_read; \
	COLLECTION prefix ## RANGE_1; \
	VARIABLE prefix ## RANGE_1_Begin_of_Range; \
	VARIABLE prefix ## RANGE_1_End_of_Range; \
	MENU prefix ## RANGE_1_page; \
	COMMAND prefix ## RANGE_1_read; \
	COMMAND prefix ## RANGE_1_write; \
	UNIT prefix ## unit_1; \
	METHOD prefix ## SAMPLING_RATE_to_ASCII; \
	VARIABLE prefix ## SAMPLING_RATE_Visible

#define USE_TRANS_ANALYSIS_MANDATORY_A(prefix) \
	USE_TRANS_ANALYSIS_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_ANALYSIS_MANDATORY_B(prefix) \
	USE_TRANS_ANALYSIS_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_ANALYSIS_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_ANALYSIS_OPTIONAL_A(prefix) \
	USE_TRANS_ANALYSIS_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_ANALYSIS_OPTIONAL_B(prefix) \
	USE_TRANS_ANALYSIS_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans1_analysis_)
#define USE_TRANS1_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans1_analysis_)
#define USE_TRANS1_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans1_analysis_)
#define USE_TRANS1_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans1_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans2_analysis_block; \
	COLLECTION trans2_analysis_BLOCK_OBJECT; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_analysis_BLOCK_OBJECT_page; \
	COMMAND trans2_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans2_analysis_ST_REV; \
	MENU trans2_analysis_ST_REV_page; \
	COMMAND trans2_analysis_ST_REV_read; \
	VARIABLE trans2_analysis_TAG_DESC; \
	MENU trans2_analysis_TAG_DESC_page; \
	COMMAND trans2_analysis_TAG_DESC_read; \
	COMMAND trans2_analysis_TAG_DESC_write; \
	VARIABLE trans2_analysis_STRATEGY; \
	MENU trans2_analysis_STRATEGY_page; \
	COMMAND trans2_analysis_STRATEGY_read; \
	COMMAND trans2_analysis_STRATEGY_write; \
	VARIABLE trans2_analysis_ALERT_KEY; \
	MENU trans2_analysis_ALERT_KEY_page; \
	COMMAND trans2_analysis_ALERT_KEY_read; \
	COMMAND trans2_analysis_ALERT_KEY_write; \
	VARIABLE trans2_analysis_TARGET_MODE; \
	MENU trans2_analysis_TARGET_MODE_page; \
	COMMAND trans2_analysis_TARGET_MODE_read; \
	COMMAND trans2_analysis_TARGET_MODE_write; \
	COLLECTION trans2_analysis_MODE_BLK; \
	VARIABLE trans2_analysis_MODE_BLK_Actual; \
	VARIABLE trans2_analysis_MODE_BLK_Permitted; \
	VARIABLE trans2_analysis_MODE_BLK_Normal; \
	MENU trans2_analysis_MODE_BLK_page; \
	COMMAND trans2_analysis_MODE_BLK_read; \
	COLLECTION trans2_analysis_ALARM_SUM; \
	VARIABLE trans2_analysis_ALARM_SUM_Current; \
	VARIABLE trans2_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans2_analysis_ALARM_SUM_Disabled; \
	MENU trans2_analysis_ALARM_SUM_page; \
	COMMAND trans2_analysis_ALARM_SUM_read; \
	VARIABLE trans2_analysis_COMPONENT_NAME; \
	MENU trans2_analysis_COMPONENT_NAME_page; \
	COMMAND trans2_analysis_COMPONENT_NAME_read; \
	COMMAND trans2_analysis_COMPONENT_NAME_write; \
	COLLECTION trans2_analysis_PV; \
	VARIABLE trans2_analysis_PV_PV; \
	VARIABLE trans2_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans2_analysis_PV_PV_Time; \
	VARIABLE trans2_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans2_analysis_PV_Measurement_Status_Limit; \
	MENU trans2_analysis_PV_page; \
	COMMAND trans2_analysis_PV_read; \
	VARIABLE trans2_analysis_PV_UNIT; \
	MENU trans2_analysis_PV_UNIT_page; \
	COMMAND trans2_analysis_PV_UNIT_read; \
	COMMAND trans2_analysis_PV_UNIT_write; \
	VARIABLE trans2_analysis_PV_UNIT_TEXT; \
	MENU trans2_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans2_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans2_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans2_analysis_ACTIVE_RANGE; \
	MENU trans2_analysis_ACTIVE_RANGE_page; \
	COMMAND trans2_analysis_ACTIVE_RANGE_read; \
	COMMAND trans2_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans2_analysis_AUTORANGE_ON; \
	MENU trans2_analysis_AUTORANGE_ON_page; \
	COMMAND trans2_analysis_AUTORANGE_ON_read; \
	COMMAND trans2_analysis_AUTORANGE_ON_write; \
	VARIABLE trans2_analysis_SAMPLING_RATE; \
	MENU trans2_analysis_SAMPLING_RATE_page; \
	COMMAND trans2_analysis_SAMPLING_RATE_read; \
	COMMAND trans2_analysis_SAMPLING_RATE_write; \
	VARIABLE trans2_analysis_NUMBER_OF_RANGES; \
	MENU trans2_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans2_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans2_analysis_RANGE_1; \
	VARIABLE trans2_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans2_analysis_RANGE_1_End_of_Range; \
	MENU trans2_analysis_RANGE_1_page; \
	COMMAND trans2_analysis_RANGE_1_read; \
	COMMAND trans2_analysis_RANGE_1_write; \
	UNIT trans2_analysis_unit_1; \
	METHOD trans2_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans2_analysis_SAMPLING_RATE_Visible

#define USE_TRANS2_ANALYSIS_MANDATORY_A \
	USE_TRANS2_ANALYSIS_MANDATORY_BOTH; \
	MENU trans2_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS2_ANALYSIS_MANDATORY_B \
	USE_TRANS2_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans2_analysis_VIEW_1; \
	MENU trans2_analysis_VIEW_1_page; \
	MENU trans2_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS2_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans2_analysis_VIEW_2; \
	MENU trans2_analysis_VIEW_2_page; \
	COLLECTION trans2_analysis_VIEW_3; \
	MENU trans2_analysis_VIEW_3_page

#define USE_TRANS2_ANALYSIS_OPTIONAL_A \
	USE_TRANS2_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans2_analysis_VIEW_1; \
	MENU trans2_analysis_VIEW_1_page; \
	MENU trans2_analysis_Simple_Dialog_Optional_A

#define USE_TRANS2_ANALYSIS_OPTIONAL_B \
	USE_TRANS2_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans2_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans2_analysis_)
#define USE_TRANS2_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans2_analysis_)
#define USE_TRANS2_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans2_analysis_)
#define USE_TRANS2_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans2_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans3_analysis_block; \
	COLLECTION trans3_analysis_BLOCK_OBJECT; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_analysis_BLOCK_OBJECT_page; \
	COMMAND trans3_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans3_analysis_ST_REV; \
	MENU trans3_analysis_ST_REV_page; \
	COMMAND trans3_analysis_ST_REV_read; \
	VARIABLE trans3_analysis_TAG_DESC; \
	MENU trans3_analysis_TAG_DESC_page; \
	COMMAND trans3_analysis_TAG_DESC_read; \
	COMMAND trans3_analysis_TAG_DESC_write; \
	VARIABLE trans3_analysis_STRATEGY; \
	MENU trans3_analysis_STRATEGY_page; \
	COMMAND trans3_analysis_STRATEGY_read; \
	COMMAND trans3_analysis_STRATEGY_write; \
	VARIABLE trans3_analysis_ALERT_KEY; \
	MENU trans3_analysis_ALERT_KEY_page; \
	COMMAND trans3_analysis_ALERT_KEY_read; \
	COMMAND trans3_analysis_ALERT_KEY_write; \
	VARIABLE trans3_analysis_TARGET_MODE; \
	MENU trans3_analysis_TARGET_MODE_page; \
	COMMAND trans3_analysis_TARGET_MODE_read; \
	COMMAND trans3_analysis_TARGET_MODE_write; \
	COLLECTION trans3_analysis_MODE_BLK; \
	VARIABLE trans3_analysis_MODE_BLK_Actual; \
	VARIABLE trans3_analysis_MODE_BLK_Permitted; \
	VARIABLE trans3_analysis_MODE_BLK_Normal; \
	MENU trans3_analysis_MODE_BLK_page; \
	COMMAND trans3_analysis_MODE_BLK_read; \
	COLLECTION trans3_analysis_ALARM_SUM; \
	VARIABLE trans3_analysis_ALARM_SUM_Current; \
	VARIABLE trans3_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans3_analysis_ALARM_SUM_Disabled; \
	MENU trans3_analysis_ALARM_SUM_page; \
	COMMAND trans3_analysis_ALARM_SUM_read; \
	VARIABLE trans3_analysis_COMPONENT_NAME; \
	MENU trans3_analysis_COMPONENT_NAME_page; \
	COMMAND trans3_analysis_COMPONENT_NAME_read; \
	COMMAND trans3_analysis_COMPONENT_NAME_write; \
	COLLECTION trans3_analysis_PV; \
	VARIABLE trans3_analysis_PV_PV; \
	VARIABLE trans3_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans3_analysis_PV_PV_Time; \
	VARIABLE trans3_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans3_analysis_PV_Measurement_Status_Limit; \
	MENU trans3_analysis_PV_page; \
	COMMAND trans3_analysis_PV_read; \
	VARIABLE trans3_analysis_PV_UNIT; \
	MENU trans3_analysis_PV_UNIT_page; \
	COMMAND trans3_analysis_PV_UNIT_read; \
	COMMAND trans3_analysis_PV_UNIT_write; \
	VARIABLE trans3_analysis_PV_UNIT_TEXT; \
	MENU trans3_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans3_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans3_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans3_analysis_ACTIVE_RANGE; \
	MENU trans3_analysis_ACTIVE_RANGE_page; \
	COMMAND trans3_analysis_ACTIVE_RANGE_read; \
	COMMAND trans3_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans3_analysis_AUTORANGE_ON; \
	MENU trans3_analysis_AUTORANGE_ON_page; \
	COMMAND trans3_analysis_AUTORANGE_ON_read; \
	COMMAND trans3_analysis_AUTORANGE_ON_write; \
	VARIABLE trans3_analysis_SAMPLING_RATE; \
	MENU trans3_analysis_SAMPLING_RATE_page; \
	COMMAND trans3_analysis_SAMPLING_RATE_read; \
	COMMAND trans3_analysis_SAMPLING_RATE_write; \
	VARIABLE trans3_analysis_NUMBER_OF_RANGES; \
	MENU trans3_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans3_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans3_analysis_RANGE_1; \
	VARIABLE trans3_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans3_analysis_RANGE_1_End_of_Range; \
	MENU trans3_analysis_RANGE_1_page; \
	COMMAND trans3_analysis_RANGE_1_read; \
	COMMAND trans3_analysis_RANGE_1_write; \
	UNIT trans3_analysis_unit_1; \
	METHOD trans3_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans3_analysis_SAMPLING_RATE_Visible

#define USE_TRANS3_ANALYSIS_MANDATORY_A \
	USE_TRANS3_ANALYSIS_MANDATORY_BOTH; \
	MENU trans3_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS3_ANALYSIS_MANDATORY_B \
	USE_TRANS3_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans3_analysis_VIEW_1; \
	MENU trans3_analysis_VIEW_1_page; \
	MENU trans3_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS3_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans3_analysis_VIEW_2; \
	MENU trans3_analysis_VIEW_2_page; \
	COLLECTION trans3_analysis_VIEW_3; \
	MENU trans3_analysis_VIEW_3_page

#define USE_TRANS3_ANALYSIS_OPTIONAL_A \
	USE_TRANS3_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans3_analysis_VIEW_1; \
	MENU trans3_analysis_VIEW_1_page; \
	MENU trans3_analysis_Simple_Dialog_Optional_A

#define USE_TRANS3_ANALYSIS_OPTIONAL_B \
	USE_TRANS3_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans3_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans3_analysis_)
#define USE_TRANS3_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans3_analysis_)
#define USE_TRANS3_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans3_analysis_)
#define USE_TRANS3_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans3_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans4_analysis_block; \
	COLLECTION trans4_analysis_BLOCK_OBJECT; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_analysis_BLOCK_OBJECT_page; \
	COMMAND trans4_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans4_analysis_ST_REV; \
	MENU trans4_analysis_ST_REV_page; \
	COMMAND trans4_analysis_ST_REV_read; \
	VARIABLE trans4_analysis_TAG_DESC; \
	MENU trans4_analysis_TAG_DESC_page; \
	COMMAND trans4_analysis_TAG_DESC_read; \
	COMMAND trans4_analysis_TAG_DESC_write; \
	VARIABLE trans4_analysis_STRATEGY; \
	MENU trans4_analysis_STRATEGY_page; \
	COMMAND trans4_analysis_STRATEGY_read; \
	COMMAND trans4_analysis_STRATEGY_write; \
	VARIABLE trans4_analysis_ALERT_KEY; \
	MENU trans4_analysis_ALERT_KEY_page; \
	COMMAND trans4_analysis_ALERT_KEY_read; \
	COMMAND trans4_analysis_ALERT_KEY_write; \
	VARIABLE trans4_analysis_TARGET_MODE; \
	MENU trans4_analysis_TARGET_MODE_page; \
	COMMAND trans4_analysis_TARGET_MODE_read; \
	COMMAND trans4_analysis_TARGET_MODE_write; \
	COLLECTION trans4_analysis_MODE_BLK; \
	VARIABLE trans4_analysis_MODE_BLK_Actual; \
	VARIABLE trans4_analysis_MODE_BLK_Permitted; \
	VARIABLE trans4_analysis_MODE_BLK_Normal; \
	MENU trans4_analysis_MODE_BLK_page; \
	COMMAND trans4_analysis_MODE_BLK_read; \
	COLLECTION trans4_analysis_ALARM_SUM; \
	VARIABLE trans4_analysis_ALARM_SUM_Current; \
	VARIABLE trans4_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans4_analysis_ALARM_SUM_Disabled; \
	MENU trans4_analysis_ALARM_SUM_page; \
	COMMAND trans4_analysis_ALARM_SUM_read; \
	VARIABLE trans4_analysis_COMPONENT_NAME; \
	MENU trans4_analysis_COMPONENT_NAME_page; \
	COMMAND trans4_analysis_COMPONENT_NAME_read; \
	COMMAND trans4_analysis_COMPONENT_NAME_write; \
	COLLECTION trans4_analysis_PV; \
	VARIABLE trans4_analysis_PV_PV; \
	VARIABLE trans4_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans4_analysis_PV_PV_Time; \
	VARIABLE trans4_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans4_analysis_PV_Measurement_Status_Limit; \
	MENU trans4_analysis_PV_page; \
	COMMAND trans4_analysis_PV_read; \
	VARIABLE trans4_analysis_PV_UNIT; \
	MENU trans4_analysis_PV_UNIT_page; \
	COMMAND trans4_analysis_PV_UNIT_read; \
	COMMAND trans4_analysis_PV_UNIT_write; \
	VARIABLE trans4_analysis_PV_UNIT_TEXT; \
	MENU trans4_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans4_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans4_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans4_analysis_ACTIVE_RANGE; \
	MENU trans4_analysis_ACTIVE_RANGE_page; \
	COMMAND trans4_analysis_ACTIVE_RANGE_read; \
	COMMAND trans4_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans4_analysis_AUTORANGE_ON; \
	MENU trans4_analysis_AUTORANGE_ON_page; \
	COMMAND trans4_analysis_AUTORANGE_ON_read; \
	COMMAND trans4_analysis_AUTORANGE_ON_write; \
	VARIABLE trans4_analysis_SAMPLING_RATE; \
	MENU trans4_analysis_SAMPLING_RATE_page; \
	COMMAND trans4_analysis_SAMPLING_RATE_read; \
	COMMAND trans4_analysis_SAMPLING_RATE_write; \
	VARIABLE trans4_analysis_NUMBER_OF_RANGES; \
	MENU trans4_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans4_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans4_analysis_RANGE_1; \
	VARIABLE trans4_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans4_analysis_RANGE_1_End_of_Range; \
	MENU trans4_analysis_RANGE_1_page; \
	COMMAND trans4_analysis_RANGE_1_read; \
	COMMAND trans4_analysis_RANGE_1_write; \
	UNIT trans4_analysis_unit_1; \
	METHOD trans4_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans4_analysis_SAMPLING_RATE_Visible

#define USE_TRANS4_ANALYSIS_MANDATORY_A \
	USE_TRANS4_ANALYSIS_MANDATORY_BOTH; \
	MENU trans4_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS4_ANALYSIS_MANDATORY_B \
	USE_TRANS4_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans4_analysis_VIEW_1; \
	MENU trans4_analysis_VIEW_1_page; \
	MENU trans4_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS4_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans4_analysis_VIEW_2; \
	MENU trans4_analysis_VIEW_2_page; \
	COLLECTION trans4_analysis_VIEW_3; \
	MENU trans4_analysis_VIEW_3_page

#define USE_TRANS4_ANALYSIS_OPTIONAL_A \
	USE_TRANS4_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans4_analysis_VIEW_1; \
	MENU trans4_analysis_VIEW_1_page; \
	MENU trans4_analysis_Simple_Dialog_Optional_A

#define USE_TRANS4_ANALYSIS_OPTIONAL_B \
	USE_TRANS4_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans4_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans4_analysis_)
#define USE_TRANS4_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans4_analysis_)
#define USE_TRANS4_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans4_analysis_)
#define USE_TRANS4_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans4_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans5_analysis_block; \
	COLLECTION trans5_analysis_BLOCK_OBJECT; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_analysis_BLOCK_OBJECT_page; \
	COMMAND trans5_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans5_analysis_ST_REV; \
	MENU trans5_analysis_ST_REV_page; \
	COMMAND trans5_analysis_ST_REV_read; \
	VARIABLE trans5_analysis_TAG_DESC; \
	MENU trans5_analysis_TAG_DESC_page; \
	COMMAND trans5_analysis_TAG_DESC_read; \
	COMMAND trans5_analysis_TAG_DESC_write; \
	VARIABLE trans5_analysis_STRATEGY; \
	MENU trans5_analysis_STRATEGY_page; \
	COMMAND trans5_analysis_STRATEGY_read; \
	COMMAND trans5_analysis_STRATEGY_write; \
	VARIABLE trans5_analysis_ALERT_KEY; \
	MENU trans5_analysis_ALERT_KEY_page; \
	COMMAND trans5_analysis_ALERT_KEY_read; \
	COMMAND trans5_analysis_ALERT_KEY_write; \
	VARIABLE trans5_analysis_TARGET_MODE; \
	MENU trans5_analysis_TARGET_MODE_page; \
	COMMAND trans5_analysis_TARGET_MODE_read; \
	COMMAND trans5_analysis_TARGET_MODE_write; \
	COLLECTION trans5_analysis_MODE_BLK; \
	VARIABLE trans5_analysis_MODE_BLK_Actual; \
	VARIABLE trans5_analysis_MODE_BLK_Permitted; \
	VARIABLE trans5_analysis_MODE_BLK_Normal; \
	MENU trans5_analysis_MODE_BLK_page; \
	COMMAND trans5_analysis_MODE_BLK_read; \
	COLLECTION trans5_analysis_ALARM_SUM; \
	VARIABLE trans5_analysis_ALARM_SUM_Current; \
	VARIABLE trans5_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans5_analysis_ALARM_SUM_Disabled; \
	MENU trans5_analysis_ALARM_SUM_page; \
	COMMAND trans5_analysis_ALARM_SUM_read; \
	VARIABLE trans5_analysis_COMPONENT_NAME; \
	MENU trans5_analysis_COMPONENT_NAME_page; \
	COMMAND trans5_analysis_COMPONENT_NAME_read; \
	COMMAND trans5_analysis_COMPONENT_NAME_write; \
	COLLECTION trans5_analysis_PV; \
	VARIABLE trans5_analysis_PV_PV; \
	VARIABLE trans5_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans5_analysis_PV_PV_Time; \
	VARIABLE trans5_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans5_analysis_PV_Measurement_Status_Limit; \
	MENU trans5_analysis_PV_page; \
	COMMAND trans5_analysis_PV_read; \
	VARIABLE trans5_analysis_PV_UNIT; \
	MENU trans5_analysis_PV_UNIT_page; \
	COMMAND trans5_analysis_PV_UNIT_read; \
	COMMAND trans5_analysis_PV_UNIT_write; \
	VARIABLE trans5_analysis_PV_UNIT_TEXT; \
	MENU trans5_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans5_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans5_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans5_analysis_ACTIVE_RANGE; \
	MENU trans5_analysis_ACTIVE_RANGE_page; \
	COMMAND trans5_analysis_ACTIVE_RANGE_read; \
	COMMAND trans5_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans5_analysis_AUTORANGE_ON; \
	MENU trans5_analysis_AUTORANGE_ON_page; \
	COMMAND trans5_analysis_AUTORANGE_ON_read; \
	COMMAND trans5_analysis_AUTORANGE_ON_write; \
	VARIABLE trans5_analysis_SAMPLING_RATE; \
	MENU trans5_analysis_SAMPLING_RATE_page; \
	COMMAND trans5_analysis_SAMPLING_RATE_read; \
	COMMAND trans5_analysis_SAMPLING_RATE_write; \
	VARIABLE trans5_analysis_NUMBER_OF_RANGES; \
	MENU trans5_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans5_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans5_analysis_RANGE_1; \
	VARIABLE trans5_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans5_analysis_RANGE_1_End_of_Range; \
	MENU trans5_analysis_RANGE_1_page; \
	COMMAND trans5_analysis_RANGE_1_read; \
	COMMAND trans5_analysis_RANGE_1_write; \
	UNIT trans5_analysis_unit_1; \
	METHOD trans5_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans5_analysis_SAMPLING_RATE_Visible

#define USE_TRANS5_ANALYSIS_MANDATORY_A \
	USE_TRANS5_ANALYSIS_MANDATORY_BOTH; \
	MENU trans5_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS5_ANALYSIS_MANDATORY_B \
	USE_TRANS5_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans5_analysis_VIEW_1; \
	MENU trans5_analysis_VIEW_1_page; \
	MENU trans5_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS5_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans5_analysis_VIEW_2; \
	MENU trans5_analysis_VIEW_2_page; \
	COLLECTION trans5_analysis_VIEW_3; \
	MENU trans5_analysis_VIEW_3_page

#define USE_TRANS5_ANALYSIS_OPTIONAL_A \
	USE_TRANS5_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans5_analysis_VIEW_1; \
	MENU trans5_analysis_VIEW_1_page; \
	MENU trans5_analysis_Simple_Dialog_Optional_A

#define USE_TRANS5_ANALYSIS_OPTIONAL_B \
	USE_TRANS5_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans5_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans5_analysis_)
#define USE_TRANS5_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans5_analysis_)
#define USE_TRANS5_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans5_analysis_)
#define USE_TRANS5_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans5_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans6_analysis_block; \
	COLLECTION trans6_analysis_BLOCK_OBJECT; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_analysis_BLOCK_OBJECT_page; \
	COMMAND trans6_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans6_analysis_ST_REV; \
	MENU trans6_analysis_ST_REV_page; \
	COMMAND trans6_analysis_ST_REV_read; \
	VARIABLE trans6_analysis_TAG_DESC; \
	MENU trans6_analysis_TAG_DESC_page; \
	COMMAND trans6_analysis_TAG_DESC_read; \
	COMMAND trans6_analysis_TAG_DESC_write; \
	VARIABLE trans6_analysis_STRATEGY; \
	MENU trans6_analysis_STRATEGY_page; \
	COMMAND trans6_analysis_STRATEGY_read; \
	COMMAND trans6_analysis_STRATEGY_write; \
	VARIABLE trans6_analysis_ALERT_KEY; \
	MENU trans6_analysis_ALERT_KEY_page; \
	COMMAND trans6_analysis_ALERT_KEY_read; \
	COMMAND trans6_analysis_ALERT_KEY_write; \
	VARIABLE trans6_analysis_TARGET_MODE; \
	MENU trans6_analysis_TARGET_MODE_page; \
	COMMAND trans6_analysis_TARGET_MODE_read; \
	COMMAND trans6_analysis_TARGET_MODE_write; \
	COLLECTION trans6_analysis_MODE_BLK; \
	VARIABLE trans6_analysis_MODE_BLK_Actual; \
	VARIABLE trans6_analysis_MODE_BLK_Permitted; \
	VARIABLE trans6_analysis_MODE_BLK_Normal; \
	MENU trans6_analysis_MODE_BLK_page; \
	COMMAND trans6_analysis_MODE_BLK_read; \
	COLLECTION trans6_analysis_ALARM_SUM; \
	VARIABLE trans6_analysis_ALARM_SUM_Current; \
	VARIABLE trans6_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans6_analysis_ALARM_SUM_Disabled; \
	MENU trans6_analysis_ALARM_SUM_page; \
	COMMAND trans6_analysis_ALARM_SUM_read; \
	VARIABLE trans6_analysis_COMPONENT_NAME; \
	MENU trans6_analysis_COMPONENT_NAME_page; \
	COMMAND trans6_analysis_COMPONENT_NAME_read; \
	COMMAND trans6_analysis_COMPONENT_NAME_write; \
	COLLECTION trans6_analysis_PV; \
	VARIABLE trans6_analysis_PV_PV; \
	VARIABLE trans6_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans6_analysis_PV_PV_Time; \
	VARIABLE trans6_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans6_analysis_PV_Measurement_Status_Limit; \
	MENU trans6_analysis_PV_page; \
	COMMAND trans6_analysis_PV_read; \
	VARIABLE trans6_analysis_PV_UNIT; \
	MENU trans6_analysis_PV_UNIT_page; \
	COMMAND trans6_analysis_PV_UNIT_read; \
	COMMAND trans6_analysis_PV_UNIT_write; \
	VARIABLE trans6_analysis_PV_UNIT_TEXT; \
	MENU trans6_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans6_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans6_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans6_analysis_ACTIVE_RANGE; \
	MENU trans6_analysis_ACTIVE_RANGE_page; \
	COMMAND trans6_analysis_ACTIVE_RANGE_read; \
	COMMAND trans6_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans6_analysis_AUTORANGE_ON; \
	MENU trans6_analysis_AUTORANGE_ON_page; \
	COMMAND trans6_analysis_AUTORANGE_ON_read; \
	COMMAND trans6_analysis_AUTORANGE_ON_write; \
	VARIABLE trans6_analysis_SAMPLING_RATE; \
	MENU trans6_analysis_SAMPLING_RATE_page; \
	COMMAND trans6_analysis_SAMPLING_RATE_read; \
	COMMAND trans6_analysis_SAMPLING_RATE_write; \
	VARIABLE trans6_analysis_NUMBER_OF_RANGES; \
	MENU trans6_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans6_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans6_analysis_RANGE_1; \
	VARIABLE trans6_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans6_analysis_RANGE_1_End_of_Range; \
	MENU trans6_analysis_RANGE_1_page; \
	COMMAND trans6_analysis_RANGE_1_read; \
	COMMAND trans6_analysis_RANGE_1_write; \
	UNIT trans6_analysis_unit_1; \
	METHOD trans6_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans6_analysis_SAMPLING_RATE_Visible

#define USE_TRANS6_ANALYSIS_MANDATORY_A \
	USE_TRANS6_ANALYSIS_MANDATORY_BOTH; \
	MENU trans6_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS6_ANALYSIS_MANDATORY_B \
	USE_TRANS6_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans6_analysis_VIEW_1; \
	MENU trans6_analysis_VIEW_1_page; \
	MENU trans6_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS6_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans6_analysis_VIEW_2; \
	MENU trans6_analysis_VIEW_2_page; \
	COLLECTION trans6_analysis_VIEW_3; \
	MENU trans6_analysis_VIEW_3_page

#define USE_TRANS6_ANALYSIS_OPTIONAL_A \
	USE_TRANS6_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans6_analysis_VIEW_1; \
	MENU trans6_analysis_VIEW_1_page; \
	MENU trans6_analysis_Simple_Dialog_Optional_A

#define USE_TRANS6_ANALYSIS_OPTIONAL_B \
	USE_TRANS6_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans6_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans6_analysis_)
#define USE_TRANS6_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans6_analysis_)
#define USE_TRANS6_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans6_analysis_)
#define USE_TRANS6_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans6_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans7_analysis_block; \
	COLLECTION trans7_analysis_BLOCK_OBJECT; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_analysis_BLOCK_OBJECT_page; \
	COMMAND trans7_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans7_analysis_ST_REV; \
	MENU trans7_analysis_ST_REV_page; \
	COMMAND trans7_analysis_ST_REV_read; \
	VARIABLE trans7_analysis_TAG_DESC; \
	MENU trans7_analysis_TAG_DESC_page; \
	COMMAND trans7_analysis_TAG_DESC_read; \
	COMMAND trans7_analysis_TAG_DESC_write; \
	VARIABLE trans7_analysis_STRATEGY; \
	MENU trans7_analysis_STRATEGY_page; \
	COMMAND trans7_analysis_STRATEGY_read; \
	COMMAND trans7_analysis_STRATEGY_write; \
	VARIABLE trans7_analysis_ALERT_KEY; \
	MENU trans7_analysis_ALERT_KEY_page; \
	COMMAND trans7_analysis_ALERT_KEY_read; \
	COMMAND trans7_analysis_ALERT_KEY_write; \
	VARIABLE trans7_analysis_TARGET_MODE; \
	MENU trans7_analysis_TARGET_MODE_page; \
	COMMAND trans7_analysis_TARGET_MODE_read; \
	COMMAND trans7_analysis_TARGET_MODE_write; \
	COLLECTION trans7_analysis_MODE_BLK; \
	VARIABLE trans7_analysis_MODE_BLK_Actual; \
	VARIABLE trans7_analysis_MODE_BLK_Permitted; \
	VARIABLE trans7_analysis_MODE_BLK_Normal; \
	MENU trans7_analysis_MODE_BLK_page; \
	COMMAND trans7_analysis_MODE_BLK_read; \
	COLLECTION trans7_analysis_ALARM_SUM; \
	VARIABLE trans7_analysis_ALARM_SUM_Current; \
	VARIABLE trans7_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans7_analysis_ALARM_SUM_Disabled; \
	MENU trans7_analysis_ALARM_SUM_page; \
	COMMAND trans7_analysis_ALARM_SUM_read; \
	VARIABLE trans7_analysis_COMPONENT_NAME; \
	MENU trans7_analysis_COMPONENT_NAME_page; \
	COMMAND trans7_analysis_COMPONENT_NAME_read; \
	COMMAND trans7_analysis_COMPONENT_NAME_write; \
	COLLECTION trans7_analysis_PV; \
	VARIABLE trans7_analysis_PV_PV; \
	VARIABLE trans7_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans7_analysis_PV_PV_Time; \
	VARIABLE trans7_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans7_analysis_PV_Measurement_Status_Limit; \
	MENU trans7_analysis_PV_page; \
	COMMAND trans7_analysis_PV_read; \
	VARIABLE trans7_analysis_PV_UNIT; \
	MENU trans7_analysis_PV_UNIT_page; \
	COMMAND trans7_analysis_PV_UNIT_read; \
	COMMAND trans7_analysis_PV_UNIT_write; \
	VARIABLE trans7_analysis_PV_UNIT_TEXT; \
	MENU trans7_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans7_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans7_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans7_analysis_ACTIVE_RANGE; \
	MENU trans7_analysis_ACTIVE_RANGE_page; \
	COMMAND trans7_analysis_ACTIVE_RANGE_read; \
	COMMAND trans7_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans7_analysis_AUTORANGE_ON; \
	MENU trans7_analysis_AUTORANGE_ON_page; \
	COMMAND trans7_analysis_AUTORANGE_ON_read; \
	COMMAND trans7_analysis_AUTORANGE_ON_write; \
	VARIABLE trans7_analysis_SAMPLING_RATE; \
	MENU trans7_analysis_SAMPLING_RATE_page; \
	COMMAND trans7_analysis_SAMPLING_RATE_read; \
	COMMAND trans7_analysis_SAMPLING_RATE_write; \
	VARIABLE trans7_analysis_NUMBER_OF_RANGES; \
	MENU trans7_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans7_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans7_analysis_RANGE_1; \
	VARIABLE trans7_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans7_analysis_RANGE_1_End_of_Range; \
	MENU trans7_analysis_RANGE_1_page; \
	COMMAND trans7_analysis_RANGE_1_read; \
	COMMAND trans7_analysis_RANGE_1_write; \
	UNIT trans7_analysis_unit_1; \
	METHOD trans7_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans7_analysis_SAMPLING_RATE_Visible

#define USE_TRANS7_ANALYSIS_MANDATORY_A \
	USE_TRANS7_ANALYSIS_MANDATORY_BOTH; \
	MENU trans7_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS7_ANALYSIS_MANDATORY_B \
	USE_TRANS7_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans7_analysis_VIEW_1; \
	MENU trans7_analysis_VIEW_1_page; \
	MENU trans7_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS7_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans7_analysis_VIEW_2; \
	MENU trans7_analysis_VIEW_2_page; \
	COLLECTION trans7_analysis_VIEW_3; \
	MENU trans7_analysis_VIEW_3_page

#define USE_TRANS7_ANALYSIS_OPTIONAL_A \
	USE_TRANS7_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans7_analysis_VIEW_1; \
	MENU trans7_analysis_VIEW_1_page; \
	MENU trans7_analysis_Simple_Dialog_Optional_A

#define USE_TRANS7_ANALYSIS_OPTIONAL_B \
	USE_TRANS7_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans7_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans7_analysis_)
#define USE_TRANS7_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans7_analysis_)
#define USE_TRANS7_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans7_analysis_)
#define USE_TRANS7_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans7_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans8_analysis_block; \
	COLLECTION trans8_analysis_BLOCK_OBJECT; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_analysis_BLOCK_OBJECT_page; \
	COMMAND trans8_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans8_analysis_ST_REV; \
	MENU trans8_analysis_ST_REV_page; \
	COMMAND trans8_analysis_ST_REV_read; \
	VARIABLE trans8_analysis_TAG_DESC; \
	MENU trans8_analysis_TAG_DESC_page; \
	COMMAND trans8_analysis_TAG_DESC_read; \
	COMMAND trans8_analysis_TAG_DESC_write; \
	VARIABLE trans8_analysis_STRATEGY; \
	MENU trans8_analysis_STRATEGY_page; \
	COMMAND trans8_analysis_STRATEGY_read; \
	COMMAND trans8_analysis_STRATEGY_write; \
	VARIABLE trans8_analysis_ALERT_KEY; \
	MENU trans8_analysis_ALERT_KEY_page; \
	COMMAND trans8_analysis_ALERT_KEY_read; \
	COMMAND trans8_analysis_ALERT_KEY_write; \
	VARIABLE trans8_analysis_TARGET_MODE; \
	MENU trans8_analysis_TARGET_MODE_page; \
	COMMAND trans8_analysis_TARGET_MODE_read; \
	COMMAND trans8_analysis_TARGET_MODE_write; \
	COLLECTION trans8_analysis_MODE_BLK; \
	VARIABLE trans8_analysis_MODE_BLK_Actual; \
	VARIABLE trans8_analysis_MODE_BLK_Permitted; \
	VARIABLE trans8_analysis_MODE_BLK_Normal; \
	MENU trans8_analysis_MODE_BLK_page; \
	COMMAND trans8_analysis_MODE_BLK_read; \
	COLLECTION trans8_analysis_ALARM_SUM; \
	VARIABLE trans8_analysis_ALARM_SUM_Current; \
	VARIABLE trans8_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans8_analysis_ALARM_SUM_Disabled; \
	MENU trans8_analysis_ALARM_SUM_page; \
	COMMAND trans8_analysis_ALARM_SUM_read; \
	VARIABLE trans8_analysis_COMPONENT_NAME; \
	MENU trans8_analysis_COMPONENT_NAME_page; \
	COMMAND trans8_analysis_COMPONENT_NAME_read; \
	COMMAND trans8_analysis_COMPONENT_NAME_write; \
	COLLECTION trans8_analysis_PV; \
	VARIABLE trans8_analysis_PV_PV; \
	VARIABLE trans8_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans8_analysis_PV_PV_Time; \
	VARIABLE trans8_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans8_analysis_PV_Measurement_Status_Limit; \
	MENU trans8_analysis_PV_page; \
	COMMAND trans8_analysis_PV_read; \
	VARIABLE trans8_analysis_PV_UNIT; \
	MENU trans8_analysis_PV_UNIT_page; \
	COMMAND trans8_analysis_PV_UNIT_read; \
	COMMAND trans8_analysis_PV_UNIT_write; \
	VARIABLE trans8_analysis_PV_UNIT_TEXT; \
	MENU trans8_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans8_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans8_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans8_analysis_ACTIVE_RANGE; \
	MENU trans8_analysis_ACTIVE_RANGE_page; \
	COMMAND trans8_analysis_ACTIVE_RANGE_read; \
	COMMAND trans8_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans8_analysis_AUTORANGE_ON; \
	MENU trans8_analysis_AUTORANGE_ON_page; \
	COMMAND trans8_analysis_AUTORANGE_ON_read; \
	COMMAND trans8_analysis_AUTORANGE_ON_write; \
	VARIABLE trans8_analysis_SAMPLING_RATE; \
	MENU trans8_analysis_SAMPLING_RATE_page; \
	COMMAND trans8_analysis_SAMPLING_RATE_read; \
	COMMAND trans8_analysis_SAMPLING_RATE_write; \
	VARIABLE trans8_analysis_NUMBER_OF_RANGES; \
	MENU trans8_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans8_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans8_analysis_RANGE_1; \
	VARIABLE trans8_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans8_analysis_RANGE_1_End_of_Range; \
	MENU trans8_analysis_RANGE_1_page; \
	COMMAND trans8_analysis_RANGE_1_read; \
	COMMAND trans8_analysis_RANGE_1_write; \
	UNIT trans8_analysis_unit_1; \
	METHOD trans8_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans8_analysis_SAMPLING_RATE_Visible

#define USE_TRANS8_ANALYSIS_MANDATORY_A \
	USE_TRANS8_ANALYSIS_MANDATORY_BOTH; \
	MENU trans8_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS8_ANALYSIS_MANDATORY_B \
	USE_TRANS8_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans8_analysis_VIEW_1; \
	MENU trans8_analysis_VIEW_1_page; \
	MENU trans8_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS8_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans8_analysis_VIEW_2; \
	MENU trans8_analysis_VIEW_2_page; \
	COLLECTION trans8_analysis_VIEW_3; \
	MENU trans8_analysis_VIEW_3_page

#define USE_TRANS8_ANALYSIS_OPTIONAL_A \
	USE_TRANS8_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans8_analysis_VIEW_1; \
	MENU trans8_analysis_VIEW_1_page; \
	MENU trans8_analysis_Simple_Dialog_Optional_A

#define USE_TRANS8_ANALYSIS_OPTIONAL_B \
	USE_TRANS8_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans8_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans8_analysis_)
#define USE_TRANS8_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans8_analysis_)
#define USE_TRANS8_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans8_analysis_)
#define USE_TRANS8_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans8_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans9_analysis_block; \
	COLLECTION trans9_analysis_BLOCK_OBJECT; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_analysis_BLOCK_OBJECT_page; \
	COMMAND trans9_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans9_analysis_ST_REV; \
	MENU trans9_analysis_ST_REV_page; \
	COMMAND trans9_analysis_ST_REV_read; \
	VARIABLE trans9_analysis_TAG_DESC; \
	MENU trans9_analysis_TAG_DESC_page; \
	COMMAND trans9_analysis_TAG_DESC_read; \
	COMMAND trans9_analysis_TAG_DESC_write; \
	VARIABLE trans9_analysis_STRATEGY; \
	MENU trans9_analysis_STRATEGY_page; \
	COMMAND trans9_analysis_STRATEGY_read; \
	COMMAND trans9_analysis_STRATEGY_write; \
	VARIABLE trans9_analysis_ALERT_KEY; \
	MENU trans9_analysis_ALERT_KEY_page; \
	COMMAND trans9_analysis_ALERT_KEY_read; \
	COMMAND trans9_analysis_ALERT_KEY_write; \
	VARIABLE trans9_analysis_TARGET_MODE; \
	MENU trans9_analysis_TARGET_MODE_page; \
	COMMAND trans9_analysis_TARGET_MODE_read; \
	COMMAND trans9_analysis_TARGET_MODE_write; \
	COLLECTION trans9_analysis_MODE_BLK; \
	VARIABLE trans9_analysis_MODE_BLK_Actual; \
	VARIABLE trans9_analysis_MODE_BLK_Permitted; \
	VARIABLE trans9_analysis_MODE_BLK_Normal; \
	MENU trans9_analysis_MODE_BLK_page; \
	COMMAND trans9_analysis_MODE_BLK_read; \
	COLLECTION trans9_analysis_ALARM_SUM; \
	VARIABLE trans9_analysis_ALARM_SUM_Current; \
	VARIABLE trans9_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans9_analysis_ALARM_SUM_Disabled; \
	MENU trans9_analysis_ALARM_SUM_page; \
	COMMAND trans9_analysis_ALARM_SUM_read; \
	VARIABLE trans9_analysis_COMPONENT_NAME; \
	MENU trans9_analysis_COMPONENT_NAME_page; \
	COMMAND trans9_analysis_COMPONENT_NAME_read; \
	COMMAND trans9_analysis_COMPONENT_NAME_write; \
	COLLECTION trans9_analysis_PV; \
	VARIABLE trans9_analysis_PV_PV; \
	VARIABLE trans9_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans9_analysis_PV_PV_Time; \
	VARIABLE trans9_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans9_analysis_PV_Measurement_Status_Limit; \
	MENU trans9_analysis_PV_page; \
	COMMAND trans9_analysis_PV_read; \
	VARIABLE trans9_analysis_PV_UNIT; \
	MENU trans9_analysis_PV_UNIT_page; \
	COMMAND trans9_analysis_PV_UNIT_read; \
	COMMAND trans9_analysis_PV_UNIT_write; \
	VARIABLE trans9_analysis_PV_UNIT_TEXT; \
	MENU trans9_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans9_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans9_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans9_analysis_ACTIVE_RANGE; \
	MENU trans9_analysis_ACTIVE_RANGE_page; \
	COMMAND trans9_analysis_ACTIVE_RANGE_read; \
	COMMAND trans9_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans9_analysis_AUTORANGE_ON; \
	MENU trans9_analysis_AUTORANGE_ON_page; \
	COMMAND trans9_analysis_AUTORANGE_ON_read; \
	COMMAND trans9_analysis_AUTORANGE_ON_write; \
	VARIABLE trans9_analysis_SAMPLING_RATE; \
	MENU trans9_analysis_SAMPLING_RATE_page; \
	COMMAND trans9_analysis_SAMPLING_RATE_read; \
	COMMAND trans9_analysis_SAMPLING_RATE_write; \
	VARIABLE trans9_analysis_NUMBER_OF_RANGES; \
	MENU trans9_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans9_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans9_analysis_RANGE_1; \
	VARIABLE trans9_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans9_analysis_RANGE_1_End_of_Range; \
	MENU trans9_analysis_RANGE_1_page; \
	COMMAND trans9_analysis_RANGE_1_read; \
	COMMAND trans9_analysis_RANGE_1_write; \
	UNIT trans9_analysis_unit_1; \
	METHOD trans9_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans9_analysis_SAMPLING_RATE_Visible

#define USE_TRANS9_ANALYSIS_MANDATORY_A \
	USE_TRANS9_ANALYSIS_MANDATORY_BOTH; \
	MENU trans9_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS9_ANALYSIS_MANDATORY_B \
	USE_TRANS9_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans9_analysis_VIEW_1; \
	MENU trans9_analysis_VIEW_1_page; \
	MENU trans9_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS9_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans9_analysis_VIEW_2; \
	MENU trans9_analysis_VIEW_2_page; \
	COLLECTION trans9_analysis_VIEW_3; \
	MENU trans9_analysis_VIEW_3_page

#define USE_TRANS9_ANALYSIS_OPTIONAL_A \
	USE_TRANS9_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans9_analysis_VIEW_1; \
	MENU trans9_analysis_VIEW_1_page; \
	MENU trans9_analysis_Simple_Dialog_Optional_A

#define USE_TRANS9_ANALYSIS_OPTIONAL_B \
	USE_TRANS9_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans9_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans9_analysis_)
#define USE_TRANS9_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans9_analysis_)
#define USE_TRANS9_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans9_analysis_)
#define USE_TRANS9_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans9_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans10_analysis_block; \
	COLLECTION trans10_analysis_BLOCK_OBJECT; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_analysis_BLOCK_OBJECT_page; \
	COMMAND trans10_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans10_analysis_ST_REV; \
	MENU trans10_analysis_ST_REV_page; \
	COMMAND trans10_analysis_ST_REV_read; \
	VARIABLE trans10_analysis_TAG_DESC; \
	MENU trans10_analysis_TAG_DESC_page; \
	COMMAND trans10_analysis_TAG_DESC_read; \
	COMMAND trans10_analysis_TAG_DESC_write; \
	VARIABLE trans10_analysis_STRATEGY; \
	MENU trans10_analysis_STRATEGY_page; \
	COMMAND trans10_analysis_STRATEGY_read; \
	COMMAND trans10_analysis_STRATEGY_write; \
	VARIABLE trans10_analysis_ALERT_KEY; \
	MENU trans10_analysis_ALERT_KEY_page; \
	COMMAND trans10_analysis_ALERT_KEY_read; \
	COMMAND trans10_analysis_ALERT_KEY_write; \
	VARIABLE trans10_analysis_TARGET_MODE; \
	MENU trans10_analysis_TARGET_MODE_page; \
	COMMAND trans10_analysis_TARGET_MODE_read; \
	COMMAND trans10_analysis_TARGET_MODE_write; \
	COLLECTION trans10_analysis_MODE_BLK; \
	VARIABLE trans10_analysis_MODE_BLK_Actual; \
	VARIABLE trans10_analysis_MODE_BLK_Permitted; \
	VARIABLE trans10_analysis_MODE_BLK_Normal; \
	MENU trans10_analysis_MODE_BLK_page; \
	COMMAND trans10_analysis_MODE_BLK_read; \
	COLLECTION trans10_analysis_ALARM_SUM; \
	VARIABLE trans10_analysis_ALARM_SUM_Current; \
	VARIABLE trans10_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans10_analysis_ALARM_SUM_Disabled; \
	MENU trans10_analysis_ALARM_SUM_page; \
	COMMAND trans10_analysis_ALARM_SUM_read; \
	VARIABLE trans10_analysis_COMPONENT_NAME; \
	MENU trans10_analysis_COMPONENT_NAME_page; \
	COMMAND trans10_analysis_COMPONENT_NAME_read; \
	COMMAND trans10_analysis_COMPONENT_NAME_write; \
	COLLECTION trans10_analysis_PV; \
	VARIABLE trans10_analysis_PV_PV; \
	VARIABLE trans10_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans10_analysis_PV_PV_Time; \
	VARIABLE trans10_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans10_analysis_PV_Measurement_Status_Limit; \
	MENU trans10_analysis_PV_page; \
	COMMAND trans10_analysis_PV_read; \
	VARIABLE trans10_analysis_PV_UNIT; \
	MENU trans10_analysis_PV_UNIT_page; \
	COMMAND trans10_analysis_PV_UNIT_read; \
	COMMAND trans10_analysis_PV_UNIT_write; \
	VARIABLE trans10_analysis_PV_UNIT_TEXT; \
	MENU trans10_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans10_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans10_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans10_analysis_ACTIVE_RANGE; \
	MENU trans10_analysis_ACTIVE_RANGE_page; \
	COMMAND trans10_analysis_ACTIVE_RANGE_read; \
	COMMAND trans10_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans10_analysis_AUTORANGE_ON; \
	MENU trans10_analysis_AUTORANGE_ON_page; \
	COMMAND trans10_analysis_AUTORANGE_ON_read; \
	COMMAND trans10_analysis_AUTORANGE_ON_write; \
	VARIABLE trans10_analysis_SAMPLING_RATE; \
	MENU trans10_analysis_SAMPLING_RATE_page; \
	COMMAND trans10_analysis_SAMPLING_RATE_read; \
	COMMAND trans10_analysis_SAMPLING_RATE_write; \
	VARIABLE trans10_analysis_NUMBER_OF_RANGES; \
	MENU trans10_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans10_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans10_analysis_RANGE_1; \
	VARIABLE trans10_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans10_analysis_RANGE_1_End_of_Range; \
	MENU trans10_analysis_RANGE_1_page; \
	COMMAND trans10_analysis_RANGE_1_read; \
	COMMAND trans10_analysis_RANGE_1_write; \
	UNIT trans10_analysis_unit_1; \
	METHOD trans10_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans10_analysis_SAMPLING_RATE_Visible

#define USE_TRANS10_ANALYSIS_MANDATORY_A \
	USE_TRANS10_ANALYSIS_MANDATORY_BOTH; \
	MENU trans10_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS10_ANALYSIS_MANDATORY_B \
	USE_TRANS10_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans10_analysis_VIEW_1; \
	MENU trans10_analysis_VIEW_1_page; \
	MENU trans10_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS10_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans10_analysis_VIEW_2; \
	MENU trans10_analysis_VIEW_2_page; \
	COLLECTION trans10_analysis_VIEW_3; \
	MENU trans10_analysis_VIEW_3_page

#define USE_TRANS10_ANALYSIS_OPTIONAL_A \
	USE_TRANS10_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans10_analysis_VIEW_1; \
	MENU trans10_analysis_VIEW_1_page; \
	MENU trans10_analysis_Simple_Dialog_Optional_A

#define USE_TRANS10_ANALYSIS_OPTIONAL_B \
	USE_TRANS10_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans10_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans10_analysis_)
#define USE_TRANS10_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans10_analysis_)
#define USE_TRANS10_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans10_analysis_)
#define USE_TRANS10_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans10_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans11_analysis_block; \
	COLLECTION trans11_analysis_BLOCK_OBJECT; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_analysis_BLOCK_OBJECT_page; \
	COMMAND trans11_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans11_analysis_ST_REV; \
	MENU trans11_analysis_ST_REV_page; \
	COMMAND trans11_analysis_ST_REV_read; \
	VARIABLE trans11_analysis_TAG_DESC; \
	MENU trans11_analysis_TAG_DESC_page; \
	COMMAND trans11_analysis_TAG_DESC_read; \
	COMMAND trans11_analysis_TAG_DESC_write; \
	VARIABLE trans11_analysis_STRATEGY; \
	MENU trans11_analysis_STRATEGY_page; \
	COMMAND trans11_analysis_STRATEGY_read; \
	COMMAND trans11_analysis_STRATEGY_write; \
	VARIABLE trans11_analysis_ALERT_KEY; \
	MENU trans11_analysis_ALERT_KEY_page; \
	COMMAND trans11_analysis_ALERT_KEY_read; \
	COMMAND trans11_analysis_ALERT_KEY_write; \
	VARIABLE trans11_analysis_TARGET_MODE; \
	MENU trans11_analysis_TARGET_MODE_page; \
	COMMAND trans11_analysis_TARGET_MODE_read; \
	COMMAND trans11_analysis_TARGET_MODE_write; \
	COLLECTION trans11_analysis_MODE_BLK; \
	VARIABLE trans11_analysis_MODE_BLK_Actual; \
	VARIABLE trans11_analysis_MODE_BLK_Permitted; \
	VARIABLE trans11_analysis_MODE_BLK_Normal; \
	MENU trans11_analysis_MODE_BLK_page; \
	COMMAND trans11_analysis_MODE_BLK_read; \
	COLLECTION trans11_analysis_ALARM_SUM; \
	VARIABLE trans11_analysis_ALARM_SUM_Current; \
	VARIABLE trans11_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans11_analysis_ALARM_SUM_Disabled; \
	MENU trans11_analysis_ALARM_SUM_page; \
	COMMAND trans11_analysis_ALARM_SUM_read; \
	VARIABLE trans11_analysis_COMPONENT_NAME; \
	MENU trans11_analysis_COMPONENT_NAME_page; \
	COMMAND trans11_analysis_COMPONENT_NAME_read; \
	COMMAND trans11_analysis_COMPONENT_NAME_write; \
	COLLECTION trans11_analysis_PV; \
	VARIABLE trans11_analysis_PV_PV; \
	VARIABLE trans11_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans11_analysis_PV_PV_Time; \
	VARIABLE trans11_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans11_analysis_PV_Measurement_Status_Limit; \
	MENU trans11_analysis_PV_page; \
	COMMAND trans11_analysis_PV_read; \
	VARIABLE trans11_analysis_PV_UNIT; \
	MENU trans11_analysis_PV_UNIT_page; \
	COMMAND trans11_analysis_PV_UNIT_read; \
	COMMAND trans11_analysis_PV_UNIT_write; \
	VARIABLE trans11_analysis_PV_UNIT_TEXT; \
	MENU trans11_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans11_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans11_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans11_analysis_ACTIVE_RANGE; \
	MENU trans11_analysis_ACTIVE_RANGE_page; \
	COMMAND trans11_analysis_ACTIVE_RANGE_read; \
	COMMAND trans11_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans11_analysis_AUTORANGE_ON; \
	MENU trans11_analysis_AUTORANGE_ON_page; \
	COMMAND trans11_analysis_AUTORANGE_ON_read; \
	COMMAND trans11_analysis_AUTORANGE_ON_write; \
	VARIABLE trans11_analysis_SAMPLING_RATE; \
	MENU trans11_analysis_SAMPLING_RATE_page; \
	COMMAND trans11_analysis_SAMPLING_RATE_read; \
	COMMAND trans11_analysis_SAMPLING_RATE_write; \
	VARIABLE trans11_analysis_NUMBER_OF_RANGES; \
	MENU trans11_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans11_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans11_analysis_RANGE_1; \
	VARIABLE trans11_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans11_analysis_RANGE_1_End_of_Range; \
	MENU trans11_analysis_RANGE_1_page; \
	COMMAND trans11_analysis_RANGE_1_read; \
	COMMAND trans11_analysis_RANGE_1_write; \
	UNIT trans11_analysis_unit_1; \
	METHOD trans11_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans11_analysis_SAMPLING_RATE_Visible

#define USE_TRANS11_ANALYSIS_MANDATORY_A \
	USE_TRANS11_ANALYSIS_MANDATORY_BOTH; \
	MENU trans11_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS11_ANALYSIS_MANDATORY_B \
	USE_TRANS11_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans11_analysis_VIEW_1; \
	MENU trans11_analysis_VIEW_1_page; \
	MENU trans11_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS11_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans11_analysis_VIEW_2; \
	MENU trans11_analysis_VIEW_2_page; \
	COLLECTION trans11_analysis_VIEW_3; \
	MENU trans11_analysis_VIEW_3_page

#define USE_TRANS11_ANALYSIS_OPTIONAL_A \
	USE_TRANS11_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans11_analysis_VIEW_1; \
	MENU trans11_analysis_VIEW_1_page; \
	MENU trans11_analysis_Simple_Dialog_Optional_A

#define USE_TRANS11_ANALYSIS_OPTIONAL_B \
	USE_TRANS11_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans11_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans11_analysis_)
#define USE_TRANS11_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans11_analysis_)
#define USE_TRANS11_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans11_analysis_)
#define USE_TRANS11_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans11_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans12_analysis_block; \
	COLLECTION trans12_analysis_BLOCK_OBJECT; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_analysis_BLOCK_OBJECT_page; \
	COMMAND trans12_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans12_analysis_ST_REV; \
	MENU trans12_analysis_ST_REV_page; \
	COMMAND trans12_analysis_ST_REV_read; \
	VARIABLE trans12_analysis_TAG_DESC; \
	MENU trans12_analysis_TAG_DESC_page; \
	COMMAND trans12_analysis_TAG_DESC_read; \
	COMMAND trans12_analysis_TAG_DESC_write; \
	VARIABLE trans12_analysis_STRATEGY; \
	MENU trans12_analysis_STRATEGY_page; \
	COMMAND trans12_analysis_STRATEGY_read; \
	COMMAND trans12_analysis_STRATEGY_write; \
	VARIABLE trans12_analysis_ALERT_KEY; \
	MENU trans12_analysis_ALERT_KEY_page; \
	COMMAND trans12_analysis_ALERT_KEY_read; \
	COMMAND trans12_analysis_ALERT_KEY_write; \
	VARIABLE trans12_analysis_TARGET_MODE; \
	MENU trans12_analysis_TARGET_MODE_page; \
	COMMAND trans12_analysis_TARGET_MODE_read; \
	COMMAND trans12_analysis_TARGET_MODE_write; \
	COLLECTION trans12_analysis_MODE_BLK; \
	VARIABLE trans12_analysis_MODE_BLK_Actual; \
	VARIABLE trans12_analysis_MODE_BLK_Permitted; \
	VARIABLE trans12_analysis_MODE_BLK_Normal; \
	MENU trans12_analysis_MODE_BLK_page; \
	COMMAND trans12_analysis_MODE_BLK_read; \
	COLLECTION trans12_analysis_ALARM_SUM; \
	VARIABLE trans12_analysis_ALARM_SUM_Current; \
	VARIABLE trans12_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans12_analysis_ALARM_SUM_Disabled; \
	MENU trans12_analysis_ALARM_SUM_page; \
	COMMAND trans12_analysis_ALARM_SUM_read; \
	VARIABLE trans12_analysis_COMPONENT_NAME; \
	MENU trans12_analysis_COMPONENT_NAME_page; \
	COMMAND trans12_analysis_COMPONENT_NAME_read; \
	COMMAND trans12_analysis_COMPONENT_NAME_write; \
	COLLECTION trans12_analysis_PV; \
	VARIABLE trans12_analysis_PV_PV; \
	VARIABLE trans12_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans12_analysis_PV_PV_Time; \
	VARIABLE trans12_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans12_analysis_PV_Measurement_Status_Limit; \
	MENU trans12_analysis_PV_page; \
	COMMAND trans12_analysis_PV_read; \
	VARIABLE trans12_analysis_PV_UNIT; \
	MENU trans12_analysis_PV_UNIT_page; \
	COMMAND trans12_analysis_PV_UNIT_read; \
	COMMAND trans12_analysis_PV_UNIT_write; \
	VARIABLE trans12_analysis_PV_UNIT_TEXT; \
	MENU trans12_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans12_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans12_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans12_analysis_ACTIVE_RANGE; \
	MENU trans12_analysis_ACTIVE_RANGE_page; \
	COMMAND trans12_analysis_ACTIVE_RANGE_read; \
	COMMAND trans12_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans12_analysis_AUTORANGE_ON; \
	MENU trans12_analysis_AUTORANGE_ON_page; \
	COMMAND trans12_analysis_AUTORANGE_ON_read; \
	COMMAND trans12_analysis_AUTORANGE_ON_write; \
	VARIABLE trans12_analysis_SAMPLING_RATE; \
	MENU trans12_analysis_SAMPLING_RATE_page; \
	COMMAND trans12_analysis_SAMPLING_RATE_read; \
	COMMAND trans12_analysis_SAMPLING_RATE_write; \
	VARIABLE trans12_analysis_NUMBER_OF_RANGES; \
	MENU trans12_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans12_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans12_analysis_RANGE_1; \
	VARIABLE trans12_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans12_analysis_RANGE_1_End_of_Range; \
	MENU trans12_analysis_RANGE_1_page; \
	COMMAND trans12_analysis_RANGE_1_read; \
	COMMAND trans12_analysis_RANGE_1_write; \
	UNIT trans12_analysis_unit_1; \
	METHOD trans12_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans12_analysis_SAMPLING_RATE_Visible

#define USE_TRANS12_ANALYSIS_MANDATORY_A \
	USE_TRANS12_ANALYSIS_MANDATORY_BOTH; \
	MENU trans12_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS12_ANALYSIS_MANDATORY_B \
	USE_TRANS12_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans12_analysis_VIEW_1; \
	MENU trans12_analysis_VIEW_1_page; \
	MENU trans12_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS12_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans12_analysis_VIEW_2; \
	MENU trans12_analysis_VIEW_2_page; \
	COLLECTION trans12_analysis_VIEW_3; \
	MENU trans12_analysis_VIEW_3_page

#define USE_TRANS12_ANALYSIS_OPTIONAL_A \
	USE_TRANS12_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans12_analysis_VIEW_1; \
	MENU trans12_analysis_VIEW_1_page; \
	MENU trans12_analysis_Simple_Dialog_Optional_A

#define USE_TRANS12_ANALYSIS_OPTIONAL_B \
	USE_TRANS12_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans12_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans12_analysis_)
#define USE_TRANS12_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans12_analysis_)
#define USE_TRANS12_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans12_analysis_)
#define USE_TRANS12_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans12_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans13_analysis_block; \
	COLLECTION trans13_analysis_BLOCK_OBJECT; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_analysis_BLOCK_OBJECT_page; \
	COMMAND trans13_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans13_analysis_ST_REV; \
	MENU trans13_analysis_ST_REV_page; \
	COMMAND trans13_analysis_ST_REV_read; \
	VARIABLE trans13_analysis_TAG_DESC; \
	MENU trans13_analysis_TAG_DESC_page; \
	COMMAND trans13_analysis_TAG_DESC_read; \
	COMMAND trans13_analysis_TAG_DESC_write; \
	VARIABLE trans13_analysis_STRATEGY; \
	MENU trans13_analysis_STRATEGY_page; \
	COMMAND trans13_analysis_STRATEGY_read; \
	COMMAND trans13_analysis_STRATEGY_write; \
	VARIABLE trans13_analysis_ALERT_KEY; \
	MENU trans13_analysis_ALERT_KEY_page; \
	COMMAND trans13_analysis_ALERT_KEY_read; \
	COMMAND trans13_analysis_ALERT_KEY_write; \
	VARIABLE trans13_analysis_TARGET_MODE; \
	MENU trans13_analysis_TARGET_MODE_page; \
	COMMAND trans13_analysis_TARGET_MODE_read; \
	COMMAND trans13_analysis_TARGET_MODE_write; \
	COLLECTION trans13_analysis_MODE_BLK; \
	VARIABLE trans13_analysis_MODE_BLK_Actual; \
	VARIABLE trans13_analysis_MODE_BLK_Permitted; \
	VARIABLE trans13_analysis_MODE_BLK_Normal; \
	MENU trans13_analysis_MODE_BLK_page; \
	COMMAND trans13_analysis_MODE_BLK_read; \
	COLLECTION trans13_analysis_ALARM_SUM; \
	VARIABLE trans13_analysis_ALARM_SUM_Current; \
	VARIABLE trans13_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans13_analysis_ALARM_SUM_Disabled; \
	MENU trans13_analysis_ALARM_SUM_page; \
	COMMAND trans13_analysis_ALARM_SUM_read; \
	VARIABLE trans13_analysis_COMPONENT_NAME; \
	MENU trans13_analysis_COMPONENT_NAME_page; \
	COMMAND trans13_analysis_COMPONENT_NAME_read; \
	COMMAND trans13_analysis_COMPONENT_NAME_write; \
	COLLECTION trans13_analysis_PV; \
	VARIABLE trans13_analysis_PV_PV; \
	VARIABLE trans13_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans13_analysis_PV_PV_Time; \
	VARIABLE trans13_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans13_analysis_PV_Measurement_Status_Limit; \
	MENU trans13_analysis_PV_page; \
	COMMAND trans13_analysis_PV_read; \
	VARIABLE trans13_analysis_PV_UNIT; \
	MENU trans13_analysis_PV_UNIT_page; \
	COMMAND trans13_analysis_PV_UNIT_read; \
	COMMAND trans13_analysis_PV_UNIT_write; \
	VARIABLE trans13_analysis_PV_UNIT_TEXT; \
	MENU trans13_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans13_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans13_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans13_analysis_ACTIVE_RANGE; \
	MENU trans13_analysis_ACTIVE_RANGE_page; \
	COMMAND trans13_analysis_ACTIVE_RANGE_read; \
	COMMAND trans13_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans13_analysis_AUTORANGE_ON; \
	MENU trans13_analysis_AUTORANGE_ON_page; \
	COMMAND trans13_analysis_AUTORANGE_ON_read; \
	COMMAND trans13_analysis_AUTORANGE_ON_write; \
	VARIABLE trans13_analysis_SAMPLING_RATE; \
	MENU trans13_analysis_SAMPLING_RATE_page; \
	COMMAND trans13_analysis_SAMPLING_RATE_read; \
	COMMAND trans13_analysis_SAMPLING_RATE_write; \
	VARIABLE trans13_analysis_NUMBER_OF_RANGES; \
	MENU trans13_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans13_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans13_analysis_RANGE_1; \
	VARIABLE trans13_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans13_analysis_RANGE_1_End_of_Range; \
	MENU trans13_analysis_RANGE_1_page; \
	COMMAND trans13_analysis_RANGE_1_read; \
	COMMAND trans13_analysis_RANGE_1_write; \
	UNIT trans13_analysis_unit_1; \
	METHOD trans13_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans13_analysis_SAMPLING_RATE_Visible

#define USE_TRANS13_ANALYSIS_MANDATORY_A \
	USE_TRANS13_ANALYSIS_MANDATORY_BOTH; \
	MENU trans13_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS13_ANALYSIS_MANDATORY_B \
	USE_TRANS13_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans13_analysis_VIEW_1; \
	MENU trans13_analysis_VIEW_1_page; \
	MENU trans13_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS13_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans13_analysis_VIEW_2; \
	MENU trans13_analysis_VIEW_2_page; \
	COLLECTION trans13_analysis_VIEW_3; \
	MENU trans13_analysis_VIEW_3_page

#define USE_TRANS13_ANALYSIS_OPTIONAL_A \
	USE_TRANS13_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans13_analysis_VIEW_1; \
	MENU trans13_analysis_VIEW_1_page; \
	MENU trans13_analysis_Simple_Dialog_Optional_A

#define USE_TRANS13_ANALYSIS_OPTIONAL_B \
	USE_TRANS13_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans13_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans13_analysis_)
#define USE_TRANS13_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans13_analysis_)
#define USE_TRANS13_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans13_analysis_)
#define USE_TRANS13_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans13_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans14_analysis_block; \
	COLLECTION trans14_analysis_BLOCK_OBJECT; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_analysis_BLOCK_OBJECT_page; \
	COMMAND trans14_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans14_analysis_ST_REV; \
	MENU trans14_analysis_ST_REV_page; \
	COMMAND trans14_analysis_ST_REV_read; \
	VARIABLE trans14_analysis_TAG_DESC; \
	MENU trans14_analysis_TAG_DESC_page; \
	COMMAND trans14_analysis_TAG_DESC_read; \
	COMMAND trans14_analysis_TAG_DESC_write; \
	VARIABLE trans14_analysis_STRATEGY; \
	MENU trans14_analysis_STRATEGY_page; \
	COMMAND trans14_analysis_STRATEGY_read; \
	COMMAND trans14_analysis_STRATEGY_write; \
	VARIABLE trans14_analysis_ALERT_KEY; \
	MENU trans14_analysis_ALERT_KEY_page; \
	COMMAND trans14_analysis_ALERT_KEY_read; \
	COMMAND trans14_analysis_ALERT_KEY_write; \
	VARIABLE trans14_analysis_TARGET_MODE; \
	MENU trans14_analysis_TARGET_MODE_page; \
	COMMAND trans14_analysis_TARGET_MODE_read; \
	COMMAND trans14_analysis_TARGET_MODE_write; \
	COLLECTION trans14_analysis_MODE_BLK; \
	VARIABLE trans14_analysis_MODE_BLK_Actual; \
	VARIABLE trans14_analysis_MODE_BLK_Permitted; \
	VARIABLE trans14_analysis_MODE_BLK_Normal; \
	MENU trans14_analysis_MODE_BLK_page; \
	COMMAND trans14_analysis_MODE_BLK_read; \
	COLLECTION trans14_analysis_ALARM_SUM; \
	VARIABLE trans14_analysis_ALARM_SUM_Current; \
	VARIABLE trans14_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans14_analysis_ALARM_SUM_Disabled; \
	MENU trans14_analysis_ALARM_SUM_page; \
	COMMAND trans14_analysis_ALARM_SUM_read; \
	VARIABLE trans14_analysis_COMPONENT_NAME; \
	MENU trans14_analysis_COMPONENT_NAME_page; \
	COMMAND trans14_analysis_COMPONENT_NAME_read; \
	COMMAND trans14_analysis_COMPONENT_NAME_write; \
	COLLECTION trans14_analysis_PV; \
	VARIABLE trans14_analysis_PV_PV; \
	VARIABLE trans14_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans14_analysis_PV_PV_Time; \
	VARIABLE trans14_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans14_analysis_PV_Measurement_Status_Limit; \
	MENU trans14_analysis_PV_page; \
	COMMAND trans14_analysis_PV_read; \
	VARIABLE trans14_analysis_PV_UNIT; \
	MENU trans14_analysis_PV_UNIT_page; \
	COMMAND trans14_analysis_PV_UNIT_read; \
	COMMAND trans14_analysis_PV_UNIT_write; \
	VARIABLE trans14_analysis_PV_UNIT_TEXT; \
	MENU trans14_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans14_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans14_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans14_analysis_ACTIVE_RANGE; \
	MENU trans14_analysis_ACTIVE_RANGE_page; \
	COMMAND trans14_analysis_ACTIVE_RANGE_read; \
	COMMAND trans14_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans14_analysis_AUTORANGE_ON; \
	MENU trans14_analysis_AUTORANGE_ON_page; \
	COMMAND trans14_analysis_AUTORANGE_ON_read; \
	COMMAND trans14_analysis_AUTORANGE_ON_write; \
	VARIABLE trans14_analysis_SAMPLING_RATE; \
	MENU trans14_analysis_SAMPLING_RATE_page; \
	COMMAND trans14_analysis_SAMPLING_RATE_read; \
	COMMAND trans14_analysis_SAMPLING_RATE_write; \
	VARIABLE trans14_analysis_NUMBER_OF_RANGES; \
	MENU trans14_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans14_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans14_analysis_RANGE_1; \
	VARIABLE trans14_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans14_analysis_RANGE_1_End_of_Range; \
	MENU trans14_analysis_RANGE_1_page; \
	COMMAND trans14_analysis_RANGE_1_read; \
	COMMAND trans14_analysis_RANGE_1_write; \
	UNIT trans14_analysis_unit_1; \
	METHOD trans14_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans14_analysis_SAMPLING_RATE_Visible

#define USE_TRANS14_ANALYSIS_MANDATORY_A \
	USE_TRANS14_ANALYSIS_MANDATORY_BOTH; \
	MENU trans14_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS14_ANALYSIS_MANDATORY_B \
	USE_TRANS14_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans14_analysis_VIEW_1; \
	MENU trans14_analysis_VIEW_1_page; \
	MENU trans14_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS14_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans14_analysis_VIEW_2; \
	MENU trans14_analysis_VIEW_2_page; \
	COLLECTION trans14_analysis_VIEW_3; \
	MENU trans14_analysis_VIEW_3_page

#define USE_TRANS14_ANALYSIS_OPTIONAL_A \
	USE_TRANS14_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans14_analysis_VIEW_1; \
	MENU trans14_analysis_VIEW_1_page; \
	MENU trans14_analysis_Simple_Dialog_Optional_A

#define USE_TRANS14_ANALYSIS_OPTIONAL_B \
	USE_TRANS14_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans14_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans14_analysis_)
#define USE_TRANS14_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans14_analysis_)
#define USE_TRANS14_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans14_analysis_)
#define USE_TRANS14_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans14_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_ANALYSIS_MANDATORY_BOTH \
	BLOCK trans15_analysis_block; \
	COLLECTION trans15_analysis_BLOCK_OBJECT; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Class; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_analysis_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_analysis_BLOCK_OBJECT_page; \
	COMMAND trans15_analysis_BLOCK_OBJECT_read; \
	VARIABLE trans15_analysis_ST_REV; \
	MENU trans15_analysis_ST_REV_page; \
	COMMAND trans15_analysis_ST_REV_read; \
	VARIABLE trans15_analysis_TAG_DESC; \
	MENU trans15_analysis_TAG_DESC_page; \
	COMMAND trans15_analysis_TAG_DESC_read; \
	COMMAND trans15_analysis_TAG_DESC_write; \
	VARIABLE trans15_analysis_STRATEGY; \
	MENU trans15_analysis_STRATEGY_page; \
	COMMAND trans15_analysis_STRATEGY_read; \
	COMMAND trans15_analysis_STRATEGY_write; \
	VARIABLE trans15_analysis_ALERT_KEY; \
	MENU trans15_analysis_ALERT_KEY_page; \
	COMMAND trans15_analysis_ALERT_KEY_read; \
	COMMAND trans15_analysis_ALERT_KEY_write; \
	VARIABLE trans15_analysis_TARGET_MODE; \
	MENU trans15_analysis_TARGET_MODE_page; \
	COMMAND trans15_analysis_TARGET_MODE_read; \
	COMMAND trans15_analysis_TARGET_MODE_write; \
	COLLECTION trans15_analysis_MODE_BLK; \
	VARIABLE trans15_analysis_MODE_BLK_Actual; \
	VARIABLE trans15_analysis_MODE_BLK_Permitted; \
	VARIABLE trans15_analysis_MODE_BLK_Normal; \
	MENU trans15_analysis_MODE_BLK_page; \
	COMMAND trans15_analysis_MODE_BLK_read; \
	COLLECTION trans15_analysis_ALARM_SUM; \
	VARIABLE trans15_analysis_ALARM_SUM_Current; \
	VARIABLE trans15_analysis_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_analysis_ALARM_SUM_Unreported; \
	VARIABLE trans15_analysis_ALARM_SUM_Disabled; \
	MENU trans15_analysis_ALARM_SUM_page; \
	COMMAND trans15_analysis_ALARM_SUM_read; \
	VARIABLE trans15_analysis_COMPONENT_NAME; \
	MENU trans15_analysis_COMPONENT_NAME_page; \
	COMMAND trans15_analysis_COMPONENT_NAME_read; \
	COMMAND trans15_analysis_COMPONENT_NAME_write; \
	COLLECTION trans15_analysis_PV; \
	VARIABLE trans15_analysis_PV_PV; \
	VARIABLE trans15_analysis_PV_Measurement_Status_Condensed; \
	VARIABLE trans15_analysis_PV_PV_Time; \
	VARIABLE trans15_analysis_PV_Measurement_Status_Quality; \
	VARIABLE trans15_analysis_PV_Measurement_Status_Limit; \
	MENU trans15_analysis_PV_page; \
	COMMAND trans15_analysis_PV_read; \
	VARIABLE trans15_analysis_PV_UNIT; \
	MENU trans15_analysis_PV_UNIT_page; \
	COMMAND trans15_analysis_PV_UNIT_read; \
	COMMAND trans15_analysis_PV_UNIT_write; \
	VARIABLE trans15_analysis_PV_UNIT_TEXT; \
	MENU trans15_analysis_PV_UNIT_TEXT_page; \
	COMMAND trans15_analysis_PV_UNIT_TEXT_read; \
	COMMAND trans15_analysis_PV_UNIT_TEXT_write; \
	VARIABLE trans15_analysis_ACTIVE_RANGE; \
	MENU trans15_analysis_ACTIVE_RANGE_page; \
	COMMAND trans15_analysis_ACTIVE_RANGE_read; \
	COMMAND trans15_analysis_ACTIVE_RANGE_write; \
	VARIABLE trans15_analysis_AUTORANGE_ON; \
	MENU trans15_analysis_AUTORANGE_ON_page; \
	COMMAND trans15_analysis_AUTORANGE_ON_read; \
	COMMAND trans15_analysis_AUTORANGE_ON_write; \
	VARIABLE trans15_analysis_SAMPLING_RATE; \
	MENU trans15_analysis_SAMPLING_RATE_page; \
	COMMAND trans15_analysis_SAMPLING_RATE_read; \
	COMMAND trans15_analysis_SAMPLING_RATE_write; \
	VARIABLE trans15_analysis_NUMBER_OF_RANGES; \
	MENU trans15_analysis_NUMBER_OF_RANGES_page; \
	COMMAND trans15_analysis_NUMBER_OF_RANGES_read; \
	COLLECTION trans15_analysis_RANGE_1; \
	VARIABLE trans15_analysis_RANGE_1_Begin_of_Range; \
	VARIABLE trans15_analysis_RANGE_1_End_of_Range; \
	MENU trans15_analysis_RANGE_1_page; \
	COMMAND trans15_analysis_RANGE_1_read; \
	COMMAND trans15_analysis_RANGE_1_write; \
	UNIT trans15_analysis_unit_1; \
	METHOD trans15_analysis_SAMPLING_RATE_to_ASCII; \
	VARIABLE trans15_analysis_SAMPLING_RATE_Visible

#define USE_TRANS15_ANALYSIS_MANDATORY_A \
	USE_TRANS15_ANALYSIS_MANDATORY_BOTH; \
	MENU trans15_analysis_Simple_Dialog_Mandatory_A

#define USE_TRANS15_ANALYSIS_MANDATORY_B \
	USE_TRANS15_ANALYSIS_MANDATORY_BOTH; \
	COLLECTION trans15_analysis_VIEW_1; \
	MENU trans15_analysis_VIEW_1_page; \
	MENU trans15_analysis_Simple_Dialog_Mandatory_B

#define USE_TRANS15_ANALYSIS_OPTIONAL_BOTH \
	COLLECTION trans15_analysis_VIEW_2; \
	MENU trans15_analysis_VIEW_2_page; \
	COLLECTION trans15_analysis_VIEW_3; \
	MENU trans15_analysis_VIEW_3_page

#define USE_TRANS15_ANALYSIS_OPTIONAL_A \
	USE_TRANS15_ANALYSIS_OPTIONAL_BOTH; \
	COLLECTION trans15_analysis_VIEW_1; \
	MENU trans15_analysis_VIEW_1_page; \
	MENU trans15_analysis_Simple_Dialog_Optional_A

#define USE_TRANS15_ANALYSIS_OPTIONAL_B \
	USE_TRANS15_ANALYSIS_OPTIONAL_BOTH; \
	MENU trans15_analysis_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_ANALYSIS_MANDATORY_A USE_TRANS_ANALYSIS_MANDATORY_A(trans15_analysis_)
#define USE_TRANS15_ANALYSIS_MANDATORY_B USE_TRANS_ANALYSIS_MANDATORY_B(trans15_analysis_)
#define USE_TRANS15_ANALYSIS_OPTIONAL_A  USE_TRANS_ANALYSIS_OPTIONAL_A(trans15_analysis_)
#define USE_TRANS15_ANALYSIS_OPTIONAL_B  USE_TRANS_ANALYSIS_OPTIONAL_B(trans15_analysis_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_TRANSFER_MANDATORY_BOTH \
	BLOCK trans1_Transfer_block; \
	COLLECTION trans1_Transfer_BLOCK_OBJECT; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans1_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans1_Transfer_ST_REV; \
	MENU trans1_Transfer_ST_REV_page; \
	COMMAND trans1_Transfer_ST_REV_read; \
	VARIABLE trans1_Transfer_TAG_DESC; \
	MENU trans1_Transfer_TAG_DESC_page; \
	COMMAND trans1_Transfer_TAG_DESC_read; \
	COMMAND trans1_Transfer_TAG_DESC_write; \
	VARIABLE trans1_Transfer_STRATEGY; \
	MENU trans1_Transfer_STRATEGY_page; \
	COMMAND trans1_Transfer_STRATEGY_read; \
	COMMAND trans1_Transfer_STRATEGY_write; \
	VARIABLE trans1_Transfer_ALERT_KEY; \
	MENU trans1_Transfer_ALERT_KEY_page; \
	COMMAND trans1_Transfer_ALERT_KEY_read; \
	COMMAND trans1_Transfer_ALERT_KEY_write; \
	VARIABLE trans1_Transfer_TARGET_MODE; \
	MENU trans1_Transfer_TARGET_MODE_page; \
	COMMAND trans1_Transfer_TARGET_MODE_read; \
	COMMAND trans1_Transfer_TARGET_MODE_write; \
	COLLECTION trans1_Transfer_MODE_BLK; \
	VARIABLE trans1_Transfer_MODE_BLK_Actual; \
	VARIABLE trans1_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans1_Transfer_MODE_BLK_Normal; \
	MENU trans1_Transfer_MODE_BLK_page; \
	COMMAND trans1_Transfer_MODE_BLK_read; \
	COLLECTION trans1_Transfer_ALARM_SUM; \
	VARIABLE trans1_Transfer_ALARM_SUM_Current; \
	VARIABLE trans1_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans1_Transfer_ALARM_SUM_Disabled; \
	MENU trans1_Transfer_ALARM_SUM_page; \
	COMMAND trans1_Transfer_ALARM_SUM_read; \
	VARIABLE trans1_Transfer_CHANNEL; \
	MENU trans1_Transfer_CHANNEL_page; \
	COMMAND trans1_Transfer_CHANNEL_read; \
	COMMAND trans1_Transfer_CHANNEL_write; \
	COLLECTION trans1_Transfer_PV; \
	VARIABLE trans1_Transfer_PV_PV; \
	VARIABLE trans1_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans1_Transfer_PV_PV_Time; \
	VARIABLE trans1_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans1_Transfer_PV_Measurement_Status_Limit; \
	MENU trans1_Transfer_PV_page; \
	COMMAND trans1_Transfer_PV_read; \
	VARIABLE trans1_Transfer_PV_UNIT; \
	MENU trans1_Transfer_PV_UNIT_page; \
	COMMAND trans1_Transfer_PV_UNIT_read; \
	COMMAND trans1_Transfer_PV_UNIT_write; \
	VARIABLE trans1_Transfer_PV_UNIT_TEXT; \
	MENU trans1_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans1_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans1_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans1_Transfer_STATIC_VALUE; \
	MENU trans1_Transfer_STATIC_VALUE_page; \
	COMMAND trans1_Transfer_STATIC_VALUE_read; \
	COMMAND trans1_Transfer_STATIC_VALUE_write; \
	VARIABLE trans1_Transfer_CORRECTION_CHANNEL; \
	MENU trans1_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans1_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans1_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans1_Transfer_FB_VALUE; \
	VARIABLE trans1_Transfer_FB_VALUE_Value; \
	VARIABLE trans1_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans1_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans1_Transfer_FB_VALUE_Status_Limit; \
	MENU trans1_Transfer_FB_VALUE_page; \
	COMMAND trans1_Transfer_FB_VALUE_read; \
	COMMAND trans1_Transfer_FB_VALUE_write; \
	VARIABLE trans1_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans1_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans1_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans1_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans1_Transfer_CALCULATION_1; \
	VARIABLE trans1_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans1_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans1_Transfer_CALCULATION_1_Choice; \
	MENU trans1_Transfer_CALCULATION_1_page; \
	COMMAND trans1_Transfer_CALCULATION_1_read; \
	COMMAND trans1_Transfer_CALCULATION_1_write; \
	UNIT trans1_Transfer_unit_1

#define USE_TRANS1_TRANSFER_MANDATORY_A \
	USE_TRANS1_TRANSFER_MANDATORY_BOTH; \
	MENU trans1_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS1_TRANSFER_MANDATORY_B \
	USE_TRANS1_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans1_Transfer_VIEW_1; \
	MENU trans1_Transfer_VIEW_1_page; \
	MENU trans1_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS1_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans1_Transfer_VIEW_2; \
	MENU trans1_Transfer_VIEW_2_page; \
	COLLECTION trans1_Transfer_VIEW_3; \
	MENU trans1_Transfer_VIEW_3_page

#define USE_TRANS1_TRANSFER_OPTIONAL_A \
	USE_TRANS1_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans1_Transfer_VIEW_1; \
	MENU trans1_Transfer_VIEW_1_page; \
	MENU trans1_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS1_TRANSFER_OPTIONAL_B \
	USE_TRANS1_TRANSFER_OPTIONAL_BOTH; \
	MENU trans1_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_TRANSFER_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	COLLECTION prefix ## PV; \
	VARIABLE prefix ## PV_PV; \
	VARIABLE prefix ## PV_Measurement_Status_Condensed; \
	VARIABLE prefix ## PV_PV_Time; \
	VARIABLE prefix ## PV_Measurement_Status_Quality; \
	VARIABLE prefix ## PV_Measurement_Status_Limit; \
	MENU prefix ## PV_page; \
	COMMAND prefix ## PV_read; \
	VARIABLE prefix ## PV_UNIT; \
	MENU prefix ## PV_UNIT_page; \
	COMMAND prefix ## PV_UNIT_read; \
	COMMAND prefix ## PV_UNIT_write; \
	VARIABLE prefix ## PV_UNIT_TEXT; \
	MENU prefix ## PV_UNIT_TEXT_page; \
	COMMAND prefix ## PV_UNIT_TEXT_read; \
	COMMAND prefix ## PV_UNIT_TEXT_write; \
	VARIABLE prefix ## STATIC_VALUE; \
	MENU prefix ## STATIC_VALUE_page; \
	COMMAND prefix ## STATIC_VALUE_read; \
	COMMAND prefix ## STATIC_VALUE_write; \
	VARIABLE prefix ## CORRECTION_CHANNEL; \
	MENU prefix ## CORRECTION_CHANNEL_page; \
	COMMAND prefix ## CORRECTION_CHANNEL_read; \
	COMMAND prefix ## CORRECTION_CHANNEL_write; \
	COLLECTION prefix ## FB_VALUE; \
	VARIABLE prefix ## FB_VALUE_Value; \
	VARIABLE prefix ## FB_VALUE_Status_Condensed; \
	VARIABLE prefix ## FB_VALUE_Status_Quality; \
	VARIABLE prefix ## FB_VALUE_Status_Limit; \
	MENU prefix ## FB_VALUE_page; \
	COMMAND prefix ## FB_VALUE_read; \
	COMMAND prefix ## FB_VALUE_write; \
	VARIABLE prefix ## NUMBER_OF_CALCULATION; \
	MENU prefix ## NUMBER_OF_CALCULATION_page; \
	COMMAND prefix ## NUMBER_OF_CALCULATION_read; \
	COMMAND prefix ## NUMBER_OF_CALCULATION_write; \
	COLLECTION prefix ## CALCULATION_1; \
	VARIABLE prefix ## CALCULATION_1_Function_Type; \
	VARIABLE prefix ## CALCULATION_1_Subtype; \
	VARIABLE prefix ## CALCULATION_1_Choice; \
	MENU prefix ## CALCULATION_1_page; \
	COMMAND prefix ## CALCULATION_1_read; \
	COMMAND prefix ## CALCULATION_1_write; \
	UNIT prefix ## unit_1

#define USE_TRANS_TRANSFER_MANDATORY_A(prefix) \
	USE_TRANS_TRANSFER_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_TRANSFER_MANDATORY_B(prefix) \
	USE_TRANS_TRANSFER_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_TRANSFER_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_TRANSFER_OPTIONAL_A(prefix) \
	USE_TRANS_TRANSFER_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_TRANSFER_OPTIONAL_B(prefix) \
	USE_TRANS_TRANSFER_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans1_Transfer_)
#define USE_TRANS1_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans1_Transfer_)
#define USE_TRANS1_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans1_Transfer_)
#define USE_TRANS1_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans1_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_TRANSFER_MANDATORY_BOTH \
	BLOCK trans2_Transfer_block; \
	COLLECTION trans2_Transfer_BLOCK_OBJECT; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans2_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans2_Transfer_ST_REV; \
	MENU trans2_Transfer_ST_REV_page; \
	COMMAND trans2_Transfer_ST_REV_read; \
	VARIABLE trans2_Transfer_TAG_DESC; \
	MENU trans2_Transfer_TAG_DESC_page; \
	COMMAND trans2_Transfer_TAG_DESC_read; \
	COMMAND trans2_Transfer_TAG_DESC_write; \
	VARIABLE trans2_Transfer_STRATEGY; \
	MENU trans2_Transfer_STRATEGY_page; \
	COMMAND trans2_Transfer_STRATEGY_read; \
	COMMAND trans2_Transfer_STRATEGY_write; \
	VARIABLE trans2_Transfer_ALERT_KEY; \
	MENU trans2_Transfer_ALERT_KEY_page; \
	COMMAND trans2_Transfer_ALERT_KEY_read; \
	COMMAND trans2_Transfer_ALERT_KEY_write; \
	VARIABLE trans2_Transfer_TARGET_MODE; \
	MENU trans2_Transfer_TARGET_MODE_page; \
	COMMAND trans2_Transfer_TARGET_MODE_read; \
	COMMAND trans2_Transfer_TARGET_MODE_write; \
	COLLECTION trans2_Transfer_MODE_BLK; \
	VARIABLE trans2_Transfer_MODE_BLK_Actual; \
	VARIABLE trans2_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans2_Transfer_MODE_BLK_Normal; \
	MENU trans2_Transfer_MODE_BLK_page; \
	COMMAND trans2_Transfer_MODE_BLK_read; \
	COLLECTION trans2_Transfer_ALARM_SUM; \
	VARIABLE trans2_Transfer_ALARM_SUM_Current; \
	VARIABLE trans2_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans2_Transfer_ALARM_SUM_Disabled; \
	MENU trans2_Transfer_ALARM_SUM_page; \
	COMMAND trans2_Transfer_ALARM_SUM_read; \
	VARIABLE trans2_Transfer_CHANNEL; \
	MENU trans2_Transfer_CHANNEL_page; \
	COMMAND trans2_Transfer_CHANNEL_read; \
	COMMAND trans2_Transfer_CHANNEL_write; \
	COLLECTION trans2_Transfer_PV; \
	VARIABLE trans2_Transfer_PV_PV; \
	VARIABLE trans2_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans2_Transfer_PV_PV_Time; \
	VARIABLE trans2_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans2_Transfer_PV_Measurement_Status_Limit; \
	MENU trans2_Transfer_PV_page; \
	COMMAND trans2_Transfer_PV_read; \
	VARIABLE trans2_Transfer_PV_UNIT; \
	MENU trans2_Transfer_PV_UNIT_page; \
	COMMAND trans2_Transfer_PV_UNIT_read; \
	COMMAND trans2_Transfer_PV_UNIT_write; \
	VARIABLE trans2_Transfer_PV_UNIT_TEXT; \
	MENU trans2_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans2_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans2_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans2_Transfer_STATIC_VALUE; \
	MENU trans2_Transfer_STATIC_VALUE_page; \
	COMMAND trans2_Transfer_STATIC_VALUE_read; \
	COMMAND trans2_Transfer_STATIC_VALUE_write; \
	VARIABLE trans2_Transfer_CORRECTION_CHANNEL; \
	MENU trans2_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans2_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans2_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans2_Transfer_FB_VALUE; \
	VARIABLE trans2_Transfer_FB_VALUE_Value; \
	VARIABLE trans2_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans2_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans2_Transfer_FB_VALUE_Status_Limit; \
	MENU trans2_Transfer_FB_VALUE_page; \
	COMMAND trans2_Transfer_FB_VALUE_read; \
	COMMAND trans2_Transfer_FB_VALUE_write; \
	VARIABLE trans2_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans2_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans2_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans2_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans2_Transfer_CALCULATION_1; \
	VARIABLE trans2_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans2_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans2_Transfer_CALCULATION_1_Choice; \
	MENU trans2_Transfer_CALCULATION_1_page; \
	COMMAND trans2_Transfer_CALCULATION_1_read; \
	COMMAND trans2_Transfer_CALCULATION_1_write; \
	UNIT trans2_Transfer_unit_1

#define USE_TRANS2_TRANSFER_MANDATORY_A \
	USE_TRANS2_TRANSFER_MANDATORY_BOTH; \
	MENU trans2_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS2_TRANSFER_MANDATORY_B \
	USE_TRANS2_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans2_Transfer_VIEW_1; \
	MENU trans2_Transfer_VIEW_1_page; \
	MENU trans2_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS2_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans2_Transfer_VIEW_2; \
	MENU trans2_Transfer_VIEW_2_page; \
	COLLECTION trans2_Transfer_VIEW_3; \
	MENU trans2_Transfer_VIEW_3_page

#define USE_TRANS2_TRANSFER_OPTIONAL_A \
	USE_TRANS2_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans2_Transfer_VIEW_1; \
	MENU trans2_Transfer_VIEW_1_page; \
	MENU trans2_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS2_TRANSFER_OPTIONAL_B \
	USE_TRANS2_TRANSFER_OPTIONAL_BOTH; \
	MENU trans2_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans2_Transfer_)
#define USE_TRANS2_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans2_Transfer_)
#define USE_TRANS2_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans2_Transfer_)
#define USE_TRANS2_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans2_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_TRANSFER_MANDATORY_BOTH \
	BLOCK trans3_Transfer_block; \
	COLLECTION trans3_Transfer_BLOCK_OBJECT; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans3_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans3_Transfer_ST_REV; \
	MENU trans3_Transfer_ST_REV_page; \
	COMMAND trans3_Transfer_ST_REV_read; \
	VARIABLE trans3_Transfer_TAG_DESC; \
	MENU trans3_Transfer_TAG_DESC_page; \
	COMMAND trans3_Transfer_TAG_DESC_read; \
	COMMAND trans3_Transfer_TAG_DESC_write; \
	VARIABLE trans3_Transfer_STRATEGY; \
	MENU trans3_Transfer_STRATEGY_page; \
	COMMAND trans3_Transfer_STRATEGY_read; \
	COMMAND trans3_Transfer_STRATEGY_write; \
	VARIABLE trans3_Transfer_ALERT_KEY; \
	MENU trans3_Transfer_ALERT_KEY_page; \
	COMMAND trans3_Transfer_ALERT_KEY_read; \
	COMMAND trans3_Transfer_ALERT_KEY_write; \
	VARIABLE trans3_Transfer_TARGET_MODE; \
	MENU trans3_Transfer_TARGET_MODE_page; \
	COMMAND trans3_Transfer_TARGET_MODE_read; \
	COMMAND trans3_Transfer_TARGET_MODE_write; \
	COLLECTION trans3_Transfer_MODE_BLK; \
	VARIABLE trans3_Transfer_MODE_BLK_Actual; \
	VARIABLE trans3_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans3_Transfer_MODE_BLK_Normal; \
	MENU trans3_Transfer_MODE_BLK_page; \
	COMMAND trans3_Transfer_MODE_BLK_read; \
	COLLECTION trans3_Transfer_ALARM_SUM; \
	VARIABLE trans3_Transfer_ALARM_SUM_Current; \
	VARIABLE trans3_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans3_Transfer_ALARM_SUM_Disabled; \
	MENU trans3_Transfer_ALARM_SUM_page; \
	COMMAND trans3_Transfer_ALARM_SUM_read; \
	VARIABLE trans3_Transfer_CHANNEL; \
	MENU trans3_Transfer_CHANNEL_page; \
	COMMAND trans3_Transfer_CHANNEL_read; \
	COMMAND trans3_Transfer_CHANNEL_write; \
	COLLECTION trans3_Transfer_PV; \
	VARIABLE trans3_Transfer_PV_PV; \
	VARIABLE trans3_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans3_Transfer_PV_PV_Time; \
	VARIABLE trans3_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans3_Transfer_PV_Measurement_Status_Limit; \
	MENU trans3_Transfer_PV_page; \
	COMMAND trans3_Transfer_PV_read; \
	VARIABLE trans3_Transfer_PV_UNIT; \
	MENU trans3_Transfer_PV_UNIT_page; \
	COMMAND trans3_Transfer_PV_UNIT_read; \
	COMMAND trans3_Transfer_PV_UNIT_write; \
	VARIABLE trans3_Transfer_PV_UNIT_TEXT; \
	MENU trans3_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans3_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans3_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans3_Transfer_STATIC_VALUE; \
	MENU trans3_Transfer_STATIC_VALUE_page; \
	COMMAND trans3_Transfer_STATIC_VALUE_read; \
	COMMAND trans3_Transfer_STATIC_VALUE_write; \
	VARIABLE trans3_Transfer_CORRECTION_CHANNEL; \
	MENU trans3_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans3_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans3_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans3_Transfer_FB_VALUE; \
	VARIABLE trans3_Transfer_FB_VALUE_Value; \
	VARIABLE trans3_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans3_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans3_Transfer_FB_VALUE_Status_Limit; \
	MENU trans3_Transfer_FB_VALUE_page; \
	COMMAND trans3_Transfer_FB_VALUE_read; \
	COMMAND trans3_Transfer_FB_VALUE_write; \
	VARIABLE trans3_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans3_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans3_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans3_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans3_Transfer_CALCULATION_1; \
	VARIABLE trans3_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans3_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans3_Transfer_CALCULATION_1_Choice; \
	MENU trans3_Transfer_CALCULATION_1_page; \
	COMMAND trans3_Transfer_CALCULATION_1_read; \
	COMMAND trans3_Transfer_CALCULATION_1_write; \
	UNIT trans3_Transfer_unit_1

#define USE_TRANS3_TRANSFER_MANDATORY_A \
	USE_TRANS3_TRANSFER_MANDATORY_BOTH; \
	MENU trans3_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS3_TRANSFER_MANDATORY_B \
	USE_TRANS3_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans3_Transfer_VIEW_1; \
	MENU trans3_Transfer_VIEW_1_page; \
	MENU trans3_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS3_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans3_Transfer_VIEW_2; \
	MENU trans3_Transfer_VIEW_2_page; \
	COLLECTION trans3_Transfer_VIEW_3; \
	MENU trans3_Transfer_VIEW_3_page

#define USE_TRANS3_TRANSFER_OPTIONAL_A \
	USE_TRANS3_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans3_Transfer_VIEW_1; \
	MENU trans3_Transfer_VIEW_1_page; \
	MENU trans3_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS3_TRANSFER_OPTIONAL_B \
	USE_TRANS3_TRANSFER_OPTIONAL_BOTH; \
	MENU trans3_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans3_Transfer_)
#define USE_TRANS3_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans3_Transfer_)
#define USE_TRANS3_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans3_Transfer_)
#define USE_TRANS3_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans3_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_TRANSFER_MANDATORY_BOTH \
	BLOCK trans4_Transfer_block; \
	COLLECTION trans4_Transfer_BLOCK_OBJECT; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans4_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans4_Transfer_ST_REV; \
	MENU trans4_Transfer_ST_REV_page; \
	COMMAND trans4_Transfer_ST_REV_read; \
	VARIABLE trans4_Transfer_TAG_DESC; \
	MENU trans4_Transfer_TAG_DESC_page; \
	COMMAND trans4_Transfer_TAG_DESC_read; \
	COMMAND trans4_Transfer_TAG_DESC_write; \
	VARIABLE trans4_Transfer_STRATEGY; \
	MENU trans4_Transfer_STRATEGY_page; \
	COMMAND trans4_Transfer_STRATEGY_read; \
	COMMAND trans4_Transfer_STRATEGY_write; \
	VARIABLE trans4_Transfer_ALERT_KEY; \
	MENU trans4_Transfer_ALERT_KEY_page; \
	COMMAND trans4_Transfer_ALERT_KEY_read; \
	COMMAND trans4_Transfer_ALERT_KEY_write; \
	VARIABLE trans4_Transfer_TARGET_MODE; \
	MENU trans4_Transfer_TARGET_MODE_page; \
	COMMAND trans4_Transfer_TARGET_MODE_read; \
	COMMAND trans4_Transfer_TARGET_MODE_write; \
	COLLECTION trans4_Transfer_MODE_BLK; \
	VARIABLE trans4_Transfer_MODE_BLK_Actual; \
	VARIABLE trans4_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans4_Transfer_MODE_BLK_Normal; \
	MENU trans4_Transfer_MODE_BLK_page; \
	COMMAND trans4_Transfer_MODE_BLK_read; \
	COLLECTION trans4_Transfer_ALARM_SUM; \
	VARIABLE trans4_Transfer_ALARM_SUM_Current; \
	VARIABLE trans4_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans4_Transfer_ALARM_SUM_Disabled; \
	MENU trans4_Transfer_ALARM_SUM_page; \
	COMMAND trans4_Transfer_ALARM_SUM_read; \
	VARIABLE trans4_Transfer_CHANNEL; \
	MENU trans4_Transfer_CHANNEL_page; \
	COMMAND trans4_Transfer_CHANNEL_read; \
	COMMAND trans4_Transfer_CHANNEL_write; \
	COLLECTION trans4_Transfer_PV; \
	VARIABLE trans4_Transfer_PV_PV; \
	VARIABLE trans4_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans4_Transfer_PV_PV_Time; \
	VARIABLE trans4_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans4_Transfer_PV_Measurement_Status_Limit; \
	MENU trans4_Transfer_PV_page; \
	COMMAND trans4_Transfer_PV_read; \
	VARIABLE trans4_Transfer_PV_UNIT; \
	MENU trans4_Transfer_PV_UNIT_page; \
	COMMAND trans4_Transfer_PV_UNIT_read; \
	COMMAND trans4_Transfer_PV_UNIT_write; \
	VARIABLE trans4_Transfer_PV_UNIT_TEXT; \
	MENU trans4_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans4_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans4_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans4_Transfer_STATIC_VALUE; \
	MENU trans4_Transfer_STATIC_VALUE_page; \
	COMMAND trans4_Transfer_STATIC_VALUE_read; \
	COMMAND trans4_Transfer_STATIC_VALUE_write; \
	VARIABLE trans4_Transfer_CORRECTION_CHANNEL; \
	MENU trans4_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans4_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans4_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans4_Transfer_FB_VALUE; \
	VARIABLE trans4_Transfer_FB_VALUE_Value; \
	VARIABLE trans4_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans4_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans4_Transfer_FB_VALUE_Status_Limit; \
	MENU trans4_Transfer_FB_VALUE_page; \
	COMMAND trans4_Transfer_FB_VALUE_read; \
	COMMAND trans4_Transfer_FB_VALUE_write; \
	VARIABLE trans4_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans4_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans4_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans4_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans4_Transfer_CALCULATION_1; \
	VARIABLE trans4_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans4_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans4_Transfer_CALCULATION_1_Choice; \
	MENU trans4_Transfer_CALCULATION_1_page; \
	COMMAND trans4_Transfer_CALCULATION_1_read; \
	COMMAND trans4_Transfer_CALCULATION_1_write; \
	UNIT trans4_Transfer_unit_1

#define USE_TRANS4_TRANSFER_MANDATORY_A \
	USE_TRANS4_TRANSFER_MANDATORY_BOTH; \
	MENU trans4_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS4_TRANSFER_MANDATORY_B \
	USE_TRANS4_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans4_Transfer_VIEW_1; \
	MENU trans4_Transfer_VIEW_1_page; \
	MENU trans4_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS4_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans4_Transfer_VIEW_2; \
	MENU trans4_Transfer_VIEW_2_page; \
	COLLECTION trans4_Transfer_VIEW_3; \
	MENU trans4_Transfer_VIEW_3_page

#define USE_TRANS4_TRANSFER_OPTIONAL_A \
	USE_TRANS4_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans4_Transfer_VIEW_1; \
	MENU trans4_Transfer_VIEW_1_page; \
	MENU trans4_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS4_TRANSFER_OPTIONAL_B \
	USE_TRANS4_TRANSFER_OPTIONAL_BOTH; \
	MENU trans4_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans4_Transfer_)
#define USE_TRANS4_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans4_Transfer_)
#define USE_TRANS4_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans4_Transfer_)
#define USE_TRANS4_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans4_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_TRANSFER_MANDATORY_BOTH \
	BLOCK trans5_Transfer_block; \
	COLLECTION trans5_Transfer_BLOCK_OBJECT; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans5_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans5_Transfer_ST_REV; \
	MENU trans5_Transfer_ST_REV_page; \
	COMMAND trans5_Transfer_ST_REV_read; \
	VARIABLE trans5_Transfer_TAG_DESC; \
	MENU trans5_Transfer_TAG_DESC_page; \
	COMMAND trans5_Transfer_TAG_DESC_read; \
	COMMAND trans5_Transfer_TAG_DESC_write; \
	VARIABLE trans5_Transfer_STRATEGY; \
	MENU trans5_Transfer_STRATEGY_page; \
	COMMAND trans5_Transfer_STRATEGY_read; \
	COMMAND trans5_Transfer_STRATEGY_write; \
	VARIABLE trans5_Transfer_ALERT_KEY; \
	MENU trans5_Transfer_ALERT_KEY_page; \
	COMMAND trans5_Transfer_ALERT_KEY_read; \
	COMMAND trans5_Transfer_ALERT_KEY_write; \
	VARIABLE trans5_Transfer_TARGET_MODE; \
	MENU trans5_Transfer_TARGET_MODE_page; \
	COMMAND trans5_Transfer_TARGET_MODE_read; \
	COMMAND trans5_Transfer_TARGET_MODE_write; \
	COLLECTION trans5_Transfer_MODE_BLK; \
	VARIABLE trans5_Transfer_MODE_BLK_Actual; \
	VARIABLE trans5_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans5_Transfer_MODE_BLK_Normal; \
	MENU trans5_Transfer_MODE_BLK_page; \
	COMMAND trans5_Transfer_MODE_BLK_read; \
	COLLECTION trans5_Transfer_ALARM_SUM; \
	VARIABLE trans5_Transfer_ALARM_SUM_Current; \
	VARIABLE trans5_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans5_Transfer_ALARM_SUM_Disabled; \
	MENU trans5_Transfer_ALARM_SUM_page; \
	COMMAND trans5_Transfer_ALARM_SUM_read; \
	VARIABLE trans5_Transfer_CHANNEL; \
	MENU trans5_Transfer_CHANNEL_page; \
	COMMAND trans5_Transfer_CHANNEL_read; \
	COMMAND trans5_Transfer_CHANNEL_write; \
	COLLECTION trans5_Transfer_PV; \
	VARIABLE trans5_Transfer_PV_PV; \
	VARIABLE trans5_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans5_Transfer_PV_PV_Time; \
	VARIABLE trans5_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans5_Transfer_PV_Measurement_Status_Limit; \
	MENU trans5_Transfer_PV_page; \
	COMMAND trans5_Transfer_PV_read; \
	VARIABLE trans5_Transfer_PV_UNIT; \
	MENU trans5_Transfer_PV_UNIT_page; \
	COMMAND trans5_Transfer_PV_UNIT_read; \
	COMMAND trans5_Transfer_PV_UNIT_write; \
	VARIABLE trans5_Transfer_PV_UNIT_TEXT; \
	MENU trans5_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans5_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans5_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans5_Transfer_STATIC_VALUE; \
	MENU trans5_Transfer_STATIC_VALUE_page; \
	COMMAND trans5_Transfer_STATIC_VALUE_read; \
	COMMAND trans5_Transfer_STATIC_VALUE_write; \
	VARIABLE trans5_Transfer_CORRECTION_CHANNEL; \
	MENU trans5_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans5_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans5_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans5_Transfer_FB_VALUE; \
	VARIABLE trans5_Transfer_FB_VALUE_Value; \
	VARIABLE trans5_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans5_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans5_Transfer_FB_VALUE_Status_Limit; \
	MENU trans5_Transfer_FB_VALUE_page; \
	COMMAND trans5_Transfer_FB_VALUE_read; \
	COMMAND trans5_Transfer_FB_VALUE_write; \
	VARIABLE trans5_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans5_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans5_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans5_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans5_Transfer_CALCULATION_1; \
	VARIABLE trans5_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans5_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans5_Transfer_CALCULATION_1_Choice; \
	MENU trans5_Transfer_CALCULATION_1_page; \
	COMMAND trans5_Transfer_CALCULATION_1_read; \
	COMMAND trans5_Transfer_CALCULATION_1_write; \
	UNIT trans5_Transfer_unit_1

#define USE_TRANS5_TRANSFER_MANDATORY_A \
	USE_TRANS5_TRANSFER_MANDATORY_BOTH; \
	MENU trans5_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS5_TRANSFER_MANDATORY_B \
	USE_TRANS5_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans5_Transfer_VIEW_1; \
	MENU trans5_Transfer_VIEW_1_page; \
	MENU trans5_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS5_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans5_Transfer_VIEW_2; \
	MENU trans5_Transfer_VIEW_2_page; \
	COLLECTION trans5_Transfer_VIEW_3; \
	MENU trans5_Transfer_VIEW_3_page

#define USE_TRANS5_TRANSFER_OPTIONAL_A \
	USE_TRANS5_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans5_Transfer_VIEW_1; \
	MENU trans5_Transfer_VIEW_1_page; \
	MENU trans5_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS5_TRANSFER_OPTIONAL_B \
	USE_TRANS5_TRANSFER_OPTIONAL_BOTH; \
	MENU trans5_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans5_Transfer_)
#define USE_TRANS5_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans5_Transfer_)
#define USE_TRANS5_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans5_Transfer_)
#define USE_TRANS5_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans5_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_TRANSFER_MANDATORY_BOTH \
	BLOCK trans6_Transfer_block; \
	COLLECTION trans6_Transfer_BLOCK_OBJECT; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans6_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans6_Transfer_ST_REV; \
	MENU trans6_Transfer_ST_REV_page; \
	COMMAND trans6_Transfer_ST_REV_read; \
	VARIABLE trans6_Transfer_TAG_DESC; \
	MENU trans6_Transfer_TAG_DESC_page; \
	COMMAND trans6_Transfer_TAG_DESC_read; \
	COMMAND trans6_Transfer_TAG_DESC_write; \
	VARIABLE trans6_Transfer_STRATEGY; \
	MENU trans6_Transfer_STRATEGY_page; \
	COMMAND trans6_Transfer_STRATEGY_read; \
	COMMAND trans6_Transfer_STRATEGY_write; \
	VARIABLE trans6_Transfer_ALERT_KEY; \
	MENU trans6_Transfer_ALERT_KEY_page; \
	COMMAND trans6_Transfer_ALERT_KEY_read; \
	COMMAND trans6_Transfer_ALERT_KEY_write; \
	VARIABLE trans6_Transfer_TARGET_MODE; \
	MENU trans6_Transfer_TARGET_MODE_page; \
	COMMAND trans6_Transfer_TARGET_MODE_read; \
	COMMAND trans6_Transfer_TARGET_MODE_write; \
	COLLECTION trans6_Transfer_MODE_BLK; \
	VARIABLE trans6_Transfer_MODE_BLK_Actual; \
	VARIABLE trans6_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans6_Transfer_MODE_BLK_Normal; \
	MENU trans6_Transfer_MODE_BLK_page; \
	COMMAND trans6_Transfer_MODE_BLK_read; \
	COLLECTION trans6_Transfer_ALARM_SUM; \
	VARIABLE trans6_Transfer_ALARM_SUM_Current; \
	VARIABLE trans6_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans6_Transfer_ALARM_SUM_Disabled; \
	MENU trans6_Transfer_ALARM_SUM_page; \
	COMMAND trans6_Transfer_ALARM_SUM_read; \
	VARIABLE trans6_Transfer_CHANNEL; \
	MENU trans6_Transfer_CHANNEL_page; \
	COMMAND trans6_Transfer_CHANNEL_read; \
	COMMAND trans6_Transfer_CHANNEL_write; \
	COLLECTION trans6_Transfer_PV; \
	VARIABLE trans6_Transfer_PV_PV; \
	VARIABLE trans6_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans6_Transfer_PV_PV_Time; \
	VARIABLE trans6_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans6_Transfer_PV_Measurement_Status_Limit; \
	MENU trans6_Transfer_PV_page; \
	COMMAND trans6_Transfer_PV_read; \
	VARIABLE trans6_Transfer_PV_UNIT; \
	MENU trans6_Transfer_PV_UNIT_page; \
	COMMAND trans6_Transfer_PV_UNIT_read; \
	COMMAND trans6_Transfer_PV_UNIT_write; \
	VARIABLE trans6_Transfer_PV_UNIT_TEXT; \
	MENU trans6_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans6_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans6_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans6_Transfer_STATIC_VALUE; \
	MENU trans6_Transfer_STATIC_VALUE_page; \
	COMMAND trans6_Transfer_STATIC_VALUE_read; \
	COMMAND trans6_Transfer_STATIC_VALUE_write; \
	VARIABLE trans6_Transfer_CORRECTION_CHANNEL; \
	MENU trans6_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans6_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans6_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans6_Transfer_FB_VALUE; \
	VARIABLE trans6_Transfer_FB_VALUE_Value; \
	VARIABLE trans6_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans6_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans6_Transfer_FB_VALUE_Status_Limit; \
	MENU trans6_Transfer_FB_VALUE_page; \
	COMMAND trans6_Transfer_FB_VALUE_read; \
	COMMAND trans6_Transfer_FB_VALUE_write; \
	VARIABLE trans6_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans6_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans6_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans6_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans6_Transfer_CALCULATION_1; \
	VARIABLE trans6_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans6_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans6_Transfer_CALCULATION_1_Choice; \
	MENU trans6_Transfer_CALCULATION_1_page; \
	COMMAND trans6_Transfer_CALCULATION_1_read; \
	COMMAND trans6_Transfer_CALCULATION_1_write; \
	UNIT trans6_Transfer_unit_1

#define USE_TRANS6_TRANSFER_MANDATORY_A \
	USE_TRANS6_TRANSFER_MANDATORY_BOTH; \
	MENU trans6_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS6_TRANSFER_MANDATORY_B \
	USE_TRANS6_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans6_Transfer_VIEW_1; \
	MENU trans6_Transfer_VIEW_1_page; \
	MENU trans6_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS6_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans6_Transfer_VIEW_2; \
	MENU trans6_Transfer_VIEW_2_page; \
	COLLECTION trans6_Transfer_VIEW_3; \
	MENU trans6_Transfer_VIEW_3_page

#define USE_TRANS6_TRANSFER_OPTIONAL_A \
	USE_TRANS6_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans6_Transfer_VIEW_1; \
	MENU trans6_Transfer_VIEW_1_page; \
	MENU trans6_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS6_TRANSFER_OPTIONAL_B \
	USE_TRANS6_TRANSFER_OPTIONAL_BOTH; \
	MENU trans6_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans6_Transfer_)
#define USE_TRANS6_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans6_Transfer_)
#define USE_TRANS6_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans6_Transfer_)
#define USE_TRANS6_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans6_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_TRANSFER_MANDATORY_BOTH \
	BLOCK trans7_Transfer_block; \
	COLLECTION trans7_Transfer_BLOCK_OBJECT; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans7_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans7_Transfer_ST_REV; \
	MENU trans7_Transfer_ST_REV_page; \
	COMMAND trans7_Transfer_ST_REV_read; \
	VARIABLE trans7_Transfer_TAG_DESC; \
	MENU trans7_Transfer_TAG_DESC_page; \
	COMMAND trans7_Transfer_TAG_DESC_read; \
	COMMAND trans7_Transfer_TAG_DESC_write; \
	VARIABLE trans7_Transfer_STRATEGY; \
	MENU trans7_Transfer_STRATEGY_page; \
	COMMAND trans7_Transfer_STRATEGY_read; \
	COMMAND trans7_Transfer_STRATEGY_write; \
	VARIABLE trans7_Transfer_ALERT_KEY; \
	MENU trans7_Transfer_ALERT_KEY_page; \
	COMMAND trans7_Transfer_ALERT_KEY_read; \
	COMMAND trans7_Transfer_ALERT_KEY_write; \
	VARIABLE trans7_Transfer_TARGET_MODE; \
	MENU trans7_Transfer_TARGET_MODE_page; \
	COMMAND trans7_Transfer_TARGET_MODE_read; \
	COMMAND trans7_Transfer_TARGET_MODE_write; \
	COLLECTION trans7_Transfer_MODE_BLK; \
	VARIABLE trans7_Transfer_MODE_BLK_Actual; \
	VARIABLE trans7_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans7_Transfer_MODE_BLK_Normal; \
	MENU trans7_Transfer_MODE_BLK_page; \
	COMMAND trans7_Transfer_MODE_BLK_read; \
	COLLECTION trans7_Transfer_ALARM_SUM; \
	VARIABLE trans7_Transfer_ALARM_SUM_Current; \
	VARIABLE trans7_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans7_Transfer_ALARM_SUM_Disabled; \
	MENU trans7_Transfer_ALARM_SUM_page; \
	COMMAND trans7_Transfer_ALARM_SUM_read; \
	VARIABLE trans7_Transfer_CHANNEL; \
	MENU trans7_Transfer_CHANNEL_page; \
	COMMAND trans7_Transfer_CHANNEL_read; \
	COMMAND trans7_Transfer_CHANNEL_write; \
	COLLECTION trans7_Transfer_PV; \
	VARIABLE trans7_Transfer_PV_PV; \
	VARIABLE trans7_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans7_Transfer_PV_PV_Time; \
	VARIABLE trans7_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans7_Transfer_PV_Measurement_Status_Limit; \
	MENU trans7_Transfer_PV_page; \
	COMMAND trans7_Transfer_PV_read; \
	VARIABLE trans7_Transfer_PV_UNIT; \
	MENU trans7_Transfer_PV_UNIT_page; \
	COMMAND trans7_Transfer_PV_UNIT_read; \
	COMMAND trans7_Transfer_PV_UNIT_write; \
	VARIABLE trans7_Transfer_PV_UNIT_TEXT; \
	MENU trans7_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans7_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans7_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans7_Transfer_STATIC_VALUE; \
	MENU trans7_Transfer_STATIC_VALUE_page; \
	COMMAND trans7_Transfer_STATIC_VALUE_read; \
	COMMAND trans7_Transfer_STATIC_VALUE_write; \
	VARIABLE trans7_Transfer_CORRECTION_CHANNEL; \
	MENU trans7_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans7_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans7_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans7_Transfer_FB_VALUE; \
	VARIABLE trans7_Transfer_FB_VALUE_Value; \
	VARIABLE trans7_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans7_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans7_Transfer_FB_VALUE_Status_Limit; \
	MENU trans7_Transfer_FB_VALUE_page; \
	COMMAND trans7_Transfer_FB_VALUE_read; \
	COMMAND trans7_Transfer_FB_VALUE_write; \
	VARIABLE trans7_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans7_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans7_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans7_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans7_Transfer_CALCULATION_1; \
	VARIABLE trans7_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans7_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans7_Transfer_CALCULATION_1_Choice; \
	MENU trans7_Transfer_CALCULATION_1_page; \
	COMMAND trans7_Transfer_CALCULATION_1_read; \
	COMMAND trans7_Transfer_CALCULATION_1_write; \
	UNIT trans7_Transfer_unit_1

#define USE_TRANS7_TRANSFER_MANDATORY_A \
	USE_TRANS7_TRANSFER_MANDATORY_BOTH; \
	MENU trans7_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS7_TRANSFER_MANDATORY_B \
	USE_TRANS7_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans7_Transfer_VIEW_1; \
	MENU trans7_Transfer_VIEW_1_page; \
	MENU trans7_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS7_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans7_Transfer_VIEW_2; \
	MENU trans7_Transfer_VIEW_2_page; \
	COLLECTION trans7_Transfer_VIEW_3; \
	MENU trans7_Transfer_VIEW_3_page

#define USE_TRANS7_TRANSFER_OPTIONAL_A \
	USE_TRANS7_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans7_Transfer_VIEW_1; \
	MENU trans7_Transfer_VIEW_1_page; \
	MENU trans7_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS7_TRANSFER_OPTIONAL_B \
	USE_TRANS7_TRANSFER_OPTIONAL_BOTH; \
	MENU trans7_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans7_Transfer_)
#define USE_TRANS7_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans7_Transfer_)
#define USE_TRANS7_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans7_Transfer_)
#define USE_TRANS7_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans7_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_TRANSFER_MANDATORY_BOTH \
	BLOCK trans8_Transfer_block; \
	COLLECTION trans8_Transfer_BLOCK_OBJECT; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans8_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans8_Transfer_ST_REV; \
	MENU trans8_Transfer_ST_REV_page; \
	COMMAND trans8_Transfer_ST_REV_read; \
	VARIABLE trans8_Transfer_TAG_DESC; \
	MENU trans8_Transfer_TAG_DESC_page; \
	COMMAND trans8_Transfer_TAG_DESC_read; \
	COMMAND trans8_Transfer_TAG_DESC_write; \
	VARIABLE trans8_Transfer_STRATEGY; \
	MENU trans8_Transfer_STRATEGY_page; \
	COMMAND trans8_Transfer_STRATEGY_read; \
	COMMAND trans8_Transfer_STRATEGY_write; \
	VARIABLE trans8_Transfer_ALERT_KEY; \
	MENU trans8_Transfer_ALERT_KEY_page; \
	COMMAND trans8_Transfer_ALERT_KEY_read; \
	COMMAND trans8_Transfer_ALERT_KEY_write; \
	VARIABLE trans8_Transfer_TARGET_MODE; \
	MENU trans8_Transfer_TARGET_MODE_page; \
	COMMAND trans8_Transfer_TARGET_MODE_read; \
	COMMAND trans8_Transfer_TARGET_MODE_write; \
	COLLECTION trans8_Transfer_MODE_BLK; \
	VARIABLE trans8_Transfer_MODE_BLK_Actual; \
	VARIABLE trans8_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans8_Transfer_MODE_BLK_Normal; \
	MENU trans8_Transfer_MODE_BLK_page; \
	COMMAND trans8_Transfer_MODE_BLK_read; \
	COLLECTION trans8_Transfer_ALARM_SUM; \
	VARIABLE trans8_Transfer_ALARM_SUM_Current; \
	VARIABLE trans8_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans8_Transfer_ALARM_SUM_Disabled; \
	MENU trans8_Transfer_ALARM_SUM_page; \
	COMMAND trans8_Transfer_ALARM_SUM_read; \
	VARIABLE trans8_Transfer_CHANNEL; \
	MENU trans8_Transfer_CHANNEL_page; \
	COMMAND trans8_Transfer_CHANNEL_read; \
	COMMAND trans8_Transfer_CHANNEL_write; \
	COLLECTION trans8_Transfer_PV; \
	VARIABLE trans8_Transfer_PV_PV; \
	VARIABLE trans8_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans8_Transfer_PV_PV_Time; \
	VARIABLE trans8_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans8_Transfer_PV_Measurement_Status_Limit; \
	MENU trans8_Transfer_PV_page; \
	COMMAND trans8_Transfer_PV_read; \
	VARIABLE trans8_Transfer_PV_UNIT; \
	MENU trans8_Transfer_PV_UNIT_page; \
	COMMAND trans8_Transfer_PV_UNIT_read; \
	COMMAND trans8_Transfer_PV_UNIT_write; \
	VARIABLE trans8_Transfer_PV_UNIT_TEXT; \
	MENU trans8_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans8_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans8_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans8_Transfer_STATIC_VALUE; \
	MENU trans8_Transfer_STATIC_VALUE_page; \
	COMMAND trans8_Transfer_STATIC_VALUE_read; \
	COMMAND trans8_Transfer_STATIC_VALUE_write; \
	VARIABLE trans8_Transfer_CORRECTION_CHANNEL; \
	MENU trans8_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans8_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans8_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans8_Transfer_FB_VALUE; \
	VARIABLE trans8_Transfer_FB_VALUE_Value; \
	VARIABLE trans8_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans8_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans8_Transfer_FB_VALUE_Status_Limit; \
	MENU trans8_Transfer_FB_VALUE_page; \
	COMMAND trans8_Transfer_FB_VALUE_read; \
	COMMAND trans8_Transfer_FB_VALUE_write; \
	VARIABLE trans8_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans8_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans8_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans8_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans8_Transfer_CALCULATION_1; \
	VARIABLE trans8_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans8_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans8_Transfer_CALCULATION_1_Choice; \
	MENU trans8_Transfer_CALCULATION_1_page; \
	COMMAND trans8_Transfer_CALCULATION_1_read; \
	COMMAND trans8_Transfer_CALCULATION_1_write; \
	UNIT trans8_Transfer_unit_1

#define USE_TRANS8_TRANSFER_MANDATORY_A \
	USE_TRANS8_TRANSFER_MANDATORY_BOTH; \
	MENU trans8_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS8_TRANSFER_MANDATORY_B \
	USE_TRANS8_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans8_Transfer_VIEW_1; \
	MENU trans8_Transfer_VIEW_1_page; \
	MENU trans8_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS8_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans8_Transfer_VIEW_2; \
	MENU trans8_Transfer_VIEW_2_page; \
	COLLECTION trans8_Transfer_VIEW_3; \
	MENU trans8_Transfer_VIEW_3_page

#define USE_TRANS8_TRANSFER_OPTIONAL_A \
	USE_TRANS8_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans8_Transfer_VIEW_1; \
	MENU trans8_Transfer_VIEW_1_page; \
	MENU trans8_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS8_TRANSFER_OPTIONAL_B \
	USE_TRANS8_TRANSFER_OPTIONAL_BOTH; \
	MENU trans8_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans8_Transfer_)
#define USE_TRANS8_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans8_Transfer_)
#define USE_TRANS8_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans8_Transfer_)
#define USE_TRANS8_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans8_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_TRANSFER_MANDATORY_BOTH \
	BLOCK trans9_Transfer_block; \
	COLLECTION trans9_Transfer_BLOCK_OBJECT; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans9_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans9_Transfer_ST_REV; \
	MENU trans9_Transfer_ST_REV_page; \
	COMMAND trans9_Transfer_ST_REV_read; \
	VARIABLE trans9_Transfer_TAG_DESC; \
	MENU trans9_Transfer_TAG_DESC_page; \
	COMMAND trans9_Transfer_TAG_DESC_read; \
	COMMAND trans9_Transfer_TAG_DESC_write; \
	VARIABLE trans9_Transfer_STRATEGY; \
	MENU trans9_Transfer_STRATEGY_page; \
	COMMAND trans9_Transfer_STRATEGY_read; \
	COMMAND trans9_Transfer_STRATEGY_write; \
	VARIABLE trans9_Transfer_ALERT_KEY; \
	MENU trans9_Transfer_ALERT_KEY_page; \
	COMMAND trans9_Transfer_ALERT_KEY_read; \
	COMMAND trans9_Transfer_ALERT_KEY_write; \
	VARIABLE trans9_Transfer_TARGET_MODE; \
	MENU trans9_Transfer_TARGET_MODE_page; \
	COMMAND trans9_Transfer_TARGET_MODE_read; \
	COMMAND trans9_Transfer_TARGET_MODE_write; \
	COLLECTION trans9_Transfer_MODE_BLK; \
	VARIABLE trans9_Transfer_MODE_BLK_Actual; \
	VARIABLE trans9_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans9_Transfer_MODE_BLK_Normal; \
	MENU trans9_Transfer_MODE_BLK_page; \
	COMMAND trans9_Transfer_MODE_BLK_read; \
	COLLECTION trans9_Transfer_ALARM_SUM; \
	VARIABLE trans9_Transfer_ALARM_SUM_Current; \
	VARIABLE trans9_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans9_Transfer_ALARM_SUM_Disabled; \
	MENU trans9_Transfer_ALARM_SUM_page; \
	COMMAND trans9_Transfer_ALARM_SUM_read; \
	VARIABLE trans9_Transfer_CHANNEL; \
	MENU trans9_Transfer_CHANNEL_page; \
	COMMAND trans9_Transfer_CHANNEL_read; \
	COMMAND trans9_Transfer_CHANNEL_write; \
	COLLECTION trans9_Transfer_PV; \
	VARIABLE trans9_Transfer_PV_PV; \
	VARIABLE trans9_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans9_Transfer_PV_PV_Time; \
	VARIABLE trans9_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans9_Transfer_PV_Measurement_Status_Limit; \
	MENU trans9_Transfer_PV_page; \
	COMMAND trans9_Transfer_PV_read; \
	VARIABLE trans9_Transfer_PV_UNIT; \
	MENU trans9_Transfer_PV_UNIT_page; \
	COMMAND trans9_Transfer_PV_UNIT_read; \
	COMMAND trans9_Transfer_PV_UNIT_write; \
	VARIABLE trans9_Transfer_PV_UNIT_TEXT; \
	MENU trans9_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans9_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans9_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans9_Transfer_STATIC_VALUE; \
	MENU trans9_Transfer_STATIC_VALUE_page; \
	COMMAND trans9_Transfer_STATIC_VALUE_read; \
	COMMAND trans9_Transfer_STATIC_VALUE_write; \
	VARIABLE trans9_Transfer_CORRECTION_CHANNEL; \
	MENU trans9_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans9_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans9_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans9_Transfer_FB_VALUE; \
	VARIABLE trans9_Transfer_FB_VALUE_Value; \
	VARIABLE trans9_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans9_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans9_Transfer_FB_VALUE_Status_Limit; \
	MENU trans9_Transfer_FB_VALUE_page; \
	COMMAND trans9_Transfer_FB_VALUE_read; \
	COMMAND trans9_Transfer_FB_VALUE_write; \
	VARIABLE trans9_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans9_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans9_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans9_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans9_Transfer_CALCULATION_1; \
	VARIABLE trans9_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans9_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans9_Transfer_CALCULATION_1_Choice; \
	MENU trans9_Transfer_CALCULATION_1_page; \
	COMMAND trans9_Transfer_CALCULATION_1_read; \
	COMMAND trans9_Transfer_CALCULATION_1_write; \
	UNIT trans9_Transfer_unit_1

#define USE_TRANS9_TRANSFER_MANDATORY_A \
	USE_TRANS9_TRANSFER_MANDATORY_BOTH; \
	MENU trans9_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS9_TRANSFER_MANDATORY_B \
	USE_TRANS9_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans9_Transfer_VIEW_1; \
	MENU trans9_Transfer_VIEW_1_page; \
	MENU trans9_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS9_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans9_Transfer_VIEW_2; \
	MENU trans9_Transfer_VIEW_2_page; \
	COLLECTION trans9_Transfer_VIEW_3; \
	MENU trans9_Transfer_VIEW_3_page

#define USE_TRANS9_TRANSFER_OPTIONAL_A \
	USE_TRANS9_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans9_Transfer_VIEW_1; \
	MENU trans9_Transfer_VIEW_1_page; \
	MENU trans9_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS9_TRANSFER_OPTIONAL_B \
	USE_TRANS9_TRANSFER_OPTIONAL_BOTH; \
	MENU trans9_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans9_Transfer_)
#define USE_TRANS9_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans9_Transfer_)
#define USE_TRANS9_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans9_Transfer_)
#define USE_TRANS9_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans9_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_TRANSFER_MANDATORY_BOTH \
	BLOCK trans10_Transfer_block; \
	COLLECTION trans10_Transfer_BLOCK_OBJECT; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans10_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans10_Transfer_ST_REV; \
	MENU trans10_Transfer_ST_REV_page; \
	COMMAND trans10_Transfer_ST_REV_read; \
	VARIABLE trans10_Transfer_TAG_DESC; \
	MENU trans10_Transfer_TAG_DESC_page; \
	COMMAND trans10_Transfer_TAG_DESC_read; \
	COMMAND trans10_Transfer_TAG_DESC_write; \
	VARIABLE trans10_Transfer_STRATEGY; \
	MENU trans10_Transfer_STRATEGY_page; \
	COMMAND trans10_Transfer_STRATEGY_read; \
	COMMAND trans10_Transfer_STRATEGY_write; \
	VARIABLE trans10_Transfer_ALERT_KEY; \
	MENU trans10_Transfer_ALERT_KEY_page; \
	COMMAND trans10_Transfer_ALERT_KEY_read; \
	COMMAND trans10_Transfer_ALERT_KEY_write; \
	VARIABLE trans10_Transfer_TARGET_MODE; \
	MENU trans10_Transfer_TARGET_MODE_page; \
	COMMAND trans10_Transfer_TARGET_MODE_read; \
	COMMAND trans10_Transfer_TARGET_MODE_write; \
	COLLECTION trans10_Transfer_MODE_BLK; \
	VARIABLE trans10_Transfer_MODE_BLK_Actual; \
	VARIABLE trans10_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans10_Transfer_MODE_BLK_Normal; \
	MENU trans10_Transfer_MODE_BLK_page; \
	COMMAND trans10_Transfer_MODE_BLK_read; \
	COLLECTION trans10_Transfer_ALARM_SUM; \
	VARIABLE trans10_Transfer_ALARM_SUM_Current; \
	VARIABLE trans10_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans10_Transfer_ALARM_SUM_Disabled; \
	MENU trans10_Transfer_ALARM_SUM_page; \
	COMMAND trans10_Transfer_ALARM_SUM_read; \
	VARIABLE trans10_Transfer_CHANNEL; \
	MENU trans10_Transfer_CHANNEL_page; \
	COMMAND trans10_Transfer_CHANNEL_read; \
	COMMAND trans10_Transfer_CHANNEL_write; \
	COLLECTION trans10_Transfer_PV; \
	VARIABLE trans10_Transfer_PV_PV; \
	VARIABLE trans10_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans10_Transfer_PV_PV_Time; \
	VARIABLE trans10_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans10_Transfer_PV_Measurement_Status_Limit; \
	MENU trans10_Transfer_PV_page; \
	COMMAND trans10_Transfer_PV_read; \
	VARIABLE trans10_Transfer_PV_UNIT; \
	MENU trans10_Transfer_PV_UNIT_page; \
	COMMAND trans10_Transfer_PV_UNIT_read; \
	COMMAND trans10_Transfer_PV_UNIT_write; \
	VARIABLE trans10_Transfer_PV_UNIT_TEXT; \
	MENU trans10_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans10_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans10_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans10_Transfer_STATIC_VALUE; \
	MENU trans10_Transfer_STATIC_VALUE_page; \
	COMMAND trans10_Transfer_STATIC_VALUE_read; \
	COMMAND trans10_Transfer_STATIC_VALUE_write; \
	VARIABLE trans10_Transfer_CORRECTION_CHANNEL; \
	MENU trans10_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans10_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans10_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans10_Transfer_FB_VALUE; \
	VARIABLE trans10_Transfer_FB_VALUE_Value; \
	VARIABLE trans10_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans10_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans10_Transfer_FB_VALUE_Status_Limit; \
	MENU trans10_Transfer_FB_VALUE_page; \
	COMMAND trans10_Transfer_FB_VALUE_read; \
	COMMAND trans10_Transfer_FB_VALUE_write; \
	VARIABLE trans10_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans10_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans10_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans10_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans10_Transfer_CALCULATION_1; \
	VARIABLE trans10_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans10_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans10_Transfer_CALCULATION_1_Choice; \
	MENU trans10_Transfer_CALCULATION_1_page; \
	COMMAND trans10_Transfer_CALCULATION_1_read; \
	COMMAND trans10_Transfer_CALCULATION_1_write; \
	UNIT trans10_Transfer_unit_1

#define USE_TRANS10_TRANSFER_MANDATORY_A \
	USE_TRANS10_TRANSFER_MANDATORY_BOTH; \
	MENU trans10_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS10_TRANSFER_MANDATORY_B \
	USE_TRANS10_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans10_Transfer_VIEW_1; \
	MENU trans10_Transfer_VIEW_1_page; \
	MENU trans10_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS10_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans10_Transfer_VIEW_2; \
	MENU trans10_Transfer_VIEW_2_page; \
	COLLECTION trans10_Transfer_VIEW_3; \
	MENU trans10_Transfer_VIEW_3_page

#define USE_TRANS10_TRANSFER_OPTIONAL_A \
	USE_TRANS10_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans10_Transfer_VIEW_1; \
	MENU trans10_Transfer_VIEW_1_page; \
	MENU trans10_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS10_TRANSFER_OPTIONAL_B \
	USE_TRANS10_TRANSFER_OPTIONAL_BOTH; \
	MENU trans10_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans10_Transfer_)
#define USE_TRANS10_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans10_Transfer_)
#define USE_TRANS10_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans10_Transfer_)
#define USE_TRANS10_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans10_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_TRANSFER_MANDATORY_BOTH \
	BLOCK trans11_Transfer_block; \
	COLLECTION trans11_Transfer_BLOCK_OBJECT; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans11_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans11_Transfer_ST_REV; \
	MENU trans11_Transfer_ST_REV_page; \
	COMMAND trans11_Transfer_ST_REV_read; \
	VARIABLE trans11_Transfer_TAG_DESC; \
	MENU trans11_Transfer_TAG_DESC_page; \
	COMMAND trans11_Transfer_TAG_DESC_read; \
	COMMAND trans11_Transfer_TAG_DESC_write; \
	VARIABLE trans11_Transfer_STRATEGY; \
	MENU trans11_Transfer_STRATEGY_page; \
	COMMAND trans11_Transfer_STRATEGY_read; \
	COMMAND trans11_Transfer_STRATEGY_write; \
	VARIABLE trans11_Transfer_ALERT_KEY; \
	MENU trans11_Transfer_ALERT_KEY_page; \
	COMMAND trans11_Transfer_ALERT_KEY_read; \
	COMMAND trans11_Transfer_ALERT_KEY_write; \
	VARIABLE trans11_Transfer_TARGET_MODE; \
	MENU trans11_Transfer_TARGET_MODE_page; \
	COMMAND trans11_Transfer_TARGET_MODE_read; \
	COMMAND trans11_Transfer_TARGET_MODE_write; \
	COLLECTION trans11_Transfer_MODE_BLK; \
	VARIABLE trans11_Transfer_MODE_BLK_Actual; \
	VARIABLE trans11_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans11_Transfer_MODE_BLK_Normal; \
	MENU trans11_Transfer_MODE_BLK_page; \
	COMMAND trans11_Transfer_MODE_BLK_read; \
	COLLECTION trans11_Transfer_ALARM_SUM; \
	VARIABLE trans11_Transfer_ALARM_SUM_Current; \
	VARIABLE trans11_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans11_Transfer_ALARM_SUM_Disabled; \
	MENU trans11_Transfer_ALARM_SUM_page; \
	COMMAND trans11_Transfer_ALARM_SUM_read; \
	VARIABLE trans11_Transfer_CHANNEL; \
	MENU trans11_Transfer_CHANNEL_page; \
	COMMAND trans11_Transfer_CHANNEL_read; \
	COMMAND trans11_Transfer_CHANNEL_write; \
	COLLECTION trans11_Transfer_PV; \
	VARIABLE trans11_Transfer_PV_PV; \
	VARIABLE trans11_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans11_Transfer_PV_PV_Time; \
	VARIABLE trans11_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans11_Transfer_PV_Measurement_Status_Limit; \
	MENU trans11_Transfer_PV_page; \
	COMMAND trans11_Transfer_PV_read; \
	VARIABLE trans11_Transfer_PV_UNIT; \
	MENU trans11_Transfer_PV_UNIT_page; \
	COMMAND trans11_Transfer_PV_UNIT_read; \
	COMMAND trans11_Transfer_PV_UNIT_write; \
	VARIABLE trans11_Transfer_PV_UNIT_TEXT; \
	MENU trans11_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans11_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans11_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans11_Transfer_STATIC_VALUE; \
	MENU trans11_Transfer_STATIC_VALUE_page; \
	COMMAND trans11_Transfer_STATIC_VALUE_read; \
	COMMAND trans11_Transfer_STATIC_VALUE_write; \
	VARIABLE trans11_Transfer_CORRECTION_CHANNEL; \
	MENU trans11_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans11_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans11_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans11_Transfer_FB_VALUE; \
	VARIABLE trans11_Transfer_FB_VALUE_Value; \
	VARIABLE trans11_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans11_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans11_Transfer_FB_VALUE_Status_Limit; \
	MENU trans11_Transfer_FB_VALUE_page; \
	COMMAND trans11_Transfer_FB_VALUE_read; \
	COMMAND trans11_Transfer_FB_VALUE_write; \
	VARIABLE trans11_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans11_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans11_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans11_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans11_Transfer_CALCULATION_1; \
	VARIABLE trans11_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans11_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans11_Transfer_CALCULATION_1_Choice; \
	MENU trans11_Transfer_CALCULATION_1_page; \
	COMMAND trans11_Transfer_CALCULATION_1_read; \
	COMMAND trans11_Transfer_CALCULATION_1_write; \
	UNIT trans11_Transfer_unit_1

#define USE_TRANS11_TRANSFER_MANDATORY_A \
	USE_TRANS11_TRANSFER_MANDATORY_BOTH; \
	MENU trans11_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS11_TRANSFER_MANDATORY_B \
	USE_TRANS11_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans11_Transfer_VIEW_1; \
	MENU trans11_Transfer_VIEW_1_page; \
	MENU trans11_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS11_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans11_Transfer_VIEW_2; \
	MENU trans11_Transfer_VIEW_2_page; \
	COLLECTION trans11_Transfer_VIEW_3; \
	MENU trans11_Transfer_VIEW_3_page

#define USE_TRANS11_TRANSFER_OPTIONAL_A \
	USE_TRANS11_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans11_Transfer_VIEW_1; \
	MENU trans11_Transfer_VIEW_1_page; \
	MENU trans11_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS11_TRANSFER_OPTIONAL_B \
	USE_TRANS11_TRANSFER_OPTIONAL_BOTH; \
	MENU trans11_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans11_Transfer_)
#define USE_TRANS11_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans11_Transfer_)
#define USE_TRANS11_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans11_Transfer_)
#define USE_TRANS11_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans11_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_TRANSFER_MANDATORY_BOTH \
	BLOCK trans12_Transfer_block; \
	COLLECTION trans12_Transfer_BLOCK_OBJECT; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans12_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans12_Transfer_ST_REV; \
	MENU trans12_Transfer_ST_REV_page; \
	COMMAND trans12_Transfer_ST_REV_read; \
	VARIABLE trans12_Transfer_TAG_DESC; \
	MENU trans12_Transfer_TAG_DESC_page; \
	COMMAND trans12_Transfer_TAG_DESC_read; \
	COMMAND trans12_Transfer_TAG_DESC_write; \
	VARIABLE trans12_Transfer_STRATEGY; \
	MENU trans12_Transfer_STRATEGY_page; \
	COMMAND trans12_Transfer_STRATEGY_read; \
	COMMAND trans12_Transfer_STRATEGY_write; \
	VARIABLE trans12_Transfer_ALERT_KEY; \
	MENU trans12_Transfer_ALERT_KEY_page; \
	COMMAND trans12_Transfer_ALERT_KEY_read; \
	COMMAND trans12_Transfer_ALERT_KEY_write; \
	VARIABLE trans12_Transfer_TARGET_MODE; \
	MENU trans12_Transfer_TARGET_MODE_page; \
	COMMAND trans12_Transfer_TARGET_MODE_read; \
	COMMAND trans12_Transfer_TARGET_MODE_write; \
	COLLECTION trans12_Transfer_MODE_BLK; \
	VARIABLE trans12_Transfer_MODE_BLK_Actual; \
	VARIABLE trans12_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans12_Transfer_MODE_BLK_Normal; \
	MENU trans12_Transfer_MODE_BLK_page; \
	COMMAND trans12_Transfer_MODE_BLK_read; \
	COLLECTION trans12_Transfer_ALARM_SUM; \
	VARIABLE trans12_Transfer_ALARM_SUM_Current; \
	VARIABLE trans12_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans12_Transfer_ALARM_SUM_Disabled; \
	MENU trans12_Transfer_ALARM_SUM_page; \
	COMMAND trans12_Transfer_ALARM_SUM_read; \
	VARIABLE trans12_Transfer_CHANNEL; \
	MENU trans12_Transfer_CHANNEL_page; \
	COMMAND trans12_Transfer_CHANNEL_read; \
	COMMAND trans12_Transfer_CHANNEL_write; \
	COLLECTION trans12_Transfer_PV; \
	VARIABLE trans12_Transfer_PV_PV; \
	VARIABLE trans12_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans12_Transfer_PV_PV_Time; \
	VARIABLE trans12_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans12_Transfer_PV_Measurement_Status_Limit; \
	MENU trans12_Transfer_PV_page; \
	COMMAND trans12_Transfer_PV_read; \
	VARIABLE trans12_Transfer_PV_UNIT; \
	MENU trans12_Transfer_PV_UNIT_page; \
	COMMAND trans12_Transfer_PV_UNIT_read; \
	COMMAND trans12_Transfer_PV_UNIT_write; \
	VARIABLE trans12_Transfer_PV_UNIT_TEXT; \
	MENU trans12_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans12_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans12_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans12_Transfer_STATIC_VALUE; \
	MENU trans12_Transfer_STATIC_VALUE_page; \
	COMMAND trans12_Transfer_STATIC_VALUE_read; \
	COMMAND trans12_Transfer_STATIC_VALUE_write; \
	VARIABLE trans12_Transfer_CORRECTION_CHANNEL; \
	MENU trans12_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans12_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans12_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans12_Transfer_FB_VALUE; \
	VARIABLE trans12_Transfer_FB_VALUE_Value; \
	VARIABLE trans12_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans12_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans12_Transfer_FB_VALUE_Status_Limit; \
	MENU trans12_Transfer_FB_VALUE_page; \
	COMMAND trans12_Transfer_FB_VALUE_read; \
	COMMAND trans12_Transfer_FB_VALUE_write; \
	VARIABLE trans12_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans12_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans12_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans12_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans12_Transfer_CALCULATION_1; \
	VARIABLE trans12_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans12_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans12_Transfer_CALCULATION_1_Choice; \
	MENU trans12_Transfer_CALCULATION_1_page; \
	COMMAND trans12_Transfer_CALCULATION_1_read; \
	COMMAND trans12_Transfer_CALCULATION_1_write; \
	UNIT trans12_Transfer_unit_1

#define USE_TRANS12_TRANSFER_MANDATORY_A \
	USE_TRANS12_TRANSFER_MANDATORY_BOTH; \
	MENU trans12_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS12_TRANSFER_MANDATORY_B \
	USE_TRANS12_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans12_Transfer_VIEW_1; \
	MENU trans12_Transfer_VIEW_1_page; \
	MENU trans12_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS12_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans12_Transfer_VIEW_2; \
	MENU trans12_Transfer_VIEW_2_page; \
	COLLECTION trans12_Transfer_VIEW_3; \
	MENU trans12_Transfer_VIEW_3_page

#define USE_TRANS12_TRANSFER_OPTIONAL_A \
	USE_TRANS12_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans12_Transfer_VIEW_1; \
	MENU trans12_Transfer_VIEW_1_page; \
	MENU trans12_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS12_TRANSFER_OPTIONAL_B \
	USE_TRANS12_TRANSFER_OPTIONAL_BOTH; \
	MENU trans12_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans12_Transfer_)
#define USE_TRANS12_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans12_Transfer_)
#define USE_TRANS12_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans12_Transfer_)
#define USE_TRANS12_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans12_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_TRANSFER_MANDATORY_BOTH \
	BLOCK trans13_Transfer_block; \
	COLLECTION trans13_Transfer_BLOCK_OBJECT; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans13_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans13_Transfer_ST_REV; \
	MENU trans13_Transfer_ST_REV_page; \
	COMMAND trans13_Transfer_ST_REV_read; \
	VARIABLE trans13_Transfer_TAG_DESC; \
	MENU trans13_Transfer_TAG_DESC_page; \
	COMMAND trans13_Transfer_TAG_DESC_read; \
	COMMAND trans13_Transfer_TAG_DESC_write; \
	VARIABLE trans13_Transfer_STRATEGY; \
	MENU trans13_Transfer_STRATEGY_page; \
	COMMAND trans13_Transfer_STRATEGY_read; \
	COMMAND trans13_Transfer_STRATEGY_write; \
	VARIABLE trans13_Transfer_ALERT_KEY; \
	MENU trans13_Transfer_ALERT_KEY_page; \
	COMMAND trans13_Transfer_ALERT_KEY_read; \
	COMMAND trans13_Transfer_ALERT_KEY_write; \
	VARIABLE trans13_Transfer_TARGET_MODE; \
	MENU trans13_Transfer_TARGET_MODE_page; \
	COMMAND trans13_Transfer_TARGET_MODE_read; \
	COMMAND trans13_Transfer_TARGET_MODE_write; \
	COLLECTION trans13_Transfer_MODE_BLK; \
	VARIABLE trans13_Transfer_MODE_BLK_Actual; \
	VARIABLE trans13_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans13_Transfer_MODE_BLK_Normal; \
	MENU trans13_Transfer_MODE_BLK_page; \
	COMMAND trans13_Transfer_MODE_BLK_read; \
	COLLECTION trans13_Transfer_ALARM_SUM; \
	VARIABLE trans13_Transfer_ALARM_SUM_Current; \
	VARIABLE trans13_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans13_Transfer_ALARM_SUM_Disabled; \
	MENU trans13_Transfer_ALARM_SUM_page; \
	COMMAND trans13_Transfer_ALARM_SUM_read; \
	VARIABLE trans13_Transfer_CHANNEL; \
	MENU trans13_Transfer_CHANNEL_page; \
	COMMAND trans13_Transfer_CHANNEL_read; \
	COMMAND trans13_Transfer_CHANNEL_write; \
	COLLECTION trans13_Transfer_PV; \
	VARIABLE trans13_Transfer_PV_PV; \
	VARIABLE trans13_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans13_Transfer_PV_PV_Time; \
	VARIABLE trans13_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans13_Transfer_PV_Measurement_Status_Limit; \
	MENU trans13_Transfer_PV_page; \
	COMMAND trans13_Transfer_PV_read; \
	VARIABLE trans13_Transfer_PV_UNIT; \
	MENU trans13_Transfer_PV_UNIT_page; \
	COMMAND trans13_Transfer_PV_UNIT_read; \
	COMMAND trans13_Transfer_PV_UNIT_write; \
	VARIABLE trans13_Transfer_PV_UNIT_TEXT; \
	MENU trans13_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans13_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans13_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans13_Transfer_STATIC_VALUE; \
	MENU trans13_Transfer_STATIC_VALUE_page; \
	COMMAND trans13_Transfer_STATIC_VALUE_read; \
	COMMAND trans13_Transfer_STATIC_VALUE_write; \
	VARIABLE trans13_Transfer_CORRECTION_CHANNEL; \
	MENU trans13_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans13_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans13_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans13_Transfer_FB_VALUE; \
	VARIABLE trans13_Transfer_FB_VALUE_Value; \
	VARIABLE trans13_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans13_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans13_Transfer_FB_VALUE_Status_Limit; \
	MENU trans13_Transfer_FB_VALUE_page; \
	COMMAND trans13_Transfer_FB_VALUE_read; \
	COMMAND trans13_Transfer_FB_VALUE_write; \
	VARIABLE trans13_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans13_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans13_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans13_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans13_Transfer_CALCULATION_1; \
	VARIABLE trans13_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans13_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans13_Transfer_CALCULATION_1_Choice; \
	MENU trans13_Transfer_CALCULATION_1_page; \
	COMMAND trans13_Transfer_CALCULATION_1_read; \
	COMMAND trans13_Transfer_CALCULATION_1_write; \
	UNIT trans13_Transfer_unit_1

#define USE_TRANS13_TRANSFER_MANDATORY_A \
	USE_TRANS13_TRANSFER_MANDATORY_BOTH; \
	MENU trans13_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS13_TRANSFER_MANDATORY_B \
	USE_TRANS13_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans13_Transfer_VIEW_1; \
	MENU trans13_Transfer_VIEW_1_page; \
	MENU trans13_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS13_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans13_Transfer_VIEW_2; \
	MENU trans13_Transfer_VIEW_2_page; \
	COLLECTION trans13_Transfer_VIEW_3; \
	MENU trans13_Transfer_VIEW_3_page

#define USE_TRANS13_TRANSFER_OPTIONAL_A \
	USE_TRANS13_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans13_Transfer_VIEW_1; \
	MENU trans13_Transfer_VIEW_1_page; \
	MENU trans13_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS13_TRANSFER_OPTIONAL_B \
	USE_TRANS13_TRANSFER_OPTIONAL_BOTH; \
	MENU trans13_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans13_Transfer_)
#define USE_TRANS13_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans13_Transfer_)
#define USE_TRANS13_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans13_Transfer_)
#define USE_TRANS13_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans13_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_TRANSFER_MANDATORY_BOTH \
	BLOCK trans14_Transfer_block; \
	COLLECTION trans14_Transfer_BLOCK_OBJECT; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans14_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans14_Transfer_ST_REV; \
	MENU trans14_Transfer_ST_REV_page; \
	COMMAND trans14_Transfer_ST_REV_read; \
	VARIABLE trans14_Transfer_TAG_DESC; \
	MENU trans14_Transfer_TAG_DESC_page; \
	COMMAND trans14_Transfer_TAG_DESC_read; \
	COMMAND trans14_Transfer_TAG_DESC_write; \
	VARIABLE trans14_Transfer_STRATEGY; \
	MENU trans14_Transfer_STRATEGY_page; \
	COMMAND trans14_Transfer_STRATEGY_read; \
	COMMAND trans14_Transfer_STRATEGY_write; \
	VARIABLE trans14_Transfer_ALERT_KEY; \
	MENU trans14_Transfer_ALERT_KEY_page; \
	COMMAND trans14_Transfer_ALERT_KEY_read; \
	COMMAND trans14_Transfer_ALERT_KEY_write; \
	VARIABLE trans14_Transfer_TARGET_MODE; \
	MENU trans14_Transfer_TARGET_MODE_page; \
	COMMAND trans14_Transfer_TARGET_MODE_read; \
	COMMAND trans14_Transfer_TARGET_MODE_write; \
	COLLECTION trans14_Transfer_MODE_BLK; \
	VARIABLE trans14_Transfer_MODE_BLK_Actual; \
	VARIABLE trans14_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans14_Transfer_MODE_BLK_Normal; \
	MENU trans14_Transfer_MODE_BLK_page; \
	COMMAND trans14_Transfer_MODE_BLK_read; \
	COLLECTION trans14_Transfer_ALARM_SUM; \
	VARIABLE trans14_Transfer_ALARM_SUM_Current; \
	VARIABLE trans14_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans14_Transfer_ALARM_SUM_Disabled; \
	MENU trans14_Transfer_ALARM_SUM_page; \
	COMMAND trans14_Transfer_ALARM_SUM_read; \
	VARIABLE trans14_Transfer_CHANNEL; \
	MENU trans14_Transfer_CHANNEL_page; \
	COMMAND trans14_Transfer_CHANNEL_read; \
	COMMAND trans14_Transfer_CHANNEL_write; \
	COLLECTION trans14_Transfer_PV; \
	VARIABLE trans14_Transfer_PV_PV; \
	VARIABLE trans14_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans14_Transfer_PV_PV_Time; \
	VARIABLE trans14_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans14_Transfer_PV_Measurement_Status_Limit; \
	MENU trans14_Transfer_PV_page; \
	COMMAND trans14_Transfer_PV_read; \
	VARIABLE trans14_Transfer_PV_UNIT; \
	MENU trans14_Transfer_PV_UNIT_page; \
	COMMAND trans14_Transfer_PV_UNIT_read; \
	COMMAND trans14_Transfer_PV_UNIT_write; \
	VARIABLE trans14_Transfer_PV_UNIT_TEXT; \
	MENU trans14_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans14_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans14_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans14_Transfer_STATIC_VALUE; \
	MENU trans14_Transfer_STATIC_VALUE_page; \
	COMMAND trans14_Transfer_STATIC_VALUE_read; \
	COMMAND trans14_Transfer_STATIC_VALUE_write; \
	VARIABLE trans14_Transfer_CORRECTION_CHANNEL; \
	MENU trans14_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans14_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans14_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans14_Transfer_FB_VALUE; \
	VARIABLE trans14_Transfer_FB_VALUE_Value; \
	VARIABLE trans14_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans14_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans14_Transfer_FB_VALUE_Status_Limit; \
	MENU trans14_Transfer_FB_VALUE_page; \
	COMMAND trans14_Transfer_FB_VALUE_read; \
	COMMAND trans14_Transfer_FB_VALUE_write; \
	VARIABLE trans14_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans14_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans14_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans14_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans14_Transfer_CALCULATION_1; \
	VARIABLE trans14_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans14_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans14_Transfer_CALCULATION_1_Choice; \
	MENU trans14_Transfer_CALCULATION_1_page; \
	COMMAND trans14_Transfer_CALCULATION_1_read; \
	COMMAND trans14_Transfer_CALCULATION_1_write; \
	UNIT trans14_Transfer_unit_1

#define USE_TRANS14_TRANSFER_MANDATORY_A \
	USE_TRANS14_TRANSFER_MANDATORY_BOTH; \
	MENU trans14_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS14_TRANSFER_MANDATORY_B \
	USE_TRANS14_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans14_Transfer_VIEW_1; \
	MENU trans14_Transfer_VIEW_1_page; \
	MENU trans14_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS14_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans14_Transfer_VIEW_2; \
	MENU trans14_Transfer_VIEW_2_page; \
	COLLECTION trans14_Transfer_VIEW_3; \
	MENU trans14_Transfer_VIEW_3_page

#define USE_TRANS14_TRANSFER_OPTIONAL_A \
	USE_TRANS14_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans14_Transfer_VIEW_1; \
	MENU trans14_Transfer_VIEW_1_page; \
	MENU trans14_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS14_TRANSFER_OPTIONAL_B \
	USE_TRANS14_TRANSFER_OPTIONAL_BOTH; \
	MENU trans14_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans14_Transfer_)
#define USE_TRANS14_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans14_Transfer_)
#define USE_TRANS14_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans14_Transfer_)
#define USE_TRANS14_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans14_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_TRANSFER_MANDATORY_BOTH \
	BLOCK trans15_Transfer_block; \
	COLLECTION trans15_Transfer_BLOCK_OBJECT; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Transfer_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Transfer_BLOCK_OBJECT_page; \
	COMMAND trans15_Transfer_BLOCK_OBJECT_read; \
	VARIABLE trans15_Transfer_ST_REV; \
	MENU trans15_Transfer_ST_REV_page; \
	COMMAND trans15_Transfer_ST_REV_read; \
	VARIABLE trans15_Transfer_TAG_DESC; \
	MENU trans15_Transfer_TAG_DESC_page; \
	COMMAND trans15_Transfer_TAG_DESC_read; \
	COMMAND trans15_Transfer_TAG_DESC_write; \
	VARIABLE trans15_Transfer_STRATEGY; \
	MENU trans15_Transfer_STRATEGY_page; \
	COMMAND trans15_Transfer_STRATEGY_read; \
	COMMAND trans15_Transfer_STRATEGY_write; \
	VARIABLE trans15_Transfer_ALERT_KEY; \
	MENU trans15_Transfer_ALERT_KEY_page; \
	COMMAND trans15_Transfer_ALERT_KEY_read; \
	COMMAND trans15_Transfer_ALERT_KEY_write; \
	VARIABLE trans15_Transfer_TARGET_MODE; \
	MENU trans15_Transfer_TARGET_MODE_page; \
	COMMAND trans15_Transfer_TARGET_MODE_read; \
	COMMAND trans15_Transfer_TARGET_MODE_write; \
	COLLECTION trans15_Transfer_MODE_BLK; \
	VARIABLE trans15_Transfer_MODE_BLK_Actual; \
	VARIABLE trans15_Transfer_MODE_BLK_Permitted; \
	VARIABLE trans15_Transfer_MODE_BLK_Normal; \
	MENU trans15_Transfer_MODE_BLK_page; \
	COMMAND trans15_Transfer_MODE_BLK_read; \
	COLLECTION trans15_Transfer_ALARM_SUM; \
	VARIABLE trans15_Transfer_ALARM_SUM_Current; \
	VARIABLE trans15_Transfer_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Transfer_ALARM_SUM_Unreported; \
	VARIABLE trans15_Transfer_ALARM_SUM_Disabled; \
	MENU trans15_Transfer_ALARM_SUM_page; \
	COMMAND trans15_Transfer_ALARM_SUM_read; \
	VARIABLE trans15_Transfer_CHANNEL; \
	MENU trans15_Transfer_CHANNEL_page; \
	COMMAND trans15_Transfer_CHANNEL_read; \
	COMMAND trans15_Transfer_CHANNEL_write; \
	COLLECTION trans15_Transfer_PV; \
	VARIABLE trans15_Transfer_PV_PV; \
	VARIABLE trans15_Transfer_PV_Measurement_Status_Condensed; \
	VARIABLE trans15_Transfer_PV_PV_Time; \
	VARIABLE trans15_Transfer_PV_Measurement_Status_Quality; \
	VARIABLE trans15_Transfer_PV_Measurement_Status_Limit; \
	MENU trans15_Transfer_PV_page; \
	COMMAND trans15_Transfer_PV_read; \
	VARIABLE trans15_Transfer_PV_UNIT; \
	MENU trans15_Transfer_PV_UNIT_page; \
	COMMAND trans15_Transfer_PV_UNIT_read; \
	COMMAND trans15_Transfer_PV_UNIT_write; \
	VARIABLE trans15_Transfer_PV_UNIT_TEXT; \
	MENU trans15_Transfer_PV_UNIT_TEXT_page; \
	COMMAND trans15_Transfer_PV_UNIT_TEXT_read; \
	COMMAND trans15_Transfer_PV_UNIT_TEXT_write; \
	VARIABLE trans15_Transfer_STATIC_VALUE; \
	MENU trans15_Transfer_STATIC_VALUE_page; \
	COMMAND trans15_Transfer_STATIC_VALUE_read; \
	COMMAND trans15_Transfer_STATIC_VALUE_write; \
	VARIABLE trans15_Transfer_CORRECTION_CHANNEL; \
	MENU trans15_Transfer_CORRECTION_CHANNEL_page; \
	COMMAND trans15_Transfer_CORRECTION_CHANNEL_read; \
	COMMAND trans15_Transfer_CORRECTION_CHANNEL_write; \
	COLLECTION trans15_Transfer_FB_VALUE; \
	VARIABLE trans15_Transfer_FB_VALUE_Value; \
	VARIABLE trans15_Transfer_FB_VALUE_Status_Condensed; \
	VARIABLE trans15_Transfer_FB_VALUE_Status_Quality; \
	VARIABLE trans15_Transfer_FB_VALUE_Status_Limit; \
	MENU trans15_Transfer_FB_VALUE_page; \
	COMMAND trans15_Transfer_FB_VALUE_read; \
	COMMAND trans15_Transfer_FB_VALUE_write; \
	VARIABLE trans15_Transfer_NUMBER_OF_CALCULATION; \
	MENU trans15_Transfer_NUMBER_OF_CALCULATION_page; \
	COMMAND trans15_Transfer_NUMBER_OF_CALCULATION_read; \
	COMMAND trans15_Transfer_NUMBER_OF_CALCULATION_write; \
	COLLECTION trans15_Transfer_CALCULATION_1; \
	VARIABLE trans15_Transfer_CALCULATION_1_Function_Type; \
	VARIABLE trans15_Transfer_CALCULATION_1_Subtype; \
	VARIABLE trans15_Transfer_CALCULATION_1_Choice; \
	MENU trans15_Transfer_CALCULATION_1_page; \
	COMMAND trans15_Transfer_CALCULATION_1_read; \
	COMMAND trans15_Transfer_CALCULATION_1_write; \
	UNIT trans15_Transfer_unit_1

#define USE_TRANS15_TRANSFER_MANDATORY_A \
	USE_TRANS15_TRANSFER_MANDATORY_BOTH; \
	MENU trans15_Transfer_Simple_Dialog_Mandatory_A

#define USE_TRANS15_TRANSFER_MANDATORY_B \
	USE_TRANS15_TRANSFER_MANDATORY_BOTH; \
	COLLECTION trans15_Transfer_VIEW_1; \
	MENU trans15_Transfer_VIEW_1_page; \
	MENU trans15_Transfer_Simple_Dialog_Mandatory_B

#define USE_TRANS15_TRANSFER_OPTIONAL_BOTH \
	COLLECTION trans15_Transfer_VIEW_2; \
	MENU trans15_Transfer_VIEW_2_page; \
	COLLECTION trans15_Transfer_VIEW_3; \
	MENU trans15_Transfer_VIEW_3_page

#define USE_TRANS15_TRANSFER_OPTIONAL_A \
	USE_TRANS15_TRANSFER_OPTIONAL_BOTH; \
	COLLECTION trans15_Transfer_VIEW_1; \
	MENU trans15_Transfer_VIEW_1_page; \
	MENU trans15_Transfer_Simple_Dialog_Optional_A

#define USE_TRANS15_TRANSFER_OPTIONAL_B \
	USE_TRANS15_TRANSFER_OPTIONAL_BOTH; \
	MENU trans15_Transfer_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_TRANSFER_MANDATORY_A USE_TRANS_TRANSFER_MANDATORY_A(trans15_Transfer_)
#define USE_TRANS15_TRANSFER_MANDATORY_B USE_TRANS_TRANSFER_MANDATORY_B(trans15_Transfer_)
#define USE_TRANS15_TRANSFER_OPTIONAL_A  USE_TRANS_TRANSFER_OPTIONAL_A(trans15_Transfer_)
#define USE_TRANS15_TRANSFER_OPTIONAL_B  USE_TRANS_TRANSFER_OPTIONAL_B(trans15_Transfer_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans1_Control_pH_block; \
	COLLECTION trans1_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans1_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans1_Control_pH_ST_REV; \
	MENU trans1_Control_pH_ST_REV_page; \
	COMMAND trans1_Control_pH_ST_REV_read; \
	VARIABLE trans1_Control_pH_TAG_DESC; \
	MENU trans1_Control_pH_TAG_DESC_page; \
	COMMAND trans1_Control_pH_TAG_DESC_read; \
	COMMAND trans1_Control_pH_TAG_DESC_write; \
	VARIABLE trans1_Control_pH_STRATEGY; \
	MENU trans1_Control_pH_STRATEGY_page; \
	COMMAND trans1_Control_pH_STRATEGY_read; \
	COMMAND trans1_Control_pH_STRATEGY_write; \
	VARIABLE trans1_Control_pH_ALERT_KEY; \
	MENU trans1_Control_pH_ALERT_KEY_page; \
	COMMAND trans1_Control_pH_ALERT_KEY_read; \
	COMMAND trans1_Control_pH_ALERT_KEY_write; \
	VARIABLE trans1_Control_pH_TARGET_MODE; \
	MENU trans1_Control_pH_TARGET_MODE_page; \
	COMMAND trans1_Control_pH_TARGET_MODE_read; \
	COMMAND trans1_Control_pH_TARGET_MODE_write; \
	COLLECTION trans1_Control_pH_MODE_BLK; \
	VARIABLE trans1_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans1_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans1_Control_pH_MODE_BLK_Normal; \
	MENU trans1_Control_pH_MODE_BLK_page; \
	COMMAND trans1_Control_pH_MODE_BLK_read; \
	COLLECTION trans1_Control_pH_ALARM_SUM; \
	VARIABLE trans1_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans1_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans1_Control_pH_ALARM_SUM_Disabled; \
	MENU trans1_Control_pH_ALARM_SUM_page; \
	COMMAND trans1_Control_pH_ALARM_SUM_read; \
	VARIABLE trans1_Control_pH_BLOCK_TYPE; \
	MENU trans1_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans1_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans1_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans1_Control_pH_COMMAND; \
	MENU trans1_Control_pH_COMMAND_page; \
	COMMAND trans1_Control_pH_COMMAND_read; \
	COMMAND trans1_Control_pH_COMMAND_write; \
	VARIABLE trans1_Control_pH_STATUS; \
	MENU trans1_Control_pH_STATUS_page; \
	COMMAND trans1_Control_pH_STATUS_read; \
	VARIABLE trans1_Control_pH_CHANNEL; \
	MENU trans1_Control_pH_CHANNEL_page; \
	COMMAND trans1_Control_pH_CHANNEL_read; \
	COMMAND trans1_Control_pH_CHANNEL_write; \
	COLLECTION trans1_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans1_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans1_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans1_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans1_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans1_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans1_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans1_Control_pH_RECIPE; \
	MENU trans1_Control_pH_RECIPE_page; \
	COMMAND trans1_Control_pH_RECIPE_read; \
	COMMAND trans1_Control_pH_RECIPE_write; \
	VARIABLE trans1_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans1_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans1_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS1_CONTROL_PH_MANDATORY_A \
	USE_TRANS1_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans1_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS1_CONTROL_PH_MANDATORY_B \
	USE_TRANS1_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans1_Control_pH_VIEW_1; \
	MENU trans1_Control_pH_VIEW_1_page; \
	MENU trans1_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS1_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans1_Control_pH_QUALITY_type; \
	ARRAY trans1_Control_pH_QUALITY; \
	MENU trans1_Control_pH_QUALITY_page; \
	COMMAND trans1_Control_pH_QUALITY_read; \
	VARIABLE trans1_Control_pH_SP_type; \
	ARRAY trans1_Control_pH_SP; \
	MENU trans1_Control_pH_SP_page; \
	COMMAND trans1_Control_pH_SP_read; \
	COMMAND trans1_Control_pH_SP_write; \
	VARIABLE trans1_Control_pH_PV_type; \
	ARRAY trans1_Control_pH_PV; \
	MENU trans1_Control_pH_PV_page; \
	COMMAND trans1_Control_pH_PV_read; \
	VARIABLE trans1_Control_pH_CTB_MASTER; \
	MENU trans1_Control_pH_CTB_MASTER_page; \
	COMMAND trans1_Control_pH_CTB_MASTER_read; \
	COMMAND trans1_Control_pH_CTB_MASTER_write; \
	VARIABLE trans1_Control_pH_SELECTION_type; \
	ARRAY trans1_Control_pH_SELECTION; \
	MENU trans1_Control_pH_SELECTION_page; \
	COMMAND trans1_Control_pH_SELECTION_read; \
	COMMAND trans1_Control_pH_SELECTION_write; \
	VARIABLE trans1_Control_pH_NUMBER_PARAMETERS; \
	MENU trans1_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans1_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans1_Control_pH_BUFFER_NUMBER; \
	MENU trans1_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans1_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans1_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans1_Control_pH_ZERO; \
	MENU trans1_Control_pH_ZERO_page; \
	COMMAND trans1_Control_pH_ZERO_read; \
	COMMAND trans1_Control_pH_ZERO_write; \
	VARIABLE trans1_Control_pH_SLOPE; \
	MENU trans1_Control_pH_SLOPE_page; \
	COMMAND trans1_Control_pH_SLOPE_read; \
	COMMAND trans1_Control_pH_SLOPE_write; \
	COLLECTION trans1_Control_pH_VIEW_2; \
	MENU trans1_Control_pH_VIEW_2_page; \
	COLLECTION trans1_Control_pH_VIEW_3; \
	MENU trans1_Control_pH_VIEW_3_page

#define USE_TRANS1_CONTROL_PH_OPTIONAL_A \
	USE_TRANS1_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans1_Control_pH_VIEW_1; \
	MENU trans1_Control_pH_VIEW_1_page; \
	MENU trans1_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS1_CONTROL_PH_OPTIONAL_B \
	USE_TRANS1_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans1_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_CONTROL_PH_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## BLOCK_TYPE; \
	MENU prefix ## BLOCK_TYPE_page; \
	COMMAND prefix ## BLOCK_TYPE_read; \
	COMMAND prefix ## BLOCK_TYPE_write; \
	VARIABLE prefix ## COMMAND; \
	MENU prefix ## COMMAND_page; \
	COMMAND prefix ## COMMAND_read; \
	COMMAND prefix ## COMMAND_write; \
	VARIABLE prefix ## STATUS; \
	MENU prefix ## STATUS_page; \
	COMMAND prefix ## STATUS_read; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	COLLECTION prefix ## SEQUENCE_CONTROL; \
	COLLECTION prefix ## SEQUENCE_CONTROL_Time; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Month; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Years; \
	COLLECTION prefix ## SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Command; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Control_Active; \
	MENU prefix ## SEQUENCE_CONTROL_page; \
	COMMAND prefix ## SEQUENCE_CONTROL_read; \
	COMMAND prefix ## SEQUENCE_CONTROL_write; \
	VARIABLE prefix ## RECIPE; \
	MENU prefix ## RECIPE_page; \
	COMMAND prefix ## RECIPE_read; \
	COMMAND prefix ## RECIPE_write; \
	VARIABLE prefix ## PARAMETER_SET_NUMBER; \
	MENU prefix ## PARAMETER_SET_NUMBER_page; \
	COMMAND prefix ## PARAMETER_SET_NUMBER_read

#define USE_TRANS_CONTROL_PH_MANDATORY_A(prefix) \
	USE_TRANS_CONTROL_PH_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_CONTROL_PH_MANDATORY_B(prefix) \
	USE_TRANS_CONTROL_PH_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_CONTROL_PH_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## QUALITY_type; \
	ARRAY prefix ## QUALITY; \
	MENU prefix ## QUALITY_page; \
	COMMAND prefix ## QUALITY_read; \
	VARIABLE prefix ## SP_type; \
	ARRAY prefix ## SP; \
	MENU prefix ## SP_page; \
	COMMAND prefix ## SP_read; \
	COMMAND prefix ## SP_write; \
	VARIABLE prefix ## PV_type; \
	ARRAY prefix ## PV; \
	MENU prefix ## PV_page; \
	COMMAND prefix ## PV_read; \
	VARIABLE prefix ## CTB_MASTER; \
	MENU prefix ## CTB_MASTER_page; \
	COMMAND prefix ## CTB_MASTER_read; \
	COMMAND prefix ## CTB_MASTER_write; \
	VARIABLE prefix ## SELECTION_type; \
	ARRAY prefix ## SELECTION; \
	MENU prefix ## SELECTION_page; \
	COMMAND prefix ## SELECTION_read; \
	COMMAND prefix ## SELECTION_write; \
	VARIABLE prefix ## NUMBER_PARAMETERS; \
	MENU prefix ## NUMBER_PARAMETERS_page; \
	COMMAND prefix ## NUMBER_PARAMETERS_read; \
	VARIABLE prefix ## BUFFER_NUMBER; \
	MENU prefix ## BUFFER_NUMBER_page; \
	COMMAND prefix ## BUFFER_NUMBER_read; \
	COMMAND prefix ## BUFFER_NUMBER_write; \
	VARIABLE prefix ## ZERO; \
	MENU prefix ## ZERO_page; \
	COMMAND prefix ## ZERO_read; \
	COMMAND prefix ## ZERO_write; \
	VARIABLE prefix ## SLOPE; \
	MENU prefix ## SLOPE_page; \
	COMMAND prefix ## SLOPE_read; \
	COMMAND prefix ## SLOPE_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_CONTROL_PH_OPTIONAL_A(prefix) \
	USE_TRANS_CONTROL_PH_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_CONTROL_PH_OPTIONAL_B(prefix) \
	USE_TRANS_CONTROL_PH_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans1_Control_pH_)
#define USE_TRANS1_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans1_Control_pH_)
#define USE_TRANS1_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans1_Control_pH_)
#define USE_TRANS1_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans1_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans2_Control_pH_block; \
	COLLECTION trans2_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans2_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans2_Control_pH_ST_REV; \
	MENU trans2_Control_pH_ST_REV_page; \
	COMMAND trans2_Control_pH_ST_REV_read; \
	VARIABLE trans2_Control_pH_TAG_DESC; \
	MENU trans2_Control_pH_TAG_DESC_page; \
	COMMAND trans2_Control_pH_TAG_DESC_read; \
	COMMAND trans2_Control_pH_TAG_DESC_write; \
	VARIABLE trans2_Control_pH_STRATEGY; \
	MENU trans2_Control_pH_STRATEGY_page; \
	COMMAND trans2_Control_pH_STRATEGY_read; \
	COMMAND trans2_Control_pH_STRATEGY_write; \
	VARIABLE trans2_Control_pH_ALERT_KEY; \
	MENU trans2_Control_pH_ALERT_KEY_page; \
	COMMAND trans2_Control_pH_ALERT_KEY_read; \
	COMMAND trans2_Control_pH_ALERT_KEY_write; \
	VARIABLE trans2_Control_pH_TARGET_MODE; \
	MENU trans2_Control_pH_TARGET_MODE_page; \
	COMMAND trans2_Control_pH_TARGET_MODE_read; \
	COMMAND trans2_Control_pH_TARGET_MODE_write; \
	COLLECTION trans2_Control_pH_MODE_BLK; \
	VARIABLE trans2_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans2_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans2_Control_pH_MODE_BLK_Normal; \
	MENU trans2_Control_pH_MODE_BLK_page; \
	COMMAND trans2_Control_pH_MODE_BLK_read; \
	COLLECTION trans2_Control_pH_ALARM_SUM; \
	VARIABLE trans2_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans2_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans2_Control_pH_ALARM_SUM_Disabled; \
	MENU trans2_Control_pH_ALARM_SUM_page; \
	COMMAND trans2_Control_pH_ALARM_SUM_read; \
	VARIABLE trans2_Control_pH_BLOCK_TYPE; \
	MENU trans2_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans2_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans2_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans2_Control_pH_COMMAND; \
	MENU trans2_Control_pH_COMMAND_page; \
	COMMAND trans2_Control_pH_COMMAND_read; \
	COMMAND trans2_Control_pH_COMMAND_write; \
	VARIABLE trans2_Control_pH_STATUS; \
	MENU trans2_Control_pH_STATUS_page; \
	COMMAND trans2_Control_pH_STATUS_read; \
	VARIABLE trans2_Control_pH_CHANNEL; \
	MENU trans2_Control_pH_CHANNEL_page; \
	COMMAND trans2_Control_pH_CHANNEL_read; \
	COMMAND trans2_Control_pH_CHANNEL_write; \
	COLLECTION trans2_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans2_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans2_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans2_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans2_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans2_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans2_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans2_Control_pH_RECIPE; \
	MENU trans2_Control_pH_RECIPE_page; \
	COMMAND trans2_Control_pH_RECIPE_read; \
	COMMAND trans2_Control_pH_RECIPE_write; \
	VARIABLE trans2_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans2_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans2_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS2_CONTROL_PH_MANDATORY_A \
	USE_TRANS2_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans2_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS2_CONTROL_PH_MANDATORY_B \
	USE_TRANS2_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans2_Control_pH_VIEW_1; \
	MENU trans2_Control_pH_VIEW_1_page; \
	MENU trans2_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS2_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans2_Control_pH_QUALITY_type; \
	ARRAY trans2_Control_pH_QUALITY; \
	MENU trans2_Control_pH_QUALITY_page; \
	COMMAND trans2_Control_pH_QUALITY_read; \
	VARIABLE trans2_Control_pH_SP_type; \
	ARRAY trans2_Control_pH_SP; \
	MENU trans2_Control_pH_SP_page; \
	COMMAND trans2_Control_pH_SP_read; \
	COMMAND trans2_Control_pH_SP_write; \
	VARIABLE trans2_Control_pH_PV_type; \
	ARRAY trans2_Control_pH_PV; \
	MENU trans2_Control_pH_PV_page; \
	COMMAND trans2_Control_pH_PV_read; \
	VARIABLE trans2_Control_pH_CTB_MASTER; \
	MENU trans2_Control_pH_CTB_MASTER_page; \
	COMMAND trans2_Control_pH_CTB_MASTER_read; \
	COMMAND trans2_Control_pH_CTB_MASTER_write; \
	VARIABLE trans2_Control_pH_SELECTION_type; \
	ARRAY trans2_Control_pH_SELECTION; \
	MENU trans2_Control_pH_SELECTION_page; \
	COMMAND trans2_Control_pH_SELECTION_read; \
	COMMAND trans2_Control_pH_SELECTION_write; \
	VARIABLE trans2_Control_pH_NUMBER_PARAMETERS; \
	MENU trans2_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans2_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans2_Control_pH_BUFFER_NUMBER; \
	MENU trans2_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans2_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans2_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans2_Control_pH_ZERO; \
	MENU trans2_Control_pH_ZERO_page; \
	COMMAND trans2_Control_pH_ZERO_read; \
	COMMAND trans2_Control_pH_ZERO_write; \
	VARIABLE trans2_Control_pH_SLOPE; \
	MENU trans2_Control_pH_SLOPE_page; \
	COMMAND trans2_Control_pH_SLOPE_read; \
	COMMAND trans2_Control_pH_SLOPE_write; \
	COLLECTION trans2_Control_pH_VIEW_2; \
	MENU trans2_Control_pH_VIEW_2_page; \
	COLLECTION trans2_Control_pH_VIEW_3; \
	MENU trans2_Control_pH_VIEW_3_page

#define USE_TRANS2_CONTROL_PH_OPTIONAL_A \
	USE_TRANS2_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans2_Control_pH_VIEW_1; \
	MENU trans2_Control_pH_VIEW_1_page; \
	MENU trans2_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS2_CONTROL_PH_OPTIONAL_B \
	USE_TRANS2_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans2_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans2_Control_pH_)
#define USE_TRANS2_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans2_Control_pH_)
#define USE_TRANS2_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans2_Control_pH_)
#define USE_TRANS2_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans2_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans3_Control_pH_block; \
	COLLECTION trans3_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans3_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans3_Control_pH_ST_REV; \
	MENU trans3_Control_pH_ST_REV_page; \
	COMMAND trans3_Control_pH_ST_REV_read; \
	VARIABLE trans3_Control_pH_TAG_DESC; \
	MENU trans3_Control_pH_TAG_DESC_page; \
	COMMAND trans3_Control_pH_TAG_DESC_read; \
	COMMAND trans3_Control_pH_TAG_DESC_write; \
	VARIABLE trans3_Control_pH_STRATEGY; \
	MENU trans3_Control_pH_STRATEGY_page; \
	COMMAND trans3_Control_pH_STRATEGY_read; \
	COMMAND trans3_Control_pH_STRATEGY_write; \
	VARIABLE trans3_Control_pH_ALERT_KEY; \
	MENU trans3_Control_pH_ALERT_KEY_page; \
	COMMAND trans3_Control_pH_ALERT_KEY_read; \
	COMMAND trans3_Control_pH_ALERT_KEY_write; \
	VARIABLE trans3_Control_pH_TARGET_MODE; \
	MENU trans3_Control_pH_TARGET_MODE_page; \
	COMMAND trans3_Control_pH_TARGET_MODE_read; \
	COMMAND trans3_Control_pH_TARGET_MODE_write; \
	COLLECTION trans3_Control_pH_MODE_BLK; \
	VARIABLE trans3_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans3_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans3_Control_pH_MODE_BLK_Normal; \
	MENU trans3_Control_pH_MODE_BLK_page; \
	COMMAND trans3_Control_pH_MODE_BLK_read; \
	COLLECTION trans3_Control_pH_ALARM_SUM; \
	VARIABLE trans3_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans3_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans3_Control_pH_ALARM_SUM_Disabled; \
	MENU trans3_Control_pH_ALARM_SUM_page; \
	COMMAND trans3_Control_pH_ALARM_SUM_read; \
	VARIABLE trans3_Control_pH_BLOCK_TYPE; \
	MENU trans3_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans3_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans3_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans3_Control_pH_COMMAND; \
	MENU trans3_Control_pH_COMMAND_page; \
	COMMAND trans3_Control_pH_COMMAND_read; \
	COMMAND trans3_Control_pH_COMMAND_write; \
	VARIABLE trans3_Control_pH_STATUS; \
	MENU trans3_Control_pH_STATUS_page; \
	COMMAND trans3_Control_pH_STATUS_read; \
	VARIABLE trans3_Control_pH_CHANNEL; \
	MENU trans3_Control_pH_CHANNEL_page; \
	COMMAND trans3_Control_pH_CHANNEL_read; \
	COMMAND trans3_Control_pH_CHANNEL_write; \
	COLLECTION trans3_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans3_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans3_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans3_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans3_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans3_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans3_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans3_Control_pH_RECIPE; \
	MENU trans3_Control_pH_RECIPE_page; \
	COMMAND trans3_Control_pH_RECIPE_read; \
	COMMAND trans3_Control_pH_RECIPE_write; \
	VARIABLE trans3_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans3_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans3_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS3_CONTROL_PH_MANDATORY_A \
	USE_TRANS3_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans3_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS3_CONTROL_PH_MANDATORY_B \
	USE_TRANS3_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans3_Control_pH_VIEW_1; \
	MENU trans3_Control_pH_VIEW_1_page; \
	MENU trans3_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS3_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans3_Control_pH_QUALITY_type; \
	ARRAY trans3_Control_pH_QUALITY; \
	MENU trans3_Control_pH_QUALITY_page; \
	COMMAND trans3_Control_pH_QUALITY_read; \
	VARIABLE trans3_Control_pH_SP_type; \
	ARRAY trans3_Control_pH_SP; \
	MENU trans3_Control_pH_SP_page; \
	COMMAND trans3_Control_pH_SP_read; \
	COMMAND trans3_Control_pH_SP_write; \
	VARIABLE trans3_Control_pH_PV_type; \
	ARRAY trans3_Control_pH_PV; \
	MENU trans3_Control_pH_PV_page; \
	COMMAND trans3_Control_pH_PV_read; \
	VARIABLE trans3_Control_pH_CTB_MASTER; \
	MENU trans3_Control_pH_CTB_MASTER_page; \
	COMMAND trans3_Control_pH_CTB_MASTER_read; \
	COMMAND trans3_Control_pH_CTB_MASTER_write; \
	VARIABLE trans3_Control_pH_SELECTION_type; \
	ARRAY trans3_Control_pH_SELECTION; \
	MENU trans3_Control_pH_SELECTION_page; \
	COMMAND trans3_Control_pH_SELECTION_read; \
	COMMAND trans3_Control_pH_SELECTION_write; \
	VARIABLE trans3_Control_pH_NUMBER_PARAMETERS; \
	MENU trans3_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans3_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans3_Control_pH_BUFFER_NUMBER; \
	MENU trans3_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans3_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans3_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans3_Control_pH_ZERO; \
	MENU trans3_Control_pH_ZERO_page; \
	COMMAND trans3_Control_pH_ZERO_read; \
	COMMAND trans3_Control_pH_ZERO_write; \
	VARIABLE trans3_Control_pH_SLOPE; \
	MENU trans3_Control_pH_SLOPE_page; \
	COMMAND trans3_Control_pH_SLOPE_read; \
	COMMAND trans3_Control_pH_SLOPE_write; \
	COLLECTION trans3_Control_pH_VIEW_2; \
	MENU trans3_Control_pH_VIEW_2_page; \
	COLLECTION trans3_Control_pH_VIEW_3; \
	MENU trans3_Control_pH_VIEW_3_page

#define USE_TRANS3_CONTROL_PH_OPTIONAL_A \
	USE_TRANS3_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans3_Control_pH_VIEW_1; \
	MENU trans3_Control_pH_VIEW_1_page; \
	MENU trans3_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS3_CONTROL_PH_OPTIONAL_B \
	USE_TRANS3_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans3_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans3_Control_pH_)
#define USE_TRANS3_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans3_Control_pH_)
#define USE_TRANS3_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans3_Control_pH_)
#define USE_TRANS3_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans3_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans4_Control_pH_block; \
	COLLECTION trans4_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans4_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans4_Control_pH_ST_REV; \
	MENU trans4_Control_pH_ST_REV_page; \
	COMMAND trans4_Control_pH_ST_REV_read; \
	VARIABLE trans4_Control_pH_TAG_DESC; \
	MENU trans4_Control_pH_TAG_DESC_page; \
	COMMAND trans4_Control_pH_TAG_DESC_read; \
	COMMAND trans4_Control_pH_TAG_DESC_write; \
	VARIABLE trans4_Control_pH_STRATEGY; \
	MENU trans4_Control_pH_STRATEGY_page; \
	COMMAND trans4_Control_pH_STRATEGY_read; \
	COMMAND trans4_Control_pH_STRATEGY_write; \
	VARIABLE trans4_Control_pH_ALERT_KEY; \
	MENU trans4_Control_pH_ALERT_KEY_page; \
	COMMAND trans4_Control_pH_ALERT_KEY_read; \
	COMMAND trans4_Control_pH_ALERT_KEY_write; \
	VARIABLE trans4_Control_pH_TARGET_MODE; \
	MENU trans4_Control_pH_TARGET_MODE_page; \
	COMMAND trans4_Control_pH_TARGET_MODE_read; \
	COMMAND trans4_Control_pH_TARGET_MODE_write; \
	COLLECTION trans4_Control_pH_MODE_BLK; \
	VARIABLE trans4_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans4_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans4_Control_pH_MODE_BLK_Normal; \
	MENU trans4_Control_pH_MODE_BLK_page; \
	COMMAND trans4_Control_pH_MODE_BLK_read; \
	COLLECTION trans4_Control_pH_ALARM_SUM; \
	VARIABLE trans4_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans4_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans4_Control_pH_ALARM_SUM_Disabled; \
	MENU trans4_Control_pH_ALARM_SUM_page; \
	COMMAND trans4_Control_pH_ALARM_SUM_read; \
	VARIABLE trans4_Control_pH_BLOCK_TYPE; \
	MENU trans4_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans4_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans4_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans4_Control_pH_COMMAND; \
	MENU trans4_Control_pH_COMMAND_page; \
	COMMAND trans4_Control_pH_COMMAND_read; \
	COMMAND trans4_Control_pH_COMMAND_write; \
	VARIABLE trans4_Control_pH_STATUS; \
	MENU trans4_Control_pH_STATUS_page; \
	COMMAND trans4_Control_pH_STATUS_read; \
	VARIABLE trans4_Control_pH_CHANNEL; \
	MENU trans4_Control_pH_CHANNEL_page; \
	COMMAND trans4_Control_pH_CHANNEL_read; \
	COMMAND trans4_Control_pH_CHANNEL_write; \
	COLLECTION trans4_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans4_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans4_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans4_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans4_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans4_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans4_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans4_Control_pH_RECIPE; \
	MENU trans4_Control_pH_RECIPE_page; \
	COMMAND trans4_Control_pH_RECIPE_read; \
	COMMAND trans4_Control_pH_RECIPE_write; \
	VARIABLE trans4_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans4_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans4_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS4_CONTROL_PH_MANDATORY_A \
	USE_TRANS4_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans4_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS4_CONTROL_PH_MANDATORY_B \
	USE_TRANS4_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans4_Control_pH_VIEW_1; \
	MENU trans4_Control_pH_VIEW_1_page; \
	MENU trans4_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS4_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans4_Control_pH_QUALITY_type; \
	ARRAY trans4_Control_pH_QUALITY; \
	MENU trans4_Control_pH_QUALITY_page; \
	COMMAND trans4_Control_pH_QUALITY_read; \
	VARIABLE trans4_Control_pH_SP_type; \
	ARRAY trans4_Control_pH_SP; \
	MENU trans4_Control_pH_SP_page; \
	COMMAND trans4_Control_pH_SP_read; \
	COMMAND trans4_Control_pH_SP_write; \
	VARIABLE trans4_Control_pH_PV_type; \
	ARRAY trans4_Control_pH_PV; \
	MENU trans4_Control_pH_PV_page; \
	COMMAND trans4_Control_pH_PV_read; \
	VARIABLE trans4_Control_pH_CTB_MASTER; \
	MENU trans4_Control_pH_CTB_MASTER_page; \
	COMMAND trans4_Control_pH_CTB_MASTER_read; \
	COMMAND trans4_Control_pH_CTB_MASTER_write; \
	VARIABLE trans4_Control_pH_SELECTION_type; \
	ARRAY trans4_Control_pH_SELECTION; \
	MENU trans4_Control_pH_SELECTION_page; \
	COMMAND trans4_Control_pH_SELECTION_read; \
	COMMAND trans4_Control_pH_SELECTION_write; \
	VARIABLE trans4_Control_pH_NUMBER_PARAMETERS; \
	MENU trans4_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans4_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans4_Control_pH_BUFFER_NUMBER; \
	MENU trans4_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans4_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans4_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans4_Control_pH_ZERO; \
	MENU trans4_Control_pH_ZERO_page; \
	COMMAND trans4_Control_pH_ZERO_read; \
	COMMAND trans4_Control_pH_ZERO_write; \
	VARIABLE trans4_Control_pH_SLOPE; \
	MENU trans4_Control_pH_SLOPE_page; \
	COMMAND trans4_Control_pH_SLOPE_read; \
	COMMAND trans4_Control_pH_SLOPE_write; \
	COLLECTION trans4_Control_pH_VIEW_2; \
	MENU trans4_Control_pH_VIEW_2_page; \
	COLLECTION trans4_Control_pH_VIEW_3; \
	MENU trans4_Control_pH_VIEW_3_page

#define USE_TRANS4_CONTROL_PH_OPTIONAL_A \
	USE_TRANS4_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans4_Control_pH_VIEW_1; \
	MENU trans4_Control_pH_VIEW_1_page; \
	MENU trans4_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS4_CONTROL_PH_OPTIONAL_B \
	USE_TRANS4_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans4_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans4_Control_pH_)
#define USE_TRANS4_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans4_Control_pH_)
#define USE_TRANS4_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans4_Control_pH_)
#define USE_TRANS4_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans4_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans5_Control_pH_block; \
	COLLECTION trans5_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans5_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans5_Control_pH_ST_REV; \
	MENU trans5_Control_pH_ST_REV_page; \
	COMMAND trans5_Control_pH_ST_REV_read; \
	VARIABLE trans5_Control_pH_TAG_DESC; \
	MENU trans5_Control_pH_TAG_DESC_page; \
	COMMAND trans5_Control_pH_TAG_DESC_read; \
	COMMAND trans5_Control_pH_TAG_DESC_write; \
	VARIABLE trans5_Control_pH_STRATEGY; \
	MENU trans5_Control_pH_STRATEGY_page; \
	COMMAND trans5_Control_pH_STRATEGY_read; \
	COMMAND trans5_Control_pH_STRATEGY_write; \
	VARIABLE trans5_Control_pH_ALERT_KEY; \
	MENU trans5_Control_pH_ALERT_KEY_page; \
	COMMAND trans5_Control_pH_ALERT_KEY_read; \
	COMMAND trans5_Control_pH_ALERT_KEY_write; \
	VARIABLE trans5_Control_pH_TARGET_MODE; \
	MENU trans5_Control_pH_TARGET_MODE_page; \
	COMMAND trans5_Control_pH_TARGET_MODE_read; \
	COMMAND trans5_Control_pH_TARGET_MODE_write; \
	COLLECTION trans5_Control_pH_MODE_BLK; \
	VARIABLE trans5_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans5_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans5_Control_pH_MODE_BLK_Normal; \
	MENU trans5_Control_pH_MODE_BLK_page; \
	COMMAND trans5_Control_pH_MODE_BLK_read; \
	COLLECTION trans5_Control_pH_ALARM_SUM; \
	VARIABLE trans5_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans5_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans5_Control_pH_ALARM_SUM_Disabled; \
	MENU trans5_Control_pH_ALARM_SUM_page; \
	COMMAND trans5_Control_pH_ALARM_SUM_read; \
	VARIABLE trans5_Control_pH_BLOCK_TYPE; \
	MENU trans5_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans5_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans5_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans5_Control_pH_COMMAND; \
	MENU trans5_Control_pH_COMMAND_page; \
	COMMAND trans5_Control_pH_COMMAND_read; \
	COMMAND trans5_Control_pH_COMMAND_write; \
	VARIABLE trans5_Control_pH_STATUS; \
	MENU trans5_Control_pH_STATUS_page; \
	COMMAND trans5_Control_pH_STATUS_read; \
	VARIABLE trans5_Control_pH_CHANNEL; \
	MENU trans5_Control_pH_CHANNEL_page; \
	COMMAND trans5_Control_pH_CHANNEL_read; \
	COMMAND trans5_Control_pH_CHANNEL_write; \
	COLLECTION trans5_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans5_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans5_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans5_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans5_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans5_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans5_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans5_Control_pH_RECIPE; \
	MENU trans5_Control_pH_RECIPE_page; \
	COMMAND trans5_Control_pH_RECIPE_read; \
	COMMAND trans5_Control_pH_RECIPE_write; \
	VARIABLE trans5_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans5_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans5_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS5_CONTROL_PH_MANDATORY_A \
	USE_TRANS5_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans5_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS5_CONTROL_PH_MANDATORY_B \
	USE_TRANS5_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans5_Control_pH_VIEW_1; \
	MENU trans5_Control_pH_VIEW_1_page; \
	MENU trans5_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS5_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans5_Control_pH_QUALITY_type; \
	ARRAY trans5_Control_pH_QUALITY; \
	MENU trans5_Control_pH_QUALITY_page; \
	COMMAND trans5_Control_pH_QUALITY_read; \
	VARIABLE trans5_Control_pH_SP_type; \
	ARRAY trans5_Control_pH_SP; \
	MENU trans5_Control_pH_SP_page; \
	COMMAND trans5_Control_pH_SP_read; \
	COMMAND trans5_Control_pH_SP_write; \
	VARIABLE trans5_Control_pH_PV_type; \
	ARRAY trans5_Control_pH_PV; \
	MENU trans5_Control_pH_PV_page; \
	COMMAND trans5_Control_pH_PV_read; \
	VARIABLE trans5_Control_pH_CTB_MASTER; \
	MENU trans5_Control_pH_CTB_MASTER_page; \
	COMMAND trans5_Control_pH_CTB_MASTER_read; \
	COMMAND trans5_Control_pH_CTB_MASTER_write; \
	VARIABLE trans5_Control_pH_SELECTION_type; \
	ARRAY trans5_Control_pH_SELECTION; \
	MENU trans5_Control_pH_SELECTION_page; \
	COMMAND trans5_Control_pH_SELECTION_read; \
	COMMAND trans5_Control_pH_SELECTION_write; \
	VARIABLE trans5_Control_pH_NUMBER_PARAMETERS; \
	MENU trans5_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans5_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans5_Control_pH_BUFFER_NUMBER; \
	MENU trans5_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans5_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans5_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans5_Control_pH_ZERO; \
	MENU trans5_Control_pH_ZERO_page; \
	COMMAND trans5_Control_pH_ZERO_read; \
	COMMAND trans5_Control_pH_ZERO_write; \
	VARIABLE trans5_Control_pH_SLOPE; \
	MENU trans5_Control_pH_SLOPE_page; \
	COMMAND trans5_Control_pH_SLOPE_read; \
	COMMAND trans5_Control_pH_SLOPE_write; \
	COLLECTION trans5_Control_pH_VIEW_2; \
	MENU trans5_Control_pH_VIEW_2_page; \
	COLLECTION trans5_Control_pH_VIEW_3; \
	MENU trans5_Control_pH_VIEW_3_page

#define USE_TRANS5_CONTROL_PH_OPTIONAL_A \
	USE_TRANS5_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans5_Control_pH_VIEW_1; \
	MENU trans5_Control_pH_VIEW_1_page; \
	MENU trans5_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS5_CONTROL_PH_OPTIONAL_B \
	USE_TRANS5_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans5_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans5_Control_pH_)
#define USE_TRANS5_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans5_Control_pH_)
#define USE_TRANS5_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans5_Control_pH_)
#define USE_TRANS5_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans5_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans6_Control_pH_block; \
	COLLECTION trans6_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans6_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans6_Control_pH_ST_REV; \
	MENU trans6_Control_pH_ST_REV_page; \
	COMMAND trans6_Control_pH_ST_REV_read; \
	VARIABLE trans6_Control_pH_TAG_DESC; \
	MENU trans6_Control_pH_TAG_DESC_page; \
	COMMAND trans6_Control_pH_TAG_DESC_read; \
	COMMAND trans6_Control_pH_TAG_DESC_write; \
	VARIABLE trans6_Control_pH_STRATEGY; \
	MENU trans6_Control_pH_STRATEGY_page; \
	COMMAND trans6_Control_pH_STRATEGY_read; \
	COMMAND trans6_Control_pH_STRATEGY_write; \
	VARIABLE trans6_Control_pH_ALERT_KEY; \
	MENU trans6_Control_pH_ALERT_KEY_page; \
	COMMAND trans6_Control_pH_ALERT_KEY_read; \
	COMMAND trans6_Control_pH_ALERT_KEY_write; \
	VARIABLE trans6_Control_pH_TARGET_MODE; \
	MENU trans6_Control_pH_TARGET_MODE_page; \
	COMMAND trans6_Control_pH_TARGET_MODE_read; \
	COMMAND trans6_Control_pH_TARGET_MODE_write; \
	COLLECTION trans6_Control_pH_MODE_BLK; \
	VARIABLE trans6_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans6_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans6_Control_pH_MODE_BLK_Normal; \
	MENU trans6_Control_pH_MODE_BLK_page; \
	COMMAND trans6_Control_pH_MODE_BLK_read; \
	COLLECTION trans6_Control_pH_ALARM_SUM; \
	VARIABLE trans6_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans6_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans6_Control_pH_ALARM_SUM_Disabled; \
	MENU trans6_Control_pH_ALARM_SUM_page; \
	COMMAND trans6_Control_pH_ALARM_SUM_read; \
	VARIABLE trans6_Control_pH_BLOCK_TYPE; \
	MENU trans6_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans6_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans6_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans6_Control_pH_COMMAND; \
	MENU trans6_Control_pH_COMMAND_page; \
	COMMAND trans6_Control_pH_COMMAND_read; \
	COMMAND trans6_Control_pH_COMMAND_write; \
	VARIABLE trans6_Control_pH_STATUS; \
	MENU trans6_Control_pH_STATUS_page; \
	COMMAND trans6_Control_pH_STATUS_read; \
	VARIABLE trans6_Control_pH_CHANNEL; \
	MENU trans6_Control_pH_CHANNEL_page; \
	COMMAND trans6_Control_pH_CHANNEL_read; \
	COMMAND trans6_Control_pH_CHANNEL_write; \
	COLLECTION trans6_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans6_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans6_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans6_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans6_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans6_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans6_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans6_Control_pH_RECIPE; \
	MENU trans6_Control_pH_RECIPE_page; \
	COMMAND trans6_Control_pH_RECIPE_read; \
	COMMAND trans6_Control_pH_RECIPE_write; \
	VARIABLE trans6_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans6_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans6_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS6_CONTROL_PH_MANDATORY_A \
	USE_TRANS6_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans6_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS6_CONTROL_PH_MANDATORY_B \
	USE_TRANS6_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans6_Control_pH_VIEW_1; \
	MENU trans6_Control_pH_VIEW_1_page; \
	MENU trans6_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS6_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans6_Control_pH_QUALITY_type; \
	ARRAY trans6_Control_pH_QUALITY; \
	MENU trans6_Control_pH_QUALITY_page; \
	COMMAND trans6_Control_pH_QUALITY_read; \
	VARIABLE trans6_Control_pH_SP_type; \
	ARRAY trans6_Control_pH_SP; \
	MENU trans6_Control_pH_SP_page; \
	COMMAND trans6_Control_pH_SP_read; \
	COMMAND trans6_Control_pH_SP_write; \
	VARIABLE trans6_Control_pH_PV_type; \
	ARRAY trans6_Control_pH_PV; \
	MENU trans6_Control_pH_PV_page; \
	COMMAND trans6_Control_pH_PV_read; \
	VARIABLE trans6_Control_pH_CTB_MASTER; \
	MENU trans6_Control_pH_CTB_MASTER_page; \
	COMMAND trans6_Control_pH_CTB_MASTER_read; \
	COMMAND trans6_Control_pH_CTB_MASTER_write; \
	VARIABLE trans6_Control_pH_SELECTION_type; \
	ARRAY trans6_Control_pH_SELECTION; \
	MENU trans6_Control_pH_SELECTION_page; \
	COMMAND trans6_Control_pH_SELECTION_read; \
	COMMAND trans6_Control_pH_SELECTION_write; \
	VARIABLE trans6_Control_pH_NUMBER_PARAMETERS; \
	MENU trans6_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans6_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans6_Control_pH_BUFFER_NUMBER; \
	MENU trans6_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans6_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans6_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans6_Control_pH_ZERO; \
	MENU trans6_Control_pH_ZERO_page; \
	COMMAND trans6_Control_pH_ZERO_read; \
	COMMAND trans6_Control_pH_ZERO_write; \
	VARIABLE trans6_Control_pH_SLOPE; \
	MENU trans6_Control_pH_SLOPE_page; \
	COMMAND trans6_Control_pH_SLOPE_read; \
	COMMAND trans6_Control_pH_SLOPE_write; \
	COLLECTION trans6_Control_pH_VIEW_2; \
	MENU trans6_Control_pH_VIEW_2_page; \
	COLLECTION trans6_Control_pH_VIEW_3; \
	MENU trans6_Control_pH_VIEW_3_page

#define USE_TRANS6_CONTROL_PH_OPTIONAL_A \
	USE_TRANS6_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans6_Control_pH_VIEW_1; \
	MENU trans6_Control_pH_VIEW_1_page; \
	MENU trans6_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS6_CONTROL_PH_OPTIONAL_B \
	USE_TRANS6_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans6_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans6_Control_pH_)
#define USE_TRANS6_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans6_Control_pH_)
#define USE_TRANS6_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans6_Control_pH_)
#define USE_TRANS6_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans6_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans7_Control_pH_block; \
	COLLECTION trans7_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans7_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans7_Control_pH_ST_REV; \
	MENU trans7_Control_pH_ST_REV_page; \
	COMMAND trans7_Control_pH_ST_REV_read; \
	VARIABLE trans7_Control_pH_TAG_DESC; \
	MENU trans7_Control_pH_TAG_DESC_page; \
	COMMAND trans7_Control_pH_TAG_DESC_read; \
	COMMAND trans7_Control_pH_TAG_DESC_write; \
	VARIABLE trans7_Control_pH_STRATEGY; \
	MENU trans7_Control_pH_STRATEGY_page; \
	COMMAND trans7_Control_pH_STRATEGY_read; \
	COMMAND trans7_Control_pH_STRATEGY_write; \
	VARIABLE trans7_Control_pH_ALERT_KEY; \
	MENU trans7_Control_pH_ALERT_KEY_page; \
	COMMAND trans7_Control_pH_ALERT_KEY_read; \
	COMMAND trans7_Control_pH_ALERT_KEY_write; \
	VARIABLE trans7_Control_pH_TARGET_MODE; \
	MENU trans7_Control_pH_TARGET_MODE_page; \
	COMMAND trans7_Control_pH_TARGET_MODE_read; \
	COMMAND trans7_Control_pH_TARGET_MODE_write; \
	COLLECTION trans7_Control_pH_MODE_BLK; \
	VARIABLE trans7_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans7_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans7_Control_pH_MODE_BLK_Normal; \
	MENU trans7_Control_pH_MODE_BLK_page; \
	COMMAND trans7_Control_pH_MODE_BLK_read; \
	COLLECTION trans7_Control_pH_ALARM_SUM; \
	VARIABLE trans7_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans7_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans7_Control_pH_ALARM_SUM_Disabled; \
	MENU trans7_Control_pH_ALARM_SUM_page; \
	COMMAND trans7_Control_pH_ALARM_SUM_read; \
	VARIABLE trans7_Control_pH_BLOCK_TYPE; \
	MENU trans7_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans7_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans7_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans7_Control_pH_COMMAND; \
	MENU trans7_Control_pH_COMMAND_page; \
	COMMAND trans7_Control_pH_COMMAND_read; \
	COMMAND trans7_Control_pH_COMMAND_write; \
	VARIABLE trans7_Control_pH_STATUS; \
	MENU trans7_Control_pH_STATUS_page; \
	COMMAND trans7_Control_pH_STATUS_read; \
	VARIABLE trans7_Control_pH_CHANNEL; \
	MENU trans7_Control_pH_CHANNEL_page; \
	COMMAND trans7_Control_pH_CHANNEL_read; \
	COMMAND trans7_Control_pH_CHANNEL_write; \
	COLLECTION trans7_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans7_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans7_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans7_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans7_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans7_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans7_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans7_Control_pH_RECIPE; \
	MENU trans7_Control_pH_RECIPE_page; \
	COMMAND trans7_Control_pH_RECIPE_read; \
	COMMAND trans7_Control_pH_RECIPE_write; \
	VARIABLE trans7_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans7_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans7_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS7_CONTROL_PH_MANDATORY_A \
	USE_TRANS7_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans7_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS7_CONTROL_PH_MANDATORY_B \
	USE_TRANS7_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans7_Control_pH_VIEW_1; \
	MENU trans7_Control_pH_VIEW_1_page; \
	MENU trans7_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS7_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans7_Control_pH_QUALITY_type; \
	ARRAY trans7_Control_pH_QUALITY; \
	MENU trans7_Control_pH_QUALITY_page; \
	COMMAND trans7_Control_pH_QUALITY_read; \
	VARIABLE trans7_Control_pH_SP_type; \
	ARRAY trans7_Control_pH_SP; \
	MENU trans7_Control_pH_SP_page; \
	COMMAND trans7_Control_pH_SP_read; \
	COMMAND trans7_Control_pH_SP_write; \
	VARIABLE trans7_Control_pH_PV_type; \
	ARRAY trans7_Control_pH_PV; \
	MENU trans7_Control_pH_PV_page; \
	COMMAND trans7_Control_pH_PV_read; \
	VARIABLE trans7_Control_pH_CTB_MASTER; \
	MENU trans7_Control_pH_CTB_MASTER_page; \
	COMMAND trans7_Control_pH_CTB_MASTER_read; \
	COMMAND trans7_Control_pH_CTB_MASTER_write; \
	VARIABLE trans7_Control_pH_SELECTION_type; \
	ARRAY trans7_Control_pH_SELECTION; \
	MENU trans7_Control_pH_SELECTION_page; \
	COMMAND trans7_Control_pH_SELECTION_read; \
	COMMAND trans7_Control_pH_SELECTION_write; \
	VARIABLE trans7_Control_pH_NUMBER_PARAMETERS; \
	MENU trans7_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans7_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans7_Control_pH_BUFFER_NUMBER; \
	MENU trans7_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans7_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans7_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans7_Control_pH_ZERO; \
	MENU trans7_Control_pH_ZERO_page; \
	COMMAND trans7_Control_pH_ZERO_read; \
	COMMAND trans7_Control_pH_ZERO_write; \
	VARIABLE trans7_Control_pH_SLOPE; \
	MENU trans7_Control_pH_SLOPE_page; \
	COMMAND trans7_Control_pH_SLOPE_read; \
	COMMAND trans7_Control_pH_SLOPE_write; \
	COLLECTION trans7_Control_pH_VIEW_2; \
	MENU trans7_Control_pH_VIEW_2_page; \
	COLLECTION trans7_Control_pH_VIEW_3; \
	MENU trans7_Control_pH_VIEW_3_page

#define USE_TRANS7_CONTROL_PH_OPTIONAL_A \
	USE_TRANS7_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans7_Control_pH_VIEW_1; \
	MENU trans7_Control_pH_VIEW_1_page; \
	MENU trans7_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS7_CONTROL_PH_OPTIONAL_B \
	USE_TRANS7_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans7_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans7_Control_pH_)
#define USE_TRANS7_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans7_Control_pH_)
#define USE_TRANS7_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans7_Control_pH_)
#define USE_TRANS7_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans7_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans8_Control_pH_block; \
	COLLECTION trans8_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans8_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans8_Control_pH_ST_REV; \
	MENU trans8_Control_pH_ST_REV_page; \
	COMMAND trans8_Control_pH_ST_REV_read; \
	VARIABLE trans8_Control_pH_TAG_DESC; \
	MENU trans8_Control_pH_TAG_DESC_page; \
	COMMAND trans8_Control_pH_TAG_DESC_read; \
	COMMAND trans8_Control_pH_TAG_DESC_write; \
	VARIABLE trans8_Control_pH_STRATEGY; \
	MENU trans8_Control_pH_STRATEGY_page; \
	COMMAND trans8_Control_pH_STRATEGY_read; \
	COMMAND trans8_Control_pH_STRATEGY_write; \
	VARIABLE trans8_Control_pH_ALERT_KEY; \
	MENU trans8_Control_pH_ALERT_KEY_page; \
	COMMAND trans8_Control_pH_ALERT_KEY_read; \
	COMMAND trans8_Control_pH_ALERT_KEY_write; \
	VARIABLE trans8_Control_pH_TARGET_MODE; \
	MENU trans8_Control_pH_TARGET_MODE_page; \
	COMMAND trans8_Control_pH_TARGET_MODE_read; \
	COMMAND trans8_Control_pH_TARGET_MODE_write; \
	COLLECTION trans8_Control_pH_MODE_BLK; \
	VARIABLE trans8_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans8_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans8_Control_pH_MODE_BLK_Normal; \
	MENU trans8_Control_pH_MODE_BLK_page; \
	COMMAND trans8_Control_pH_MODE_BLK_read; \
	COLLECTION trans8_Control_pH_ALARM_SUM; \
	VARIABLE trans8_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans8_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans8_Control_pH_ALARM_SUM_Disabled; \
	MENU trans8_Control_pH_ALARM_SUM_page; \
	COMMAND trans8_Control_pH_ALARM_SUM_read; \
	VARIABLE trans8_Control_pH_BLOCK_TYPE; \
	MENU trans8_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans8_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans8_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans8_Control_pH_COMMAND; \
	MENU trans8_Control_pH_COMMAND_page; \
	COMMAND trans8_Control_pH_COMMAND_read; \
	COMMAND trans8_Control_pH_COMMAND_write; \
	VARIABLE trans8_Control_pH_STATUS; \
	MENU trans8_Control_pH_STATUS_page; \
	COMMAND trans8_Control_pH_STATUS_read; \
	VARIABLE trans8_Control_pH_CHANNEL; \
	MENU trans8_Control_pH_CHANNEL_page; \
	COMMAND trans8_Control_pH_CHANNEL_read; \
	COMMAND trans8_Control_pH_CHANNEL_write; \
	COLLECTION trans8_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans8_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans8_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans8_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans8_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans8_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans8_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans8_Control_pH_RECIPE; \
	MENU trans8_Control_pH_RECIPE_page; \
	COMMAND trans8_Control_pH_RECIPE_read; \
	COMMAND trans8_Control_pH_RECIPE_write; \
	VARIABLE trans8_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans8_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans8_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS8_CONTROL_PH_MANDATORY_A \
	USE_TRANS8_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans8_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS8_CONTROL_PH_MANDATORY_B \
	USE_TRANS8_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans8_Control_pH_VIEW_1; \
	MENU trans8_Control_pH_VIEW_1_page; \
	MENU trans8_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS8_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans8_Control_pH_QUALITY_type; \
	ARRAY trans8_Control_pH_QUALITY; \
	MENU trans8_Control_pH_QUALITY_page; \
	COMMAND trans8_Control_pH_QUALITY_read; \
	VARIABLE trans8_Control_pH_SP_type; \
	ARRAY trans8_Control_pH_SP; \
	MENU trans8_Control_pH_SP_page; \
	COMMAND trans8_Control_pH_SP_read; \
	COMMAND trans8_Control_pH_SP_write; \
	VARIABLE trans8_Control_pH_PV_type; \
	ARRAY trans8_Control_pH_PV; \
	MENU trans8_Control_pH_PV_page; \
	COMMAND trans8_Control_pH_PV_read; \
	VARIABLE trans8_Control_pH_CTB_MASTER; \
	MENU trans8_Control_pH_CTB_MASTER_page; \
	COMMAND trans8_Control_pH_CTB_MASTER_read; \
	COMMAND trans8_Control_pH_CTB_MASTER_write; \
	VARIABLE trans8_Control_pH_SELECTION_type; \
	ARRAY trans8_Control_pH_SELECTION; \
	MENU trans8_Control_pH_SELECTION_page; \
	COMMAND trans8_Control_pH_SELECTION_read; \
	COMMAND trans8_Control_pH_SELECTION_write; \
	VARIABLE trans8_Control_pH_NUMBER_PARAMETERS; \
	MENU trans8_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans8_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans8_Control_pH_BUFFER_NUMBER; \
	MENU trans8_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans8_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans8_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans8_Control_pH_ZERO; \
	MENU trans8_Control_pH_ZERO_page; \
	COMMAND trans8_Control_pH_ZERO_read; \
	COMMAND trans8_Control_pH_ZERO_write; \
	VARIABLE trans8_Control_pH_SLOPE; \
	MENU trans8_Control_pH_SLOPE_page; \
	COMMAND trans8_Control_pH_SLOPE_read; \
	COMMAND trans8_Control_pH_SLOPE_write; \
	COLLECTION trans8_Control_pH_VIEW_2; \
	MENU trans8_Control_pH_VIEW_2_page; \
	COLLECTION trans8_Control_pH_VIEW_3; \
	MENU trans8_Control_pH_VIEW_3_page

#define USE_TRANS8_CONTROL_PH_OPTIONAL_A \
	USE_TRANS8_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans8_Control_pH_VIEW_1; \
	MENU trans8_Control_pH_VIEW_1_page; \
	MENU trans8_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS8_CONTROL_PH_OPTIONAL_B \
	USE_TRANS8_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans8_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans8_Control_pH_)
#define USE_TRANS8_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans8_Control_pH_)
#define USE_TRANS8_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans8_Control_pH_)
#define USE_TRANS8_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans8_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans9_Control_pH_block; \
	COLLECTION trans9_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans9_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans9_Control_pH_ST_REV; \
	MENU trans9_Control_pH_ST_REV_page; \
	COMMAND trans9_Control_pH_ST_REV_read; \
	VARIABLE trans9_Control_pH_TAG_DESC; \
	MENU trans9_Control_pH_TAG_DESC_page; \
	COMMAND trans9_Control_pH_TAG_DESC_read; \
	COMMAND trans9_Control_pH_TAG_DESC_write; \
	VARIABLE trans9_Control_pH_STRATEGY; \
	MENU trans9_Control_pH_STRATEGY_page; \
	COMMAND trans9_Control_pH_STRATEGY_read; \
	COMMAND trans9_Control_pH_STRATEGY_write; \
	VARIABLE trans9_Control_pH_ALERT_KEY; \
	MENU trans9_Control_pH_ALERT_KEY_page; \
	COMMAND trans9_Control_pH_ALERT_KEY_read; \
	COMMAND trans9_Control_pH_ALERT_KEY_write; \
	VARIABLE trans9_Control_pH_TARGET_MODE; \
	MENU trans9_Control_pH_TARGET_MODE_page; \
	COMMAND trans9_Control_pH_TARGET_MODE_read; \
	COMMAND trans9_Control_pH_TARGET_MODE_write; \
	COLLECTION trans9_Control_pH_MODE_BLK; \
	VARIABLE trans9_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans9_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans9_Control_pH_MODE_BLK_Normal; \
	MENU trans9_Control_pH_MODE_BLK_page; \
	COMMAND trans9_Control_pH_MODE_BLK_read; \
	COLLECTION trans9_Control_pH_ALARM_SUM; \
	VARIABLE trans9_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans9_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans9_Control_pH_ALARM_SUM_Disabled; \
	MENU trans9_Control_pH_ALARM_SUM_page; \
	COMMAND trans9_Control_pH_ALARM_SUM_read; \
	VARIABLE trans9_Control_pH_BLOCK_TYPE; \
	MENU trans9_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans9_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans9_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans9_Control_pH_COMMAND; \
	MENU trans9_Control_pH_COMMAND_page; \
	COMMAND trans9_Control_pH_COMMAND_read; \
	COMMAND trans9_Control_pH_COMMAND_write; \
	VARIABLE trans9_Control_pH_STATUS; \
	MENU trans9_Control_pH_STATUS_page; \
	COMMAND trans9_Control_pH_STATUS_read; \
	VARIABLE trans9_Control_pH_CHANNEL; \
	MENU trans9_Control_pH_CHANNEL_page; \
	COMMAND trans9_Control_pH_CHANNEL_read; \
	COMMAND trans9_Control_pH_CHANNEL_write; \
	COLLECTION trans9_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans9_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans9_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans9_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans9_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans9_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans9_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans9_Control_pH_RECIPE; \
	MENU trans9_Control_pH_RECIPE_page; \
	COMMAND trans9_Control_pH_RECIPE_read; \
	COMMAND trans9_Control_pH_RECIPE_write; \
	VARIABLE trans9_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans9_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans9_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS9_CONTROL_PH_MANDATORY_A \
	USE_TRANS9_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans9_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS9_CONTROL_PH_MANDATORY_B \
	USE_TRANS9_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans9_Control_pH_VIEW_1; \
	MENU trans9_Control_pH_VIEW_1_page; \
	MENU trans9_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS9_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans9_Control_pH_QUALITY_type; \
	ARRAY trans9_Control_pH_QUALITY; \
	MENU trans9_Control_pH_QUALITY_page; \
	COMMAND trans9_Control_pH_QUALITY_read; \
	VARIABLE trans9_Control_pH_SP_type; \
	ARRAY trans9_Control_pH_SP; \
	MENU trans9_Control_pH_SP_page; \
	COMMAND trans9_Control_pH_SP_read; \
	COMMAND trans9_Control_pH_SP_write; \
	VARIABLE trans9_Control_pH_PV_type; \
	ARRAY trans9_Control_pH_PV; \
	MENU trans9_Control_pH_PV_page; \
	COMMAND trans9_Control_pH_PV_read; \
	VARIABLE trans9_Control_pH_CTB_MASTER; \
	MENU trans9_Control_pH_CTB_MASTER_page; \
	COMMAND trans9_Control_pH_CTB_MASTER_read; \
	COMMAND trans9_Control_pH_CTB_MASTER_write; \
	VARIABLE trans9_Control_pH_SELECTION_type; \
	ARRAY trans9_Control_pH_SELECTION; \
	MENU trans9_Control_pH_SELECTION_page; \
	COMMAND trans9_Control_pH_SELECTION_read; \
	COMMAND trans9_Control_pH_SELECTION_write; \
	VARIABLE trans9_Control_pH_NUMBER_PARAMETERS; \
	MENU trans9_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans9_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans9_Control_pH_BUFFER_NUMBER; \
	MENU trans9_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans9_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans9_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans9_Control_pH_ZERO; \
	MENU trans9_Control_pH_ZERO_page; \
	COMMAND trans9_Control_pH_ZERO_read; \
	COMMAND trans9_Control_pH_ZERO_write; \
	VARIABLE trans9_Control_pH_SLOPE; \
	MENU trans9_Control_pH_SLOPE_page; \
	COMMAND trans9_Control_pH_SLOPE_read; \
	COMMAND trans9_Control_pH_SLOPE_write; \
	COLLECTION trans9_Control_pH_VIEW_2; \
	MENU trans9_Control_pH_VIEW_2_page; \
	COLLECTION trans9_Control_pH_VIEW_3; \
	MENU trans9_Control_pH_VIEW_3_page

#define USE_TRANS9_CONTROL_PH_OPTIONAL_A \
	USE_TRANS9_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans9_Control_pH_VIEW_1; \
	MENU trans9_Control_pH_VIEW_1_page; \
	MENU trans9_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS9_CONTROL_PH_OPTIONAL_B \
	USE_TRANS9_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans9_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans9_Control_pH_)
#define USE_TRANS9_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans9_Control_pH_)
#define USE_TRANS9_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans9_Control_pH_)
#define USE_TRANS9_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans9_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans10_Control_pH_block; \
	COLLECTION trans10_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans10_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans10_Control_pH_ST_REV; \
	MENU trans10_Control_pH_ST_REV_page; \
	COMMAND trans10_Control_pH_ST_REV_read; \
	VARIABLE trans10_Control_pH_TAG_DESC; \
	MENU trans10_Control_pH_TAG_DESC_page; \
	COMMAND trans10_Control_pH_TAG_DESC_read; \
	COMMAND trans10_Control_pH_TAG_DESC_write; \
	VARIABLE trans10_Control_pH_STRATEGY; \
	MENU trans10_Control_pH_STRATEGY_page; \
	COMMAND trans10_Control_pH_STRATEGY_read; \
	COMMAND trans10_Control_pH_STRATEGY_write; \
	VARIABLE trans10_Control_pH_ALERT_KEY; \
	MENU trans10_Control_pH_ALERT_KEY_page; \
	COMMAND trans10_Control_pH_ALERT_KEY_read; \
	COMMAND trans10_Control_pH_ALERT_KEY_write; \
	VARIABLE trans10_Control_pH_TARGET_MODE; \
	MENU trans10_Control_pH_TARGET_MODE_page; \
	COMMAND trans10_Control_pH_TARGET_MODE_read; \
	COMMAND trans10_Control_pH_TARGET_MODE_write; \
	COLLECTION trans10_Control_pH_MODE_BLK; \
	VARIABLE trans10_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans10_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans10_Control_pH_MODE_BLK_Normal; \
	MENU trans10_Control_pH_MODE_BLK_page; \
	COMMAND trans10_Control_pH_MODE_BLK_read; \
	COLLECTION trans10_Control_pH_ALARM_SUM; \
	VARIABLE trans10_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans10_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans10_Control_pH_ALARM_SUM_Disabled; \
	MENU trans10_Control_pH_ALARM_SUM_page; \
	COMMAND trans10_Control_pH_ALARM_SUM_read; \
	VARIABLE trans10_Control_pH_BLOCK_TYPE; \
	MENU trans10_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans10_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans10_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans10_Control_pH_COMMAND; \
	MENU trans10_Control_pH_COMMAND_page; \
	COMMAND trans10_Control_pH_COMMAND_read; \
	COMMAND trans10_Control_pH_COMMAND_write; \
	VARIABLE trans10_Control_pH_STATUS; \
	MENU trans10_Control_pH_STATUS_page; \
	COMMAND trans10_Control_pH_STATUS_read; \
	VARIABLE trans10_Control_pH_CHANNEL; \
	MENU trans10_Control_pH_CHANNEL_page; \
	COMMAND trans10_Control_pH_CHANNEL_read; \
	COMMAND trans10_Control_pH_CHANNEL_write; \
	COLLECTION trans10_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans10_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans10_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans10_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans10_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans10_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans10_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans10_Control_pH_RECIPE; \
	MENU trans10_Control_pH_RECIPE_page; \
	COMMAND trans10_Control_pH_RECIPE_read; \
	COMMAND trans10_Control_pH_RECIPE_write; \
	VARIABLE trans10_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans10_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans10_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS10_CONTROL_PH_MANDATORY_A \
	USE_TRANS10_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans10_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS10_CONTROL_PH_MANDATORY_B \
	USE_TRANS10_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans10_Control_pH_VIEW_1; \
	MENU trans10_Control_pH_VIEW_1_page; \
	MENU trans10_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS10_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans10_Control_pH_QUALITY_type; \
	ARRAY trans10_Control_pH_QUALITY; \
	MENU trans10_Control_pH_QUALITY_page; \
	COMMAND trans10_Control_pH_QUALITY_read; \
	VARIABLE trans10_Control_pH_SP_type; \
	ARRAY trans10_Control_pH_SP; \
	MENU trans10_Control_pH_SP_page; \
	COMMAND trans10_Control_pH_SP_read; \
	COMMAND trans10_Control_pH_SP_write; \
	VARIABLE trans10_Control_pH_PV_type; \
	ARRAY trans10_Control_pH_PV; \
	MENU trans10_Control_pH_PV_page; \
	COMMAND trans10_Control_pH_PV_read; \
	VARIABLE trans10_Control_pH_CTB_MASTER; \
	MENU trans10_Control_pH_CTB_MASTER_page; \
	COMMAND trans10_Control_pH_CTB_MASTER_read; \
	COMMAND trans10_Control_pH_CTB_MASTER_write; \
	VARIABLE trans10_Control_pH_SELECTION_type; \
	ARRAY trans10_Control_pH_SELECTION; \
	MENU trans10_Control_pH_SELECTION_page; \
	COMMAND trans10_Control_pH_SELECTION_read; \
	COMMAND trans10_Control_pH_SELECTION_write; \
	VARIABLE trans10_Control_pH_NUMBER_PARAMETERS; \
	MENU trans10_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans10_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans10_Control_pH_BUFFER_NUMBER; \
	MENU trans10_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans10_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans10_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans10_Control_pH_ZERO; \
	MENU trans10_Control_pH_ZERO_page; \
	COMMAND trans10_Control_pH_ZERO_read; \
	COMMAND trans10_Control_pH_ZERO_write; \
	VARIABLE trans10_Control_pH_SLOPE; \
	MENU trans10_Control_pH_SLOPE_page; \
	COMMAND trans10_Control_pH_SLOPE_read; \
	COMMAND trans10_Control_pH_SLOPE_write; \
	COLLECTION trans10_Control_pH_VIEW_2; \
	MENU trans10_Control_pH_VIEW_2_page; \
	COLLECTION trans10_Control_pH_VIEW_3; \
	MENU trans10_Control_pH_VIEW_3_page

#define USE_TRANS10_CONTROL_PH_OPTIONAL_A \
	USE_TRANS10_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans10_Control_pH_VIEW_1; \
	MENU trans10_Control_pH_VIEW_1_page; \
	MENU trans10_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS10_CONTROL_PH_OPTIONAL_B \
	USE_TRANS10_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans10_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans10_Control_pH_)
#define USE_TRANS10_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans10_Control_pH_)
#define USE_TRANS10_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans10_Control_pH_)
#define USE_TRANS10_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans10_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans11_Control_pH_block; \
	COLLECTION trans11_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans11_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans11_Control_pH_ST_REV; \
	MENU trans11_Control_pH_ST_REV_page; \
	COMMAND trans11_Control_pH_ST_REV_read; \
	VARIABLE trans11_Control_pH_TAG_DESC; \
	MENU trans11_Control_pH_TAG_DESC_page; \
	COMMAND trans11_Control_pH_TAG_DESC_read; \
	COMMAND trans11_Control_pH_TAG_DESC_write; \
	VARIABLE trans11_Control_pH_STRATEGY; \
	MENU trans11_Control_pH_STRATEGY_page; \
	COMMAND trans11_Control_pH_STRATEGY_read; \
	COMMAND trans11_Control_pH_STRATEGY_write; \
	VARIABLE trans11_Control_pH_ALERT_KEY; \
	MENU trans11_Control_pH_ALERT_KEY_page; \
	COMMAND trans11_Control_pH_ALERT_KEY_read; \
	COMMAND trans11_Control_pH_ALERT_KEY_write; \
	VARIABLE trans11_Control_pH_TARGET_MODE; \
	MENU trans11_Control_pH_TARGET_MODE_page; \
	COMMAND trans11_Control_pH_TARGET_MODE_read; \
	COMMAND trans11_Control_pH_TARGET_MODE_write; \
	COLLECTION trans11_Control_pH_MODE_BLK; \
	VARIABLE trans11_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans11_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans11_Control_pH_MODE_BLK_Normal; \
	MENU trans11_Control_pH_MODE_BLK_page; \
	COMMAND trans11_Control_pH_MODE_BLK_read; \
	COLLECTION trans11_Control_pH_ALARM_SUM; \
	VARIABLE trans11_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans11_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans11_Control_pH_ALARM_SUM_Disabled; \
	MENU trans11_Control_pH_ALARM_SUM_page; \
	COMMAND trans11_Control_pH_ALARM_SUM_read; \
	VARIABLE trans11_Control_pH_BLOCK_TYPE; \
	MENU trans11_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans11_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans11_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans11_Control_pH_COMMAND; \
	MENU trans11_Control_pH_COMMAND_page; \
	COMMAND trans11_Control_pH_COMMAND_read; \
	COMMAND trans11_Control_pH_COMMAND_write; \
	VARIABLE trans11_Control_pH_STATUS; \
	MENU trans11_Control_pH_STATUS_page; \
	COMMAND trans11_Control_pH_STATUS_read; \
	VARIABLE trans11_Control_pH_CHANNEL; \
	MENU trans11_Control_pH_CHANNEL_page; \
	COMMAND trans11_Control_pH_CHANNEL_read; \
	COMMAND trans11_Control_pH_CHANNEL_write; \
	COLLECTION trans11_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans11_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans11_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans11_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans11_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans11_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans11_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans11_Control_pH_RECIPE; \
	MENU trans11_Control_pH_RECIPE_page; \
	COMMAND trans11_Control_pH_RECIPE_read; \
	COMMAND trans11_Control_pH_RECIPE_write; \
	VARIABLE trans11_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans11_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans11_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS11_CONTROL_PH_MANDATORY_A \
	USE_TRANS11_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans11_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS11_CONTROL_PH_MANDATORY_B \
	USE_TRANS11_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans11_Control_pH_VIEW_1; \
	MENU trans11_Control_pH_VIEW_1_page; \
	MENU trans11_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS11_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans11_Control_pH_QUALITY_type; \
	ARRAY trans11_Control_pH_QUALITY; \
	MENU trans11_Control_pH_QUALITY_page; \
	COMMAND trans11_Control_pH_QUALITY_read; \
	VARIABLE trans11_Control_pH_SP_type; \
	ARRAY trans11_Control_pH_SP; \
	MENU trans11_Control_pH_SP_page; \
	COMMAND trans11_Control_pH_SP_read; \
	COMMAND trans11_Control_pH_SP_write; \
	VARIABLE trans11_Control_pH_PV_type; \
	ARRAY trans11_Control_pH_PV; \
	MENU trans11_Control_pH_PV_page; \
	COMMAND trans11_Control_pH_PV_read; \
	VARIABLE trans11_Control_pH_CTB_MASTER; \
	MENU trans11_Control_pH_CTB_MASTER_page; \
	COMMAND trans11_Control_pH_CTB_MASTER_read; \
	COMMAND trans11_Control_pH_CTB_MASTER_write; \
	VARIABLE trans11_Control_pH_SELECTION_type; \
	ARRAY trans11_Control_pH_SELECTION; \
	MENU trans11_Control_pH_SELECTION_page; \
	COMMAND trans11_Control_pH_SELECTION_read; \
	COMMAND trans11_Control_pH_SELECTION_write; \
	VARIABLE trans11_Control_pH_NUMBER_PARAMETERS; \
	MENU trans11_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans11_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans11_Control_pH_BUFFER_NUMBER; \
	MENU trans11_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans11_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans11_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans11_Control_pH_ZERO; \
	MENU trans11_Control_pH_ZERO_page; \
	COMMAND trans11_Control_pH_ZERO_read; \
	COMMAND trans11_Control_pH_ZERO_write; \
	VARIABLE trans11_Control_pH_SLOPE; \
	MENU trans11_Control_pH_SLOPE_page; \
	COMMAND trans11_Control_pH_SLOPE_read; \
	COMMAND trans11_Control_pH_SLOPE_write; \
	COLLECTION trans11_Control_pH_VIEW_2; \
	MENU trans11_Control_pH_VIEW_2_page; \
	COLLECTION trans11_Control_pH_VIEW_3; \
	MENU trans11_Control_pH_VIEW_3_page

#define USE_TRANS11_CONTROL_PH_OPTIONAL_A \
	USE_TRANS11_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans11_Control_pH_VIEW_1; \
	MENU trans11_Control_pH_VIEW_1_page; \
	MENU trans11_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS11_CONTROL_PH_OPTIONAL_B \
	USE_TRANS11_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans11_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans11_Control_pH_)
#define USE_TRANS11_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans11_Control_pH_)
#define USE_TRANS11_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans11_Control_pH_)
#define USE_TRANS11_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans11_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans12_Control_pH_block; \
	COLLECTION trans12_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans12_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans12_Control_pH_ST_REV; \
	MENU trans12_Control_pH_ST_REV_page; \
	COMMAND trans12_Control_pH_ST_REV_read; \
	VARIABLE trans12_Control_pH_TAG_DESC; \
	MENU trans12_Control_pH_TAG_DESC_page; \
	COMMAND trans12_Control_pH_TAG_DESC_read; \
	COMMAND trans12_Control_pH_TAG_DESC_write; \
	VARIABLE trans12_Control_pH_STRATEGY; \
	MENU trans12_Control_pH_STRATEGY_page; \
	COMMAND trans12_Control_pH_STRATEGY_read; \
	COMMAND trans12_Control_pH_STRATEGY_write; \
	VARIABLE trans12_Control_pH_ALERT_KEY; \
	MENU trans12_Control_pH_ALERT_KEY_page; \
	COMMAND trans12_Control_pH_ALERT_KEY_read; \
	COMMAND trans12_Control_pH_ALERT_KEY_write; \
	VARIABLE trans12_Control_pH_TARGET_MODE; \
	MENU trans12_Control_pH_TARGET_MODE_page; \
	COMMAND trans12_Control_pH_TARGET_MODE_read; \
	COMMAND trans12_Control_pH_TARGET_MODE_write; \
	COLLECTION trans12_Control_pH_MODE_BLK; \
	VARIABLE trans12_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans12_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans12_Control_pH_MODE_BLK_Normal; \
	MENU trans12_Control_pH_MODE_BLK_page; \
	COMMAND trans12_Control_pH_MODE_BLK_read; \
	COLLECTION trans12_Control_pH_ALARM_SUM; \
	VARIABLE trans12_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans12_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans12_Control_pH_ALARM_SUM_Disabled; \
	MENU trans12_Control_pH_ALARM_SUM_page; \
	COMMAND trans12_Control_pH_ALARM_SUM_read; \
	VARIABLE trans12_Control_pH_BLOCK_TYPE; \
	MENU trans12_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans12_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans12_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans12_Control_pH_COMMAND; \
	MENU trans12_Control_pH_COMMAND_page; \
	COMMAND trans12_Control_pH_COMMAND_read; \
	COMMAND trans12_Control_pH_COMMAND_write; \
	VARIABLE trans12_Control_pH_STATUS; \
	MENU trans12_Control_pH_STATUS_page; \
	COMMAND trans12_Control_pH_STATUS_read; \
	VARIABLE trans12_Control_pH_CHANNEL; \
	MENU trans12_Control_pH_CHANNEL_page; \
	COMMAND trans12_Control_pH_CHANNEL_read; \
	COMMAND trans12_Control_pH_CHANNEL_write; \
	COLLECTION trans12_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans12_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans12_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans12_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans12_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans12_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans12_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans12_Control_pH_RECIPE; \
	MENU trans12_Control_pH_RECIPE_page; \
	COMMAND trans12_Control_pH_RECIPE_read; \
	COMMAND trans12_Control_pH_RECIPE_write; \
	VARIABLE trans12_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans12_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans12_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS12_CONTROL_PH_MANDATORY_A \
	USE_TRANS12_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans12_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS12_CONTROL_PH_MANDATORY_B \
	USE_TRANS12_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans12_Control_pH_VIEW_1; \
	MENU trans12_Control_pH_VIEW_1_page; \
	MENU trans12_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS12_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans12_Control_pH_QUALITY_type; \
	ARRAY trans12_Control_pH_QUALITY; \
	MENU trans12_Control_pH_QUALITY_page; \
	COMMAND trans12_Control_pH_QUALITY_read; \
	VARIABLE trans12_Control_pH_SP_type; \
	ARRAY trans12_Control_pH_SP; \
	MENU trans12_Control_pH_SP_page; \
	COMMAND trans12_Control_pH_SP_read; \
	COMMAND trans12_Control_pH_SP_write; \
	VARIABLE trans12_Control_pH_PV_type; \
	ARRAY trans12_Control_pH_PV; \
	MENU trans12_Control_pH_PV_page; \
	COMMAND trans12_Control_pH_PV_read; \
	VARIABLE trans12_Control_pH_CTB_MASTER; \
	MENU trans12_Control_pH_CTB_MASTER_page; \
	COMMAND trans12_Control_pH_CTB_MASTER_read; \
	COMMAND trans12_Control_pH_CTB_MASTER_write; \
	VARIABLE trans12_Control_pH_SELECTION_type; \
	ARRAY trans12_Control_pH_SELECTION; \
	MENU trans12_Control_pH_SELECTION_page; \
	COMMAND trans12_Control_pH_SELECTION_read; \
	COMMAND trans12_Control_pH_SELECTION_write; \
	VARIABLE trans12_Control_pH_NUMBER_PARAMETERS; \
	MENU trans12_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans12_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans12_Control_pH_BUFFER_NUMBER; \
	MENU trans12_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans12_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans12_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans12_Control_pH_ZERO; \
	MENU trans12_Control_pH_ZERO_page; \
	COMMAND trans12_Control_pH_ZERO_read; \
	COMMAND trans12_Control_pH_ZERO_write; \
	VARIABLE trans12_Control_pH_SLOPE; \
	MENU trans12_Control_pH_SLOPE_page; \
	COMMAND trans12_Control_pH_SLOPE_read; \
	COMMAND trans12_Control_pH_SLOPE_write; \
	COLLECTION trans12_Control_pH_VIEW_2; \
	MENU trans12_Control_pH_VIEW_2_page; \
	COLLECTION trans12_Control_pH_VIEW_3; \
	MENU trans12_Control_pH_VIEW_3_page

#define USE_TRANS12_CONTROL_PH_OPTIONAL_A \
	USE_TRANS12_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans12_Control_pH_VIEW_1; \
	MENU trans12_Control_pH_VIEW_1_page; \
	MENU trans12_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS12_CONTROL_PH_OPTIONAL_B \
	USE_TRANS12_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans12_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans12_Control_pH_)
#define USE_TRANS12_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans12_Control_pH_)
#define USE_TRANS12_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans12_Control_pH_)
#define USE_TRANS12_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans12_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans13_Control_pH_block; \
	COLLECTION trans13_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans13_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans13_Control_pH_ST_REV; \
	MENU trans13_Control_pH_ST_REV_page; \
	COMMAND trans13_Control_pH_ST_REV_read; \
	VARIABLE trans13_Control_pH_TAG_DESC; \
	MENU trans13_Control_pH_TAG_DESC_page; \
	COMMAND trans13_Control_pH_TAG_DESC_read; \
	COMMAND trans13_Control_pH_TAG_DESC_write; \
	VARIABLE trans13_Control_pH_STRATEGY; \
	MENU trans13_Control_pH_STRATEGY_page; \
	COMMAND trans13_Control_pH_STRATEGY_read; \
	COMMAND trans13_Control_pH_STRATEGY_write; \
	VARIABLE trans13_Control_pH_ALERT_KEY; \
	MENU trans13_Control_pH_ALERT_KEY_page; \
	COMMAND trans13_Control_pH_ALERT_KEY_read; \
	COMMAND trans13_Control_pH_ALERT_KEY_write; \
	VARIABLE trans13_Control_pH_TARGET_MODE; \
	MENU trans13_Control_pH_TARGET_MODE_page; \
	COMMAND trans13_Control_pH_TARGET_MODE_read; \
	COMMAND trans13_Control_pH_TARGET_MODE_write; \
	COLLECTION trans13_Control_pH_MODE_BLK; \
	VARIABLE trans13_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans13_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans13_Control_pH_MODE_BLK_Normal; \
	MENU trans13_Control_pH_MODE_BLK_page; \
	COMMAND trans13_Control_pH_MODE_BLK_read; \
	COLLECTION trans13_Control_pH_ALARM_SUM; \
	VARIABLE trans13_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans13_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans13_Control_pH_ALARM_SUM_Disabled; \
	MENU trans13_Control_pH_ALARM_SUM_page; \
	COMMAND trans13_Control_pH_ALARM_SUM_read; \
	VARIABLE trans13_Control_pH_BLOCK_TYPE; \
	MENU trans13_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans13_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans13_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans13_Control_pH_COMMAND; \
	MENU trans13_Control_pH_COMMAND_page; \
	COMMAND trans13_Control_pH_COMMAND_read; \
	COMMAND trans13_Control_pH_COMMAND_write; \
	VARIABLE trans13_Control_pH_STATUS; \
	MENU trans13_Control_pH_STATUS_page; \
	COMMAND trans13_Control_pH_STATUS_read; \
	VARIABLE trans13_Control_pH_CHANNEL; \
	MENU trans13_Control_pH_CHANNEL_page; \
	COMMAND trans13_Control_pH_CHANNEL_read; \
	COMMAND trans13_Control_pH_CHANNEL_write; \
	COLLECTION trans13_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans13_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans13_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans13_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans13_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans13_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans13_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans13_Control_pH_RECIPE; \
	MENU trans13_Control_pH_RECIPE_page; \
	COMMAND trans13_Control_pH_RECIPE_read; \
	COMMAND trans13_Control_pH_RECIPE_write; \
	VARIABLE trans13_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans13_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans13_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS13_CONTROL_PH_MANDATORY_A \
	USE_TRANS13_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans13_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS13_CONTROL_PH_MANDATORY_B \
	USE_TRANS13_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans13_Control_pH_VIEW_1; \
	MENU trans13_Control_pH_VIEW_1_page; \
	MENU trans13_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS13_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans13_Control_pH_QUALITY_type; \
	ARRAY trans13_Control_pH_QUALITY; \
	MENU trans13_Control_pH_QUALITY_page; \
	COMMAND trans13_Control_pH_QUALITY_read; \
	VARIABLE trans13_Control_pH_SP_type; \
	ARRAY trans13_Control_pH_SP; \
	MENU trans13_Control_pH_SP_page; \
	COMMAND trans13_Control_pH_SP_read; \
	COMMAND trans13_Control_pH_SP_write; \
	VARIABLE trans13_Control_pH_PV_type; \
	ARRAY trans13_Control_pH_PV; \
	MENU trans13_Control_pH_PV_page; \
	COMMAND trans13_Control_pH_PV_read; \
	VARIABLE trans13_Control_pH_CTB_MASTER; \
	MENU trans13_Control_pH_CTB_MASTER_page; \
	COMMAND trans13_Control_pH_CTB_MASTER_read; \
	COMMAND trans13_Control_pH_CTB_MASTER_write; \
	VARIABLE trans13_Control_pH_SELECTION_type; \
	ARRAY trans13_Control_pH_SELECTION; \
	MENU trans13_Control_pH_SELECTION_page; \
	COMMAND trans13_Control_pH_SELECTION_read; \
	COMMAND trans13_Control_pH_SELECTION_write; \
	VARIABLE trans13_Control_pH_NUMBER_PARAMETERS; \
	MENU trans13_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans13_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans13_Control_pH_BUFFER_NUMBER; \
	MENU trans13_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans13_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans13_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans13_Control_pH_ZERO; \
	MENU trans13_Control_pH_ZERO_page; \
	COMMAND trans13_Control_pH_ZERO_read; \
	COMMAND trans13_Control_pH_ZERO_write; \
	VARIABLE trans13_Control_pH_SLOPE; \
	MENU trans13_Control_pH_SLOPE_page; \
	COMMAND trans13_Control_pH_SLOPE_read; \
	COMMAND trans13_Control_pH_SLOPE_write; \
	COLLECTION trans13_Control_pH_VIEW_2; \
	MENU trans13_Control_pH_VIEW_2_page; \
	COLLECTION trans13_Control_pH_VIEW_3; \
	MENU trans13_Control_pH_VIEW_3_page

#define USE_TRANS13_CONTROL_PH_OPTIONAL_A \
	USE_TRANS13_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans13_Control_pH_VIEW_1; \
	MENU trans13_Control_pH_VIEW_1_page; \
	MENU trans13_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS13_CONTROL_PH_OPTIONAL_B \
	USE_TRANS13_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans13_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans13_Control_pH_)
#define USE_TRANS13_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans13_Control_pH_)
#define USE_TRANS13_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans13_Control_pH_)
#define USE_TRANS13_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans13_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans14_Control_pH_block; \
	COLLECTION trans14_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans14_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans14_Control_pH_ST_REV; \
	MENU trans14_Control_pH_ST_REV_page; \
	COMMAND trans14_Control_pH_ST_REV_read; \
	VARIABLE trans14_Control_pH_TAG_DESC; \
	MENU trans14_Control_pH_TAG_DESC_page; \
	COMMAND trans14_Control_pH_TAG_DESC_read; \
	COMMAND trans14_Control_pH_TAG_DESC_write; \
	VARIABLE trans14_Control_pH_STRATEGY; \
	MENU trans14_Control_pH_STRATEGY_page; \
	COMMAND trans14_Control_pH_STRATEGY_read; \
	COMMAND trans14_Control_pH_STRATEGY_write; \
	VARIABLE trans14_Control_pH_ALERT_KEY; \
	MENU trans14_Control_pH_ALERT_KEY_page; \
	COMMAND trans14_Control_pH_ALERT_KEY_read; \
	COMMAND trans14_Control_pH_ALERT_KEY_write; \
	VARIABLE trans14_Control_pH_TARGET_MODE; \
	MENU trans14_Control_pH_TARGET_MODE_page; \
	COMMAND trans14_Control_pH_TARGET_MODE_read; \
	COMMAND trans14_Control_pH_TARGET_MODE_write; \
	COLLECTION trans14_Control_pH_MODE_BLK; \
	VARIABLE trans14_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans14_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans14_Control_pH_MODE_BLK_Normal; \
	MENU trans14_Control_pH_MODE_BLK_page; \
	COMMAND trans14_Control_pH_MODE_BLK_read; \
	COLLECTION trans14_Control_pH_ALARM_SUM; \
	VARIABLE trans14_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans14_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans14_Control_pH_ALARM_SUM_Disabled; \
	MENU trans14_Control_pH_ALARM_SUM_page; \
	COMMAND trans14_Control_pH_ALARM_SUM_read; \
	VARIABLE trans14_Control_pH_BLOCK_TYPE; \
	MENU trans14_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans14_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans14_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans14_Control_pH_COMMAND; \
	MENU trans14_Control_pH_COMMAND_page; \
	COMMAND trans14_Control_pH_COMMAND_read; \
	COMMAND trans14_Control_pH_COMMAND_write; \
	VARIABLE trans14_Control_pH_STATUS; \
	MENU trans14_Control_pH_STATUS_page; \
	COMMAND trans14_Control_pH_STATUS_read; \
	VARIABLE trans14_Control_pH_CHANNEL; \
	MENU trans14_Control_pH_CHANNEL_page; \
	COMMAND trans14_Control_pH_CHANNEL_read; \
	COMMAND trans14_Control_pH_CHANNEL_write; \
	COLLECTION trans14_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans14_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans14_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans14_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans14_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans14_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans14_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans14_Control_pH_RECIPE; \
	MENU trans14_Control_pH_RECIPE_page; \
	COMMAND trans14_Control_pH_RECIPE_read; \
	COMMAND trans14_Control_pH_RECIPE_write; \
	VARIABLE trans14_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans14_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans14_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS14_CONTROL_PH_MANDATORY_A \
	USE_TRANS14_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans14_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS14_CONTROL_PH_MANDATORY_B \
	USE_TRANS14_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans14_Control_pH_VIEW_1; \
	MENU trans14_Control_pH_VIEW_1_page; \
	MENU trans14_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS14_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans14_Control_pH_QUALITY_type; \
	ARRAY trans14_Control_pH_QUALITY; \
	MENU trans14_Control_pH_QUALITY_page; \
	COMMAND trans14_Control_pH_QUALITY_read; \
	VARIABLE trans14_Control_pH_SP_type; \
	ARRAY trans14_Control_pH_SP; \
	MENU trans14_Control_pH_SP_page; \
	COMMAND trans14_Control_pH_SP_read; \
	COMMAND trans14_Control_pH_SP_write; \
	VARIABLE trans14_Control_pH_PV_type; \
	ARRAY trans14_Control_pH_PV; \
	MENU trans14_Control_pH_PV_page; \
	COMMAND trans14_Control_pH_PV_read; \
	VARIABLE trans14_Control_pH_CTB_MASTER; \
	MENU trans14_Control_pH_CTB_MASTER_page; \
	COMMAND trans14_Control_pH_CTB_MASTER_read; \
	COMMAND trans14_Control_pH_CTB_MASTER_write; \
	VARIABLE trans14_Control_pH_SELECTION_type; \
	ARRAY trans14_Control_pH_SELECTION; \
	MENU trans14_Control_pH_SELECTION_page; \
	COMMAND trans14_Control_pH_SELECTION_read; \
	COMMAND trans14_Control_pH_SELECTION_write; \
	VARIABLE trans14_Control_pH_NUMBER_PARAMETERS; \
	MENU trans14_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans14_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans14_Control_pH_BUFFER_NUMBER; \
	MENU trans14_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans14_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans14_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans14_Control_pH_ZERO; \
	MENU trans14_Control_pH_ZERO_page; \
	COMMAND trans14_Control_pH_ZERO_read; \
	COMMAND trans14_Control_pH_ZERO_write; \
	VARIABLE trans14_Control_pH_SLOPE; \
	MENU trans14_Control_pH_SLOPE_page; \
	COMMAND trans14_Control_pH_SLOPE_read; \
	COMMAND trans14_Control_pH_SLOPE_write; \
	COLLECTION trans14_Control_pH_VIEW_2; \
	MENU trans14_Control_pH_VIEW_2_page; \
	COLLECTION trans14_Control_pH_VIEW_3; \
	MENU trans14_Control_pH_VIEW_3_page

#define USE_TRANS14_CONTROL_PH_OPTIONAL_A \
	USE_TRANS14_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans14_Control_pH_VIEW_1; \
	MENU trans14_Control_pH_VIEW_1_page; \
	MENU trans14_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS14_CONTROL_PH_OPTIONAL_B \
	USE_TRANS14_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans14_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans14_Control_pH_)
#define USE_TRANS14_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans14_Control_pH_)
#define USE_TRANS14_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans14_Control_pH_)
#define USE_TRANS14_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans14_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_CONTROL_PH_MANDATORY_BOTH \
	BLOCK trans15_Control_pH_block; \
	COLLECTION trans15_Control_pH_BLOCK_OBJECT; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Control_pH_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Control_pH_BLOCK_OBJECT_page; \
	COMMAND trans15_Control_pH_BLOCK_OBJECT_read; \
	VARIABLE trans15_Control_pH_ST_REV; \
	MENU trans15_Control_pH_ST_REV_page; \
	COMMAND trans15_Control_pH_ST_REV_read; \
	VARIABLE trans15_Control_pH_TAG_DESC; \
	MENU trans15_Control_pH_TAG_DESC_page; \
	COMMAND trans15_Control_pH_TAG_DESC_read; \
	COMMAND trans15_Control_pH_TAG_DESC_write; \
	VARIABLE trans15_Control_pH_STRATEGY; \
	MENU trans15_Control_pH_STRATEGY_page; \
	COMMAND trans15_Control_pH_STRATEGY_read; \
	COMMAND trans15_Control_pH_STRATEGY_write; \
	VARIABLE trans15_Control_pH_ALERT_KEY; \
	MENU trans15_Control_pH_ALERT_KEY_page; \
	COMMAND trans15_Control_pH_ALERT_KEY_read; \
	COMMAND trans15_Control_pH_ALERT_KEY_write; \
	VARIABLE trans15_Control_pH_TARGET_MODE; \
	MENU trans15_Control_pH_TARGET_MODE_page; \
	COMMAND trans15_Control_pH_TARGET_MODE_read; \
	COMMAND trans15_Control_pH_TARGET_MODE_write; \
	COLLECTION trans15_Control_pH_MODE_BLK; \
	VARIABLE trans15_Control_pH_MODE_BLK_Actual; \
	VARIABLE trans15_Control_pH_MODE_BLK_Permitted; \
	VARIABLE trans15_Control_pH_MODE_BLK_Normal; \
	MENU trans15_Control_pH_MODE_BLK_page; \
	COMMAND trans15_Control_pH_MODE_BLK_read; \
	COLLECTION trans15_Control_pH_ALARM_SUM; \
	VARIABLE trans15_Control_pH_ALARM_SUM_Current; \
	VARIABLE trans15_Control_pH_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Control_pH_ALARM_SUM_Unreported; \
	VARIABLE trans15_Control_pH_ALARM_SUM_Disabled; \
	MENU trans15_Control_pH_ALARM_SUM_page; \
	COMMAND trans15_Control_pH_ALARM_SUM_read; \
	VARIABLE trans15_Control_pH_BLOCK_TYPE; \
	MENU trans15_Control_pH_BLOCK_TYPE_page; \
	COMMAND trans15_Control_pH_BLOCK_TYPE_read; \
	COMMAND trans15_Control_pH_BLOCK_TYPE_write; \
	VARIABLE trans15_Control_pH_COMMAND; \
	MENU trans15_Control_pH_COMMAND_page; \
	COMMAND trans15_Control_pH_COMMAND_read; \
	COMMAND trans15_Control_pH_COMMAND_write; \
	VARIABLE trans15_Control_pH_STATUS; \
	MENU trans15_Control_pH_STATUS_page; \
	COMMAND trans15_Control_pH_STATUS_read; \
	VARIABLE trans15_Control_pH_CHANNEL; \
	MENU trans15_Control_pH_CHANNEL_page; \
	COMMAND trans15_Control_pH_CHANNEL_read; \
	COMMAND trans15_Control_pH_CHANNEL_write; \
	COLLECTION trans15_Control_pH_SEQUENCE_CONTROL; \
	COLLECTION trans15_Control_pH_SEQUENCE_CONTROL_Time; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans15_Control_pH_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Command; \
	VARIABLE trans15_Control_pH_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans15_Control_pH_SEQUENCE_CONTROL_page; \
	COMMAND trans15_Control_pH_SEQUENCE_CONTROL_read; \
	COMMAND trans15_Control_pH_SEQUENCE_CONTROL_write; \
	VARIABLE trans15_Control_pH_RECIPE; \
	MENU trans15_Control_pH_RECIPE_page; \
	COMMAND trans15_Control_pH_RECIPE_read; \
	COMMAND trans15_Control_pH_RECIPE_write; \
	VARIABLE trans15_Control_pH_PARAMETER_SET_NUMBER; \
	MENU trans15_Control_pH_PARAMETER_SET_NUMBER_page; \
	COMMAND trans15_Control_pH_PARAMETER_SET_NUMBER_read

#define USE_TRANS15_CONTROL_PH_MANDATORY_A \
	USE_TRANS15_CONTROL_PH_MANDATORY_BOTH; \
	MENU trans15_Control_pH_Simple_Dialog_Mandatory_A

#define USE_TRANS15_CONTROL_PH_MANDATORY_B \
	USE_TRANS15_CONTROL_PH_MANDATORY_BOTH; \
	COLLECTION trans15_Control_pH_VIEW_1; \
	MENU trans15_Control_pH_VIEW_1_page; \
	MENU trans15_Control_pH_Simple_Dialog_Mandatory_B

#define USE_TRANS15_CONTROL_PH_OPTIONAL_BOTH \
	VARIABLE trans15_Control_pH_QUALITY_type; \
	ARRAY trans15_Control_pH_QUALITY; \
	MENU trans15_Control_pH_QUALITY_page; \
	COMMAND trans15_Control_pH_QUALITY_read; \
	VARIABLE trans15_Control_pH_SP_type; \
	ARRAY trans15_Control_pH_SP; \
	MENU trans15_Control_pH_SP_page; \
	COMMAND trans15_Control_pH_SP_read; \
	COMMAND trans15_Control_pH_SP_write; \
	VARIABLE trans15_Control_pH_PV_type; \
	ARRAY trans15_Control_pH_PV; \
	MENU trans15_Control_pH_PV_page; \
	COMMAND trans15_Control_pH_PV_read; \
	VARIABLE trans15_Control_pH_CTB_MASTER; \
	MENU trans15_Control_pH_CTB_MASTER_page; \
	COMMAND trans15_Control_pH_CTB_MASTER_read; \
	COMMAND trans15_Control_pH_CTB_MASTER_write; \
	VARIABLE trans15_Control_pH_SELECTION_type; \
	ARRAY trans15_Control_pH_SELECTION; \
	MENU trans15_Control_pH_SELECTION_page; \
	COMMAND trans15_Control_pH_SELECTION_read; \
	COMMAND trans15_Control_pH_SELECTION_write; \
	VARIABLE trans15_Control_pH_NUMBER_PARAMETERS; \
	MENU trans15_Control_pH_NUMBER_PARAMETERS_page; \
	COMMAND trans15_Control_pH_NUMBER_PARAMETERS_read; \
	VARIABLE trans15_Control_pH_BUFFER_NUMBER; \
	MENU trans15_Control_pH_BUFFER_NUMBER_page; \
	COMMAND trans15_Control_pH_BUFFER_NUMBER_read; \
	COMMAND trans15_Control_pH_BUFFER_NUMBER_write; \
	VARIABLE trans15_Control_pH_ZERO; \
	MENU trans15_Control_pH_ZERO_page; \
	COMMAND trans15_Control_pH_ZERO_read; \
	COMMAND trans15_Control_pH_ZERO_write; \
	VARIABLE trans15_Control_pH_SLOPE; \
	MENU trans15_Control_pH_SLOPE_page; \
	COMMAND trans15_Control_pH_SLOPE_read; \
	COMMAND trans15_Control_pH_SLOPE_write; \
	COLLECTION trans15_Control_pH_VIEW_2; \
	MENU trans15_Control_pH_VIEW_2_page; \
	COLLECTION trans15_Control_pH_VIEW_3; \
	MENU trans15_Control_pH_VIEW_3_page

#define USE_TRANS15_CONTROL_PH_OPTIONAL_A \
	USE_TRANS15_CONTROL_PH_OPTIONAL_BOTH; \
	COLLECTION trans15_Control_pH_VIEW_1; \
	MENU trans15_Control_pH_VIEW_1_page; \
	MENU trans15_Control_pH_Simple_Dialog_Optional_A

#define USE_TRANS15_CONTROL_PH_OPTIONAL_B \
	USE_TRANS15_CONTROL_PH_OPTIONAL_BOTH; \
	MENU trans15_Control_pH_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_CONTROL_PH_MANDATORY_A USE_TRANS_CONTROL_PH_MANDATORY_A(trans15_Control_pH_)
#define USE_TRANS15_CONTROL_PH_MANDATORY_B USE_TRANS_CONTROL_PH_MANDATORY_B(trans15_Control_pH_)
#define USE_TRANS15_CONTROL_PH_OPTIONAL_A  USE_TRANS_CONTROL_PH_OPTIONAL_A(trans15_Control_pH_)
#define USE_TRANS15_CONTROL_PH_OPTIONAL_B  USE_TRANS_CONTROL_PH_OPTIONAL_B(trans15_Control_pH_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans1_Control_Cond_block; \
	COLLECTION trans1_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans1_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans1_Control_Cond_ST_REV; \
	MENU trans1_Control_Cond_ST_REV_page; \
	COMMAND trans1_Control_Cond_ST_REV_read; \
	VARIABLE trans1_Control_Cond_TAG_DESC; \
	MENU trans1_Control_Cond_TAG_DESC_page; \
	COMMAND trans1_Control_Cond_TAG_DESC_read; \
	COMMAND trans1_Control_Cond_TAG_DESC_write; \
	VARIABLE trans1_Control_Cond_STRATEGY; \
	MENU trans1_Control_Cond_STRATEGY_page; \
	COMMAND trans1_Control_Cond_STRATEGY_read; \
	COMMAND trans1_Control_Cond_STRATEGY_write; \
	VARIABLE trans1_Control_Cond_ALERT_KEY; \
	MENU trans1_Control_Cond_ALERT_KEY_page; \
	COMMAND trans1_Control_Cond_ALERT_KEY_read; \
	COMMAND trans1_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans1_Control_Cond_TARGET_MODE; \
	MENU trans1_Control_Cond_TARGET_MODE_page; \
	COMMAND trans1_Control_Cond_TARGET_MODE_read; \
	COMMAND trans1_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans1_Control_Cond_MODE_BLK; \
	VARIABLE trans1_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans1_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans1_Control_Cond_MODE_BLK_Normal; \
	MENU trans1_Control_Cond_MODE_BLK_page; \
	COMMAND trans1_Control_Cond_MODE_BLK_read; \
	COLLECTION trans1_Control_Cond_ALARM_SUM; \
	VARIABLE trans1_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans1_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans1_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans1_Control_Cond_ALARM_SUM_page; \
	COMMAND trans1_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans1_Control_Cond_BLOCK_TYPE; \
	MENU trans1_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans1_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans1_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans1_Control_Cond_COMMAND; \
	MENU trans1_Control_Cond_COMMAND_page; \
	COMMAND trans1_Control_Cond_COMMAND_read; \
	COMMAND trans1_Control_Cond_COMMAND_write; \
	VARIABLE trans1_Control_Cond_STATUS; \
	MENU trans1_Control_Cond_STATUS_page; \
	COMMAND trans1_Control_Cond_STATUS_read; \
	VARIABLE trans1_Control_Cond_CHANNEL; \
	MENU trans1_Control_Cond_CHANNEL_page; \
	COMMAND trans1_Control_Cond_CHANNEL_read; \
	COMMAND trans1_Control_Cond_CHANNEL_write; \
	COLLECTION trans1_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans1_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans1_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans1_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans1_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans1_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans1_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans1_Control_Cond_RECIPE; \
	MENU trans1_Control_Cond_RECIPE_page; \
	COMMAND trans1_Control_Cond_RECIPE_read; \
	COMMAND trans1_Control_Cond_RECIPE_write; \
	VARIABLE trans1_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans1_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans1_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS1_CONTROL_COND_MANDATORY_A \
	USE_TRANS1_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans1_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS1_CONTROL_COND_MANDATORY_B \
	USE_TRANS1_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans1_Control_Cond_VIEW_1; \
	MENU trans1_Control_Cond_VIEW_1_page; \
	MENU trans1_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS1_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans1_Control_Cond_QUALITY_type; \
	ARRAY trans1_Control_Cond_QUALITY; \
	MENU trans1_Control_Cond_QUALITY_page; \
	COMMAND trans1_Control_Cond_QUALITY_read; \
	VARIABLE trans1_Control_Cond_SP_type; \
	ARRAY trans1_Control_Cond_SP; \
	MENU trans1_Control_Cond_SP_page; \
	COMMAND trans1_Control_Cond_SP_read; \
	COMMAND trans1_Control_Cond_SP_write; \
	VARIABLE trans1_Control_Cond_PV_type; \
	ARRAY trans1_Control_Cond_PV; \
	MENU trans1_Control_Cond_PV_page; \
	COMMAND trans1_Control_Cond_PV_read; \
	VARIABLE trans1_Control_Cond_CTB_MASTER; \
	MENU trans1_Control_Cond_CTB_MASTER_page; \
	COMMAND trans1_Control_Cond_CTB_MASTER_read; \
	COMMAND trans1_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans1_Control_Cond_SELECTION_type; \
	ARRAY trans1_Control_Cond_SELECTION; \
	MENU trans1_Control_Cond_SELECTION_page; \
	COMMAND trans1_Control_Cond_SELECTION_read; \
	COMMAND trans1_Control_Cond_SELECTION_write; \
	VARIABLE trans1_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans1_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans1_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans1_Control_Cond_CELL_CONSTANT; \
	MENU trans1_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans1_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans1_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans1_Control_Cond_VIEW_2; \
	MENU trans1_Control_Cond_VIEW_2_page; \
	COLLECTION trans1_Control_Cond_VIEW_3; \
	MENU trans1_Control_Cond_VIEW_3_page

#define USE_TRANS1_CONTROL_COND_OPTIONAL_A \
	USE_TRANS1_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans1_Control_Cond_VIEW_1; \
	MENU trans1_Control_Cond_VIEW_1_page; \
	MENU trans1_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS1_CONTROL_COND_OPTIONAL_B \
	USE_TRANS1_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans1_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_CONTROL_COND_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## BLOCK_TYPE; \
	MENU prefix ## BLOCK_TYPE_page; \
	COMMAND prefix ## BLOCK_TYPE_read; \
	COMMAND prefix ## BLOCK_TYPE_write; \
	VARIABLE prefix ## COMMAND; \
	MENU prefix ## COMMAND_page; \
	COMMAND prefix ## COMMAND_read; \
	COMMAND prefix ## COMMAND_write; \
	VARIABLE prefix ## STATUS; \
	MENU prefix ## STATUS_page; \
	COMMAND prefix ## STATUS_read; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	COLLECTION prefix ## SEQUENCE_CONTROL; \
	COLLECTION prefix ## SEQUENCE_CONTROL_Time; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Month; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Years; \
	COLLECTION prefix ## SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Command; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Control_Active; \
	MENU prefix ## SEQUENCE_CONTROL_page; \
	COMMAND prefix ## SEQUENCE_CONTROL_read; \
	COMMAND prefix ## SEQUENCE_CONTROL_write; \
	VARIABLE prefix ## RECIPE; \
	MENU prefix ## RECIPE_page; \
	COMMAND prefix ## RECIPE_read; \
	COMMAND prefix ## RECIPE_write; \
	VARIABLE prefix ## PARAMETER_SET_NUMBER; \
	MENU prefix ## PARAMETER_SET_NUMBER_page; \
	COMMAND prefix ## PARAMETER_SET_NUMBER_read

#define USE_TRANS_CONTROL_COND_MANDATORY_A(prefix) \
	USE_TRANS_CONTROL_COND_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_CONTROL_COND_MANDATORY_B(prefix) \
	USE_TRANS_CONTROL_COND_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_CONTROL_COND_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## QUALITY_type; \
	ARRAY prefix ## QUALITY; \
	MENU prefix ## QUALITY_page; \
	COMMAND prefix ## QUALITY_read; \
	VARIABLE prefix ## SP_type; \
	ARRAY prefix ## SP; \
	MENU prefix ## SP_page; \
	COMMAND prefix ## SP_read; \
	COMMAND prefix ## SP_write; \
	VARIABLE prefix ## PV_type; \
	ARRAY prefix ## PV; \
	MENU prefix ## PV_page; \
	COMMAND prefix ## PV_read; \
	VARIABLE prefix ## CTB_MASTER; \
	MENU prefix ## CTB_MASTER_page; \
	COMMAND prefix ## CTB_MASTER_read; \
	COMMAND prefix ## CTB_MASTER_write; \
	VARIABLE prefix ## SELECTION_type; \
	ARRAY prefix ## SELECTION; \
	MENU prefix ## SELECTION_page; \
	COMMAND prefix ## SELECTION_read; \
	COMMAND prefix ## SELECTION_write; \
	VARIABLE prefix ## NUMBER_PARAMETERS; \
	MENU prefix ## NUMBER_PARAMETERS_page; \
	COMMAND prefix ## NUMBER_PARAMETERS_read; \
	VARIABLE prefix ## CELL_CONSTANT; \
	MENU prefix ## CELL_CONSTANT_page; \
	COMMAND prefix ## CELL_CONSTANT_read; \
	COMMAND prefix ## CELL_CONSTANT_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_CONTROL_COND_OPTIONAL_A(prefix) \
	USE_TRANS_CONTROL_COND_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_CONTROL_COND_OPTIONAL_B(prefix) \
	USE_TRANS_CONTROL_COND_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans1_Control_Cond_)
#define USE_TRANS1_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans1_Control_Cond_)
#define USE_TRANS1_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans1_Control_Cond_)
#define USE_TRANS1_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans1_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans2_Control_Cond_block; \
	COLLECTION trans2_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans2_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans2_Control_Cond_ST_REV; \
	MENU trans2_Control_Cond_ST_REV_page; \
	COMMAND trans2_Control_Cond_ST_REV_read; \
	VARIABLE trans2_Control_Cond_TAG_DESC; \
	MENU trans2_Control_Cond_TAG_DESC_page; \
	COMMAND trans2_Control_Cond_TAG_DESC_read; \
	COMMAND trans2_Control_Cond_TAG_DESC_write; \
	VARIABLE trans2_Control_Cond_STRATEGY; \
	MENU trans2_Control_Cond_STRATEGY_page; \
	COMMAND trans2_Control_Cond_STRATEGY_read; \
	COMMAND trans2_Control_Cond_STRATEGY_write; \
	VARIABLE trans2_Control_Cond_ALERT_KEY; \
	MENU trans2_Control_Cond_ALERT_KEY_page; \
	COMMAND trans2_Control_Cond_ALERT_KEY_read; \
	COMMAND trans2_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans2_Control_Cond_TARGET_MODE; \
	MENU trans2_Control_Cond_TARGET_MODE_page; \
	COMMAND trans2_Control_Cond_TARGET_MODE_read; \
	COMMAND trans2_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans2_Control_Cond_MODE_BLK; \
	VARIABLE trans2_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans2_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans2_Control_Cond_MODE_BLK_Normal; \
	MENU trans2_Control_Cond_MODE_BLK_page; \
	COMMAND trans2_Control_Cond_MODE_BLK_read; \
	COLLECTION trans2_Control_Cond_ALARM_SUM; \
	VARIABLE trans2_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans2_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans2_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans2_Control_Cond_ALARM_SUM_page; \
	COMMAND trans2_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans2_Control_Cond_BLOCK_TYPE; \
	MENU trans2_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans2_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans2_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans2_Control_Cond_COMMAND; \
	MENU trans2_Control_Cond_COMMAND_page; \
	COMMAND trans2_Control_Cond_COMMAND_read; \
	COMMAND trans2_Control_Cond_COMMAND_write; \
	VARIABLE trans2_Control_Cond_STATUS; \
	MENU trans2_Control_Cond_STATUS_page; \
	COMMAND trans2_Control_Cond_STATUS_read; \
	VARIABLE trans2_Control_Cond_CHANNEL; \
	MENU trans2_Control_Cond_CHANNEL_page; \
	COMMAND trans2_Control_Cond_CHANNEL_read; \
	COMMAND trans2_Control_Cond_CHANNEL_write; \
	COLLECTION trans2_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans2_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans2_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans2_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans2_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans2_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans2_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans2_Control_Cond_RECIPE; \
	MENU trans2_Control_Cond_RECIPE_page; \
	COMMAND trans2_Control_Cond_RECIPE_read; \
	COMMAND trans2_Control_Cond_RECIPE_write; \
	VARIABLE trans2_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans2_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans2_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS2_CONTROL_COND_MANDATORY_A \
	USE_TRANS2_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans2_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS2_CONTROL_COND_MANDATORY_B \
	USE_TRANS2_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans2_Control_Cond_VIEW_1; \
	MENU trans2_Control_Cond_VIEW_1_page; \
	MENU trans2_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS2_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans2_Control_Cond_QUALITY_type; \
	ARRAY trans2_Control_Cond_QUALITY; \
	MENU trans2_Control_Cond_QUALITY_page; \
	COMMAND trans2_Control_Cond_QUALITY_read; \
	VARIABLE trans2_Control_Cond_SP_type; \
	ARRAY trans2_Control_Cond_SP; \
	MENU trans2_Control_Cond_SP_page; \
	COMMAND trans2_Control_Cond_SP_read; \
	COMMAND trans2_Control_Cond_SP_write; \
	VARIABLE trans2_Control_Cond_PV_type; \
	ARRAY trans2_Control_Cond_PV; \
	MENU trans2_Control_Cond_PV_page; \
	COMMAND trans2_Control_Cond_PV_read; \
	VARIABLE trans2_Control_Cond_CTB_MASTER; \
	MENU trans2_Control_Cond_CTB_MASTER_page; \
	COMMAND trans2_Control_Cond_CTB_MASTER_read; \
	COMMAND trans2_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans2_Control_Cond_SELECTION_type; \
	ARRAY trans2_Control_Cond_SELECTION; \
	MENU trans2_Control_Cond_SELECTION_page; \
	COMMAND trans2_Control_Cond_SELECTION_read; \
	COMMAND trans2_Control_Cond_SELECTION_write; \
	VARIABLE trans2_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans2_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans2_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans2_Control_Cond_CELL_CONSTANT; \
	MENU trans2_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans2_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans2_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans2_Control_Cond_VIEW_2; \
	MENU trans2_Control_Cond_VIEW_2_page; \
	COLLECTION trans2_Control_Cond_VIEW_3; \
	MENU trans2_Control_Cond_VIEW_3_page

#define USE_TRANS2_CONTROL_COND_OPTIONAL_A \
	USE_TRANS2_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans2_Control_Cond_VIEW_1; \
	MENU trans2_Control_Cond_VIEW_1_page; \
	MENU trans2_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS2_CONTROL_COND_OPTIONAL_B \
	USE_TRANS2_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans2_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans2_Control_Cond_)
#define USE_TRANS2_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans2_Control_Cond_)
#define USE_TRANS2_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans2_Control_Cond_)
#define USE_TRANS2_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans2_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans3_Control_Cond_block; \
	COLLECTION trans3_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans3_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans3_Control_Cond_ST_REV; \
	MENU trans3_Control_Cond_ST_REV_page; \
	COMMAND trans3_Control_Cond_ST_REV_read; \
	VARIABLE trans3_Control_Cond_TAG_DESC; \
	MENU trans3_Control_Cond_TAG_DESC_page; \
	COMMAND trans3_Control_Cond_TAG_DESC_read; \
	COMMAND trans3_Control_Cond_TAG_DESC_write; \
	VARIABLE trans3_Control_Cond_STRATEGY; \
	MENU trans3_Control_Cond_STRATEGY_page; \
	COMMAND trans3_Control_Cond_STRATEGY_read; \
	COMMAND trans3_Control_Cond_STRATEGY_write; \
	VARIABLE trans3_Control_Cond_ALERT_KEY; \
	MENU trans3_Control_Cond_ALERT_KEY_page; \
	COMMAND trans3_Control_Cond_ALERT_KEY_read; \
	COMMAND trans3_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans3_Control_Cond_TARGET_MODE; \
	MENU trans3_Control_Cond_TARGET_MODE_page; \
	COMMAND trans3_Control_Cond_TARGET_MODE_read; \
	COMMAND trans3_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans3_Control_Cond_MODE_BLK; \
	VARIABLE trans3_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans3_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans3_Control_Cond_MODE_BLK_Normal; \
	MENU trans3_Control_Cond_MODE_BLK_page; \
	COMMAND trans3_Control_Cond_MODE_BLK_read; \
	COLLECTION trans3_Control_Cond_ALARM_SUM; \
	VARIABLE trans3_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans3_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans3_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans3_Control_Cond_ALARM_SUM_page; \
	COMMAND trans3_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans3_Control_Cond_BLOCK_TYPE; \
	MENU trans3_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans3_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans3_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans3_Control_Cond_COMMAND; \
	MENU trans3_Control_Cond_COMMAND_page; \
	COMMAND trans3_Control_Cond_COMMAND_read; \
	COMMAND trans3_Control_Cond_COMMAND_write; \
	VARIABLE trans3_Control_Cond_STATUS; \
	MENU trans3_Control_Cond_STATUS_page; \
	COMMAND trans3_Control_Cond_STATUS_read; \
	VARIABLE trans3_Control_Cond_CHANNEL; \
	MENU trans3_Control_Cond_CHANNEL_page; \
	COMMAND trans3_Control_Cond_CHANNEL_read; \
	COMMAND trans3_Control_Cond_CHANNEL_write; \
	COLLECTION trans3_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans3_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans3_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans3_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans3_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans3_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans3_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans3_Control_Cond_RECIPE; \
	MENU trans3_Control_Cond_RECIPE_page; \
	COMMAND trans3_Control_Cond_RECIPE_read; \
	COMMAND trans3_Control_Cond_RECIPE_write; \
	VARIABLE trans3_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans3_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans3_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS3_CONTROL_COND_MANDATORY_A \
	USE_TRANS3_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans3_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS3_CONTROL_COND_MANDATORY_B \
	USE_TRANS3_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans3_Control_Cond_VIEW_1; \
	MENU trans3_Control_Cond_VIEW_1_page; \
	MENU trans3_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS3_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans3_Control_Cond_QUALITY_type; \
	ARRAY trans3_Control_Cond_QUALITY; \
	MENU trans3_Control_Cond_QUALITY_page; \
	COMMAND trans3_Control_Cond_QUALITY_read; \
	VARIABLE trans3_Control_Cond_SP_type; \
	ARRAY trans3_Control_Cond_SP; \
	MENU trans3_Control_Cond_SP_page; \
	COMMAND trans3_Control_Cond_SP_read; \
	COMMAND trans3_Control_Cond_SP_write; \
	VARIABLE trans3_Control_Cond_PV_type; \
	ARRAY trans3_Control_Cond_PV; \
	MENU trans3_Control_Cond_PV_page; \
	COMMAND trans3_Control_Cond_PV_read; \
	VARIABLE trans3_Control_Cond_CTB_MASTER; \
	MENU trans3_Control_Cond_CTB_MASTER_page; \
	COMMAND trans3_Control_Cond_CTB_MASTER_read; \
	COMMAND trans3_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans3_Control_Cond_SELECTION_type; \
	ARRAY trans3_Control_Cond_SELECTION; \
	MENU trans3_Control_Cond_SELECTION_page; \
	COMMAND trans3_Control_Cond_SELECTION_read; \
	COMMAND trans3_Control_Cond_SELECTION_write; \
	VARIABLE trans3_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans3_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans3_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans3_Control_Cond_CELL_CONSTANT; \
	MENU trans3_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans3_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans3_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans3_Control_Cond_VIEW_2; \
	MENU trans3_Control_Cond_VIEW_2_page; \
	COLLECTION trans3_Control_Cond_VIEW_3; \
	MENU trans3_Control_Cond_VIEW_3_page

#define USE_TRANS3_CONTROL_COND_OPTIONAL_A \
	USE_TRANS3_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans3_Control_Cond_VIEW_1; \
	MENU trans3_Control_Cond_VIEW_1_page; \
	MENU trans3_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS3_CONTROL_COND_OPTIONAL_B \
	USE_TRANS3_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans3_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans3_Control_Cond_)
#define USE_TRANS3_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans3_Control_Cond_)
#define USE_TRANS3_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans3_Control_Cond_)
#define USE_TRANS3_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans3_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans4_Control_Cond_block; \
	COLLECTION trans4_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans4_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans4_Control_Cond_ST_REV; \
	MENU trans4_Control_Cond_ST_REV_page; \
	COMMAND trans4_Control_Cond_ST_REV_read; \
	VARIABLE trans4_Control_Cond_TAG_DESC; \
	MENU trans4_Control_Cond_TAG_DESC_page; \
	COMMAND trans4_Control_Cond_TAG_DESC_read; \
	COMMAND trans4_Control_Cond_TAG_DESC_write; \
	VARIABLE trans4_Control_Cond_STRATEGY; \
	MENU trans4_Control_Cond_STRATEGY_page; \
	COMMAND trans4_Control_Cond_STRATEGY_read; \
	COMMAND trans4_Control_Cond_STRATEGY_write; \
	VARIABLE trans4_Control_Cond_ALERT_KEY; \
	MENU trans4_Control_Cond_ALERT_KEY_page; \
	COMMAND trans4_Control_Cond_ALERT_KEY_read; \
	COMMAND trans4_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans4_Control_Cond_TARGET_MODE; \
	MENU trans4_Control_Cond_TARGET_MODE_page; \
	COMMAND trans4_Control_Cond_TARGET_MODE_read; \
	COMMAND trans4_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans4_Control_Cond_MODE_BLK; \
	VARIABLE trans4_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans4_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans4_Control_Cond_MODE_BLK_Normal; \
	MENU trans4_Control_Cond_MODE_BLK_page; \
	COMMAND trans4_Control_Cond_MODE_BLK_read; \
	COLLECTION trans4_Control_Cond_ALARM_SUM; \
	VARIABLE trans4_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans4_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans4_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans4_Control_Cond_ALARM_SUM_page; \
	COMMAND trans4_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans4_Control_Cond_BLOCK_TYPE; \
	MENU trans4_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans4_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans4_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans4_Control_Cond_COMMAND; \
	MENU trans4_Control_Cond_COMMAND_page; \
	COMMAND trans4_Control_Cond_COMMAND_read; \
	COMMAND trans4_Control_Cond_COMMAND_write; \
	VARIABLE trans4_Control_Cond_STATUS; \
	MENU trans4_Control_Cond_STATUS_page; \
	COMMAND trans4_Control_Cond_STATUS_read; \
	VARIABLE trans4_Control_Cond_CHANNEL; \
	MENU trans4_Control_Cond_CHANNEL_page; \
	COMMAND trans4_Control_Cond_CHANNEL_read; \
	COMMAND trans4_Control_Cond_CHANNEL_write; \
	COLLECTION trans4_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans4_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans4_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans4_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans4_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans4_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans4_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans4_Control_Cond_RECIPE; \
	MENU trans4_Control_Cond_RECIPE_page; \
	COMMAND trans4_Control_Cond_RECIPE_read; \
	COMMAND trans4_Control_Cond_RECIPE_write; \
	VARIABLE trans4_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans4_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans4_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS4_CONTROL_COND_MANDATORY_A \
	USE_TRANS4_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans4_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS4_CONTROL_COND_MANDATORY_B \
	USE_TRANS4_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans4_Control_Cond_VIEW_1; \
	MENU trans4_Control_Cond_VIEW_1_page; \
	MENU trans4_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS4_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans4_Control_Cond_QUALITY_type; \
	ARRAY trans4_Control_Cond_QUALITY; \
	MENU trans4_Control_Cond_QUALITY_page; \
	COMMAND trans4_Control_Cond_QUALITY_read; \
	VARIABLE trans4_Control_Cond_SP_type; \
	ARRAY trans4_Control_Cond_SP; \
	MENU trans4_Control_Cond_SP_page; \
	COMMAND trans4_Control_Cond_SP_read; \
	COMMAND trans4_Control_Cond_SP_write; \
	VARIABLE trans4_Control_Cond_PV_type; \
	ARRAY trans4_Control_Cond_PV; \
	MENU trans4_Control_Cond_PV_page; \
	COMMAND trans4_Control_Cond_PV_read; \
	VARIABLE trans4_Control_Cond_CTB_MASTER; \
	MENU trans4_Control_Cond_CTB_MASTER_page; \
	COMMAND trans4_Control_Cond_CTB_MASTER_read; \
	COMMAND trans4_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans4_Control_Cond_SELECTION_type; \
	ARRAY trans4_Control_Cond_SELECTION; \
	MENU trans4_Control_Cond_SELECTION_page; \
	COMMAND trans4_Control_Cond_SELECTION_read; \
	COMMAND trans4_Control_Cond_SELECTION_write; \
	VARIABLE trans4_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans4_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans4_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans4_Control_Cond_CELL_CONSTANT; \
	MENU trans4_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans4_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans4_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans4_Control_Cond_VIEW_2; \
	MENU trans4_Control_Cond_VIEW_2_page; \
	COLLECTION trans4_Control_Cond_VIEW_3; \
	MENU trans4_Control_Cond_VIEW_3_page

#define USE_TRANS4_CONTROL_COND_OPTIONAL_A \
	USE_TRANS4_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans4_Control_Cond_VIEW_1; \
	MENU trans4_Control_Cond_VIEW_1_page; \
	MENU trans4_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS4_CONTROL_COND_OPTIONAL_B \
	USE_TRANS4_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans4_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans4_Control_Cond_)
#define USE_TRANS4_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans4_Control_Cond_)
#define USE_TRANS4_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans4_Control_Cond_)
#define USE_TRANS4_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans4_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans5_Control_Cond_block; \
	COLLECTION trans5_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans5_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans5_Control_Cond_ST_REV; \
	MENU trans5_Control_Cond_ST_REV_page; \
	COMMAND trans5_Control_Cond_ST_REV_read; \
	VARIABLE trans5_Control_Cond_TAG_DESC; \
	MENU trans5_Control_Cond_TAG_DESC_page; \
	COMMAND trans5_Control_Cond_TAG_DESC_read; \
	COMMAND trans5_Control_Cond_TAG_DESC_write; \
	VARIABLE trans5_Control_Cond_STRATEGY; \
	MENU trans5_Control_Cond_STRATEGY_page; \
	COMMAND trans5_Control_Cond_STRATEGY_read; \
	COMMAND trans5_Control_Cond_STRATEGY_write; \
	VARIABLE trans5_Control_Cond_ALERT_KEY; \
	MENU trans5_Control_Cond_ALERT_KEY_page; \
	COMMAND trans5_Control_Cond_ALERT_KEY_read; \
	COMMAND trans5_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans5_Control_Cond_TARGET_MODE; \
	MENU trans5_Control_Cond_TARGET_MODE_page; \
	COMMAND trans5_Control_Cond_TARGET_MODE_read; \
	COMMAND trans5_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans5_Control_Cond_MODE_BLK; \
	VARIABLE trans5_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans5_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans5_Control_Cond_MODE_BLK_Normal; \
	MENU trans5_Control_Cond_MODE_BLK_page; \
	COMMAND trans5_Control_Cond_MODE_BLK_read; \
	COLLECTION trans5_Control_Cond_ALARM_SUM; \
	VARIABLE trans5_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans5_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans5_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans5_Control_Cond_ALARM_SUM_page; \
	COMMAND trans5_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans5_Control_Cond_BLOCK_TYPE; \
	MENU trans5_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans5_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans5_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans5_Control_Cond_COMMAND; \
	MENU trans5_Control_Cond_COMMAND_page; \
	COMMAND trans5_Control_Cond_COMMAND_read; \
	COMMAND trans5_Control_Cond_COMMAND_write; \
	VARIABLE trans5_Control_Cond_STATUS; \
	MENU trans5_Control_Cond_STATUS_page; \
	COMMAND trans5_Control_Cond_STATUS_read; \
	VARIABLE trans5_Control_Cond_CHANNEL; \
	MENU trans5_Control_Cond_CHANNEL_page; \
	COMMAND trans5_Control_Cond_CHANNEL_read; \
	COMMAND trans5_Control_Cond_CHANNEL_write; \
	COLLECTION trans5_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans5_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans5_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans5_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans5_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans5_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans5_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans5_Control_Cond_RECIPE; \
	MENU trans5_Control_Cond_RECIPE_page; \
	COMMAND trans5_Control_Cond_RECIPE_read; \
	COMMAND trans5_Control_Cond_RECIPE_write; \
	VARIABLE trans5_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans5_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans5_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS5_CONTROL_COND_MANDATORY_A \
	USE_TRANS5_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans5_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS5_CONTROL_COND_MANDATORY_B \
	USE_TRANS5_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans5_Control_Cond_VIEW_1; \
	MENU trans5_Control_Cond_VIEW_1_page; \
	MENU trans5_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS5_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans5_Control_Cond_QUALITY_type; \
	ARRAY trans5_Control_Cond_QUALITY; \
	MENU trans5_Control_Cond_QUALITY_page; \
	COMMAND trans5_Control_Cond_QUALITY_read; \
	VARIABLE trans5_Control_Cond_SP_type; \
	ARRAY trans5_Control_Cond_SP; \
	MENU trans5_Control_Cond_SP_page; \
	COMMAND trans5_Control_Cond_SP_read; \
	COMMAND trans5_Control_Cond_SP_write; \
	VARIABLE trans5_Control_Cond_PV_type; \
	ARRAY trans5_Control_Cond_PV; \
	MENU trans5_Control_Cond_PV_page; \
	COMMAND trans5_Control_Cond_PV_read; \
	VARIABLE trans5_Control_Cond_CTB_MASTER; \
	MENU trans5_Control_Cond_CTB_MASTER_page; \
	COMMAND trans5_Control_Cond_CTB_MASTER_read; \
	COMMAND trans5_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans5_Control_Cond_SELECTION_type; \
	ARRAY trans5_Control_Cond_SELECTION; \
	MENU trans5_Control_Cond_SELECTION_page; \
	COMMAND trans5_Control_Cond_SELECTION_read; \
	COMMAND trans5_Control_Cond_SELECTION_write; \
	VARIABLE trans5_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans5_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans5_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans5_Control_Cond_CELL_CONSTANT; \
	MENU trans5_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans5_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans5_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans5_Control_Cond_VIEW_2; \
	MENU trans5_Control_Cond_VIEW_2_page; \
	COLLECTION trans5_Control_Cond_VIEW_3; \
	MENU trans5_Control_Cond_VIEW_3_page

#define USE_TRANS5_CONTROL_COND_OPTIONAL_A \
	USE_TRANS5_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans5_Control_Cond_VIEW_1; \
	MENU trans5_Control_Cond_VIEW_1_page; \
	MENU trans5_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS5_CONTROL_COND_OPTIONAL_B \
	USE_TRANS5_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans5_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans5_Control_Cond_)
#define USE_TRANS5_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans5_Control_Cond_)
#define USE_TRANS5_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans5_Control_Cond_)
#define USE_TRANS5_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans5_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans6_Control_Cond_block; \
	COLLECTION trans6_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans6_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans6_Control_Cond_ST_REV; \
	MENU trans6_Control_Cond_ST_REV_page; \
	COMMAND trans6_Control_Cond_ST_REV_read; \
	VARIABLE trans6_Control_Cond_TAG_DESC; \
	MENU trans6_Control_Cond_TAG_DESC_page; \
	COMMAND trans6_Control_Cond_TAG_DESC_read; \
	COMMAND trans6_Control_Cond_TAG_DESC_write; \
	VARIABLE trans6_Control_Cond_STRATEGY; \
	MENU trans6_Control_Cond_STRATEGY_page; \
	COMMAND trans6_Control_Cond_STRATEGY_read; \
	COMMAND trans6_Control_Cond_STRATEGY_write; \
	VARIABLE trans6_Control_Cond_ALERT_KEY; \
	MENU trans6_Control_Cond_ALERT_KEY_page; \
	COMMAND trans6_Control_Cond_ALERT_KEY_read; \
	COMMAND trans6_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans6_Control_Cond_TARGET_MODE; \
	MENU trans6_Control_Cond_TARGET_MODE_page; \
	COMMAND trans6_Control_Cond_TARGET_MODE_read; \
	COMMAND trans6_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans6_Control_Cond_MODE_BLK; \
	VARIABLE trans6_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans6_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans6_Control_Cond_MODE_BLK_Normal; \
	MENU trans6_Control_Cond_MODE_BLK_page; \
	COMMAND trans6_Control_Cond_MODE_BLK_read; \
	COLLECTION trans6_Control_Cond_ALARM_SUM; \
	VARIABLE trans6_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans6_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans6_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans6_Control_Cond_ALARM_SUM_page; \
	COMMAND trans6_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans6_Control_Cond_BLOCK_TYPE; \
	MENU trans6_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans6_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans6_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans6_Control_Cond_COMMAND; \
	MENU trans6_Control_Cond_COMMAND_page; \
	COMMAND trans6_Control_Cond_COMMAND_read; \
	COMMAND trans6_Control_Cond_COMMAND_write; \
	VARIABLE trans6_Control_Cond_STATUS; \
	MENU trans6_Control_Cond_STATUS_page; \
	COMMAND trans6_Control_Cond_STATUS_read; \
	VARIABLE trans6_Control_Cond_CHANNEL; \
	MENU trans6_Control_Cond_CHANNEL_page; \
	COMMAND trans6_Control_Cond_CHANNEL_read; \
	COMMAND trans6_Control_Cond_CHANNEL_write; \
	COLLECTION trans6_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans6_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans6_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans6_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans6_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans6_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans6_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans6_Control_Cond_RECIPE; \
	MENU trans6_Control_Cond_RECIPE_page; \
	COMMAND trans6_Control_Cond_RECIPE_read; \
	COMMAND trans6_Control_Cond_RECIPE_write; \
	VARIABLE trans6_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans6_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans6_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS6_CONTROL_COND_MANDATORY_A \
	USE_TRANS6_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans6_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS6_CONTROL_COND_MANDATORY_B \
	USE_TRANS6_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans6_Control_Cond_VIEW_1; \
	MENU trans6_Control_Cond_VIEW_1_page; \
	MENU trans6_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS6_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans6_Control_Cond_QUALITY_type; \
	ARRAY trans6_Control_Cond_QUALITY; \
	MENU trans6_Control_Cond_QUALITY_page; \
	COMMAND trans6_Control_Cond_QUALITY_read; \
	VARIABLE trans6_Control_Cond_SP_type; \
	ARRAY trans6_Control_Cond_SP; \
	MENU trans6_Control_Cond_SP_page; \
	COMMAND trans6_Control_Cond_SP_read; \
	COMMAND trans6_Control_Cond_SP_write; \
	VARIABLE trans6_Control_Cond_PV_type; \
	ARRAY trans6_Control_Cond_PV; \
	MENU trans6_Control_Cond_PV_page; \
	COMMAND trans6_Control_Cond_PV_read; \
	VARIABLE trans6_Control_Cond_CTB_MASTER; \
	MENU trans6_Control_Cond_CTB_MASTER_page; \
	COMMAND trans6_Control_Cond_CTB_MASTER_read; \
	COMMAND trans6_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans6_Control_Cond_SELECTION_type; \
	ARRAY trans6_Control_Cond_SELECTION; \
	MENU trans6_Control_Cond_SELECTION_page; \
	COMMAND trans6_Control_Cond_SELECTION_read; \
	COMMAND trans6_Control_Cond_SELECTION_write; \
	VARIABLE trans6_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans6_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans6_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans6_Control_Cond_CELL_CONSTANT; \
	MENU trans6_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans6_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans6_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans6_Control_Cond_VIEW_2; \
	MENU trans6_Control_Cond_VIEW_2_page; \
	COLLECTION trans6_Control_Cond_VIEW_3; \
	MENU trans6_Control_Cond_VIEW_3_page

#define USE_TRANS6_CONTROL_COND_OPTIONAL_A \
	USE_TRANS6_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans6_Control_Cond_VIEW_1; \
	MENU trans6_Control_Cond_VIEW_1_page; \
	MENU trans6_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS6_CONTROL_COND_OPTIONAL_B \
	USE_TRANS6_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans6_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans6_Control_Cond_)
#define USE_TRANS6_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans6_Control_Cond_)
#define USE_TRANS6_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans6_Control_Cond_)
#define USE_TRANS6_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans6_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans7_Control_Cond_block; \
	COLLECTION trans7_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans7_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans7_Control_Cond_ST_REV; \
	MENU trans7_Control_Cond_ST_REV_page; \
	COMMAND trans7_Control_Cond_ST_REV_read; \
	VARIABLE trans7_Control_Cond_TAG_DESC; \
	MENU trans7_Control_Cond_TAG_DESC_page; \
	COMMAND trans7_Control_Cond_TAG_DESC_read; \
	COMMAND trans7_Control_Cond_TAG_DESC_write; \
	VARIABLE trans7_Control_Cond_STRATEGY; \
	MENU trans7_Control_Cond_STRATEGY_page; \
	COMMAND trans7_Control_Cond_STRATEGY_read; \
	COMMAND trans7_Control_Cond_STRATEGY_write; \
	VARIABLE trans7_Control_Cond_ALERT_KEY; \
	MENU trans7_Control_Cond_ALERT_KEY_page; \
	COMMAND trans7_Control_Cond_ALERT_KEY_read; \
	COMMAND trans7_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans7_Control_Cond_TARGET_MODE; \
	MENU trans7_Control_Cond_TARGET_MODE_page; \
	COMMAND trans7_Control_Cond_TARGET_MODE_read; \
	COMMAND trans7_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans7_Control_Cond_MODE_BLK; \
	VARIABLE trans7_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans7_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans7_Control_Cond_MODE_BLK_Normal; \
	MENU trans7_Control_Cond_MODE_BLK_page; \
	COMMAND trans7_Control_Cond_MODE_BLK_read; \
	COLLECTION trans7_Control_Cond_ALARM_SUM; \
	VARIABLE trans7_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans7_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans7_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans7_Control_Cond_ALARM_SUM_page; \
	COMMAND trans7_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans7_Control_Cond_BLOCK_TYPE; \
	MENU trans7_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans7_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans7_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans7_Control_Cond_COMMAND; \
	MENU trans7_Control_Cond_COMMAND_page; \
	COMMAND trans7_Control_Cond_COMMAND_read; \
	COMMAND trans7_Control_Cond_COMMAND_write; \
	VARIABLE trans7_Control_Cond_STATUS; \
	MENU trans7_Control_Cond_STATUS_page; \
	COMMAND trans7_Control_Cond_STATUS_read; \
	VARIABLE trans7_Control_Cond_CHANNEL; \
	MENU trans7_Control_Cond_CHANNEL_page; \
	COMMAND trans7_Control_Cond_CHANNEL_read; \
	COMMAND trans7_Control_Cond_CHANNEL_write; \
	COLLECTION trans7_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans7_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans7_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans7_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans7_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans7_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans7_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans7_Control_Cond_RECIPE; \
	MENU trans7_Control_Cond_RECIPE_page; \
	COMMAND trans7_Control_Cond_RECIPE_read; \
	COMMAND trans7_Control_Cond_RECIPE_write; \
	VARIABLE trans7_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans7_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans7_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS7_CONTROL_COND_MANDATORY_A \
	USE_TRANS7_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans7_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS7_CONTROL_COND_MANDATORY_B \
	USE_TRANS7_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans7_Control_Cond_VIEW_1; \
	MENU trans7_Control_Cond_VIEW_1_page; \
	MENU trans7_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS7_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans7_Control_Cond_QUALITY_type; \
	ARRAY trans7_Control_Cond_QUALITY; \
	MENU trans7_Control_Cond_QUALITY_page; \
	COMMAND trans7_Control_Cond_QUALITY_read; \
	VARIABLE trans7_Control_Cond_SP_type; \
	ARRAY trans7_Control_Cond_SP; \
	MENU trans7_Control_Cond_SP_page; \
	COMMAND trans7_Control_Cond_SP_read; \
	COMMAND trans7_Control_Cond_SP_write; \
	VARIABLE trans7_Control_Cond_PV_type; \
	ARRAY trans7_Control_Cond_PV; \
	MENU trans7_Control_Cond_PV_page; \
	COMMAND trans7_Control_Cond_PV_read; \
	VARIABLE trans7_Control_Cond_CTB_MASTER; \
	MENU trans7_Control_Cond_CTB_MASTER_page; \
	COMMAND trans7_Control_Cond_CTB_MASTER_read; \
	COMMAND trans7_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans7_Control_Cond_SELECTION_type; \
	ARRAY trans7_Control_Cond_SELECTION; \
	MENU trans7_Control_Cond_SELECTION_page; \
	COMMAND trans7_Control_Cond_SELECTION_read; \
	COMMAND trans7_Control_Cond_SELECTION_write; \
	VARIABLE trans7_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans7_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans7_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans7_Control_Cond_CELL_CONSTANT; \
	MENU trans7_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans7_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans7_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans7_Control_Cond_VIEW_2; \
	MENU trans7_Control_Cond_VIEW_2_page; \
	COLLECTION trans7_Control_Cond_VIEW_3; \
	MENU trans7_Control_Cond_VIEW_3_page

#define USE_TRANS7_CONTROL_COND_OPTIONAL_A \
	USE_TRANS7_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans7_Control_Cond_VIEW_1; \
	MENU trans7_Control_Cond_VIEW_1_page; \
	MENU trans7_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS7_CONTROL_COND_OPTIONAL_B \
	USE_TRANS7_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans7_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans7_Control_Cond_)
#define USE_TRANS7_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans7_Control_Cond_)
#define USE_TRANS7_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans7_Control_Cond_)
#define USE_TRANS7_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans7_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans8_Control_Cond_block; \
	COLLECTION trans8_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans8_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans8_Control_Cond_ST_REV; \
	MENU trans8_Control_Cond_ST_REV_page; \
	COMMAND trans8_Control_Cond_ST_REV_read; \
	VARIABLE trans8_Control_Cond_TAG_DESC; \
	MENU trans8_Control_Cond_TAG_DESC_page; \
	COMMAND trans8_Control_Cond_TAG_DESC_read; \
	COMMAND trans8_Control_Cond_TAG_DESC_write; \
	VARIABLE trans8_Control_Cond_STRATEGY; \
	MENU trans8_Control_Cond_STRATEGY_page; \
	COMMAND trans8_Control_Cond_STRATEGY_read; \
	COMMAND trans8_Control_Cond_STRATEGY_write; \
	VARIABLE trans8_Control_Cond_ALERT_KEY; \
	MENU trans8_Control_Cond_ALERT_KEY_page; \
	COMMAND trans8_Control_Cond_ALERT_KEY_read; \
	COMMAND trans8_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans8_Control_Cond_TARGET_MODE; \
	MENU trans8_Control_Cond_TARGET_MODE_page; \
	COMMAND trans8_Control_Cond_TARGET_MODE_read; \
	COMMAND trans8_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans8_Control_Cond_MODE_BLK; \
	VARIABLE trans8_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans8_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans8_Control_Cond_MODE_BLK_Normal; \
	MENU trans8_Control_Cond_MODE_BLK_page; \
	COMMAND trans8_Control_Cond_MODE_BLK_read; \
	COLLECTION trans8_Control_Cond_ALARM_SUM; \
	VARIABLE trans8_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans8_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans8_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans8_Control_Cond_ALARM_SUM_page; \
	COMMAND trans8_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans8_Control_Cond_BLOCK_TYPE; \
	MENU trans8_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans8_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans8_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans8_Control_Cond_COMMAND; \
	MENU trans8_Control_Cond_COMMAND_page; \
	COMMAND trans8_Control_Cond_COMMAND_read; \
	COMMAND trans8_Control_Cond_COMMAND_write; \
	VARIABLE trans8_Control_Cond_STATUS; \
	MENU trans8_Control_Cond_STATUS_page; \
	COMMAND trans8_Control_Cond_STATUS_read; \
	VARIABLE trans8_Control_Cond_CHANNEL; \
	MENU trans8_Control_Cond_CHANNEL_page; \
	COMMAND trans8_Control_Cond_CHANNEL_read; \
	COMMAND trans8_Control_Cond_CHANNEL_write; \
	COLLECTION trans8_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans8_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans8_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans8_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans8_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans8_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans8_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans8_Control_Cond_RECIPE; \
	MENU trans8_Control_Cond_RECIPE_page; \
	COMMAND trans8_Control_Cond_RECIPE_read; \
	COMMAND trans8_Control_Cond_RECIPE_write; \
	VARIABLE trans8_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans8_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans8_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS8_CONTROL_COND_MANDATORY_A \
	USE_TRANS8_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans8_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS8_CONTROL_COND_MANDATORY_B \
	USE_TRANS8_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans8_Control_Cond_VIEW_1; \
	MENU trans8_Control_Cond_VIEW_1_page; \
	MENU trans8_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS8_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans8_Control_Cond_QUALITY_type; \
	ARRAY trans8_Control_Cond_QUALITY; \
	MENU trans8_Control_Cond_QUALITY_page; \
	COMMAND trans8_Control_Cond_QUALITY_read; \
	VARIABLE trans8_Control_Cond_SP_type; \
	ARRAY trans8_Control_Cond_SP; \
	MENU trans8_Control_Cond_SP_page; \
	COMMAND trans8_Control_Cond_SP_read; \
	COMMAND trans8_Control_Cond_SP_write; \
	VARIABLE trans8_Control_Cond_PV_type; \
	ARRAY trans8_Control_Cond_PV; \
	MENU trans8_Control_Cond_PV_page; \
	COMMAND trans8_Control_Cond_PV_read; \
	VARIABLE trans8_Control_Cond_CTB_MASTER; \
	MENU trans8_Control_Cond_CTB_MASTER_page; \
	COMMAND trans8_Control_Cond_CTB_MASTER_read; \
	COMMAND trans8_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans8_Control_Cond_SELECTION_type; \
	ARRAY trans8_Control_Cond_SELECTION; \
	MENU trans8_Control_Cond_SELECTION_page; \
	COMMAND trans8_Control_Cond_SELECTION_read; \
	COMMAND trans8_Control_Cond_SELECTION_write; \
	VARIABLE trans8_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans8_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans8_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans8_Control_Cond_CELL_CONSTANT; \
	MENU trans8_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans8_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans8_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans8_Control_Cond_VIEW_2; \
	MENU trans8_Control_Cond_VIEW_2_page; \
	COLLECTION trans8_Control_Cond_VIEW_3; \
	MENU trans8_Control_Cond_VIEW_3_page

#define USE_TRANS8_CONTROL_COND_OPTIONAL_A \
	USE_TRANS8_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans8_Control_Cond_VIEW_1; \
	MENU trans8_Control_Cond_VIEW_1_page; \
	MENU trans8_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS8_CONTROL_COND_OPTIONAL_B \
	USE_TRANS8_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans8_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans8_Control_Cond_)
#define USE_TRANS8_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans8_Control_Cond_)
#define USE_TRANS8_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans8_Control_Cond_)
#define USE_TRANS8_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans8_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans9_Control_Cond_block; \
	COLLECTION trans9_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans9_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans9_Control_Cond_ST_REV; \
	MENU trans9_Control_Cond_ST_REV_page; \
	COMMAND trans9_Control_Cond_ST_REV_read; \
	VARIABLE trans9_Control_Cond_TAG_DESC; \
	MENU trans9_Control_Cond_TAG_DESC_page; \
	COMMAND trans9_Control_Cond_TAG_DESC_read; \
	COMMAND trans9_Control_Cond_TAG_DESC_write; \
	VARIABLE trans9_Control_Cond_STRATEGY; \
	MENU trans9_Control_Cond_STRATEGY_page; \
	COMMAND trans9_Control_Cond_STRATEGY_read; \
	COMMAND trans9_Control_Cond_STRATEGY_write; \
	VARIABLE trans9_Control_Cond_ALERT_KEY; \
	MENU trans9_Control_Cond_ALERT_KEY_page; \
	COMMAND trans9_Control_Cond_ALERT_KEY_read; \
	COMMAND trans9_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans9_Control_Cond_TARGET_MODE; \
	MENU trans9_Control_Cond_TARGET_MODE_page; \
	COMMAND trans9_Control_Cond_TARGET_MODE_read; \
	COMMAND trans9_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans9_Control_Cond_MODE_BLK; \
	VARIABLE trans9_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans9_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans9_Control_Cond_MODE_BLK_Normal; \
	MENU trans9_Control_Cond_MODE_BLK_page; \
	COMMAND trans9_Control_Cond_MODE_BLK_read; \
	COLLECTION trans9_Control_Cond_ALARM_SUM; \
	VARIABLE trans9_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans9_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans9_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans9_Control_Cond_ALARM_SUM_page; \
	COMMAND trans9_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans9_Control_Cond_BLOCK_TYPE; \
	MENU trans9_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans9_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans9_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans9_Control_Cond_COMMAND; \
	MENU trans9_Control_Cond_COMMAND_page; \
	COMMAND trans9_Control_Cond_COMMAND_read; \
	COMMAND trans9_Control_Cond_COMMAND_write; \
	VARIABLE trans9_Control_Cond_STATUS; \
	MENU trans9_Control_Cond_STATUS_page; \
	COMMAND trans9_Control_Cond_STATUS_read; \
	VARIABLE trans9_Control_Cond_CHANNEL; \
	MENU trans9_Control_Cond_CHANNEL_page; \
	COMMAND trans9_Control_Cond_CHANNEL_read; \
	COMMAND trans9_Control_Cond_CHANNEL_write; \
	COLLECTION trans9_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans9_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans9_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans9_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans9_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans9_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans9_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans9_Control_Cond_RECIPE; \
	MENU trans9_Control_Cond_RECIPE_page; \
	COMMAND trans9_Control_Cond_RECIPE_read; \
	COMMAND trans9_Control_Cond_RECIPE_write; \
	VARIABLE trans9_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans9_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans9_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS9_CONTROL_COND_MANDATORY_A \
	USE_TRANS9_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans9_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS9_CONTROL_COND_MANDATORY_B \
	USE_TRANS9_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans9_Control_Cond_VIEW_1; \
	MENU trans9_Control_Cond_VIEW_1_page; \
	MENU trans9_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS9_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans9_Control_Cond_QUALITY_type; \
	ARRAY trans9_Control_Cond_QUALITY; \
	MENU trans9_Control_Cond_QUALITY_page; \
	COMMAND trans9_Control_Cond_QUALITY_read; \
	VARIABLE trans9_Control_Cond_SP_type; \
	ARRAY trans9_Control_Cond_SP; \
	MENU trans9_Control_Cond_SP_page; \
	COMMAND trans9_Control_Cond_SP_read; \
	COMMAND trans9_Control_Cond_SP_write; \
	VARIABLE trans9_Control_Cond_PV_type; \
	ARRAY trans9_Control_Cond_PV; \
	MENU trans9_Control_Cond_PV_page; \
	COMMAND trans9_Control_Cond_PV_read; \
	VARIABLE trans9_Control_Cond_CTB_MASTER; \
	MENU trans9_Control_Cond_CTB_MASTER_page; \
	COMMAND trans9_Control_Cond_CTB_MASTER_read; \
	COMMAND trans9_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans9_Control_Cond_SELECTION_type; \
	ARRAY trans9_Control_Cond_SELECTION; \
	MENU trans9_Control_Cond_SELECTION_page; \
	COMMAND trans9_Control_Cond_SELECTION_read; \
	COMMAND trans9_Control_Cond_SELECTION_write; \
	VARIABLE trans9_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans9_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans9_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans9_Control_Cond_CELL_CONSTANT; \
	MENU trans9_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans9_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans9_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans9_Control_Cond_VIEW_2; \
	MENU trans9_Control_Cond_VIEW_2_page; \
	COLLECTION trans9_Control_Cond_VIEW_3; \
	MENU trans9_Control_Cond_VIEW_3_page

#define USE_TRANS9_CONTROL_COND_OPTIONAL_A \
	USE_TRANS9_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans9_Control_Cond_VIEW_1; \
	MENU trans9_Control_Cond_VIEW_1_page; \
	MENU trans9_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS9_CONTROL_COND_OPTIONAL_B \
	USE_TRANS9_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans9_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans9_Control_Cond_)
#define USE_TRANS9_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans9_Control_Cond_)
#define USE_TRANS9_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans9_Control_Cond_)
#define USE_TRANS9_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans9_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans10_Control_Cond_block; \
	COLLECTION trans10_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans10_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans10_Control_Cond_ST_REV; \
	MENU trans10_Control_Cond_ST_REV_page; \
	COMMAND trans10_Control_Cond_ST_REV_read; \
	VARIABLE trans10_Control_Cond_TAG_DESC; \
	MENU trans10_Control_Cond_TAG_DESC_page; \
	COMMAND trans10_Control_Cond_TAG_DESC_read; \
	COMMAND trans10_Control_Cond_TAG_DESC_write; \
	VARIABLE trans10_Control_Cond_STRATEGY; \
	MENU trans10_Control_Cond_STRATEGY_page; \
	COMMAND trans10_Control_Cond_STRATEGY_read; \
	COMMAND trans10_Control_Cond_STRATEGY_write; \
	VARIABLE trans10_Control_Cond_ALERT_KEY; \
	MENU trans10_Control_Cond_ALERT_KEY_page; \
	COMMAND trans10_Control_Cond_ALERT_KEY_read; \
	COMMAND trans10_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans10_Control_Cond_TARGET_MODE; \
	MENU trans10_Control_Cond_TARGET_MODE_page; \
	COMMAND trans10_Control_Cond_TARGET_MODE_read; \
	COMMAND trans10_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans10_Control_Cond_MODE_BLK; \
	VARIABLE trans10_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans10_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans10_Control_Cond_MODE_BLK_Normal; \
	MENU trans10_Control_Cond_MODE_BLK_page; \
	COMMAND trans10_Control_Cond_MODE_BLK_read; \
	COLLECTION trans10_Control_Cond_ALARM_SUM; \
	VARIABLE trans10_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans10_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans10_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans10_Control_Cond_ALARM_SUM_page; \
	COMMAND trans10_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans10_Control_Cond_BLOCK_TYPE; \
	MENU trans10_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans10_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans10_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans10_Control_Cond_COMMAND; \
	MENU trans10_Control_Cond_COMMAND_page; \
	COMMAND trans10_Control_Cond_COMMAND_read; \
	COMMAND trans10_Control_Cond_COMMAND_write; \
	VARIABLE trans10_Control_Cond_STATUS; \
	MENU trans10_Control_Cond_STATUS_page; \
	COMMAND trans10_Control_Cond_STATUS_read; \
	VARIABLE trans10_Control_Cond_CHANNEL; \
	MENU trans10_Control_Cond_CHANNEL_page; \
	COMMAND trans10_Control_Cond_CHANNEL_read; \
	COMMAND trans10_Control_Cond_CHANNEL_write; \
	COLLECTION trans10_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans10_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans10_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans10_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans10_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans10_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans10_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans10_Control_Cond_RECIPE; \
	MENU trans10_Control_Cond_RECIPE_page; \
	COMMAND trans10_Control_Cond_RECIPE_read; \
	COMMAND trans10_Control_Cond_RECIPE_write; \
	VARIABLE trans10_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans10_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans10_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS10_CONTROL_COND_MANDATORY_A \
	USE_TRANS10_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans10_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS10_CONTROL_COND_MANDATORY_B \
	USE_TRANS10_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans10_Control_Cond_VIEW_1; \
	MENU trans10_Control_Cond_VIEW_1_page; \
	MENU trans10_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS10_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans10_Control_Cond_QUALITY_type; \
	ARRAY trans10_Control_Cond_QUALITY; \
	MENU trans10_Control_Cond_QUALITY_page; \
	COMMAND trans10_Control_Cond_QUALITY_read; \
	VARIABLE trans10_Control_Cond_SP_type; \
	ARRAY trans10_Control_Cond_SP; \
	MENU trans10_Control_Cond_SP_page; \
	COMMAND trans10_Control_Cond_SP_read; \
	COMMAND trans10_Control_Cond_SP_write; \
	VARIABLE trans10_Control_Cond_PV_type; \
	ARRAY trans10_Control_Cond_PV; \
	MENU trans10_Control_Cond_PV_page; \
	COMMAND trans10_Control_Cond_PV_read; \
	VARIABLE trans10_Control_Cond_CTB_MASTER; \
	MENU trans10_Control_Cond_CTB_MASTER_page; \
	COMMAND trans10_Control_Cond_CTB_MASTER_read; \
	COMMAND trans10_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans10_Control_Cond_SELECTION_type; \
	ARRAY trans10_Control_Cond_SELECTION; \
	MENU trans10_Control_Cond_SELECTION_page; \
	COMMAND trans10_Control_Cond_SELECTION_read; \
	COMMAND trans10_Control_Cond_SELECTION_write; \
	VARIABLE trans10_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans10_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans10_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans10_Control_Cond_CELL_CONSTANT; \
	MENU trans10_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans10_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans10_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans10_Control_Cond_VIEW_2; \
	MENU trans10_Control_Cond_VIEW_2_page; \
	COLLECTION trans10_Control_Cond_VIEW_3; \
	MENU trans10_Control_Cond_VIEW_3_page

#define USE_TRANS10_CONTROL_COND_OPTIONAL_A \
	USE_TRANS10_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans10_Control_Cond_VIEW_1; \
	MENU trans10_Control_Cond_VIEW_1_page; \
	MENU trans10_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS10_CONTROL_COND_OPTIONAL_B \
	USE_TRANS10_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans10_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans10_Control_Cond_)
#define USE_TRANS10_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans10_Control_Cond_)
#define USE_TRANS10_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans10_Control_Cond_)
#define USE_TRANS10_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans10_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans11_Control_Cond_block; \
	COLLECTION trans11_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans11_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans11_Control_Cond_ST_REV; \
	MENU trans11_Control_Cond_ST_REV_page; \
	COMMAND trans11_Control_Cond_ST_REV_read; \
	VARIABLE trans11_Control_Cond_TAG_DESC; \
	MENU trans11_Control_Cond_TAG_DESC_page; \
	COMMAND trans11_Control_Cond_TAG_DESC_read; \
	COMMAND trans11_Control_Cond_TAG_DESC_write; \
	VARIABLE trans11_Control_Cond_STRATEGY; \
	MENU trans11_Control_Cond_STRATEGY_page; \
	COMMAND trans11_Control_Cond_STRATEGY_read; \
	COMMAND trans11_Control_Cond_STRATEGY_write; \
	VARIABLE trans11_Control_Cond_ALERT_KEY; \
	MENU trans11_Control_Cond_ALERT_KEY_page; \
	COMMAND trans11_Control_Cond_ALERT_KEY_read; \
	COMMAND trans11_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans11_Control_Cond_TARGET_MODE; \
	MENU trans11_Control_Cond_TARGET_MODE_page; \
	COMMAND trans11_Control_Cond_TARGET_MODE_read; \
	COMMAND trans11_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans11_Control_Cond_MODE_BLK; \
	VARIABLE trans11_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans11_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans11_Control_Cond_MODE_BLK_Normal; \
	MENU trans11_Control_Cond_MODE_BLK_page; \
	COMMAND trans11_Control_Cond_MODE_BLK_read; \
	COLLECTION trans11_Control_Cond_ALARM_SUM; \
	VARIABLE trans11_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans11_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans11_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans11_Control_Cond_ALARM_SUM_page; \
	COMMAND trans11_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans11_Control_Cond_BLOCK_TYPE; \
	MENU trans11_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans11_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans11_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans11_Control_Cond_COMMAND; \
	MENU trans11_Control_Cond_COMMAND_page; \
	COMMAND trans11_Control_Cond_COMMAND_read; \
	COMMAND trans11_Control_Cond_COMMAND_write; \
	VARIABLE trans11_Control_Cond_STATUS; \
	MENU trans11_Control_Cond_STATUS_page; \
	COMMAND trans11_Control_Cond_STATUS_read; \
	VARIABLE trans11_Control_Cond_CHANNEL; \
	MENU trans11_Control_Cond_CHANNEL_page; \
	COMMAND trans11_Control_Cond_CHANNEL_read; \
	COMMAND trans11_Control_Cond_CHANNEL_write; \
	COLLECTION trans11_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans11_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans11_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans11_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans11_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans11_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans11_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans11_Control_Cond_RECIPE; \
	MENU trans11_Control_Cond_RECIPE_page; \
	COMMAND trans11_Control_Cond_RECIPE_read; \
	COMMAND trans11_Control_Cond_RECIPE_write; \
	VARIABLE trans11_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans11_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans11_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS11_CONTROL_COND_MANDATORY_A \
	USE_TRANS11_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans11_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS11_CONTROL_COND_MANDATORY_B \
	USE_TRANS11_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans11_Control_Cond_VIEW_1; \
	MENU trans11_Control_Cond_VIEW_1_page; \
	MENU trans11_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS11_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans11_Control_Cond_QUALITY_type; \
	ARRAY trans11_Control_Cond_QUALITY; \
	MENU trans11_Control_Cond_QUALITY_page; \
	COMMAND trans11_Control_Cond_QUALITY_read; \
	VARIABLE trans11_Control_Cond_SP_type; \
	ARRAY trans11_Control_Cond_SP; \
	MENU trans11_Control_Cond_SP_page; \
	COMMAND trans11_Control_Cond_SP_read; \
	COMMAND trans11_Control_Cond_SP_write; \
	VARIABLE trans11_Control_Cond_PV_type; \
	ARRAY trans11_Control_Cond_PV; \
	MENU trans11_Control_Cond_PV_page; \
	COMMAND trans11_Control_Cond_PV_read; \
	VARIABLE trans11_Control_Cond_CTB_MASTER; \
	MENU trans11_Control_Cond_CTB_MASTER_page; \
	COMMAND trans11_Control_Cond_CTB_MASTER_read; \
	COMMAND trans11_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans11_Control_Cond_SELECTION_type; \
	ARRAY trans11_Control_Cond_SELECTION; \
	MENU trans11_Control_Cond_SELECTION_page; \
	COMMAND trans11_Control_Cond_SELECTION_read; \
	COMMAND trans11_Control_Cond_SELECTION_write; \
	VARIABLE trans11_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans11_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans11_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans11_Control_Cond_CELL_CONSTANT; \
	MENU trans11_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans11_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans11_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans11_Control_Cond_VIEW_2; \
	MENU trans11_Control_Cond_VIEW_2_page; \
	COLLECTION trans11_Control_Cond_VIEW_3; \
	MENU trans11_Control_Cond_VIEW_3_page

#define USE_TRANS11_CONTROL_COND_OPTIONAL_A \
	USE_TRANS11_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans11_Control_Cond_VIEW_1; \
	MENU trans11_Control_Cond_VIEW_1_page; \
	MENU trans11_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS11_CONTROL_COND_OPTIONAL_B \
	USE_TRANS11_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans11_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans11_Control_Cond_)
#define USE_TRANS11_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans11_Control_Cond_)
#define USE_TRANS11_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans11_Control_Cond_)
#define USE_TRANS11_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans11_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans12_Control_Cond_block; \
	COLLECTION trans12_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans12_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans12_Control_Cond_ST_REV; \
	MENU trans12_Control_Cond_ST_REV_page; \
	COMMAND trans12_Control_Cond_ST_REV_read; \
	VARIABLE trans12_Control_Cond_TAG_DESC; \
	MENU trans12_Control_Cond_TAG_DESC_page; \
	COMMAND trans12_Control_Cond_TAG_DESC_read; \
	COMMAND trans12_Control_Cond_TAG_DESC_write; \
	VARIABLE trans12_Control_Cond_STRATEGY; \
	MENU trans12_Control_Cond_STRATEGY_page; \
	COMMAND trans12_Control_Cond_STRATEGY_read; \
	COMMAND trans12_Control_Cond_STRATEGY_write; \
	VARIABLE trans12_Control_Cond_ALERT_KEY; \
	MENU trans12_Control_Cond_ALERT_KEY_page; \
	COMMAND trans12_Control_Cond_ALERT_KEY_read; \
	COMMAND trans12_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans12_Control_Cond_TARGET_MODE; \
	MENU trans12_Control_Cond_TARGET_MODE_page; \
	COMMAND trans12_Control_Cond_TARGET_MODE_read; \
	COMMAND trans12_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans12_Control_Cond_MODE_BLK; \
	VARIABLE trans12_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans12_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans12_Control_Cond_MODE_BLK_Normal; \
	MENU trans12_Control_Cond_MODE_BLK_page; \
	COMMAND trans12_Control_Cond_MODE_BLK_read; \
	COLLECTION trans12_Control_Cond_ALARM_SUM; \
	VARIABLE trans12_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans12_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans12_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans12_Control_Cond_ALARM_SUM_page; \
	COMMAND trans12_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans12_Control_Cond_BLOCK_TYPE; \
	MENU trans12_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans12_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans12_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans12_Control_Cond_COMMAND; \
	MENU trans12_Control_Cond_COMMAND_page; \
	COMMAND trans12_Control_Cond_COMMAND_read; \
	COMMAND trans12_Control_Cond_COMMAND_write; \
	VARIABLE trans12_Control_Cond_STATUS; \
	MENU trans12_Control_Cond_STATUS_page; \
	COMMAND trans12_Control_Cond_STATUS_read; \
	VARIABLE trans12_Control_Cond_CHANNEL; \
	MENU trans12_Control_Cond_CHANNEL_page; \
	COMMAND trans12_Control_Cond_CHANNEL_read; \
	COMMAND trans12_Control_Cond_CHANNEL_write; \
	COLLECTION trans12_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans12_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans12_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans12_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans12_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans12_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans12_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans12_Control_Cond_RECIPE; \
	MENU trans12_Control_Cond_RECIPE_page; \
	COMMAND trans12_Control_Cond_RECIPE_read; \
	COMMAND trans12_Control_Cond_RECIPE_write; \
	VARIABLE trans12_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans12_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans12_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS12_CONTROL_COND_MANDATORY_A \
	USE_TRANS12_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans12_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS12_CONTROL_COND_MANDATORY_B \
	USE_TRANS12_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans12_Control_Cond_VIEW_1; \
	MENU trans12_Control_Cond_VIEW_1_page; \
	MENU trans12_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS12_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans12_Control_Cond_QUALITY_type; \
	ARRAY trans12_Control_Cond_QUALITY; \
	MENU trans12_Control_Cond_QUALITY_page; \
	COMMAND trans12_Control_Cond_QUALITY_read; \
	VARIABLE trans12_Control_Cond_SP_type; \
	ARRAY trans12_Control_Cond_SP; \
	MENU trans12_Control_Cond_SP_page; \
	COMMAND trans12_Control_Cond_SP_read; \
	COMMAND trans12_Control_Cond_SP_write; \
	VARIABLE trans12_Control_Cond_PV_type; \
	ARRAY trans12_Control_Cond_PV; \
	MENU trans12_Control_Cond_PV_page; \
	COMMAND trans12_Control_Cond_PV_read; \
	VARIABLE trans12_Control_Cond_CTB_MASTER; \
	MENU trans12_Control_Cond_CTB_MASTER_page; \
	COMMAND trans12_Control_Cond_CTB_MASTER_read; \
	COMMAND trans12_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans12_Control_Cond_SELECTION_type; \
	ARRAY trans12_Control_Cond_SELECTION; \
	MENU trans12_Control_Cond_SELECTION_page; \
	COMMAND trans12_Control_Cond_SELECTION_read; \
	COMMAND trans12_Control_Cond_SELECTION_write; \
	VARIABLE trans12_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans12_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans12_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans12_Control_Cond_CELL_CONSTANT; \
	MENU trans12_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans12_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans12_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans12_Control_Cond_VIEW_2; \
	MENU trans12_Control_Cond_VIEW_2_page; \
	COLLECTION trans12_Control_Cond_VIEW_3; \
	MENU trans12_Control_Cond_VIEW_3_page

#define USE_TRANS12_CONTROL_COND_OPTIONAL_A \
	USE_TRANS12_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans12_Control_Cond_VIEW_1; \
	MENU trans12_Control_Cond_VIEW_1_page; \
	MENU trans12_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS12_CONTROL_COND_OPTIONAL_B \
	USE_TRANS12_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans12_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans12_Control_Cond_)
#define USE_TRANS12_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans12_Control_Cond_)
#define USE_TRANS12_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans12_Control_Cond_)
#define USE_TRANS12_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans12_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans13_Control_Cond_block; \
	COLLECTION trans13_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans13_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans13_Control_Cond_ST_REV; \
	MENU trans13_Control_Cond_ST_REV_page; \
	COMMAND trans13_Control_Cond_ST_REV_read; \
	VARIABLE trans13_Control_Cond_TAG_DESC; \
	MENU trans13_Control_Cond_TAG_DESC_page; \
	COMMAND trans13_Control_Cond_TAG_DESC_read; \
	COMMAND trans13_Control_Cond_TAG_DESC_write; \
	VARIABLE trans13_Control_Cond_STRATEGY; \
	MENU trans13_Control_Cond_STRATEGY_page; \
	COMMAND trans13_Control_Cond_STRATEGY_read; \
	COMMAND trans13_Control_Cond_STRATEGY_write; \
	VARIABLE trans13_Control_Cond_ALERT_KEY; \
	MENU trans13_Control_Cond_ALERT_KEY_page; \
	COMMAND trans13_Control_Cond_ALERT_KEY_read; \
	COMMAND trans13_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans13_Control_Cond_TARGET_MODE; \
	MENU trans13_Control_Cond_TARGET_MODE_page; \
	COMMAND trans13_Control_Cond_TARGET_MODE_read; \
	COMMAND trans13_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans13_Control_Cond_MODE_BLK; \
	VARIABLE trans13_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans13_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans13_Control_Cond_MODE_BLK_Normal; \
	MENU trans13_Control_Cond_MODE_BLK_page; \
	COMMAND trans13_Control_Cond_MODE_BLK_read; \
	COLLECTION trans13_Control_Cond_ALARM_SUM; \
	VARIABLE trans13_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans13_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans13_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans13_Control_Cond_ALARM_SUM_page; \
	COMMAND trans13_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans13_Control_Cond_BLOCK_TYPE; \
	MENU trans13_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans13_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans13_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans13_Control_Cond_COMMAND; \
	MENU trans13_Control_Cond_COMMAND_page; \
	COMMAND trans13_Control_Cond_COMMAND_read; \
	COMMAND trans13_Control_Cond_COMMAND_write; \
	VARIABLE trans13_Control_Cond_STATUS; \
	MENU trans13_Control_Cond_STATUS_page; \
	COMMAND trans13_Control_Cond_STATUS_read; \
	VARIABLE trans13_Control_Cond_CHANNEL; \
	MENU trans13_Control_Cond_CHANNEL_page; \
	COMMAND trans13_Control_Cond_CHANNEL_read; \
	COMMAND trans13_Control_Cond_CHANNEL_write; \
	COLLECTION trans13_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans13_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans13_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans13_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans13_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans13_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans13_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans13_Control_Cond_RECIPE; \
	MENU trans13_Control_Cond_RECIPE_page; \
	COMMAND trans13_Control_Cond_RECIPE_read; \
	COMMAND trans13_Control_Cond_RECIPE_write; \
	VARIABLE trans13_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans13_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans13_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS13_CONTROL_COND_MANDATORY_A \
	USE_TRANS13_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans13_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS13_CONTROL_COND_MANDATORY_B \
	USE_TRANS13_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans13_Control_Cond_VIEW_1; \
	MENU trans13_Control_Cond_VIEW_1_page; \
	MENU trans13_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS13_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans13_Control_Cond_QUALITY_type; \
	ARRAY trans13_Control_Cond_QUALITY; \
	MENU trans13_Control_Cond_QUALITY_page; \
	COMMAND trans13_Control_Cond_QUALITY_read; \
	VARIABLE trans13_Control_Cond_SP_type; \
	ARRAY trans13_Control_Cond_SP; \
	MENU trans13_Control_Cond_SP_page; \
	COMMAND trans13_Control_Cond_SP_read; \
	COMMAND trans13_Control_Cond_SP_write; \
	VARIABLE trans13_Control_Cond_PV_type; \
	ARRAY trans13_Control_Cond_PV; \
	MENU trans13_Control_Cond_PV_page; \
	COMMAND trans13_Control_Cond_PV_read; \
	VARIABLE trans13_Control_Cond_CTB_MASTER; \
	MENU trans13_Control_Cond_CTB_MASTER_page; \
	COMMAND trans13_Control_Cond_CTB_MASTER_read; \
	COMMAND trans13_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans13_Control_Cond_SELECTION_type; \
	ARRAY trans13_Control_Cond_SELECTION; \
	MENU trans13_Control_Cond_SELECTION_page; \
	COMMAND trans13_Control_Cond_SELECTION_read; \
	COMMAND trans13_Control_Cond_SELECTION_write; \
	VARIABLE trans13_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans13_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans13_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans13_Control_Cond_CELL_CONSTANT; \
	MENU trans13_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans13_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans13_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans13_Control_Cond_VIEW_2; \
	MENU trans13_Control_Cond_VIEW_2_page; \
	COLLECTION trans13_Control_Cond_VIEW_3; \
	MENU trans13_Control_Cond_VIEW_3_page

#define USE_TRANS13_CONTROL_COND_OPTIONAL_A \
	USE_TRANS13_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans13_Control_Cond_VIEW_1; \
	MENU trans13_Control_Cond_VIEW_1_page; \
	MENU trans13_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS13_CONTROL_COND_OPTIONAL_B \
	USE_TRANS13_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans13_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans13_Control_Cond_)
#define USE_TRANS13_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans13_Control_Cond_)
#define USE_TRANS13_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans13_Control_Cond_)
#define USE_TRANS13_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans13_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans14_Control_Cond_block; \
	COLLECTION trans14_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans14_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans14_Control_Cond_ST_REV; \
	MENU trans14_Control_Cond_ST_REV_page; \
	COMMAND trans14_Control_Cond_ST_REV_read; \
	VARIABLE trans14_Control_Cond_TAG_DESC; \
	MENU trans14_Control_Cond_TAG_DESC_page; \
	COMMAND trans14_Control_Cond_TAG_DESC_read; \
	COMMAND trans14_Control_Cond_TAG_DESC_write; \
	VARIABLE trans14_Control_Cond_STRATEGY; \
	MENU trans14_Control_Cond_STRATEGY_page; \
	COMMAND trans14_Control_Cond_STRATEGY_read; \
	COMMAND trans14_Control_Cond_STRATEGY_write; \
	VARIABLE trans14_Control_Cond_ALERT_KEY; \
	MENU trans14_Control_Cond_ALERT_KEY_page; \
	COMMAND trans14_Control_Cond_ALERT_KEY_read; \
	COMMAND trans14_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans14_Control_Cond_TARGET_MODE; \
	MENU trans14_Control_Cond_TARGET_MODE_page; \
	COMMAND trans14_Control_Cond_TARGET_MODE_read; \
	COMMAND trans14_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans14_Control_Cond_MODE_BLK; \
	VARIABLE trans14_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans14_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans14_Control_Cond_MODE_BLK_Normal; \
	MENU trans14_Control_Cond_MODE_BLK_page; \
	COMMAND trans14_Control_Cond_MODE_BLK_read; \
	COLLECTION trans14_Control_Cond_ALARM_SUM; \
	VARIABLE trans14_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans14_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans14_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans14_Control_Cond_ALARM_SUM_page; \
	COMMAND trans14_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans14_Control_Cond_BLOCK_TYPE; \
	MENU trans14_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans14_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans14_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans14_Control_Cond_COMMAND; \
	MENU trans14_Control_Cond_COMMAND_page; \
	COMMAND trans14_Control_Cond_COMMAND_read; \
	COMMAND trans14_Control_Cond_COMMAND_write; \
	VARIABLE trans14_Control_Cond_STATUS; \
	MENU trans14_Control_Cond_STATUS_page; \
	COMMAND trans14_Control_Cond_STATUS_read; \
	VARIABLE trans14_Control_Cond_CHANNEL; \
	MENU trans14_Control_Cond_CHANNEL_page; \
	COMMAND trans14_Control_Cond_CHANNEL_read; \
	COMMAND trans14_Control_Cond_CHANNEL_write; \
	COLLECTION trans14_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans14_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans14_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans14_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans14_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans14_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans14_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans14_Control_Cond_RECIPE; \
	MENU trans14_Control_Cond_RECIPE_page; \
	COMMAND trans14_Control_Cond_RECIPE_read; \
	COMMAND trans14_Control_Cond_RECIPE_write; \
	VARIABLE trans14_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans14_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans14_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS14_CONTROL_COND_MANDATORY_A \
	USE_TRANS14_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans14_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS14_CONTROL_COND_MANDATORY_B \
	USE_TRANS14_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans14_Control_Cond_VIEW_1; \
	MENU trans14_Control_Cond_VIEW_1_page; \
	MENU trans14_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS14_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans14_Control_Cond_QUALITY_type; \
	ARRAY trans14_Control_Cond_QUALITY; \
	MENU trans14_Control_Cond_QUALITY_page; \
	COMMAND trans14_Control_Cond_QUALITY_read; \
	VARIABLE trans14_Control_Cond_SP_type; \
	ARRAY trans14_Control_Cond_SP; \
	MENU trans14_Control_Cond_SP_page; \
	COMMAND trans14_Control_Cond_SP_read; \
	COMMAND trans14_Control_Cond_SP_write; \
	VARIABLE trans14_Control_Cond_PV_type; \
	ARRAY trans14_Control_Cond_PV; \
	MENU trans14_Control_Cond_PV_page; \
	COMMAND trans14_Control_Cond_PV_read; \
	VARIABLE trans14_Control_Cond_CTB_MASTER; \
	MENU trans14_Control_Cond_CTB_MASTER_page; \
	COMMAND trans14_Control_Cond_CTB_MASTER_read; \
	COMMAND trans14_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans14_Control_Cond_SELECTION_type; \
	ARRAY trans14_Control_Cond_SELECTION; \
	MENU trans14_Control_Cond_SELECTION_page; \
	COMMAND trans14_Control_Cond_SELECTION_read; \
	COMMAND trans14_Control_Cond_SELECTION_write; \
	VARIABLE trans14_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans14_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans14_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans14_Control_Cond_CELL_CONSTANT; \
	MENU trans14_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans14_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans14_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans14_Control_Cond_VIEW_2; \
	MENU trans14_Control_Cond_VIEW_2_page; \
	COLLECTION trans14_Control_Cond_VIEW_3; \
	MENU trans14_Control_Cond_VIEW_3_page

#define USE_TRANS14_CONTROL_COND_OPTIONAL_A \
	USE_TRANS14_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans14_Control_Cond_VIEW_1; \
	MENU trans14_Control_Cond_VIEW_1_page; \
	MENU trans14_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS14_CONTROL_COND_OPTIONAL_B \
	USE_TRANS14_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans14_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans14_Control_Cond_)
#define USE_TRANS14_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans14_Control_Cond_)
#define USE_TRANS14_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans14_Control_Cond_)
#define USE_TRANS14_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans14_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_CONTROL_COND_MANDATORY_BOTH \
	BLOCK trans15_Control_Cond_block; \
	COLLECTION trans15_Control_Cond_BLOCK_OBJECT; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Control_Cond_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Control_Cond_BLOCK_OBJECT_page; \
	COMMAND trans15_Control_Cond_BLOCK_OBJECT_read; \
	VARIABLE trans15_Control_Cond_ST_REV; \
	MENU trans15_Control_Cond_ST_REV_page; \
	COMMAND trans15_Control_Cond_ST_REV_read; \
	VARIABLE trans15_Control_Cond_TAG_DESC; \
	MENU trans15_Control_Cond_TAG_DESC_page; \
	COMMAND trans15_Control_Cond_TAG_DESC_read; \
	COMMAND trans15_Control_Cond_TAG_DESC_write; \
	VARIABLE trans15_Control_Cond_STRATEGY; \
	MENU trans15_Control_Cond_STRATEGY_page; \
	COMMAND trans15_Control_Cond_STRATEGY_read; \
	COMMAND trans15_Control_Cond_STRATEGY_write; \
	VARIABLE trans15_Control_Cond_ALERT_KEY; \
	MENU trans15_Control_Cond_ALERT_KEY_page; \
	COMMAND trans15_Control_Cond_ALERT_KEY_read; \
	COMMAND trans15_Control_Cond_ALERT_KEY_write; \
	VARIABLE trans15_Control_Cond_TARGET_MODE; \
	MENU trans15_Control_Cond_TARGET_MODE_page; \
	COMMAND trans15_Control_Cond_TARGET_MODE_read; \
	COMMAND trans15_Control_Cond_TARGET_MODE_write; \
	COLLECTION trans15_Control_Cond_MODE_BLK; \
	VARIABLE trans15_Control_Cond_MODE_BLK_Actual; \
	VARIABLE trans15_Control_Cond_MODE_BLK_Permitted; \
	VARIABLE trans15_Control_Cond_MODE_BLK_Normal; \
	MENU trans15_Control_Cond_MODE_BLK_page; \
	COMMAND trans15_Control_Cond_MODE_BLK_read; \
	COLLECTION trans15_Control_Cond_ALARM_SUM; \
	VARIABLE trans15_Control_Cond_ALARM_SUM_Current; \
	VARIABLE trans15_Control_Cond_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Control_Cond_ALARM_SUM_Unreported; \
	VARIABLE trans15_Control_Cond_ALARM_SUM_Disabled; \
	MENU trans15_Control_Cond_ALARM_SUM_page; \
	COMMAND trans15_Control_Cond_ALARM_SUM_read; \
	VARIABLE trans15_Control_Cond_BLOCK_TYPE; \
	MENU trans15_Control_Cond_BLOCK_TYPE_page; \
	COMMAND trans15_Control_Cond_BLOCK_TYPE_read; \
	COMMAND trans15_Control_Cond_BLOCK_TYPE_write; \
	VARIABLE trans15_Control_Cond_COMMAND; \
	MENU trans15_Control_Cond_COMMAND_page; \
	COMMAND trans15_Control_Cond_COMMAND_read; \
	COMMAND trans15_Control_Cond_COMMAND_write; \
	VARIABLE trans15_Control_Cond_STATUS; \
	MENU trans15_Control_Cond_STATUS_page; \
	COMMAND trans15_Control_Cond_STATUS_read; \
	VARIABLE trans15_Control_Cond_CHANNEL; \
	MENU trans15_Control_Cond_CHANNEL_page; \
	COMMAND trans15_Control_Cond_CHANNEL_read; \
	COMMAND trans15_Control_Cond_CHANNEL_write; \
	COLLECTION trans15_Control_Cond_SEQUENCE_CONTROL; \
	COLLECTION trans15_Control_Cond_SEQUENCE_CONTROL_Time; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans15_Control_Cond_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Command; \
	VARIABLE trans15_Control_Cond_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans15_Control_Cond_SEQUENCE_CONTROL_page; \
	COMMAND trans15_Control_Cond_SEQUENCE_CONTROL_read; \
	COMMAND trans15_Control_Cond_SEQUENCE_CONTROL_write; \
	VARIABLE trans15_Control_Cond_RECIPE; \
	MENU trans15_Control_Cond_RECIPE_page; \
	COMMAND trans15_Control_Cond_RECIPE_read; \
	COMMAND trans15_Control_Cond_RECIPE_write; \
	VARIABLE trans15_Control_Cond_PARAMETER_SET_NUMBER; \
	MENU trans15_Control_Cond_PARAMETER_SET_NUMBER_page; \
	COMMAND trans15_Control_Cond_PARAMETER_SET_NUMBER_read

#define USE_TRANS15_CONTROL_COND_MANDATORY_A \
	USE_TRANS15_CONTROL_COND_MANDATORY_BOTH; \
	MENU trans15_Control_Cond_Simple_Dialog_Mandatory_A

#define USE_TRANS15_CONTROL_COND_MANDATORY_B \
	USE_TRANS15_CONTROL_COND_MANDATORY_BOTH; \
	COLLECTION trans15_Control_Cond_VIEW_1; \
	MENU trans15_Control_Cond_VIEW_1_page; \
	MENU trans15_Control_Cond_Simple_Dialog_Mandatory_B

#define USE_TRANS15_CONTROL_COND_OPTIONAL_BOTH \
	VARIABLE trans15_Control_Cond_QUALITY_type; \
	ARRAY trans15_Control_Cond_QUALITY; \
	MENU trans15_Control_Cond_QUALITY_page; \
	COMMAND trans15_Control_Cond_QUALITY_read; \
	VARIABLE trans15_Control_Cond_SP_type; \
	ARRAY trans15_Control_Cond_SP; \
	MENU trans15_Control_Cond_SP_page; \
	COMMAND trans15_Control_Cond_SP_read; \
	COMMAND trans15_Control_Cond_SP_write; \
	VARIABLE trans15_Control_Cond_PV_type; \
	ARRAY trans15_Control_Cond_PV; \
	MENU trans15_Control_Cond_PV_page; \
	COMMAND trans15_Control_Cond_PV_read; \
	VARIABLE trans15_Control_Cond_CTB_MASTER; \
	MENU trans15_Control_Cond_CTB_MASTER_page; \
	COMMAND trans15_Control_Cond_CTB_MASTER_read; \
	COMMAND trans15_Control_Cond_CTB_MASTER_write; \
	VARIABLE trans15_Control_Cond_SELECTION_type; \
	ARRAY trans15_Control_Cond_SELECTION; \
	MENU trans15_Control_Cond_SELECTION_page; \
	COMMAND trans15_Control_Cond_SELECTION_read; \
	COMMAND trans15_Control_Cond_SELECTION_write; \
	VARIABLE trans15_Control_Cond_NUMBER_PARAMETERS; \
	MENU trans15_Control_Cond_NUMBER_PARAMETERS_page; \
	COMMAND trans15_Control_Cond_NUMBER_PARAMETERS_read; \
	VARIABLE trans15_Control_Cond_CELL_CONSTANT; \
	MENU trans15_Control_Cond_CELL_CONSTANT_page; \
	COMMAND trans15_Control_Cond_CELL_CONSTANT_read; \
	COMMAND trans15_Control_Cond_CELL_CONSTANT_write; \
	COLLECTION trans15_Control_Cond_VIEW_2; \
	MENU trans15_Control_Cond_VIEW_2_page; \
	COLLECTION trans15_Control_Cond_VIEW_3; \
	MENU trans15_Control_Cond_VIEW_3_page

#define USE_TRANS15_CONTROL_COND_OPTIONAL_A \
	USE_TRANS15_CONTROL_COND_OPTIONAL_BOTH; \
	COLLECTION trans15_Control_Cond_VIEW_1; \
	MENU trans15_Control_Cond_VIEW_1_page; \
	MENU trans15_Control_Cond_Simple_Dialog_Optional_A

#define USE_TRANS15_CONTROL_COND_OPTIONAL_B \
	USE_TRANS15_CONTROL_COND_OPTIONAL_BOTH; \
	MENU trans15_Control_Cond_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_CONTROL_COND_MANDATORY_A USE_TRANS_CONTROL_COND_MANDATORY_A(trans15_Control_Cond_)
#define USE_TRANS15_CONTROL_COND_MANDATORY_B USE_TRANS_CONTROL_COND_MANDATORY_B(trans15_Control_Cond_)
#define USE_TRANS15_CONTROL_COND_OPTIONAL_A  USE_TRANS_CONTROL_COND_OPTIONAL_A(trans15_Control_Cond_)
#define USE_TRANS15_CONTROL_COND_OPTIONAL_B  USE_TRANS_CONTROL_COND_OPTIONAL_B(trans15_Control_Cond_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans1_Control_Oxyg_block; \
	COLLECTION trans1_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans1_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans1_Control_Oxyg_ST_REV; \
	MENU trans1_Control_Oxyg_ST_REV_page; \
	COMMAND trans1_Control_Oxyg_ST_REV_read; \
	VARIABLE trans1_Control_Oxyg_TAG_DESC; \
	MENU trans1_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans1_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans1_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans1_Control_Oxyg_STRATEGY; \
	MENU trans1_Control_Oxyg_STRATEGY_page; \
	COMMAND trans1_Control_Oxyg_STRATEGY_read; \
	COMMAND trans1_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans1_Control_Oxyg_ALERT_KEY; \
	MENU trans1_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans1_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans1_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans1_Control_Oxyg_TARGET_MODE; \
	MENU trans1_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans1_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans1_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans1_Control_Oxyg_MODE_BLK; \
	VARIABLE trans1_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans1_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans1_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans1_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans1_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans1_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans1_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans1_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans1_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans1_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans1_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans1_Control_Oxyg_BLOCK_TYPE; \
	MENU trans1_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans1_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans1_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans1_Control_Oxyg_COMMAND; \
	MENU trans1_Control_Oxyg_COMMAND_page; \
	COMMAND trans1_Control_Oxyg_COMMAND_read; \
	COMMAND trans1_Control_Oxyg_COMMAND_write; \
	VARIABLE trans1_Control_Oxyg_STATUS; \
	MENU trans1_Control_Oxyg_STATUS_page; \
	COMMAND trans1_Control_Oxyg_STATUS_read; \
	VARIABLE trans1_Control_Oxyg_CHANNEL; \
	MENU trans1_Control_Oxyg_CHANNEL_page; \
	COMMAND trans1_Control_Oxyg_CHANNEL_read; \
	COMMAND trans1_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans1_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans1_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans1_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans1_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans1_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans1_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans1_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans1_Control_Oxyg_RECIPE; \
	MENU trans1_Control_Oxyg_RECIPE_page; \
	COMMAND trans1_Control_Oxyg_RECIPE_read; \
	COMMAND trans1_Control_Oxyg_RECIPE_write; \
	VARIABLE trans1_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans1_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans1_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS1_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS1_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans1_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS1_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS1_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans1_Control_Oxyg_VIEW_1; \
	MENU trans1_Control_Oxyg_VIEW_1_page; \
	MENU trans1_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS1_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans1_Control_Oxyg_QUALITY_type; \
	ARRAY trans1_Control_Oxyg_QUALITY; \
	MENU trans1_Control_Oxyg_QUALITY_page; \
	COMMAND trans1_Control_Oxyg_QUALITY_read; \
	VARIABLE trans1_Control_Oxyg_SP_type; \
	ARRAY trans1_Control_Oxyg_SP; \
	MENU trans1_Control_Oxyg_SP_page; \
	COMMAND trans1_Control_Oxyg_SP_read; \
	COMMAND trans1_Control_Oxyg_SP_write; \
	VARIABLE trans1_Control_Oxyg_PV_type; \
	ARRAY trans1_Control_Oxyg_PV; \
	MENU trans1_Control_Oxyg_PV_page; \
	COMMAND trans1_Control_Oxyg_PV_read; \
	VARIABLE trans1_Control_Oxyg_CTB_MASTER; \
	MENU trans1_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans1_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans1_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans1_Control_Oxyg_SELECTION_type; \
	ARRAY trans1_Control_Oxyg_SELECTION; \
	MENU trans1_Control_Oxyg_SELECTION_page; \
	COMMAND trans1_Control_Oxyg_SELECTION_read; \
	COMMAND trans1_Control_Oxyg_SELECTION_write; \
	VARIABLE trans1_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans1_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans1_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans1_Control_Oxyg_CALOXY_TYPE; \
	MENU trans1_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans1_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans1_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans1_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans1_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans1_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans1_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans1_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans1_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans1_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans1_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans1_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans1_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans1_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans1_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans1_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans1_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans1_Control_Oxyg_CALOXY_TEMP; \
	MENU trans1_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans1_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans1_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans1_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans1_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans1_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans1_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans1_Control_Oxyg_VIEW_2; \
	MENU trans1_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans1_Control_Oxyg_VIEW_3; \
	MENU trans1_Control_Oxyg_VIEW_3_page

#define USE_TRANS1_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS1_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans1_Control_Oxyg_VIEW_1; \
	MENU trans1_Control_Oxyg_VIEW_1_page; \
	MENU trans1_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS1_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS1_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans1_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_CONTROL_OXYG_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## BLOCK_TYPE; \
	MENU prefix ## BLOCK_TYPE_page; \
	COMMAND prefix ## BLOCK_TYPE_read; \
	COMMAND prefix ## BLOCK_TYPE_write; \
	VARIABLE prefix ## COMMAND; \
	MENU prefix ## COMMAND_page; \
	COMMAND prefix ## COMMAND_read; \
	COMMAND prefix ## COMMAND_write; \
	VARIABLE prefix ## STATUS; \
	MENU prefix ## STATUS_page; \
	COMMAND prefix ## STATUS_read; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	COLLECTION prefix ## SEQUENCE_CONTROL; \
	COLLECTION prefix ## SEQUENCE_CONTROL_Time; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Month; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Years; \
	COLLECTION prefix ## SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Command; \
	VARIABLE prefix ## SEQUENCE_CONTROL_Time_Control_Active; \
	MENU prefix ## SEQUENCE_CONTROL_page; \
	COMMAND prefix ## SEQUENCE_CONTROL_read; \
	COMMAND prefix ## SEQUENCE_CONTROL_write; \
	VARIABLE prefix ## RECIPE; \
	MENU prefix ## RECIPE_page; \
	COMMAND prefix ## RECIPE_read; \
	COMMAND prefix ## RECIPE_write; \
	VARIABLE prefix ## PARAMETER_SET_NUMBER; \
	MENU prefix ## PARAMETER_SET_NUMBER_page; \
	COMMAND prefix ## PARAMETER_SET_NUMBER_read

#define USE_TRANS_CONTROL_OXYG_MANDATORY_A(prefix) \
	USE_TRANS_CONTROL_OXYG_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_CONTROL_OXYG_MANDATORY_B(prefix) \
	USE_TRANS_CONTROL_OXYG_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_CONTROL_OXYG_OPTIONAL_BOTH(prefix) \
	VARIABLE prefix ## QUALITY_type; \
	ARRAY prefix ## QUALITY; \
	MENU prefix ## QUALITY_page; \
	COMMAND prefix ## QUALITY_read; \
	VARIABLE prefix ## SP_type; \
	ARRAY prefix ## SP; \
	MENU prefix ## SP_page; \
	COMMAND prefix ## SP_read; \
	COMMAND prefix ## SP_write; \
	VARIABLE prefix ## PV_type; \
	ARRAY prefix ## PV; \
	MENU prefix ## PV_page; \
	COMMAND prefix ## PV_read; \
	VARIABLE prefix ## CTB_MASTER; \
	MENU prefix ## CTB_MASTER_page; \
	COMMAND prefix ## CTB_MASTER_read; \
	COMMAND prefix ## CTB_MASTER_write; \
	VARIABLE prefix ## SELECTION_type; \
	ARRAY prefix ## SELECTION; \
	MENU prefix ## SELECTION_page; \
	COMMAND prefix ## SELECTION_read; \
	COMMAND prefix ## SELECTION_write; \
	VARIABLE prefix ## NUMBER_PARAMETERS; \
	MENU prefix ## NUMBER_PARAMETERS_page; \
	COMMAND prefix ## NUMBER_PARAMETERS_read; \
	VARIABLE prefix ## CALOXY_TYPE; \
	MENU prefix ## CALOXY_TYPE_page; \
	COMMAND prefix ## CALOXY_TYPE_read; \
	COMMAND prefix ## CALOXY_TYPE_write; \
	COLLECTION prefix ## CALOXY_ZERO; \
	VARIABLE prefix ## CALOXY_ZERO_Value; \
	VARIABLE prefix ## CALOXY_ZERO_Status_Condensed; \
	VARIABLE prefix ## CALOXY_ZERO_Status_Quality; \
	VARIABLE prefix ## CALOXY_ZERO_Status_Limit; \
	MENU prefix ## CALOXY_ZERO_page; \
	COMMAND prefix ## CALOXY_ZERO_read; \
	COMMAND prefix ## CALOXY_ZERO_write; \
	COLLECTION prefix ## CALOXY_HIGH; \
	VARIABLE prefix ## CALOXY_HIGH_Value; \
	VARIABLE prefix ## CALOXY_HIGH_Status_Condensed; \
	VARIABLE prefix ## CALOXY_HIGH_Status_Quality; \
	VARIABLE prefix ## CALOXY_HIGH_Status_Limit; \
	MENU prefix ## CALOXY_HIGH_page; \
	COMMAND prefix ## CALOXY_HIGH_read; \
	COMMAND prefix ## CALOXY_HIGH_write; \
	VARIABLE prefix ## CALOXY_HUMIDITY_REL; \
	MENU prefix ## CALOXY_HUMIDITY_REL_page; \
	COMMAND prefix ## CALOXY_HUMIDITY_REL_read; \
	COMMAND prefix ## CALOXY_HUMIDITY_REL_write; \
	VARIABLE prefix ## CALOXY_PRESSURE; \
	MENU prefix ## CALOXY_PRESSURE_page; \
	COMMAND prefix ## CALOXY_PRESSURE_read; \
	COMMAND prefix ## CALOXY_PRESSURE_write; \
	VARIABLE prefix ## CALOXY_TEMP; \
	MENU prefix ## CALOXY_TEMP_page; \
	COMMAND prefix ## CALOXY_TEMP_read; \
	COMMAND prefix ## CALOXY_TEMP_write; \
	VARIABLE prefix ## CALOXY_BUFFER_SAT; \
	MENU prefix ## CALOXY_BUFFER_SAT_page; \
	COMMAND prefix ## CALOXY_BUFFER_SAT_read; \
	COMMAND prefix ## CALOXY_BUFFER_SAT_write; \
	VARIABLE prefix ## CALOXY_BUFFER_CONC; \
	MENU prefix ## CALOXY_BUFFER_CONC_page; \
	COMMAND prefix ## CALOXY_BUFFER_CONC_read; \
	COMMAND prefix ## CALOXY_BUFFER_CONC_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_CONTROL_OXYG_OPTIONAL_A(prefix) \
	USE_TRANS_CONTROL_OXYG_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_CONTROL_OXYG_OPTIONAL_B(prefix) \
	USE_TRANS_CONTROL_OXYG_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans1_Control_Oxyg_)
#define USE_TRANS1_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans1_Control_Oxyg_)
#define USE_TRANS1_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans1_Control_Oxyg_)
#define USE_TRANS1_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans1_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans2_Control_Oxyg_block; \
	COLLECTION trans2_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans2_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans2_Control_Oxyg_ST_REV; \
	MENU trans2_Control_Oxyg_ST_REV_page; \
	COMMAND trans2_Control_Oxyg_ST_REV_read; \
	VARIABLE trans2_Control_Oxyg_TAG_DESC; \
	MENU trans2_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans2_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans2_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans2_Control_Oxyg_STRATEGY; \
	MENU trans2_Control_Oxyg_STRATEGY_page; \
	COMMAND trans2_Control_Oxyg_STRATEGY_read; \
	COMMAND trans2_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans2_Control_Oxyg_ALERT_KEY; \
	MENU trans2_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans2_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans2_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans2_Control_Oxyg_TARGET_MODE; \
	MENU trans2_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans2_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans2_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans2_Control_Oxyg_MODE_BLK; \
	VARIABLE trans2_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans2_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans2_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans2_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans2_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans2_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans2_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans2_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans2_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans2_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans2_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans2_Control_Oxyg_BLOCK_TYPE; \
	MENU trans2_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans2_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans2_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans2_Control_Oxyg_COMMAND; \
	MENU trans2_Control_Oxyg_COMMAND_page; \
	COMMAND trans2_Control_Oxyg_COMMAND_read; \
	COMMAND trans2_Control_Oxyg_COMMAND_write; \
	VARIABLE trans2_Control_Oxyg_STATUS; \
	MENU trans2_Control_Oxyg_STATUS_page; \
	COMMAND trans2_Control_Oxyg_STATUS_read; \
	VARIABLE trans2_Control_Oxyg_CHANNEL; \
	MENU trans2_Control_Oxyg_CHANNEL_page; \
	COMMAND trans2_Control_Oxyg_CHANNEL_read; \
	COMMAND trans2_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans2_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans2_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans2_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans2_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans2_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans2_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans2_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans2_Control_Oxyg_RECIPE; \
	MENU trans2_Control_Oxyg_RECIPE_page; \
	COMMAND trans2_Control_Oxyg_RECIPE_read; \
	COMMAND trans2_Control_Oxyg_RECIPE_write; \
	VARIABLE trans2_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans2_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans2_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS2_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS2_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans2_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS2_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS2_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans2_Control_Oxyg_VIEW_1; \
	MENU trans2_Control_Oxyg_VIEW_1_page; \
	MENU trans2_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS2_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans2_Control_Oxyg_QUALITY_type; \
	ARRAY trans2_Control_Oxyg_QUALITY; \
	MENU trans2_Control_Oxyg_QUALITY_page; \
	COMMAND trans2_Control_Oxyg_QUALITY_read; \
	VARIABLE trans2_Control_Oxyg_SP_type; \
	ARRAY trans2_Control_Oxyg_SP; \
	MENU trans2_Control_Oxyg_SP_page; \
	COMMAND trans2_Control_Oxyg_SP_read; \
	COMMAND trans2_Control_Oxyg_SP_write; \
	VARIABLE trans2_Control_Oxyg_PV_type; \
	ARRAY trans2_Control_Oxyg_PV; \
	MENU trans2_Control_Oxyg_PV_page; \
	COMMAND trans2_Control_Oxyg_PV_read; \
	VARIABLE trans2_Control_Oxyg_CTB_MASTER; \
	MENU trans2_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans2_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans2_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans2_Control_Oxyg_SELECTION_type; \
	ARRAY trans2_Control_Oxyg_SELECTION; \
	MENU trans2_Control_Oxyg_SELECTION_page; \
	COMMAND trans2_Control_Oxyg_SELECTION_read; \
	COMMAND trans2_Control_Oxyg_SELECTION_write; \
	VARIABLE trans2_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans2_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans2_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans2_Control_Oxyg_CALOXY_TYPE; \
	MENU trans2_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans2_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans2_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans2_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans2_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans2_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans2_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans2_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans2_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans2_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans2_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans2_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans2_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans2_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans2_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans2_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans2_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans2_Control_Oxyg_CALOXY_TEMP; \
	MENU trans2_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans2_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans2_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans2_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans2_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans2_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans2_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans2_Control_Oxyg_VIEW_2; \
	MENU trans2_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans2_Control_Oxyg_VIEW_3; \
	MENU trans2_Control_Oxyg_VIEW_3_page

#define USE_TRANS2_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS2_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans2_Control_Oxyg_VIEW_1; \
	MENU trans2_Control_Oxyg_VIEW_1_page; \
	MENU trans2_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS2_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS2_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans2_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans2_Control_Oxyg_)
#define USE_TRANS2_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans2_Control_Oxyg_)
#define USE_TRANS2_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans2_Control_Oxyg_)
#define USE_TRANS2_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans2_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans3_Control_Oxyg_block; \
	COLLECTION trans3_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans3_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans3_Control_Oxyg_ST_REV; \
	MENU trans3_Control_Oxyg_ST_REV_page; \
	COMMAND trans3_Control_Oxyg_ST_REV_read; \
	VARIABLE trans3_Control_Oxyg_TAG_DESC; \
	MENU trans3_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans3_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans3_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans3_Control_Oxyg_STRATEGY; \
	MENU trans3_Control_Oxyg_STRATEGY_page; \
	COMMAND trans3_Control_Oxyg_STRATEGY_read; \
	COMMAND trans3_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans3_Control_Oxyg_ALERT_KEY; \
	MENU trans3_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans3_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans3_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans3_Control_Oxyg_TARGET_MODE; \
	MENU trans3_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans3_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans3_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans3_Control_Oxyg_MODE_BLK; \
	VARIABLE trans3_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans3_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans3_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans3_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans3_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans3_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans3_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans3_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans3_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans3_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans3_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans3_Control_Oxyg_BLOCK_TYPE; \
	MENU trans3_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans3_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans3_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans3_Control_Oxyg_COMMAND; \
	MENU trans3_Control_Oxyg_COMMAND_page; \
	COMMAND trans3_Control_Oxyg_COMMAND_read; \
	COMMAND trans3_Control_Oxyg_COMMAND_write; \
	VARIABLE trans3_Control_Oxyg_STATUS; \
	MENU trans3_Control_Oxyg_STATUS_page; \
	COMMAND trans3_Control_Oxyg_STATUS_read; \
	VARIABLE trans3_Control_Oxyg_CHANNEL; \
	MENU trans3_Control_Oxyg_CHANNEL_page; \
	COMMAND trans3_Control_Oxyg_CHANNEL_read; \
	COMMAND trans3_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans3_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans3_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans3_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans3_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans3_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans3_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans3_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans3_Control_Oxyg_RECIPE; \
	MENU trans3_Control_Oxyg_RECIPE_page; \
	COMMAND trans3_Control_Oxyg_RECIPE_read; \
	COMMAND trans3_Control_Oxyg_RECIPE_write; \
	VARIABLE trans3_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans3_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans3_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS3_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS3_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans3_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS3_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS3_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans3_Control_Oxyg_VIEW_1; \
	MENU trans3_Control_Oxyg_VIEW_1_page; \
	MENU trans3_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS3_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans3_Control_Oxyg_QUALITY_type; \
	ARRAY trans3_Control_Oxyg_QUALITY; \
	MENU trans3_Control_Oxyg_QUALITY_page; \
	COMMAND trans3_Control_Oxyg_QUALITY_read; \
	VARIABLE trans3_Control_Oxyg_SP_type; \
	ARRAY trans3_Control_Oxyg_SP; \
	MENU trans3_Control_Oxyg_SP_page; \
	COMMAND trans3_Control_Oxyg_SP_read; \
	COMMAND trans3_Control_Oxyg_SP_write; \
	VARIABLE trans3_Control_Oxyg_PV_type; \
	ARRAY trans3_Control_Oxyg_PV; \
	MENU trans3_Control_Oxyg_PV_page; \
	COMMAND trans3_Control_Oxyg_PV_read; \
	VARIABLE trans3_Control_Oxyg_CTB_MASTER; \
	MENU trans3_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans3_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans3_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans3_Control_Oxyg_SELECTION_type; \
	ARRAY trans3_Control_Oxyg_SELECTION; \
	MENU trans3_Control_Oxyg_SELECTION_page; \
	COMMAND trans3_Control_Oxyg_SELECTION_read; \
	COMMAND trans3_Control_Oxyg_SELECTION_write; \
	VARIABLE trans3_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans3_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans3_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans3_Control_Oxyg_CALOXY_TYPE; \
	MENU trans3_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans3_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans3_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans3_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans3_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans3_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans3_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans3_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans3_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans3_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans3_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans3_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans3_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans3_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans3_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans3_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans3_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans3_Control_Oxyg_CALOXY_TEMP; \
	MENU trans3_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans3_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans3_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans3_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans3_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans3_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans3_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans3_Control_Oxyg_VIEW_2; \
	MENU trans3_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans3_Control_Oxyg_VIEW_3; \
	MENU trans3_Control_Oxyg_VIEW_3_page

#define USE_TRANS3_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS3_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans3_Control_Oxyg_VIEW_1; \
	MENU trans3_Control_Oxyg_VIEW_1_page; \
	MENU trans3_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS3_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS3_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans3_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans3_Control_Oxyg_)
#define USE_TRANS3_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans3_Control_Oxyg_)
#define USE_TRANS3_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans3_Control_Oxyg_)
#define USE_TRANS3_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans3_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans4_Control_Oxyg_block; \
	COLLECTION trans4_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans4_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans4_Control_Oxyg_ST_REV; \
	MENU trans4_Control_Oxyg_ST_REV_page; \
	COMMAND trans4_Control_Oxyg_ST_REV_read; \
	VARIABLE trans4_Control_Oxyg_TAG_DESC; \
	MENU trans4_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans4_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans4_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans4_Control_Oxyg_STRATEGY; \
	MENU trans4_Control_Oxyg_STRATEGY_page; \
	COMMAND trans4_Control_Oxyg_STRATEGY_read; \
	COMMAND trans4_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans4_Control_Oxyg_ALERT_KEY; \
	MENU trans4_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans4_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans4_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans4_Control_Oxyg_TARGET_MODE; \
	MENU trans4_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans4_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans4_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans4_Control_Oxyg_MODE_BLK; \
	VARIABLE trans4_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans4_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans4_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans4_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans4_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans4_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans4_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans4_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans4_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans4_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans4_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans4_Control_Oxyg_BLOCK_TYPE; \
	MENU trans4_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans4_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans4_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans4_Control_Oxyg_COMMAND; \
	MENU trans4_Control_Oxyg_COMMAND_page; \
	COMMAND trans4_Control_Oxyg_COMMAND_read; \
	COMMAND trans4_Control_Oxyg_COMMAND_write; \
	VARIABLE trans4_Control_Oxyg_STATUS; \
	MENU trans4_Control_Oxyg_STATUS_page; \
	COMMAND trans4_Control_Oxyg_STATUS_read; \
	VARIABLE trans4_Control_Oxyg_CHANNEL; \
	MENU trans4_Control_Oxyg_CHANNEL_page; \
	COMMAND trans4_Control_Oxyg_CHANNEL_read; \
	COMMAND trans4_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans4_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans4_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans4_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans4_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans4_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans4_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans4_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans4_Control_Oxyg_RECIPE; \
	MENU trans4_Control_Oxyg_RECIPE_page; \
	COMMAND trans4_Control_Oxyg_RECIPE_read; \
	COMMAND trans4_Control_Oxyg_RECIPE_write; \
	VARIABLE trans4_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans4_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans4_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS4_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS4_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans4_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS4_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS4_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans4_Control_Oxyg_VIEW_1; \
	MENU trans4_Control_Oxyg_VIEW_1_page; \
	MENU trans4_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS4_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans4_Control_Oxyg_QUALITY_type; \
	ARRAY trans4_Control_Oxyg_QUALITY; \
	MENU trans4_Control_Oxyg_QUALITY_page; \
	COMMAND trans4_Control_Oxyg_QUALITY_read; \
	VARIABLE trans4_Control_Oxyg_SP_type; \
	ARRAY trans4_Control_Oxyg_SP; \
	MENU trans4_Control_Oxyg_SP_page; \
	COMMAND trans4_Control_Oxyg_SP_read; \
	COMMAND trans4_Control_Oxyg_SP_write; \
	VARIABLE trans4_Control_Oxyg_PV_type; \
	ARRAY trans4_Control_Oxyg_PV; \
	MENU trans4_Control_Oxyg_PV_page; \
	COMMAND trans4_Control_Oxyg_PV_read; \
	VARIABLE trans4_Control_Oxyg_CTB_MASTER; \
	MENU trans4_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans4_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans4_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans4_Control_Oxyg_SELECTION_type; \
	ARRAY trans4_Control_Oxyg_SELECTION; \
	MENU trans4_Control_Oxyg_SELECTION_page; \
	COMMAND trans4_Control_Oxyg_SELECTION_read; \
	COMMAND trans4_Control_Oxyg_SELECTION_write; \
	VARIABLE trans4_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans4_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans4_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans4_Control_Oxyg_CALOXY_TYPE; \
	MENU trans4_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans4_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans4_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans4_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans4_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans4_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans4_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans4_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans4_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans4_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans4_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans4_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans4_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans4_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans4_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans4_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans4_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans4_Control_Oxyg_CALOXY_TEMP; \
	MENU trans4_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans4_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans4_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans4_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans4_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans4_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans4_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans4_Control_Oxyg_VIEW_2; \
	MENU trans4_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans4_Control_Oxyg_VIEW_3; \
	MENU trans4_Control_Oxyg_VIEW_3_page

#define USE_TRANS4_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS4_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans4_Control_Oxyg_VIEW_1; \
	MENU trans4_Control_Oxyg_VIEW_1_page; \
	MENU trans4_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS4_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS4_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans4_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans4_Control_Oxyg_)
#define USE_TRANS4_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans4_Control_Oxyg_)
#define USE_TRANS4_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans4_Control_Oxyg_)
#define USE_TRANS4_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans4_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans5_Control_Oxyg_block; \
	COLLECTION trans5_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans5_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans5_Control_Oxyg_ST_REV; \
	MENU trans5_Control_Oxyg_ST_REV_page; \
	COMMAND trans5_Control_Oxyg_ST_REV_read; \
	VARIABLE trans5_Control_Oxyg_TAG_DESC; \
	MENU trans5_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans5_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans5_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans5_Control_Oxyg_STRATEGY; \
	MENU trans5_Control_Oxyg_STRATEGY_page; \
	COMMAND trans5_Control_Oxyg_STRATEGY_read; \
	COMMAND trans5_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans5_Control_Oxyg_ALERT_KEY; \
	MENU trans5_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans5_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans5_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans5_Control_Oxyg_TARGET_MODE; \
	MENU trans5_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans5_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans5_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans5_Control_Oxyg_MODE_BLK; \
	VARIABLE trans5_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans5_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans5_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans5_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans5_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans5_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans5_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans5_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans5_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans5_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans5_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans5_Control_Oxyg_BLOCK_TYPE; \
	MENU trans5_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans5_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans5_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans5_Control_Oxyg_COMMAND; \
	MENU trans5_Control_Oxyg_COMMAND_page; \
	COMMAND trans5_Control_Oxyg_COMMAND_read; \
	COMMAND trans5_Control_Oxyg_COMMAND_write; \
	VARIABLE trans5_Control_Oxyg_STATUS; \
	MENU trans5_Control_Oxyg_STATUS_page; \
	COMMAND trans5_Control_Oxyg_STATUS_read; \
	VARIABLE trans5_Control_Oxyg_CHANNEL; \
	MENU trans5_Control_Oxyg_CHANNEL_page; \
	COMMAND trans5_Control_Oxyg_CHANNEL_read; \
	COMMAND trans5_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans5_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans5_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans5_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans5_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans5_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans5_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans5_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans5_Control_Oxyg_RECIPE; \
	MENU trans5_Control_Oxyg_RECIPE_page; \
	COMMAND trans5_Control_Oxyg_RECIPE_read; \
	COMMAND trans5_Control_Oxyg_RECIPE_write; \
	VARIABLE trans5_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans5_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans5_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS5_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS5_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans5_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS5_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS5_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans5_Control_Oxyg_VIEW_1; \
	MENU trans5_Control_Oxyg_VIEW_1_page; \
	MENU trans5_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS5_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans5_Control_Oxyg_QUALITY_type; \
	ARRAY trans5_Control_Oxyg_QUALITY; \
	MENU trans5_Control_Oxyg_QUALITY_page; \
	COMMAND trans5_Control_Oxyg_QUALITY_read; \
	VARIABLE trans5_Control_Oxyg_SP_type; \
	ARRAY trans5_Control_Oxyg_SP; \
	MENU trans5_Control_Oxyg_SP_page; \
	COMMAND trans5_Control_Oxyg_SP_read; \
	COMMAND trans5_Control_Oxyg_SP_write; \
	VARIABLE trans5_Control_Oxyg_PV_type; \
	ARRAY trans5_Control_Oxyg_PV; \
	MENU trans5_Control_Oxyg_PV_page; \
	COMMAND trans5_Control_Oxyg_PV_read; \
	VARIABLE trans5_Control_Oxyg_CTB_MASTER; \
	MENU trans5_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans5_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans5_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans5_Control_Oxyg_SELECTION_type; \
	ARRAY trans5_Control_Oxyg_SELECTION; \
	MENU trans5_Control_Oxyg_SELECTION_page; \
	COMMAND trans5_Control_Oxyg_SELECTION_read; \
	COMMAND trans5_Control_Oxyg_SELECTION_write; \
	VARIABLE trans5_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans5_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans5_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans5_Control_Oxyg_CALOXY_TYPE; \
	MENU trans5_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans5_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans5_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans5_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans5_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans5_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans5_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans5_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans5_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans5_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans5_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans5_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans5_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans5_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans5_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans5_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans5_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans5_Control_Oxyg_CALOXY_TEMP; \
	MENU trans5_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans5_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans5_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans5_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans5_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans5_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans5_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans5_Control_Oxyg_VIEW_2; \
	MENU trans5_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans5_Control_Oxyg_VIEW_3; \
	MENU trans5_Control_Oxyg_VIEW_3_page

#define USE_TRANS5_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS5_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans5_Control_Oxyg_VIEW_1; \
	MENU trans5_Control_Oxyg_VIEW_1_page; \
	MENU trans5_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS5_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS5_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans5_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans5_Control_Oxyg_)
#define USE_TRANS5_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans5_Control_Oxyg_)
#define USE_TRANS5_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans5_Control_Oxyg_)
#define USE_TRANS5_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans5_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans6_Control_Oxyg_block; \
	COLLECTION trans6_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans6_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans6_Control_Oxyg_ST_REV; \
	MENU trans6_Control_Oxyg_ST_REV_page; \
	COMMAND trans6_Control_Oxyg_ST_REV_read; \
	VARIABLE trans6_Control_Oxyg_TAG_DESC; \
	MENU trans6_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans6_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans6_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans6_Control_Oxyg_STRATEGY; \
	MENU trans6_Control_Oxyg_STRATEGY_page; \
	COMMAND trans6_Control_Oxyg_STRATEGY_read; \
	COMMAND trans6_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans6_Control_Oxyg_ALERT_KEY; \
	MENU trans6_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans6_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans6_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans6_Control_Oxyg_TARGET_MODE; \
	MENU trans6_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans6_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans6_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans6_Control_Oxyg_MODE_BLK; \
	VARIABLE trans6_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans6_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans6_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans6_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans6_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans6_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans6_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans6_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans6_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans6_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans6_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans6_Control_Oxyg_BLOCK_TYPE; \
	MENU trans6_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans6_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans6_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans6_Control_Oxyg_COMMAND; \
	MENU trans6_Control_Oxyg_COMMAND_page; \
	COMMAND trans6_Control_Oxyg_COMMAND_read; \
	COMMAND trans6_Control_Oxyg_COMMAND_write; \
	VARIABLE trans6_Control_Oxyg_STATUS; \
	MENU trans6_Control_Oxyg_STATUS_page; \
	COMMAND trans6_Control_Oxyg_STATUS_read; \
	VARIABLE trans6_Control_Oxyg_CHANNEL; \
	MENU trans6_Control_Oxyg_CHANNEL_page; \
	COMMAND trans6_Control_Oxyg_CHANNEL_read; \
	COMMAND trans6_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans6_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans6_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans6_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans6_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans6_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans6_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans6_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans6_Control_Oxyg_RECIPE; \
	MENU trans6_Control_Oxyg_RECIPE_page; \
	COMMAND trans6_Control_Oxyg_RECIPE_read; \
	COMMAND trans6_Control_Oxyg_RECIPE_write; \
	VARIABLE trans6_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans6_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans6_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS6_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS6_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans6_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS6_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS6_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans6_Control_Oxyg_VIEW_1; \
	MENU trans6_Control_Oxyg_VIEW_1_page; \
	MENU trans6_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS6_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans6_Control_Oxyg_QUALITY_type; \
	ARRAY trans6_Control_Oxyg_QUALITY; \
	MENU trans6_Control_Oxyg_QUALITY_page; \
	COMMAND trans6_Control_Oxyg_QUALITY_read; \
	VARIABLE trans6_Control_Oxyg_SP_type; \
	ARRAY trans6_Control_Oxyg_SP; \
	MENU trans6_Control_Oxyg_SP_page; \
	COMMAND trans6_Control_Oxyg_SP_read; \
	COMMAND trans6_Control_Oxyg_SP_write; \
	VARIABLE trans6_Control_Oxyg_PV_type; \
	ARRAY trans6_Control_Oxyg_PV; \
	MENU trans6_Control_Oxyg_PV_page; \
	COMMAND trans6_Control_Oxyg_PV_read; \
	VARIABLE trans6_Control_Oxyg_CTB_MASTER; \
	MENU trans6_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans6_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans6_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans6_Control_Oxyg_SELECTION_type; \
	ARRAY trans6_Control_Oxyg_SELECTION; \
	MENU trans6_Control_Oxyg_SELECTION_page; \
	COMMAND trans6_Control_Oxyg_SELECTION_read; \
	COMMAND trans6_Control_Oxyg_SELECTION_write; \
	VARIABLE trans6_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans6_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans6_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans6_Control_Oxyg_CALOXY_TYPE; \
	MENU trans6_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans6_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans6_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans6_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans6_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans6_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans6_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans6_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans6_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans6_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans6_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans6_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans6_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans6_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans6_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans6_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans6_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans6_Control_Oxyg_CALOXY_TEMP; \
	MENU trans6_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans6_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans6_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans6_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans6_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans6_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans6_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans6_Control_Oxyg_VIEW_2; \
	MENU trans6_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans6_Control_Oxyg_VIEW_3; \
	MENU trans6_Control_Oxyg_VIEW_3_page

#define USE_TRANS6_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS6_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans6_Control_Oxyg_VIEW_1; \
	MENU trans6_Control_Oxyg_VIEW_1_page; \
	MENU trans6_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS6_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS6_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans6_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans6_Control_Oxyg_)
#define USE_TRANS6_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans6_Control_Oxyg_)
#define USE_TRANS6_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans6_Control_Oxyg_)
#define USE_TRANS6_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans6_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans7_Control_Oxyg_block; \
	COLLECTION trans7_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans7_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans7_Control_Oxyg_ST_REV; \
	MENU trans7_Control_Oxyg_ST_REV_page; \
	COMMAND trans7_Control_Oxyg_ST_REV_read; \
	VARIABLE trans7_Control_Oxyg_TAG_DESC; \
	MENU trans7_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans7_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans7_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans7_Control_Oxyg_STRATEGY; \
	MENU trans7_Control_Oxyg_STRATEGY_page; \
	COMMAND trans7_Control_Oxyg_STRATEGY_read; \
	COMMAND trans7_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans7_Control_Oxyg_ALERT_KEY; \
	MENU trans7_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans7_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans7_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans7_Control_Oxyg_TARGET_MODE; \
	MENU trans7_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans7_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans7_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans7_Control_Oxyg_MODE_BLK; \
	VARIABLE trans7_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans7_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans7_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans7_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans7_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans7_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans7_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans7_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans7_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans7_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans7_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans7_Control_Oxyg_BLOCK_TYPE; \
	MENU trans7_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans7_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans7_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans7_Control_Oxyg_COMMAND; \
	MENU trans7_Control_Oxyg_COMMAND_page; \
	COMMAND trans7_Control_Oxyg_COMMAND_read; \
	COMMAND trans7_Control_Oxyg_COMMAND_write; \
	VARIABLE trans7_Control_Oxyg_STATUS; \
	MENU trans7_Control_Oxyg_STATUS_page; \
	COMMAND trans7_Control_Oxyg_STATUS_read; \
	VARIABLE trans7_Control_Oxyg_CHANNEL; \
	MENU trans7_Control_Oxyg_CHANNEL_page; \
	COMMAND trans7_Control_Oxyg_CHANNEL_read; \
	COMMAND trans7_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans7_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans7_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans7_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans7_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans7_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans7_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans7_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans7_Control_Oxyg_RECIPE; \
	MENU trans7_Control_Oxyg_RECIPE_page; \
	COMMAND trans7_Control_Oxyg_RECIPE_read; \
	COMMAND trans7_Control_Oxyg_RECIPE_write; \
	VARIABLE trans7_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans7_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans7_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS7_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS7_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans7_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS7_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS7_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans7_Control_Oxyg_VIEW_1; \
	MENU trans7_Control_Oxyg_VIEW_1_page; \
	MENU trans7_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS7_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans7_Control_Oxyg_QUALITY_type; \
	ARRAY trans7_Control_Oxyg_QUALITY; \
	MENU trans7_Control_Oxyg_QUALITY_page; \
	COMMAND trans7_Control_Oxyg_QUALITY_read; \
	VARIABLE trans7_Control_Oxyg_SP_type; \
	ARRAY trans7_Control_Oxyg_SP; \
	MENU trans7_Control_Oxyg_SP_page; \
	COMMAND trans7_Control_Oxyg_SP_read; \
	COMMAND trans7_Control_Oxyg_SP_write; \
	VARIABLE trans7_Control_Oxyg_PV_type; \
	ARRAY trans7_Control_Oxyg_PV; \
	MENU trans7_Control_Oxyg_PV_page; \
	COMMAND trans7_Control_Oxyg_PV_read; \
	VARIABLE trans7_Control_Oxyg_CTB_MASTER; \
	MENU trans7_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans7_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans7_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans7_Control_Oxyg_SELECTION_type; \
	ARRAY trans7_Control_Oxyg_SELECTION; \
	MENU trans7_Control_Oxyg_SELECTION_page; \
	COMMAND trans7_Control_Oxyg_SELECTION_read; \
	COMMAND trans7_Control_Oxyg_SELECTION_write; \
	VARIABLE trans7_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans7_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans7_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans7_Control_Oxyg_CALOXY_TYPE; \
	MENU trans7_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans7_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans7_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans7_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans7_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans7_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans7_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans7_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans7_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans7_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans7_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans7_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans7_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans7_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans7_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans7_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans7_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans7_Control_Oxyg_CALOXY_TEMP; \
	MENU trans7_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans7_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans7_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans7_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans7_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans7_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans7_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans7_Control_Oxyg_VIEW_2; \
	MENU trans7_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans7_Control_Oxyg_VIEW_3; \
	MENU trans7_Control_Oxyg_VIEW_3_page

#define USE_TRANS7_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS7_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans7_Control_Oxyg_VIEW_1; \
	MENU trans7_Control_Oxyg_VIEW_1_page; \
	MENU trans7_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS7_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS7_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans7_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans7_Control_Oxyg_)
#define USE_TRANS7_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans7_Control_Oxyg_)
#define USE_TRANS7_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans7_Control_Oxyg_)
#define USE_TRANS7_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans7_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans8_Control_Oxyg_block; \
	COLLECTION trans8_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans8_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans8_Control_Oxyg_ST_REV; \
	MENU trans8_Control_Oxyg_ST_REV_page; \
	COMMAND trans8_Control_Oxyg_ST_REV_read; \
	VARIABLE trans8_Control_Oxyg_TAG_DESC; \
	MENU trans8_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans8_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans8_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans8_Control_Oxyg_STRATEGY; \
	MENU trans8_Control_Oxyg_STRATEGY_page; \
	COMMAND trans8_Control_Oxyg_STRATEGY_read; \
	COMMAND trans8_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans8_Control_Oxyg_ALERT_KEY; \
	MENU trans8_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans8_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans8_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans8_Control_Oxyg_TARGET_MODE; \
	MENU trans8_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans8_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans8_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans8_Control_Oxyg_MODE_BLK; \
	VARIABLE trans8_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans8_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans8_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans8_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans8_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans8_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans8_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans8_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans8_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans8_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans8_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans8_Control_Oxyg_BLOCK_TYPE; \
	MENU trans8_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans8_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans8_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans8_Control_Oxyg_COMMAND; \
	MENU trans8_Control_Oxyg_COMMAND_page; \
	COMMAND trans8_Control_Oxyg_COMMAND_read; \
	COMMAND trans8_Control_Oxyg_COMMAND_write; \
	VARIABLE trans8_Control_Oxyg_STATUS; \
	MENU trans8_Control_Oxyg_STATUS_page; \
	COMMAND trans8_Control_Oxyg_STATUS_read; \
	VARIABLE trans8_Control_Oxyg_CHANNEL; \
	MENU trans8_Control_Oxyg_CHANNEL_page; \
	COMMAND trans8_Control_Oxyg_CHANNEL_read; \
	COMMAND trans8_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans8_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans8_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans8_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans8_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans8_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans8_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans8_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans8_Control_Oxyg_RECIPE; \
	MENU trans8_Control_Oxyg_RECIPE_page; \
	COMMAND trans8_Control_Oxyg_RECIPE_read; \
	COMMAND trans8_Control_Oxyg_RECIPE_write; \
	VARIABLE trans8_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans8_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans8_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS8_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS8_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans8_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS8_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS8_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans8_Control_Oxyg_VIEW_1; \
	MENU trans8_Control_Oxyg_VIEW_1_page; \
	MENU trans8_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS8_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans8_Control_Oxyg_QUALITY_type; \
	ARRAY trans8_Control_Oxyg_QUALITY; \
	MENU trans8_Control_Oxyg_QUALITY_page; \
	COMMAND trans8_Control_Oxyg_QUALITY_read; \
	VARIABLE trans8_Control_Oxyg_SP_type; \
	ARRAY trans8_Control_Oxyg_SP; \
	MENU trans8_Control_Oxyg_SP_page; \
	COMMAND trans8_Control_Oxyg_SP_read; \
	COMMAND trans8_Control_Oxyg_SP_write; \
	VARIABLE trans8_Control_Oxyg_PV_type; \
	ARRAY trans8_Control_Oxyg_PV; \
	MENU trans8_Control_Oxyg_PV_page; \
	COMMAND trans8_Control_Oxyg_PV_read; \
	VARIABLE trans8_Control_Oxyg_CTB_MASTER; \
	MENU trans8_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans8_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans8_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans8_Control_Oxyg_SELECTION_type; \
	ARRAY trans8_Control_Oxyg_SELECTION; \
	MENU trans8_Control_Oxyg_SELECTION_page; \
	COMMAND trans8_Control_Oxyg_SELECTION_read; \
	COMMAND trans8_Control_Oxyg_SELECTION_write; \
	VARIABLE trans8_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans8_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans8_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans8_Control_Oxyg_CALOXY_TYPE; \
	MENU trans8_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans8_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans8_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans8_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans8_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans8_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans8_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans8_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans8_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans8_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans8_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans8_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans8_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans8_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans8_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans8_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans8_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans8_Control_Oxyg_CALOXY_TEMP; \
	MENU trans8_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans8_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans8_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans8_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans8_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans8_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans8_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans8_Control_Oxyg_VIEW_2; \
	MENU trans8_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans8_Control_Oxyg_VIEW_3; \
	MENU trans8_Control_Oxyg_VIEW_3_page

#define USE_TRANS8_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS8_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans8_Control_Oxyg_VIEW_1; \
	MENU trans8_Control_Oxyg_VIEW_1_page; \
	MENU trans8_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS8_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS8_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans8_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans8_Control_Oxyg_)
#define USE_TRANS8_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans8_Control_Oxyg_)
#define USE_TRANS8_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans8_Control_Oxyg_)
#define USE_TRANS8_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans8_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans9_Control_Oxyg_block; \
	COLLECTION trans9_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans9_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans9_Control_Oxyg_ST_REV; \
	MENU trans9_Control_Oxyg_ST_REV_page; \
	COMMAND trans9_Control_Oxyg_ST_REV_read; \
	VARIABLE trans9_Control_Oxyg_TAG_DESC; \
	MENU trans9_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans9_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans9_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans9_Control_Oxyg_STRATEGY; \
	MENU trans9_Control_Oxyg_STRATEGY_page; \
	COMMAND trans9_Control_Oxyg_STRATEGY_read; \
	COMMAND trans9_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans9_Control_Oxyg_ALERT_KEY; \
	MENU trans9_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans9_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans9_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans9_Control_Oxyg_TARGET_MODE; \
	MENU trans9_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans9_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans9_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans9_Control_Oxyg_MODE_BLK; \
	VARIABLE trans9_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans9_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans9_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans9_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans9_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans9_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans9_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans9_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans9_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans9_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans9_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans9_Control_Oxyg_BLOCK_TYPE; \
	MENU trans9_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans9_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans9_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans9_Control_Oxyg_COMMAND; \
	MENU trans9_Control_Oxyg_COMMAND_page; \
	COMMAND trans9_Control_Oxyg_COMMAND_read; \
	COMMAND trans9_Control_Oxyg_COMMAND_write; \
	VARIABLE trans9_Control_Oxyg_STATUS; \
	MENU trans9_Control_Oxyg_STATUS_page; \
	COMMAND trans9_Control_Oxyg_STATUS_read; \
	VARIABLE trans9_Control_Oxyg_CHANNEL; \
	MENU trans9_Control_Oxyg_CHANNEL_page; \
	COMMAND trans9_Control_Oxyg_CHANNEL_read; \
	COMMAND trans9_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans9_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans9_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans9_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans9_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans9_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans9_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans9_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans9_Control_Oxyg_RECIPE; \
	MENU trans9_Control_Oxyg_RECIPE_page; \
	COMMAND trans9_Control_Oxyg_RECIPE_read; \
	COMMAND trans9_Control_Oxyg_RECIPE_write; \
	VARIABLE trans9_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans9_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans9_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS9_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS9_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans9_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS9_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS9_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans9_Control_Oxyg_VIEW_1; \
	MENU trans9_Control_Oxyg_VIEW_1_page; \
	MENU trans9_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS9_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans9_Control_Oxyg_QUALITY_type; \
	ARRAY trans9_Control_Oxyg_QUALITY; \
	MENU trans9_Control_Oxyg_QUALITY_page; \
	COMMAND trans9_Control_Oxyg_QUALITY_read; \
	VARIABLE trans9_Control_Oxyg_SP_type; \
	ARRAY trans9_Control_Oxyg_SP; \
	MENU trans9_Control_Oxyg_SP_page; \
	COMMAND trans9_Control_Oxyg_SP_read; \
	COMMAND trans9_Control_Oxyg_SP_write; \
	VARIABLE trans9_Control_Oxyg_PV_type; \
	ARRAY trans9_Control_Oxyg_PV; \
	MENU trans9_Control_Oxyg_PV_page; \
	COMMAND trans9_Control_Oxyg_PV_read; \
	VARIABLE trans9_Control_Oxyg_CTB_MASTER; \
	MENU trans9_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans9_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans9_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans9_Control_Oxyg_SELECTION_type; \
	ARRAY trans9_Control_Oxyg_SELECTION; \
	MENU trans9_Control_Oxyg_SELECTION_page; \
	COMMAND trans9_Control_Oxyg_SELECTION_read; \
	COMMAND trans9_Control_Oxyg_SELECTION_write; \
	VARIABLE trans9_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans9_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans9_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans9_Control_Oxyg_CALOXY_TYPE; \
	MENU trans9_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans9_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans9_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans9_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans9_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans9_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans9_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans9_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans9_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans9_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans9_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans9_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans9_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans9_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans9_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans9_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans9_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans9_Control_Oxyg_CALOXY_TEMP; \
	MENU trans9_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans9_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans9_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans9_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans9_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans9_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans9_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans9_Control_Oxyg_VIEW_2; \
	MENU trans9_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans9_Control_Oxyg_VIEW_3; \
	MENU trans9_Control_Oxyg_VIEW_3_page

#define USE_TRANS9_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS9_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans9_Control_Oxyg_VIEW_1; \
	MENU trans9_Control_Oxyg_VIEW_1_page; \
	MENU trans9_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS9_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS9_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans9_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans9_Control_Oxyg_)
#define USE_TRANS9_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans9_Control_Oxyg_)
#define USE_TRANS9_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans9_Control_Oxyg_)
#define USE_TRANS9_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans9_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans10_Control_Oxyg_block; \
	COLLECTION trans10_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans10_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans10_Control_Oxyg_ST_REV; \
	MENU trans10_Control_Oxyg_ST_REV_page; \
	COMMAND trans10_Control_Oxyg_ST_REV_read; \
	VARIABLE trans10_Control_Oxyg_TAG_DESC; \
	MENU trans10_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans10_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans10_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans10_Control_Oxyg_STRATEGY; \
	MENU trans10_Control_Oxyg_STRATEGY_page; \
	COMMAND trans10_Control_Oxyg_STRATEGY_read; \
	COMMAND trans10_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans10_Control_Oxyg_ALERT_KEY; \
	MENU trans10_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans10_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans10_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans10_Control_Oxyg_TARGET_MODE; \
	MENU trans10_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans10_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans10_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans10_Control_Oxyg_MODE_BLK; \
	VARIABLE trans10_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans10_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans10_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans10_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans10_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans10_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans10_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans10_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans10_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans10_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans10_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans10_Control_Oxyg_BLOCK_TYPE; \
	MENU trans10_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans10_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans10_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans10_Control_Oxyg_COMMAND; \
	MENU trans10_Control_Oxyg_COMMAND_page; \
	COMMAND trans10_Control_Oxyg_COMMAND_read; \
	COMMAND trans10_Control_Oxyg_COMMAND_write; \
	VARIABLE trans10_Control_Oxyg_STATUS; \
	MENU trans10_Control_Oxyg_STATUS_page; \
	COMMAND trans10_Control_Oxyg_STATUS_read; \
	VARIABLE trans10_Control_Oxyg_CHANNEL; \
	MENU trans10_Control_Oxyg_CHANNEL_page; \
	COMMAND trans10_Control_Oxyg_CHANNEL_read; \
	COMMAND trans10_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans10_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans10_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans10_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans10_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans10_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans10_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans10_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans10_Control_Oxyg_RECIPE; \
	MENU trans10_Control_Oxyg_RECIPE_page; \
	COMMAND trans10_Control_Oxyg_RECIPE_read; \
	COMMAND trans10_Control_Oxyg_RECIPE_write; \
	VARIABLE trans10_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans10_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans10_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS10_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS10_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans10_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS10_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS10_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans10_Control_Oxyg_VIEW_1; \
	MENU trans10_Control_Oxyg_VIEW_1_page; \
	MENU trans10_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS10_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans10_Control_Oxyg_QUALITY_type; \
	ARRAY trans10_Control_Oxyg_QUALITY; \
	MENU trans10_Control_Oxyg_QUALITY_page; \
	COMMAND trans10_Control_Oxyg_QUALITY_read; \
	VARIABLE trans10_Control_Oxyg_SP_type; \
	ARRAY trans10_Control_Oxyg_SP; \
	MENU trans10_Control_Oxyg_SP_page; \
	COMMAND trans10_Control_Oxyg_SP_read; \
	COMMAND trans10_Control_Oxyg_SP_write; \
	VARIABLE trans10_Control_Oxyg_PV_type; \
	ARRAY trans10_Control_Oxyg_PV; \
	MENU trans10_Control_Oxyg_PV_page; \
	COMMAND trans10_Control_Oxyg_PV_read; \
	VARIABLE trans10_Control_Oxyg_CTB_MASTER; \
	MENU trans10_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans10_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans10_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans10_Control_Oxyg_SELECTION_type; \
	ARRAY trans10_Control_Oxyg_SELECTION; \
	MENU trans10_Control_Oxyg_SELECTION_page; \
	COMMAND trans10_Control_Oxyg_SELECTION_read; \
	COMMAND trans10_Control_Oxyg_SELECTION_write; \
	VARIABLE trans10_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans10_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans10_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans10_Control_Oxyg_CALOXY_TYPE; \
	MENU trans10_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans10_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans10_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans10_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans10_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans10_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans10_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans10_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans10_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans10_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans10_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans10_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans10_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans10_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans10_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans10_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans10_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans10_Control_Oxyg_CALOXY_TEMP; \
	MENU trans10_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans10_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans10_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans10_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans10_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans10_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans10_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans10_Control_Oxyg_VIEW_2; \
	MENU trans10_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans10_Control_Oxyg_VIEW_3; \
	MENU trans10_Control_Oxyg_VIEW_3_page

#define USE_TRANS10_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS10_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans10_Control_Oxyg_VIEW_1; \
	MENU trans10_Control_Oxyg_VIEW_1_page; \
	MENU trans10_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS10_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS10_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans10_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans10_Control_Oxyg_)
#define USE_TRANS10_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans10_Control_Oxyg_)
#define USE_TRANS10_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans10_Control_Oxyg_)
#define USE_TRANS10_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans10_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans11_Control_Oxyg_block; \
	COLLECTION trans11_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans11_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans11_Control_Oxyg_ST_REV; \
	MENU trans11_Control_Oxyg_ST_REV_page; \
	COMMAND trans11_Control_Oxyg_ST_REV_read; \
	VARIABLE trans11_Control_Oxyg_TAG_DESC; \
	MENU trans11_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans11_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans11_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans11_Control_Oxyg_STRATEGY; \
	MENU trans11_Control_Oxyg_STRATEGY_page; \
	COMMAND trans11_Control_Oxyg_STRATEGY_read; \
	COMMAND trans11_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans11_Control_Oxyg_ALERT_KEY; \
	MENU trans11_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans11_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans11_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans11_Control_Oxyg_TARGET_MODE; \
	MENU trans11_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans11_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans11_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans11_Control_Oxyg_MODE_BLK; \
	VARIABLE trans11_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans11_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans11_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans11_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans11_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans11_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans11_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans11_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans11_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans11_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans11_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans11_Control_Oxyg_BLOCK_TYPE; \
	MENU trans11_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans11_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans11_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans11_Control_Oxyg_COMMAND; \
	MENU trans11_Control_Oxyg_COMMAND_page; \
	COMMAND trans11_Control_Oxyg_COMMAND_read; \
	COMMAND trans11_Control_Oxyg_COMMAND_write; \
	VARIABLE trans11_Control_Oxyg_STATUS; \
	MENU trans11_Control_Oxyg_STATUS_page; \
	COMMAND trans11_Control_Oxyg_STATUS_read; \
	VARIABLE trans11_Control_Oxyg_CHANNEL; \
	MENU trans11_Control_Oxyg_CHANNEL_page; \
	COMMAND trans11_Control_Oxyg_CHANNEL_read; \
	COMMAND trans11_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans11_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans11_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans11_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans11_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans11_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans11_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans11_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans11_Control_Oxyg_RECIPE; \
	MENU trans11_Control_Oxyg_RECIPE_page; \
	COMMAND trans11_Control_Oxyg_RECIPE_read; \
	COMMAND trans11_Control_Oxyg_RECIPE_write; \
	VARIABLE trans11_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans11_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans11_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS11_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS11_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans11_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS11_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS11_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans11_Control_Oxyg_VIEW_1; \
	MENU trans11_Control_Oxyg_VIEW_1_page; \
	MENU trans11_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS11_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans11_Control_Oxyg_QUALITY_type; \
	ARRAY trans11_Control_Oxyg_QUALITY; \
	MENU trans11_Control_Oxyg_QUALITY_page; \
	COMMAND trans11_Control_Oxyg_QUALITY_read; \
	VARIABLE trans11_Control_Oxyg_SP_type; \
	ARRAY trans11_Control_Oxyg_SP; \
	MENU trans11_Control_Oxyg_SP_page; \
	COMMAND trans11_Control_Oxyg_SP_read; \
	COMMAND trans11_Control_Oxyg_SP_write; \
	VARIABLE trans11_Control_Oxyg_PV_type; \
	ARRAY trans11_Control_Oxyg_PV; \
	MENU trans11_Control_Oxyg_PV_page; \
	COMMAND trans11_Control_Oxyg_PV_read; \
	VARIABLE trans11_Control_Oxyg_CTB_MASTER; \
	MENU trans11_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans11_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans11_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans11_Control_Oxyg_SELECTION_type; \
	ARRAY trans11_Control_Oxyg_SELECTION; \
	MENU trans11_Control_Oxyg_SELECTION_page; \
	COMMAND trans11_Control_Oxyg_SELECTION_read; \
	COMMAND trans11_Control_Oxyg_SELECTION_write; \
	VARIABLE trans11_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans11_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans11_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans11_Control_Oxyg_CALOXY_TYPE; \
	MENU trans11_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans11_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans11_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans11_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans11_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans11_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans11_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans11_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans11_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans11_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans11_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans11_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans11_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans11_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans11_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans11_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans11_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans11_Control_Oxyg_CALOXY_TEMP; \
	MENU trans11_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans11_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans11_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans11_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans11_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans11_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans11_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans11_Control_Oxyg_VIEW_2; \
	MENU trans11_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans11_Control_Oxyg_VIEW_3; \
	MENU trans11_Control_Oxyg_VIEW_3_page

#define USE_TRANS11_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS11_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans11_Control_Oxyg_VIEW_1; \
	MENU trans11_Control_Oxyg_VIEW_1_page; \
	MENU trans11_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS11_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS11_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans11_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans11_Control_Oxyg_)
#define USE_TRANS11_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans11_Control_Oxyg_)
#define USE_TRANS11_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans11_Control_Oxyg_)
#define USE_TRANS11_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans11_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans12_Control_Oxyg_block; \
	COLLECTION trans12_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans12_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans12_Control_Oxyg_ST_REV; \
	MENU trans12_Control_Oxyg_ST_REV_page; \
	COMMAND trans12_Control_Oxyg_ST_REV_read; \
	VARIABLE trans12_Control_Oxyg_TAG_DESC; \
	MENU trans12_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans12_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans12_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans12_Control_Oxyg_STRATEGY; \
	MENU trans12_Control_Oxyg_STRATEGY_page; \
	COMMAND trans12_Control_Oxyg_STRATEGY_read; \
	COMMAND trans12_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans12_Control_Oxyg_ALERT_KEY; \
	MENU trans12_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans12_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans12_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans12_Control_Oxyg_TARGET_MODE; \
	MENU trans12_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans12_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans12_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans12_Control_Oxyg_MODE_BLK; \
	VARIABLE trans12_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans12_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans12_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans12_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans12_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans12_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans12_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans12_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans12_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans12_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans12_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans12_Control_Oxyg_BLOCK_TYPE; \
	MENU trans12_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans12_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans12_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans12_Control_Oxyg_COMMAND; \
	MENU trans12_Control_Oxyg_COMMAND_page; \
	COMMAND trans12_Control_Oxyg_COMMAND_read; \
	COMMAND trans12_Control_Oxyg_COMMAND_write; \
	VARIABLE trans12_Control_Oxyg_STATUS; \
	MENU trans12_Control_Oxyg_STATUS_page; \
	COMMAND trans12_Control_Oxyg_STATUS_read; \
	VARIABLE trans12_Control_Oxyg_CHANNEL; \
	MENU trans12_Control_Oxyg_CHANNEL_page; \
	COMMAND trans12_Control_Oxyg_CHANNEL_read; \
	COMMAND trans12_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans12_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans12_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans12_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans12_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans12_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans12_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans12_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans12_Control_Oxyg_RECIPE; \
	MENU trans12_Control_Oxyg_RECIPE_page; \
	COMMAND trans12_Control_Oxyg_RECIPE_read; \
	COMMAND trans12_Control_Oxyg_RECIPE_write; \
	VARIABLE trans12_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans12_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans12_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS12_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS12_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans12_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS12_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS12_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans12_Control_Oxyg_VIEW_1; \
	MENU trans12_Control_Oxyg_VIEW_1_page; \
	MENU trans12_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS12_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans12_Control_Oxyg_QUALITY_type; \
	ARRAY trans12_Control_Oxyg_QUALITY; \
	MENU trans12_Control_Oxyg_QUALITY_page; \
	COMMAND trans12_Control_Oxyg_QUALITY_read; \
	VARIABLE trans12_Control_Oxyg_SP_type; \
	ARRAY trans12_Control_Oxyg_SP; \
	MENU trans12_Control_Oxyg_SP_page; \
	COMMAND trans12_Control_Oxyg_SP_read; \
	COMMAND trans12_Control_Oxyg_SP_write; \
	VARIABLE trans12_Control_Oxyg_PV_type; \
	ARRAY trans12_Control_Oxyg_PV; \
	MENU trans12_Control_Oxyg_PV_page; \
	COMMAND trans12_Control_Oxyg_PV_read; \
	VARIABLE trans12_Control_Oxyg_CTB_MASTER; \
	MENU trans12_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans12_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans12_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans12_Control_Oxyg_SELECTION_type; \
	ARRAY trans12_Control_Oxyg_SELECTION; \
	MENU trans12_Control_Oxyg_SELECTION_page; \
	COMMAND trans12_Control_Oxyg_SELECTION_read; \
	COMMAND trans12_Control_Oxyg_SELECTION_write; \
	VARIABLE trans12_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans12_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans12_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans12_Control_Oxyg_CALOXY_TYPE; \
	MENU trans12_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans12_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans12_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans12_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans12_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans12_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans12_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans12_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans12_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans12_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans12_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans12_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans12_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans12_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans12_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans12_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans12_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans12_Control_Oxyg_CALOXY_TEMP; \
	MENU trans12_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans12_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans12_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans12_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans12_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans12_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans12_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans12_Control_Oxyg_VIEW_2; \
	MENU trans12_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans12_Control_Oxyg_VIEW_3; \
	MENU trans12_Control_Oxyg_VIEW_3_page

#define USE_TRANS12_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS12_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans12_Control_Oxyg_VIEW_1; \
	MENU trans12_Control_Oxyg_VIEW_1_page; \
	MENU trans12_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS12_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS12_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans12_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans12_Control_Oxyg_)
#define USE_TRANS12_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans12_Control_Oxyg_)
#define USE_TRANS12_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans12_Control_Oxyg_)
#define USE_TRANS12_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans12_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans13_Control_Oxyg_block; \
	COLLECTION trans13_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans13_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans13_Control_Oxyg_ST_REV; \
	MENU trans13_Control_Oxyg_ST_REV_page; \
	COMMAND trans13_Control_Oxyg_ST_REV_read; \
	VARIABLE trans13_Control_Oxyg_TAG_DESC; \
	MENU trans13_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans13_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans13_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans13_Control_Oxyg_STRATEGY; \
	MENU trans13_Control_Oxyg_STRATEGY_page; \
	COMMAND trans13_Control_Oxyg_STRATEGY_read; \
	COMMAND trans13_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans13_Control_Oxyg_ALERT_KEY; \
	MENU trans13_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans13_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans13_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans13_Control_Oxyg_TARGET_MODE; \
	MENU trans13_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans13_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans13_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans13_Control_Oxyg_MODE_BLK; \
	VARIABLE trans13_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans13_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans13_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans13_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans13_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans13_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans13_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans13_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans13_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans13_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans13_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans13_Control_Oxyg_BLOCK_TYPE; \
	MENU trans13_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans13_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans13_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans13_Control_Oxyg_COMMAND; \
	MENU trans13_Control_Oxyg_COMMAND_page; \
	COMMAND trans13_Control_Oxyg_COMMAND_read; \
	COMMAND trans13_Control_Oxyg_COMMAND_write; \
	VARIABLE trans13_Control_Oxyg_STATUS; \
	MENU trans13_Control_Oxyg_STATUS_page; \
	COMMAND trans13_Control_Oxyg_STATUS_read; \
	VARIABLE trans13_Control_Oxyg_CHANNEL; \
	MENU trans13_Control_Oxyg_CHANNEL_page; \
	COMMAND trans13_Control_Oxyg_CHANNEL_read; \
	COMMAND trans13_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans13_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans13_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans13_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans13_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans13_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans13_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans13_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans13_Control_Oxyg_RECIPE; \
	MENU trans13_Control_Oxyg_RECIPE_page; \
	COMMAND trans13_Control_Oxyg_RECIPE_read; \
	COMMAND trans13_Control_Oxyg_RECIPE_write; \
	VARIABLE trans13_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans13_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans13_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS13_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS13_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans13_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS13_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS13_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans13_Control_Oxyg_VIEW_1; \
	MENU trans13_Control_Oxyg_VIEW_1_page; \
	MENU trans13_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS13_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans13_Control_Oxyg_QUALITY_type; \
	ARRAY trans13_Control_Oxyg_QUALITY; \
	MENU trans13_Control_Oxyg_QUALITY_page; \
	COMMAND trans13_Control_Oxyg_QUALITY_read; \
	VARIABLE trans13_Control_Oxyg_SP_type; \
	ARRAY trans13_Control_Oxyg_SP; \
	MENU trans13_Control_Oxyg_SP_page; \
	COMMAND trans13_Control_Oxyg_SP_read; \
	COMMAND trans13_Control_Oxyg_SP_write; \
	VARIABLE trans13_Control_Oxyg_PV_type; \
	ARRAY trans13_Control_Oxyg_PV; \
	MENU trans13_Control_Oxyg_PV_page; \
	COMMAND trans13_Control_Oxyg_PV_read; \
	VARIABLE trans13_Control_Oxyg_CTB_MASTER; \
	MENU trans13_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans13_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans13_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans13_Control_Oxyg_SELECTION_type; \
	ARRAY trans13_Control_Oxyg_SELECTION; \
	MENU trans13_Control_Oxyg_SELECTION_page; \
	COMMAND trans13_Control_Oxyg_SELECTION_read; \
	COMMAND trans13_Control_Oxyg_SELECTION_write; \
	VARIABLE trans13_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans13_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans13_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans13_Control_Oxyg_CALOXY_TYPE; \
	MENU trans13_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans13_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans13_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans13_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans13_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans13_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans13_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans13_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans13_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans13_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans13_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans13_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans13_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans13_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans13_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans13_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans13_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans13_Control_Oxyg_CALOXY_TEMP; \
	MENU trans13_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans13_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans13_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans13_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans13_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans13_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans13_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans13_Control_Oxyg_VIEW_2; \
	MENU trans13_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans13_Control_Oxyg_VIEW_3; \
	MENU trans13_Control_Oxyg_VIEW_3_page

#define USE_TRANS13_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS13_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans13_Control_Oxyg_VIEW_1; \
	MENU trans13_Control_Oxyg_VIEW_1_page; \
	MENU trans13_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS13_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS13_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans13_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans13_Control_Oxyg_)
#define USE_TRANS13_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans13_Control_Oxyg_)
#define USE_TRANS13_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans13_Control_Oxyg_)
#define USE_TRANS13_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans13_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans14_Control_Oxyg_block; \
	COLLECTION trans14_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans14_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans14_Control_Oxyg_ST_REV; \
	MENU trans14_Control_Oxyg_ST_REV_page; \
	COMMAND trans14_Control_Oxyg_ST_REV_read; \
	VARIABLE trans14_Control_Oxyg_TAG_DESC; \
	MENU trans14_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans14_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans14_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans14_Control_Oxyg_STRATEGY; \
	MENU trans14_Control_Oxyg_STRATEGY_page; \
	COMMAND trans14_Control_Oxyg_STRATEGY_read; \
	COMMAND trans14_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans14_Control_Oxyg_ALERT_KEY; \
	MENU trans14_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans14_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans14_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans14_Control_Oxyg_TARGET_MODE; \
	MENU trans14_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans14_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans14_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans14_Control_Oxyg_MODE_BLK; \
	VARIABLE trans14_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans14_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans14_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans14_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans14_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans14_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans14_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans14_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans14_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans14_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans14_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans14_Control_Oxyg_BLOCK_TYPE; \
	MENU trans14_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans14_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans14_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans14_Control_Oxyg_COMMAND; \
	MENU trans14_Control_Oxyg_COMMAND_page; \
	COMMAND trans14_Control_Oxyg_COMMAND_read; \
	COMMAND trans14_Control_Oxyg_COMMAND_write; \
	VARIABLE trans14_Control_Oxyg_STATUS; \
	MENU trans14_Control_Oxyg_STATUS_page; \
	COMMAND trans14_Control_Oxyg_STATUS_read; \
	VARIABLE trans14_Control_Oxyg_CHANNEL; \
	MENU trans14_Control_Oxyg_CHANNEL_page; \
	COMMAND trans14_Control_Oxyg_CHANNEL_read; \
	COMMAND trans14_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans14_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans14_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans14_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans14_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans14_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans14_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans14_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans14_Control_Oxyg_RECIPE; \
	MENU trans14_Control_Oxyg_RECIPE_page; \
	COMMAND trans14_Control_Oxyg_RECIPE_read; \
	COMMAND trans14_Control_Oxyg_RECIPE_write; \
	VARIABLE trans14_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans14_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans14_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS14_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS14_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans14_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS14_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS14_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans14_Control_Oxyg_VIEW_1; \
	MENU trans14_Control_Oxyg_VIEW_1_page; \
	MENU trans14_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS14_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans14_Control_Oxyg_QUALITY_type; \
	ARRAY trans14_Control_Oxyg_QUALITY; \
	MENU trans14_Control_Oxyg_QUALITY_page; \
	COMMAND trans14_Control_Oxyg_QUALITY_read; \
	VARIABLE trans14_Control_Oxyg_SP_type; \
	ARRAY trans14_Control_Oxyg_SP; \
	MENU trans14_Control_Oxyg_SP_page; \
	COMMAND trans14_Control_Oxyg_SP_read; \
	COMMAND trans14_Control_Oxyg_SP_write; \
	VARIABLE trans14_Control_Oxyg_PV_type; \
	ARRAY trans14_Control_Oxyg_PV; \
	MENU trans14_Control_Oxyg_PV_page; \
	COMMAND trans14_Control_Oxyg_PV_read; \
	VARIABLE trans14_Control_Oxyg_CTB_MASTER; \
	MENU trans14_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans14_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans14_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans14_Control_Oxyg_SELECTION_type; \
	ARRAY trans14_Control_Oxyg_SELECTION; \
	MENU trans14_Control_Oxyg_SELECTION_page; \
	COMMAND trans14_Control_Oxyg_SELECTION_read; \
	COMMAND trans14_Control_Oxyg_SELECTION_write; \
	VARIABLE trans14_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans14_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans14_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans14_Control_Oxyg_CALOXY_TYPE; \
	MENU trans14_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans14_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans14_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans14_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans14_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans14_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans14_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans14_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans14_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans14_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans14_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans14_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans14_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans14_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans14_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans14_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans14_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans14_Control_Oxyg_CALOXY_TEMP; \
	MENU trans14_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans14_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans14_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans14_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans14_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans14_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans14_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans14_Control_Oxyg_VIEW_2; \
	MENU trans14_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans14_Control_Oxyg_VIEW_3; \
	MENU trans14_Control_Oxyg_VIEW_3_page

#define USE_TRANS14_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS14_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans14_Control_Oxyg_VIEW_1; \
	MENU trans14_Control_Oxyg_VIEW_1_page; \
	MENU trans14_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS14_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS14_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans14_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans14_Control_Oxyg_)
#define USE_TRANS14_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans14_Control_Oxyg_)
#define USE_TRANS14_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans14_Control_Oxyg_)
#define USE_TRANS14_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans14_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_CONTROL_OXYG_MANDATORY_BOTH \
	BLOCK trans15_Control_Oxyg_block; \
	COLLECTION trans15_Control_Oxyg_BLOCK_OBJECT; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Control_Oxyg_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Control_Oxyg_BLOCK_OBJECT_page; \
	COMMAND trans15_Control_Oxyg_BLOCK_OBJECT_read; \
	VARIABLE trans15_Control_Oxyg_ST_REV; \
	MENU trans15_Control_Oxyg_ST_REV_page; \
	COMMAND trans15_Control_Oxyg_ST_REV_read; \
	VARIABLE trans15_Control_Oxyg_TAG_DESC; \
	MENU trans15_Control_Oxyg_TAG_DESC_page; \
	COMMAND trans15_Control_Oxyg_TAG_DESC_read; \
	COMMAND trans15_Control_Oxyg_TAG_DESC_write; \
	VARIABLE trans15_Control_Oxyg_STRATEGY; \
	MENU trans15_Control_Oxyg_STRATEGY_page; \
	COMMAND trans15_Control_Oxyg_STRATEGY_read; \
	COMMAND trans15_Control_Oxyg_STRATEGY_write; \
	VARIABLE trans15_Control_Oxyg_ALERT_KEY; \
	MENU trans15_Control_Oxyg_ALERT_KEY_page; \
	COMMAND trans15_Control_Oxyg_ALERT_KEY_read; \
	COMMAND trans15_Control_Oxyg_ALERT_KEY_write; \
	VARIABLE trans15_Control_Oxyg_TARGET_MODE; \
	MENU trans15_Control_Oxyg_TARGET_MODE_page; \
	COMMAND trans15_Control_Oxyg_TARGET_MODE_read; \
	COMMAND trans15_Control_Oxyg_TARGET_MODE_write; \
	COLLECTION trans15_Control_Oxyg_MODE_BLK; \
	VARIABLE trans15_Control_Oxyg_MODE_BLK_Actual; \
	VARIABLE trans15_Control_Oxyg_MODE_BLK_Permitted; \
	VARIABLE trans15_Control_Oxyg_MODE_BLK_Normal; \
	MENU trans15_Control_Oxyg_MODE_BLK_page; \
	COMMAND trans15_Control_Oxyg_MODE_BLK_read; \
	COLLECTION trans15_Control_Oxyg_ALARM_SUM; \
	VARIABLE trans15_Control_Oxyg_ALARM_SUM_Current; \
	VARIABLE trans15_Control_Oxyg_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Control_Oxyg_ALARM_SUM_Unreported; \
	VARIABLE trans15_Control_Oxyg_ALARM_SUM_Disabled; \
	MENU trans15_Control_Oxyg_ALARM_SUM_page; \
	COMMAND trans15_Control_Oxyg_ALARM_SUM_read; \
	VARIABLE trans15_Control_Oxyg_BLOCK_TYPE; \
	MENU trans15_Control_Oxyg_BLOCK_TYPE_page; \
	COMMAND trans15_Control_Oxyg_BLOCK_TYPE_read; \
	COMMAND trans15_Control_Oxyg_BLOCK_TYPE_write; \
	VARIABLE trans15_Control_Oxyg_COMMAND; \
	MENU trans15_Control_Oxyg_COMMAND_page; \
	COMMAND trans15_Control_Oxyg_COMMAND_read; \
	COMMAND trans15_Control_Oxyg_COMMAND_write; \
	VARIABLE trans15_Control_Oxyg_STATUS; \
	MENU trans15_Control_Oxyg_STATUS_page; \
	COMMAND trans15_Control_Oxyg_STATUS_read; \
	VARIABLE trans15_Control_Oxyg_CHANNEL; \
	MENU trans15_Control_Oxyg_CHANNEL_page; \
	COMMAND trans15_Control_Oxyg_CHANNEL_read; \
	COMMAND trans15_Control_Oxyg_CHANNEL_write; \
	COLLECTION trans15_Control_Oxyg_SEQUENCE_CONTROL; \
	COLLECTION trans15_Control_Oxyg_SEQUENCE_CONTROL_Time; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Milliseconds; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Minutes; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Hours; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Day_of_Week_and_Month; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Month; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Years; \
	COLLECTION trans15_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Cycle_Time_Milliseconds; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Command; \
	VARIABLE trans15_Control_Oxyg_SEQUENCE_CONTROL_Time_Control_Active; \
	MENU trans15_Control_Oxyg_SEQUENCE_CONTROL_page; \
	COMMAND trans15_Control_Oxyg_SEQUENCE_CONTROL_read; \
	COMMAND trans15_Control_Oxyg_SEQUENCE_CONTROL_write; \
	VARIABLE trans15_Control_Oxyg_RECIPE; \
	MENU trans15_Control_Oxyg_RECIPE_page; \
	COMMAND trans15_Control_Oxyg_RECIPE_read; \
	COMMAND trans15_Control_Oxyg_RECIPE_write; \
	VARIABLE trans15_Control_Oxyg_PARAMETER_SET_NUMBER; \
	MENU trans15_Control_Oxyg_PARAMETER_SET_NUMBER_page; \
	COMMAND trans15_Control_Oxyg_PARAMETER_SET_NUMBER_read

#define USE_TRANS15_CONTROL_OXYG_MANDATORY_A \
	USE_TRANS15_CONTROL_OXYG_MANDATORY_BOTH; \
	MENU trans15_Control_Oxyg_Simple_Dialog_Mandatory_A

#define USE_TRANS15_CONTROL_OXYG_MANDATORY_B \
	USE_TRANS15_CONTROL_OXYG_MANDATORY_BOTH; \
	COLLECTION trans15_Control_Oxyg_VIEW_1; \
	MENU trans15_Control_Oxyg_VIEW_1_page; \
	MENU trans15_Control_Oxyg_Simple_Dialog_Mandatory_B

#define USE_TRANS15_CONTROL_OXYG_OPTIONAL_BOTH \
	VARIABLE trans15_Control_Oxyg_QUALITY_type; \
	ARRAY trans15_Control_Oxyg_QUALITY; \
	MENU trans15_Control_Oxyg_QUALITY_page; \
	COMMAND trans15_Control_Oxyg_QUALITY_read; \
	VARIABLE trans15_Control_Oxyg_SP_type; \
	ARRAY trans15_Control_Oxyg_SP; \
	MENU trans15_Control_Oxyg_SP_page; \
	COMMAND trans15_Control_Oxyg_SP_read; \
	COMMAND trans15_Control_Oxyg_SP_write; \
	VARIABLE trans15_Control_Oxyg_PV_type; \
	ARRAY trans15_Control_Oxyg_PV; \
	MENU trans15_Control_Oxyg_PV_page; \
	COMMAND trans15_Control_Oxyg_PV_read; \
	VARIABLE trans15_Control_Oxyg_CTB_MASTER; \
	MENU trans15_Control_Oxyg_CTB_MASTER_page; \
	COMMAND trans15_Control_Oxyg_CTB_MASTER_read; \
	COMMAND trans15_Control_Oxyg_CTB_MASTER_write; \
	VARIABLE trans15_Control_Oxyg_SELECTION_type; \
	ARRAY trans15_Control_Oxyg_SELECTION; \
	MENU trans15_Control_Oxyg_SELECTION_page; \
	COMMAND trans15_Control_Oxyg_SELECTION_read; \
	COMMAND trans15_Control_Oxyg_SELECTION_write; \
	VARIABLE trans15_Control_Oxyg_NUMBER_PARAMETERS; \
	MENU trans15_Control_Oxyg_NUMBER_PARAMETERS_page; \
	COMMAND trans15_Control_Oxyg_NUMBER_PARAMETERS_read; \
	VARIABLE trans15_Control_Oxyg_CALOXY_TYPE; \
	MENU trans15_Control_Oxyg_CALOXY_TYPE_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_TYPE_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_TYPE_write; \
	COLLECTION trans15_Control_Oxyg_CALOXY_ZERO; \
	VARIABLE trans15_Control_Oxyg_CALOXY_ZERO_Value; \
	VARIABLE trans15_Control_Oxyg_CALOXY_ZERO_Status_Condensed; \
	VARIABLE trans15_Control_Oxyg_CALOXY_ZERO_Status_Quality; \
	VARIABLE trans15_Control_Oxyg_CALOXY_ZERO_Status_Limit; \
	MENU trans15_Control_Oxyg_CALOXY_ZERO_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_ZERO_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_ZERO_write; \
	COLLECTION trans15_Control_Oxyg_CALOXY_HIGH; \
	VARIABLE trans15_Control_Oxyg_CALOXY_HIGH_Value; \
	VARIABLE trans15_Control_Oxyg_CALOXY_HIGH_Status_Condensed; \
	VARIABLE trans15_Control_Oxyg_CALOXY_HIGH_Status_Quality; \
	VARIABLE trans15_Control_Oxyg_CALOXY_HIGH_Status_Limit; \
	MENU trans15_Control_Oxyg_CALOXY_HIGH_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_HIGH_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_HIGH_write; \
	VARIABLE trans15_Control_Oxyg_CALOXY_HUMIDITY_REL; \
	MENU trans15_Control_Oxyg_CALOXY_HUMIDITY_REL_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_HUMIDITY_REL_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_HUMIDITY_REL_write; \
	VARIABLE trans15_Control_Oxyg_CALOXY_PRESSURE; \
	MENU trans15_Control_Oxyg_CALOXY_PRESSURE_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_PRESSURE_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_PRESSURE_write; \
	VARIABLE trans15_Control_Oxyg_CALOXY_TEMP; \
	MENU trans15_Control_Oxyg_CALOXY_TEMP_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_TEMP_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_TEMP_write; \
	VARIABLE trans15_Control_Oxyg_CALOXY_BUFFER_SAT; \
	MENU trans15_Control_Oxyg_CALOXY_BUFFER_SAT_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_BUFFER_SAT_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_BUFFER_SAT_write; \
	VARIABLE trans15_Control_Oxyg_CALOXY_BUFFER_CONC; \
	MENU trans15_Control_Oxyg_CALOXY_BUFFER_CONC_page; \
	COMMAND trans15_Control_Oxyg_CALOXY_BUFFER_CONC_read; \
	COMMAND trans15_Control_Oxyg_CALOXY_BUFFER_CONC_write; \
	COLLECTION trans15_Control_Oxyg_VIEW_2; \
	MENU trans15_Control_Oxyg_VIEW_2_page; \
	COLLECTION trans15_Control_Oxyg_VIEW_3; \
	MENU trans15_Control_Oxyg_VIEW_3_page

#define USE_TRANS15_CONTROL_OXYG_OPTIONAL_A \
	USE_TRANS15_CONTROL_OXYG_OPTIONAL_BOTH; \
	COLLECTION trans15_Control_Oxyg_VIEW_1; \
	MENU trans15_Control_Oxyg_VIEW_1_page; \
	MENU trans15_Control_Oxyg_Simple_Dialog_Optional_A

#define USE_TRANS15_CONTROL_OXYG_OPTIONAL_B \
	USE_TRANS15_CONTROL_OXYG_OPTIONAL_BOTH; \
	MENU trans15_Control_Oxyg_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_CONTROL_OXYG_MANDATORY_A USE_TRANS_CONTROL_OXYG_MANDATORY_A(trans15_Control_Oxyg_)
#define USE_TRANS15_CONTROL_OXYG_MANDATORY_B USE_TRANS_CONTROL_OXYG_MANDATORY_B(trans15_Control_Oxyg_)
#define USE_TRANS15_CONTROL_OXYG_OPTIONAL_A  USE_TRANS_CONTROL_OXYG_OPTIONAL_A(trans15_Control_Oxyg_)
#define USE_TRANS15_CONTROL_OXYG_OPTIONAL_B  USE_TRANS_CONTROL_OXYG_OPTIONAL_B(trans15_Control_Oxyg_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_LIMIT_MANDATORY_BOTH \
	BLOCK trans1_Limit_block; \
	COLLECTION trans1_Limit_BLOCK_OBJECT; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Limit_BLOCK_OBJECT_page; \
	COMMAND trans1_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans1_Limit_ST_REV; \
	MENU trans1_Limit_ST_REV_page; \
	COMMAND trans1_Limit_ST_REV_read; \
	VARIABLE trans1_Limit_TAG_DESC; \
	MENU trans1_Limit_TAG_DESC_page; \
	COMMAND trans1_Limit_TAG_DESC_read; \
	COMMAND trans1_Limit_TAG_DESC_write; \
	VARIABLE trans1_Limit_STRATEGY; \
	MENU trans1_Limit_STRATEGY_page; \
	COMMAND trans1_Limit_STRATEGY_read; \
	COMMAND trans1_Limit_STRATEGY_write; \
	VARIABLE trans1_Limit_ALERT_KEY; \
	MENU trans1_Limit_ALERT_KEY_page; \
	COMMAND trans1_Limit_ALERT_KEY_read; \
	COMMAND trans1_Limit_ALERT_KEY_write; \
	VARIABLE trans1_Limit_TARGET_MODE; \
	MENU trans1_Limit_TARGET_MODE_page; \
	COMMAND trans1_Limit_TARGET_MODE_read; \
	COMMAND trans1_Limit_TARGET_MODE_write; \
	COLLECTION trans1_Limit_MODE_BLK; \
	VARIABLE trans1_Limit_MODE_BLK_Actual; \
	VARIABLE trans1_Limit_MODE_BLK_Permitted; \
	VARIABLE trans1_Limit_MODE_BLK_Normal; \
	MENU trans1_Limit_MODE_BLK_page; \
	COMMAND trans1_Limit_MODE_BLK_read; \
	COLLECTION trans1_Limit_ALARM_SUM; \
	VARIABLE trans1_Limit_ALARM_SUM_Current; \
	VARIABLE trans1_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans1_Limit_ALARM_SUM_Disabled; \
	MENU trans1_Limit_ALARM_SUM_page; \
	COMMAND trans1_Limit_ALARM_SUM_read; \
	VARIABLE trans1_Limit_CHANNEL; \
	MENU trans1_Limit_CHANNEL_page; \
	COMMAND trans1_Limit_CHANNEL_read; \
	COMMAND trans1_Limit_CHANNEL_write; \
	VARIABLE trans1_Limit_THRESHOLD; \
	MENU trans1_Limit_THRESHOLD_page; \
	COMMAND trans1_Limit_THRESHOLD_read; \
	COMMAND trans1_Limit_THRESHOLD_write; \
	VARIABLE trans1_Limit_HYSTERESIS; \
	MENU trans1_Limit_HYSTERESIS_page; \
	COMMAND trans1_Limit_HYSTERESIS_read; \
	COMMAND trans1_Limit_HYSTERESIS_write; \
	VARIABLE trans1_Limit_DIRECTION; \
	MENU trans1_Limit_DIRECTION_page; \
	COMMAND trans1_Limit_DIRECTION_read; \
	COMMAND trans1_Limit_DIRECTION_write; \
	VARIABLE trans1_Limit_ON_DELAY; \
	MENU trans1_Limit_ON_DELAY_page; \
	COMMAND trans1_Limit_ON_DELAY_read; \
	COMMAND trans1_Limit_ON_DELAY_write; \
	VARIABLE trans1_Limit_OFF_DELAY; \
	MENU trans1_Limit_OFF_DELAY_page; \
	COMMAND trans1_Limit_OFF_DELAY_read; \
	COMMAND trans1_Limit_OFF_DELAY_write; \
	VARIABLE trans1_Limit_RESET; \
	MENU trans1_Limit_RESET_page; \
	COMMAND trans1_Limit_RESET_read; \
	COMMAND trans1_Limit_RESET_write; \
	VARIABLE trans1_Limit_CONFIRMATION; \
	MENU trans1_Limit_CONFIRMATION_page; \
	COMMAND trans1_Limit_CONFIRMATION_read; \
	COMMAND trans1_Limit_CONFIRMATION_write; \
	COLLECTION trans1_Limit_LIMIT_STATUS; \
	VARIABLE trans1_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans1_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans1_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans1_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans1_Limit_LIMIT_STATUS_page; \
	COMMAND trans1_Limit_LIMIT_STATUS_read

#define USE_TRANS1_LIMIT_MANDATORY_A \
	USE_TRANS1_LIMIT_MANDATORY_BOTH; \
	MENU trans1_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS1_LIMIT_MANDATORY_B \
	USE_TRANS1_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans1_Limit_VIEW_1; \
	MENU trans1_Limit_VIEW_1_page; \
	MENU trans1_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS1_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans1_Limit_VIEW_2; \
	MENU trans1_Limit_VIEW_2_page; \
	COLLECTION trans1_Limit_VIEW_3; \
	MENU trans1_Limit_VIEW_3_page

#define USE_TRANS1_LIMIT_OPTIONAL_A \
	USE_TRANS1_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans1_Limit_VIEW_1; \
	MENU trans1_Limit_VIEW_1_page; \
	MENU trans1_Limit_Simple_Dialog_Optional_A

#define USE_TRANS1_LIMIT_OPTIONAL_B \
	USE_TRANS1_LIMIT_OPTIONAL_BOTH; \
	MENU trans1_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_LIMIT_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	VARIABLE prefix ## THRESHOLD; \
	MENU prefix ## THRESHOLD_page; \
	COMMAND prefix ## THRESHOLD_read; \
	COMMAND prefix ## THRESHOLD_write; \
	VARIABLE prefix ## HYSTERESIS; \
	MENU prefix ## HYSTERESIS_page; \
	COMMAND prefix ## HYSTERESIS_read; \
	COMMAND prefix ## HYSTERESIS_write; \
	VARIABLE prefix ## DIRECTION; \
	MENU prefix ## DIRECTION_page; \
	COMMAND prefix ## DIRECTION_read; \
	COMMAND prefix ## DIRECTION_write; \
	VARIABLE prefix ## ON_DELAY; \
	MENU prefix ## ON_DELAY_page; \
	COMMAND prefix ## ON_DELAY_read; \
	COMMAND prefix ## ON_DELAY_write; \
	VARIABLE prefix ## OFF_DELAY; \
	MENU prefix ## OFF_DELAY_page; \
	COMMAND prefix ## OFF_DELAY_read; \
	COMMAND prefix ## OFF_DELAY_write; \
	VARIABLE prefix ## RESET; \
	MENU prefix ## RESET_page; \
	COMMAND prefix ## RESET_read; \
	COMMAND prefix ## RESET_write; \
	VARIABLE prefix ## CONFIRMATION; \
	MENU prefix ## CONFIRMATION_page; \
	COMMAND prefix ## CONFIRMATION_read; \
	COMMAND prefix ## CONFIRMATION_write; \
	COLLECTION prefix ## LIMIT_STATUS; \
	VARIABLE prefix ## LIMIT_STATUS_Value; \
	VARIABLE prefix ## LIMIT_STATUS_Status_Condensed; \
	VARIABLE prefix ## LIMIT_STATUS_Status_Quality; \
	VARIABLE prefix ## LIMIT_STATUS_Status_Limit; \
	MENU prefix ## LIMIT_STATUS_page; \
	COMMAND prefix ## LIMIT_STATUS_read

#define USE_TRANS_LIMIT_MANDATORY_A(prefix) \
	USE_TRANS_LIMIT_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_LIMIT_MANDATORY_B(prefix) \
	USE_TRANS_LIMIT_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_LIMIT_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_LIMIT_OPTIONAL_A(prefix) \
	USE_TRANS_LIMIT_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_LIMIT_OPTIONAL_B(prefix) \
	USE_TRANS_LIMIT_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans1_Limit_)
#define USE_TRANS1_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans1_Limit_)
#define USE_TRANS1_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans1_Limit_)
#define USE_TRANS1_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans1_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_LIMIT_MANDATORY_BOTH \
	BLOCK trans2_Limit_block; \
	COLLECTION trans2_Limit_BLOCK_OBJECT; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Limit_BLOCK_OBJECT_page; \
	COMMAND trans2_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans2_Limit_ST_REV; \
	MENU trans2_Limit_ST_REV_page; \
	COMMAND trans2_Limit_ST_REV_read; \
	VARIABLE trans2_Limit_TAG_DESC; \
	MENU trans2_Limit_TAG_DESC_page; \
	COMMAND trans2_Limit_TAG_DESC_read; \
	COMMAND trans2_Limit_TAG_DESC_write; \
	VARIABLE trans2_Limit_STRATEGY; \
	MENU trans2_Limit_STRATEGY_page; \
	COMMAND trans2_Limit_STRATEGY_read; \
	COMMAND trans2_Limit_STRATEGY_write; \
	VARIABLE trans2_Limit_ALERT_KEY; \
	MENU trans2_Limit_ALERT_KEY_page; \
	COMMAND trans2_Limit_ALERT_KEY_read; \
	COMMAND trans2_Limit_ALERT_KEY_write; \
	VARIABLE trans2_Limit_TARGET_MODE; \
	MENU trans2_Limit_TARGET_MODE_page; \
	COMMAND trans2_Limit_TARGET_MODE_read; \
	COMMAND trans2_Limit_TARGET_MODE_write; \
	COLLECTION trans2_Limit_MODE_BLK; \
	VARIABLE trans2_Limit_MODE_BLK_Actual; \
	VARIABLE trans2_Limit_MODE_BLK_Permitted; \
	VARIABLE trans2_Limit_MODE_BLK_Normal; \
	MENU trans2_Limit_MODE_BLK_page; \
	COMMAND trans2_Limit_MODE_BLK_read; \
	COLLECTION trans2_Limit_ALARM_SUM; \
	VARIABLE trans2_Limit_ALARM_SUM_Current; \
	VARIABLE trans2_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans2_Limit_ALARM_SUM_Disabled; \
	MENU trans2_Limit_ALARM_SUM_page; \
	COMMAND trans2_Limit_ALARM_SUM_read; \
	VARIABLE trans2_Limit_CHANNEL; \
	MENU trans2_Limit_CHANNEL_page; \
	COMMAND trans2_Limit_CHANNEL_read; \
	COMMAND trans2_Limit_CHANNEL_write; \
	VARIABLE trans2_Limit_THRESHOLD; \
	MENU trans2_Limit_THRESHOLD_page; \
	COMMAND trans2_Limit_THRESHOLD_read; \
	COMMAND trans2_Limit_THRESHOLD_write; \
	VARIABLE trans2_Limit_HYSTERESIS; \
	MENU trans2_Limit_HYSTERESIS_page; \
	COMMAND trans2_Limit_HYSTERESIS_read; \
	COMMAND trans2_Limit_HYSTERESIS_write; \
	VARIABLE trans2_Limit_DIRECTION; \
	MENU trans2_Limit_DIRECTION_page; \
	COMMAND trans2_Limit_DIRECTION_read; \
	COMMAND trans2_Limit_DIRECTION_write; \
	VARIABLE trans2_Limit_ON_DELAY; \
	MENU trans2_Limit_ON_DELAY_page; \
	COMMAND trans2_Limit_ON_DELAY_read; \
	COMMAND trans2_Limit_ON_DELAY_write; \
	VARIABLE trans2_Limit_OFF_DELAY; \
	MENU trans2_Limit_OFF_DELAY_page; \
	COMMAND trans2_Limit_OFF_DELAY_read; \
	COMMAND trans2_Limit_OFF_DELAY_write; \
	VARIABLE trans2_Limit_RESET; \
	MENU trans2_Limit_RESET_page; \
	COMMAND trans2_Limit_RESET_read; \
	COMMAND trans2_Limit_RESET_write; \
	VARIABLE trans2_Limit_CONFIRMATION; \
	MENU trans2_Limit_CONFIRMATION_page; \
	COMMAND trans2_Limit_CONFIRMATION_read; \
	COMMAND trans2_Limit_CONFIRMATION_write; \
	COLLECTION trans2_Limit_LIMIT_STATUS; \
	VARIABLE trans2_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans2_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans2_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans2_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans2_Limit_LIMIT_STATUS_page; \
	COMMAND trans2_Limit_LIMIT_STATUS_read

#define USE_TRANS2_LIMIT_MANDATORY_A \
	USE_TRANS2_LIMIT_MANDATORY_BOTH; \
	MENU trans2_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS2_LIMIT_MANDATORY_B \
	USE_TRANS2_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans2_Limit_VIEW_1; \
	MENU trans2_Limit_VIEW_1_page; \
	MENU trans2_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS2_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans2_Limit_VIEW_2; \
	MENU trans2_Limit_VIEW_2_page; \
	COLLECTION trans2_Limit_VIEW_3; \
	MENU trans2_Limit_VIEW_3_page

#define USE_TRANS2_LIMIT_OPTIONAL_A \
	USE_TRANS2_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans2_Limit_VIEW_1; \
	MENU trans2_Limit_VIEW_1_page; \
	MENU trans2_Limit_Simple_Dialog_Optional_A

#define USE_TRANS2_LIMIT_OPTIONAL_B \
	USE_TRANS2_LIMIT_OPTIONAL_BOTH; \
	MENU trans2_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans2_Limit_)
#define USE_TRANS2_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans2_Limit_)
#define USE_TRANS2_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans2_Limit_)
#define USE_TRANS2_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans2_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_LIMIT_MANDATORY_BOTH \
	BLOCK trans3_Limit_block; \
	COLLECTION trans3_Limit_BLOCK_OBJECT; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Limit_BLOCK_OBJECT_page; \
	COMMAND trans3_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans3_Limit_ST_REV; \
	MENU trans3_Limit_ST_REV_page; \
	COMMAND trans3_Limit_ST_REV_read; \
	VARIABLE trans3_Limit_TAG_DESC; \
	MENU trans3_Limit_TAG_DESC_page; \
	COMMAND trans3_Limit_TAG_DESC_read; \
	COMMAND trans3_Limit_TAG_DESC_write; \
	VARIABLE trans3_Limit_STRATEGY; \
	MENU trans3_Limit_STRATEGY_page; \
	COMMAND trans3_Limit_STRATEGY_read; \
	COMMAND trans3_Limit_STRATEGY_write; \
	VARIABLE trans3_Limit_ALERT_KEY; \
	MENU trans3_Limit_ALERT_KEY_page; \
	COMMAND trans3_Limit_ALERT_KEY_read; \
	COMMAND trans3_Limit_ALERT_KEY_write; \
	VARIABLE trans3_Limit_TARGET_MODE; \
	MENU trans3_Limit_TARGET_MODE_page; \
	COMMAND trans3_Limit_TARGET_MODE_read; \
	COMMAND trans3_Limit_TARGET_MODE_write; \
	COLLECTION trans3_Limit_MODE_BLK; \
	VARIABLE trans3_Limit_MODE_BLK_Actual; \
	VARIABLE trans3_Limit_MODE_BLK_Permitted; \
	VARIABLE trans3_Limit_MODE_BLK_Normal; \
	MENU trans3_Limit_MODE_BLK_page; \
	COMMAND trans3_Limit_MODE_BLK_read; \
	COLLECTION trans3_Limit_ALARM_SUM; \
	VARIABLE trans3_Limit_ALARM_SUM_Current; \
	VARIABLE trans3_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans3_Limit_ALARM_SUM_Disabled; \
	MENU trans3_Limit_ALARM_SUM_page; \
	COMMAND trans3_Limit_ALARM_SUM_read; \
	VARIABLE trans3_Limit_CHANNEL; \
	MENU trans3_Limit_CHANNEL_page; \
	COMMAND trans3_Limit_CHANNEL_read; \
	COMMAND trans3_Limit_CHANNEL_write; \
	VARIABLE trans3_Limit_THRESHOLD; \
	MENU trans3_Limit_THRESHOLD_page; \
	COMMAND trans3_Limit_THRESHOLD_read; \
	COMMAND trans3_Limit_THRESHOLD_write; \
	VARIABLE trans3_Limit_HYSTERESIS; \
	MENU trans3_Limit_HYSTERESIS_page; \
	COMMAND trans3_Limit_HYSTERESIS_read; \
	COMMAND trans3_Limit_HYSTERESIS_write; \
	VARIABLE trans3_Limit_DIRECTION; \
	MENU trans3_Limit_DIRECTION_page; \
	COMMAND trans3_Limit_DIRECTION_read; \
	COMMAND trans3_Limit_DIRECTION_write; \
	VARIABLE trans3_Limit_ON_DELAY; \
	MENU trans3_Limit_ON_DELAY_page; \
	COMMAND trans3_Limit_ON_DELAY_read; \
	COMMAND trans3_Limit_ON_DELAY_write; \
	VARIABLE trans3_Limit_OFF_DELAY; \
	MENU trans3_Limit_OFF_DELAY_page; \
	COMMAND trans3_Limit_OFF_DELAY_read; \
	COMMAND trans3_Limit_OFF_DELAY_write; \
	VARIABLE trans3_Limit_RESET; \
	MENU trans3_Limit_RESET_page; \
	COMMAND trans3_Limit_RESET_read; \
	COMMAND trans3_Limit_RESET_write; \
	VARIABLE trans3_Limit_CONFIRMATION; \
	MENU trans3_Limit_CONFIRMATION_page; \
	COMMAND trans3_Limit_CONFIRMATION_read; \
	COMMAND trans3_Limit_CONFIRMATION_write; \
	COLLECTION trans3_Limit_LIMIT_STATUS; \
	VARIABLE trans3_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans3_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans3_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans3_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans3_Limit_LIMIT_STATUS_page; \
	COMMAND trans3_Limit_LIMIT_STATUS_read

#define USE_TRANS3_LIMIT_MANDATORY_A \
	USE_TRANS3_LIMIT_MANDATORY_BOTH; \
	MENU trans3_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS3_LIMIT_MANDATORY_B \
	USE_TRANS3_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans3_Limit_VIEW_1; \
	MENU trans3_Limit_VIEW_1_page; \
	MENU trans3_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS3_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans3_Limit_VIEW_2; \
	MENU trans3_Limit_VIEW_2_page; \
	COLLECTION trans3_Limit_VIEW_3; \
	MENU trans3_Limit_VIEW_3_page

#define USE_TRANS3_LIMIT_OPTIONAL_A \
	USE_TRANS3_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans3_Limit_VIEW_1; \
	MENU trans3_Limit_VIEW_1_page; \
	MENU trans3_Limit_Simple_Dialog_Optional_A

#define USE_TRANS3_LIMIT_OPTIONAL_B \
	USE_TRANS3_LIMIT_OPTIONAL_BOTH; \
	MENU trans3_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans3_Limit_)
#define USE_TRANS3_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans3_Limit_)
#define USE_TRANS3_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans3_Limit_)
#define USE_TRANS3_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans3_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_LIMIT_MANDATORY_BOTH \
	BLOCK trans4_Limit_block; \
	COLLECTION trans4_Limit_BLOCK_OBJECT; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Limit_BLOCK_OBJECT_page; \
	COMMAND trans4_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans4_Limit_ST_REV; \
	MENU trans4_Limit_ST_REV_page; \
	COMMAND trans4_Limit_ST_REV_read; \
	VARIABLE trans4_Limit_TAG_DESC; \
	MENU trans4_Limit_TAG_DESC_page; \
	COMMAND trans4_Limit_TAG_DESC_read; \
	COMMAND trans4_Limit_TAG_DESC_write; \
	VARIABLE trans4_Limit_STRATEGY; \
	MENU trans4_Limit_STRATEGY_page; \
	COMMAND trans4_Limit_STRATEGY_read; \
	COMMAND trans4_Limit_STRATEGY_write; \
	VARIABLE trans4_Limit_ALERT_KEY; \
	MENU trans4_Limit_ALERT_KEY_page; \
	COMMAND trans4_Limit_ALERT_KEY_read; \
	COMMAND trans4_Limit_ALERT_KEY_write; \
	VARIABLE trans4_Limit_TARGET_MODE; \
	MENU trans4_Limit_TARGET_MODE_page; \
	COMMAND trans4_Limit_TARGET_MODE_read; \
	COMMAND trans4_Limit_TARGET_MODE_write; \
	COLLECTION trans4_Limit_MODE_BLK; \
	VARIABLE trans4_Limit_MODE_BLK_Actual; \
	VARIABLE trans4_Limit_MODE_BLK_Permitted; \
	VARIABLE trans4_Limit_MODE_BLK_Normal; \
	MENU trans4_Limit_MODE_BLK_page; \
	COMMAND trans4_Limit_MODE_BLK_read; \
	COLLECTION trans4_Limit_ALARM_SUM; \
	VARIABLE trans4_Limit_ALARM_SUM_Current; \
	VARIABLE trans4_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans4_Limit_ALARM_SUM_Disabled; \
	MENU trans4_Limit_ALARM_SUM_page; \
	COMMAND trans4_Limit_ALARM_SUM_read; \
	VARIABLE trans4_Limit_CHANNEL; \
	MENU trans4_Limit_CHANNEL_page; \
	COMMAND trans4_Limit_CHANNEL_read; \
	COMMAND trans4_Limit_CHANNEL_write; \
	VARIABLE trans4_Limit_THRESHOLD; \
	MENU trans4_Limit_THRESHOLD_page; \
	COMMAND trans4_Limit_THRESHOLD_read; \
	COMMAND trans4_Limit_THRESHOLD_write; \
	VARIABLE trans4_Limit_HYSTERESIS; \
	MENU trans4_Limit_HYSTERESIS_page; \
	COMMAND trans4_Limit_HYSTERESIS_read; \
	COMMAND trans4_Limit_HYSTERESIS_write; \
	VARIABLE trans4_Limit_DIRECTION; \
	MENU trans4_Limit_DIRECTION_page; \
	COMMAND trans4_Limit_DIRECTION_read; \
	COMMAND trans4_Limit_DIRECTION_write; \
	VARIABLE trans4_Limit_ON_DELAY; \
	MENU trans4_Limit_ON_DELAY_page; \
	COMMAND trans4_Limit_ON_DELAY_read; \
	COMMAND trans4_Limit_ON_DELAY_write; \
	VARIABLE trans4_Limit_OFF_DELAY; \
	MENU trans4_Limit_OFF_DELAY_page; \
	COMMAND trans4_Limit_OFF_DELAY_read; \
	COMMAND trans4_Limit_OFF_DELAY_write; \
	VARIABLE trans4_Limit_RESET; \
	MENU trans4_Limit_RESET_page; \
	COMMAND trans4_Limit_RESET_read; \
	COMMAND trans4_Limit_RESET_write; \
	VARIABLE trans4_Limit_CONFIRMATION; \
	MENU trans4_Limit_CONFIRMATION_page; \
	COMMAND trans4_Limit_CONFIRMATION_read; \
	COMMAND trans4_Limit_CONFIRMATION_write; \
	COLLECTION trans4_Limit_LIMIT_STATUS; \
	VARIABLE trans4_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans4_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans4_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans4_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans4_Limit_LIMIT_STATUS_page; \
	COMMAND trans4_Limit_LIMIT_STATUS_read

#define USE_TRANS4_LIMIT_MANDATORY_A \
	USE_TRANS4_LIMIT_MANDATORY_BOTH; \
	MENU trans4_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS4_LIMIT_MANDATORY_B \
	USE_TRANS4_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans4_Limit_VIEW_1; \
	MENU trans4_Limit_VIEW_1_page; \
	MENU trans4_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS4_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans4_Limit_VIEW_2; \
	MENU trans4_Limit_VIEW_2_page; \
	COLLECTION trans4_Limit_VIEW_3; \
	MENU trans4_Limit_VIEW_3_page

#define USE_TRANS4_LIMIT_OPTIONAL_A \
	USE_TRANS4_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans4_Limit_VIEW_1; \
	MENU trans4_Limit_VIEW_1_page; \
	MENU trans4_Limit_Simple_Dialog_Optional_A

#define USE_TRANS4_LIMIT_OPTIONAL_B \
	USE_TRANS4_LIMIT_OPTIONAL_BOTH; \
	MENU trans4_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans4_Limit_)
#define USE_TRANS4_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans4_Limit_)
#define USE_TRANS4_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans4_Limit_)
#define USE_TRANS4_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans4_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_LIMIT_MANDATORY_BOTH \
	BLOCK trans5_Limit_block; \
	COLLECTION trans5_Limit_BLOCK_OBJECT; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Limit_BLOCK_OBJECT_page; \
	COMMAND trans5_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans5_Limit_ST_REV; \
	MENU trans5_Limit_ST_REV_page; \
	COMMAND trans5_Limit_ST_REV_read; \
	VARIABLE trans5_Limit_TAG_DESC; \
	MENU trans5_Limit_TAG_DESC_page; \
	COMMAND trans5_Limit_TAG_DESC_read; \
	COMMAND trans5_Limit_TAG_DESC_write; \
	VARIABLE trans5_Limit_STRATEGY; \
	MENU trans5_Limit_STRATEGY_page; \
	COMMAND trans5_Limit_STRATEGY_read; \
	COMMAND trans5_Limit_STRATEGY_write; \
	VARIABLE trans5_Limit_ALERT_KEY; \
	MENU trans5_Limit_ALERT_KEY_page; \
	COMMAND trans5_Limit_ALERT_KEY_read; \
	COMMAND trans5_Limit_ALERT_KEY_write; \
	VARIABLE trans5_Limit_TARGET_MODE; \
	MENU trans5_Limit_TARGET_MODE_page; \
	COMMAND trans5_Limit_TARGET_MODE_read; \
	COMMAND trans5_Limit_TARGET_MODE_write; \
	COLLECTION trans5_Limit_MODE_BLK; \
	VARIABLE trans5_Limit_MODE_BLK_Actual; \
	VARIABLE trans5_Limit_MODE_BLK_Permitted; \
	VARIABLE trans5_Limit_MODE_BLK_Normal; \
	MENU trans5_Limit_MODE_BLK_page; \
	COMMAND trans5_Limit_MODE_BLK_read; \
	COLLECTION trans5_Limit_ALARM_SUM; \
	VARIABLE trans5_Limit_ALARM_SUM_Current; \
	VARIABLE trans5_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans5_Limit_ALARM_SUM_Disabled; \
	MENU trans5_Limit_ALARM_SUM_page; \
	COMMAND trans5_Limit_ALARM_SUM_read; \
	VARIABLE trans5_Limit_CHANNEL; \
	MENU trans5_Limit_CHANNEL_page; \
	COMMAND trans5_Limit_CHANNEL_read; \
	COMMAND trans5_Limit_CHANNEL_write; \
	VARIABLE trans5_Limit_THRESHOLD; \
	MENU trans5_Limit_THRESHOLD_page; \
	COMMAND trans5_Limit_THRESHOLD_read; \
	COMMAND trans5_Limit_THRESHOLD_write; \
	VARIABLE trans5_Limit_HYSTERESIS; \
	MENU trans5_Limit_HYSTERESIS_page; \
	COMMAND trans5_Limit_HYSTERESIS_read; \
	COMMAND trans5_Limit_HYSTERESIS_write; \
	VARIABLE trans5_Limit_DIRECTION; \
	MENU trans5_Limit_DIRECTION_page; \
	COMMAND trans5_Limit_DIRECTION_read; \
	COMMAND trans5_Limit_DIRECTION_write; \
	VARIABLE trans5_Limit_ON_DELAY; \
	MENU trans5_Limit_ON_DELAY_page; \
	COMMAND trans5_Limit_ON_DELAY_read; \
	COMMAND trans5_Limit_ON_DELAY_write; \
	VARIABLE trans5_Limit_OFF_DELAY; \
	MENU trans5_Limit_OFF_DELAY_page; \
	COMMAND trans5_Limit_OFF_DELAY_read; \
	COMMAND trans5_Limit_OFF_DELAY_write; \
	VARIABLE trans5_Limit_RESET; \
	MENU trans5_Limit_RESET_page; \
	COMMAND trans5_Limit_RESET_read; \
	COMMAND trans5_Limit_RESET_write; \
	VARIABLE trans5_Limit_CONFIRMATION; \
	MENU trans5_Limit_CONFIRMATION_page; \
	COMMAND trans5_Limit_CONFIRMATION_read; \
	COMMAND trans5_Limit_CONFIRMATION_write; \
	COLLECTION trans5_Limit_LIMIT_STATUS; \
	VARIABLE trans5_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans5_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans5_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans5_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans5_Limit_LIMIT_STATUS_page; \
	COMMAND trans5_Limit_LIMIT_STATUS_read

#define USE_TRANS5_LIMIT_MANDATORY_A \
	USE_TRANS5_LIMIT_MANDATORY_BOTH; \
	MENU trans5_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS5_LIMIT_MANDATORY_B \
	USE_TRANS5_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans5_Limit_VIEW_1; \
	MENU trans5_Limit_VIEW_1_page; \
	MENU trans5_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS5_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans5_Limit_VIEW_2; \
	MENU trans5_Limit_VIEW_2_page; \
	COLLECTION trans5_Limit_VIEW_3; \
	MENU trans5_Limit_VIEW_3_page

#define USE_TRANS5_LIMIT_OPTIONAL_A \
	USE_TRANS5_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans5_Limit_VIEW_1; \
	MENU trans5_Limit_VIEW_1_page; \
	MENU trans5_Limit_Simple_Dialog_Optional_A

#define USE_TRANS5_LIMIT_OPTIONAL_B \
	USE_TRANS5_LIMIT_OPTIONAL_BOTH; \
	MENU trans5_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans5_Limit_)
#define USE_TRANS5_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans5_Limit_)
#define USE_TRANS5_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans5_Limit_)
#define USE_TRANS5_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans5_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_LIMIT_MANDATORY_BOTH \
	BLOCK trans6_Limit_block; \
	COLLECTION trans6_Limit_BLOCK_OBJECT; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Limit_BLOCK_OBJECT_page; \
	COMMAND trans6_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans6_Limit_ST_REV; \
	MENU trans6_Limit_ST_REV_page; \
	COMMAND trans6_Limit_ST_REV_read; \
	VARIABLE trans6_Limit_TAG_DESC; \
	MENU trans6_Limit_TAG_DESC_page; \
	COMMAND trans6_Limit_TAG_DESC_read; \
	COMMAND trans6_Limit_TAG_DESC_write; \
	VARIABLE trans6_Limit_STRATEGY; \
	MENU trans6_Limit_STRATEGY_page; \
	COMMAND trans6_Limit_STRATEGY_read; \
	COMMAND trans6_Limit_STRATEGY_write; \
	VARIABLE trans6_Limit_ALERT_KEY; \
	MENU trans6_Limit_ALERT_KEY_page; \
	COMMAND trans6_Limit_ALERT_KEY_read; \
	COMMAND trans6_Limit_ALERT_KEY_write; \
	VARIABLE trans6_Limit_TARGET_MODE; \
	MENU trans6_Limit_TARGET_MODE_page; \
	COMMAND trans6_Limit_TARGET_MODE_read; \
	COMMAND trans6_Limit_TARGET_MODE_write; \
	COLLECTION trans6_Limit_MODE_BLK; \
	VARIABLE trans6_Limit_MODE_BLK_Actual; \
	VARIABLE trans6_Limit_MODE_BLK_Permitted; \
	VARIABLE trans6_Limit_MODE_BLK_Normal; \
	MENU trans6_Limit_MODE_BLK_page; \
	COMMAND trans6_Limit_MODE_BLK_read; \
	COLLECTION trans6_Limit_ALARM_SUM; \
	VARIABLE trans6_Limit_ALARM_SUM_Current; \
	VARIABLE trans6_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans6_Limit_ALARM_SUM_Disabled; \
	MENU trans6_Limit_ALARM_SUM_page; \
	COMMAND trans6_Limit_ALARM_SUM_read; \
	VARIABLE trans6_Limit_CHANNEL; \
	MENU trans6_Limit_CHANNEL_page; \
	COMMAND trans6_Limit_CHANNEL_read; \
	COMMAND trans6_Limit_CHANNEL_write; \
	VARIABLE trans6_Limit_THRESHOLD; \
	MENU trans6_Limit_THRESHOLD_page; \
	COMMAND trans6_Limit_THRESHOLD_read; \
	COMMAND trans6_Limit_THRESHOLD_write; \
	VARIABLE trans6_Limit_HYSTERESIS; \
	MENU trans6_Limit_HYSTERESIS_page; \
	COMMAND trans6_Limit_HYSTERESIS_read; \
	COMMAND trans6_Limit_HYSTERESIS_write; \
	VARIABLE trans6_Limit_DIRECTION; \
	MENU trans6_Limit_DIRECTION_page; \
	COMMAND trans6_Limit_DIRECTION_read; \
	COMMAND trans6_Limit_DIRECTION_write; \
	VARIABLE trans6_Limit_ON_DELAY; \
	MENU trans6_Limit_ON_DELAY_page; \
	COMMAND trans6_Limit_ON_DELAY_read; \
	COMMAND trans6_Limit_ON_DELAY_write; \
	VARIABLE trans6_Limit_OFF_DELAY; \
	MENU trans6_Limit_OFF_DELAY_page; \
	COMMAND trans6_Limit_OFF_DELAY_read; \
	COMMAND trans6_Limit_OFF_DELAY_write; \
	VARIABLE trans6_Limit_RESET; \
	MENU trans6_Limit_RESET_page; \
	COMMAND trans6_Limit_RESET_read; \
	COMMAND trans6_Limit_RESET_write; \
	VARIABLE trans6_Limit_CONFIRMATION; \
	MENU trans6_Limit_CONFIRMATION_page; \
	COMMAND trans6_Limit_CONFIRMATION_read; \
	COMMAND trans6_Limit_CONFIRMATION_write; \
	COLLECTION trans6_Limit_LIMIT_STATUS; \
	VARIABLE trans6_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans6_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans6_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans6_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans6_Limit_LIMIT_STATUS_page; \
	COMMAND trans6_Limit_LIMIT_STATUS_read

#define USE_TRANS6_LIMIT_MANDATORY_A \
	USE_TRANS6_LIMIT_MANDATORY_BOTH; \
	MENU trans6_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS6_LIMIT_MANDATORY_B \
	USE_TRANS6_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans6_Limit_VIEW_1; \
	MENU trans6_Limit_VIEW_1_page; \
	MENU trans6_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS6_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans6_Limit_VIEW_2; \
	MENU trans6_Limit_VIEW_2_page; \
	COLLECTION trans6_Limit_VIEW_3; \
	MENU trans6_Limit_VIEW_3_page

#define USE_TRANS6_LIMIT_OPTIONAL_A \
	USE_TRANS6_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans6_Limit_VIEW_1; \
	MENU trans6_Limit_VIEW_1_page; \
	MENU trans6_Limit_Simple_Dialog_Optional_A

#define USE_TRANS6_LIMIT_OPTIONAL_B \
	USE_TRANS6_LIMIT_OPTIONAL_BOTH; \
	MENU trans6_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans6_Limit_)
#define USE_TRANS6_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans6_Limit_)
#define USE_TRANS6_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans6_Limit_)
#define USE_TRANS6_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans6_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_LIMIT_MANDATORY_BOTH \
	BLOCK trans7_Limit_block; \
	COLLECTION trans7_Limit_BLOCK_OBJECT; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Limit_BLOCK_OBJECT_page; \
	COMMAND trans7_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans7_Limit_ST_REV; \
	MENU trans7_Limit_ST_REV_page; \
	COMMAND trans7_Limit_ST_REV_read; \
	VARIABLE trans7_Limit_TAG_DESC; \
	MENU trans7_Limit_TAG_DESC_page; \
	COMMAND trans7_Limit_TAG_DESC_read; \
	COMMAND trans7_Limit_TAG_DESC_write; \
	VARIABLE trans7_Limit_STRATEGY; \
	MENU trans7_Limit_STRATEGY_page; \
	COMMAND trans7_Limit_STRATEGY_read; \
	COMMAND trans7_Limit_STRATEGY_write; \
	VARIABLE trans7_Limit_ALERT_KEY; \
	MENU trans7_Limit_ALERT_KEY_page; \
	COMMAND trans7_Limit_ALERT_KEY_read; \
	COMMAND trans7_Limit_ALERT_KEY_write; \
	VARIABLE trans7_Limit_TARGET_MODE; \
	MENU trans7_Limit_TARGET_MODE_page; \
	COMMAND trans7_Limit_TARGET_MODE_read; \
	COMMAND trans7_Limit_TARGET_MODE_write; \
	COLLECTION trans7_Limit_MODE_BLK; \
	VARIABLE trans7_Limit_MODE_BLK_Actual; \
	VARIABLE trans7_Limit_MODE_BLK_Permitted; \
	VARIABLE trans7_Limit_MODE_BLK_Normal; \
	MENU trans7_Limit_MODE_BLK_page; \
	COMMAND trans7_Limit_MODE_BLK_read; \
	COLLECTION trans7_Limit_ALARM_SUM; \
	VARIABLE trans7_Limit_ALARM_SUM_Current; \
	VARIABLE trans7_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans7_Limit_ALARM_SUM_Disabled; \
	MENU trans7_Limit_ALARM_SUM_page; \
	COMMAND trans7_Limit_ALARM_SUM_read; \
	VARIABLE trans7_Limit_CHANNEL; \
	MENU trans7_Limit_CHANNEL_page; \
	COMMAND trans7_Limit_CHANNEL_read; \
	COMMAND trans7_Limit_CHANNEL_write; \
	VARIABLE trans7_Limit_THRESHOLD; \
	MENU trans7_Limit_THRESHOLD_page; \
	COMMAND trans7_Limit_THRESHOLD_read; \
	COMMAND trans7_Limit_THRESHOLD_write; \
	VARIABLE trans7_Limit_HYSTERESIS; \
	MENU trans7_Limit_HYSTERESIS_page; \
	COMMAND trans7_Limit_HYSTERESIS_read; \
	COMMAND trans7_Limit_HYSTERESIS_write; \
	VARIABLE trans7_Limit_DIRECTION; \
	MENU trans7_Limit_DIRECTION_page; \
	COMMAND trans7_Limit_DIRECTION_read; \
	COMMAND trans7_Limit_DIRECTION_write; \
	VARIABLE trans7_Limit_ON_DELAY; \
	MENU trans7_Limit_ON_DELAY_page; \
	COMMAND trans7_Limit_ON_DELAY_read; \
	COMMAND trans7_Limit_ON_DELAY_write; \
	VARIABLE trans7_Limit_OFF_DELAY; \
	MENU trans7_Limit_OFF_DELAY_page; \
	COMMAND trans7_Limit_OFF_DELAY_read; \
	COMMAND trans7_Limit_OFF_DELAY_write; \
	VARIABLE trans7_Limit_RESET; \
	MENU trans7_Limit_RESET_page; \
	COMMAND trans7_Limit_RESET_read; \
	COMMAND trans7_Limit_RESET_write; \
	VARIABLE trans7_Limit_CONFIRMATION; \
	MENU trans7_Limit_CONFIRMATION_page; \
	COMMAND trans7_Limit_CONFIRMATION_read; \
	COMMAND trans7_Limit_CONFIRMATION_write; \
	COLLECTION trans7_Limit_LIMIT_STATUS; \
	VARIABLE trans7_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans7_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans7_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans7_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans7_Limit_LIMIT_STATUS_page; \
	COMMAND trans7_Limit_LIMIT_STATUS_read

#define USE_TRANS7_LIMIT_MANDATORY_A \
	USE_TRANS7_LIMIT_MANDATORY_BOTH; \
	MENU trans7_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS7_LIMIT_MANDATORY_B \
	USE_TRANS7_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans7_Limit_VIEW_1; \
	MENU trans7_Limit_VIEW_1_page; \
	MENU trans7_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS7_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans7_Limit_VIEW_2; \
	MENU trans7_Limit_VIEW_2_page; \
	COLLECTION trans7_Limit_VIEW_3; \
	MENU trans7_Limit_VIEW_3_page

#define USE_TRANS7_LIMIT_OPTIONAL_A \
	USE_TRANS7_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans7_Limit_VIEW_1; \
	MENU trans7_Limit_VIEW_1_page; \
	MENU trans7_Limit_Simple_Dialog_Optional_A

#define USE_TRANS7_LIMIT_OPTIONAL_B \
	USE_TRANS7_LIMIT_OPTIONAL_BOTH; \
	MENU trans7_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans7_Limit_)
#define USE_TRANS7_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans7_Limit_)
#define USE_TRANS7_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans7_Limit_)
#define USE_TRANS7_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans7_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_LIMIT_MANDATORY_BOTH \
	BLOCK trans8_Limit_block; \
	COLLECTION trans8_Limit_BLOCK_OBJECT; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Limit_BLOCK_OBJECT_page; \
	COMMAND trans8_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans8_Limit_ST_REV; \
	MENU trans8_Limit_ST_REV_page; \
	COMMAND trans8_Limit_ST_REV_read; \
	VARIABLE trans8_Limit_TAG_DESC; \
	MENU trans8_Limit_TAG_DESC_page; \
	COMMAND trans8_Limit_TAG_DESC_read; \
	COMMAND trans8_Limit_TAG_DESC_write; \
	VARIABLE trans8_Limit_STRATEGY; \
	MENU trans8_Limit_STRATEGY_page; \
	COMMAND trans8_Limit_STRATEGY_read; \
	COMMAND trans8_Limit_STRATEGY_write; \
	VARIABLE trans8_Limit_ALERT_KEY; \
	MENU trans8_Limit_ALERT_KEY_page; \
	COMMAND trans8_Limit_ALERT_KEY_read; \
	COMMAND trans8_Limit_ALERT_KEY_write; \
	VARIABLE trans8_Limit_TARGET_MODE; \
	MENU trans8_Limit_TARGET_MODE_page; \
	COMMAND trans8_Limit_TARGET_MODE_read; \
	COMMAND trans8_Limit_TARGET_MODE_write; \
	COLLECTION trans8_Limit_MODE_BLK; \
	VARIABLE trans8_Limit_MODE_BLK_Actual; \
	VARIABLE trans8_Limit_MODE_BLK_Permitted; \
	VARIABLE trans8_Limit_MODE_BLK_Normal; \
	MENU trans8_Limit_MODE_BLK_page; \
	COMMAND trans8_Limit_MODE_BLK_read; \
	COLLECTION trans8_Limit_ALARM_SUM; \
	VARIABLE trans8_Limit_ALARM_SUM_Current; \
	VARIABLE trans8_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans8_Limit_ALARM_SUM_Disabled; \
	MENU trans8_Limit_ALARM_SUM_page; \
	COMMAND trans8_Limit_ALARM_SUM_read; \
	VARIABLE trans8_Limit_CHANNEL; \
	MENU trans8_Limit_CHANNEL_page; \
	COMMAND trans8_Limit_CHANNEL_read; \
	COMMAND trans8_Limit_CHANNEL_write; \
	VARIABLE trans8_Limit_THRESHOLD; \
	MENU trans8_Limit_THRESHOLD_page; \
	COMMAND trans8_Limit_THRESHOLD_read; \
	COMMAND trans8_Limit_THRESHOLD_write; \
	VARIABLE trans8_Limit_HYSTERESIS; \
	MENU trans8_Limit_HYSTERESIS_page; \
	COMMAND trans8_Limit_HYSTERESIS_read; \
	COMMAND trans8_Limit_HYSTERESIS_write; \
	VARIABLE trans8_Limit_DIRECTION; \
	MENU trans8_Limit_DIRECTION_page; \
	COMMAND trans8_Limit_DIRECTION_read; \
	COMMAND trans8_Limit_DIRECTION_write; \
	VARIABLE trans8_Limit_ON_DELAY; \
	MENU trans8_Limit_ON_DELAY_page; \
	COMMAND trans8_Limit_ON_DELAY_read; \
	COMMAND trans8_Limit_ON_DELAY_write; \
	VARIABLE trans8_Limit_OFF_DELAY; \
	MENU trans8_Limit_OFF_DELAY_page; \
	COMMAND trans8_Limit_OFF_DELAY_read; \
	COMMAND trans8_Limit_OFF_DELAY_write; \
	VARIABLE trans8_Limit_RESET; \
	MENU trans8_Limit_RESET_page; \
	COMMAND trans8_Limit_RESET_read; \
	COMMAND trans8_Limit_RESET_write; \
	VARIABLE trans8_Limit_CONFIRMATION; \
	MENU trans8_Limit_CONFIRMATION_page; \
	COMMAND trans8_Limit_CONFIRMATION_read; \
	COMMAND trans8_Limit_CONFIRMATION_write; \
	COLLECTION trans8_Limit_LIMIT_STATUS; \
	VARIABLE trans8_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans8_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans8_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans8_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans8_Limit_LIMIT_STATUS_page; \
	COMMAND trans8_Limit_LIMIT_STATUS_read

#define USE_TRANS8_LIMIT_MANDATORY_A \
	USE_TRANS8_LIMIT_MANDATORY_BOTH; \
	MENU trans8_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS8_LIMIT_MANDATORY_B \
	USE_TRANS8_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans8_Limit_VIEW_1; \
	MENU trans8_Limit_VIEW_1_page; \
	MENU trans8_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS8_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans8_Limit_VIEW_2; \
	MENU trans8_Limit_VIEW_2_page; \
	COLLECTION trans8_Limit_VIEW_3; \
	MENU trans8_Limit_VIEW_3_page

#define USE_TRANS8_LIMIT_OPTIONAL_A \
	USE_TRANS8_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans8_Limit_VIEW_1; \
	MENU trans8_Limit_VIEW_1_page; \
	MENU trans8_Limit_Simple_Dialog_Optional_A

#define USE_TRANS8_LIMIT_OPTIONAL_B \
	USE_TRANS8_LIMIT_OPTIONAL_BOTH; \
	MENU trans8_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans8_Limit_)
#define USE_TRANS8_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans8_Limit_)
#define USE_TRANS8_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans8_Limit_)
#define USE_TRANS8_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans8_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_LIMIT_MANDATORY_BOTH \
	BLOCK trans9_Limit_block; \
	COLLECTION trans9_Limit_BLOCK_OBJECT; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Limit_BLOCK_OBJECT_page; \
	COMMAND trans9_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans9_Limit_ST_REV; \
	MENU trans9_Limit_ST_REV_page; \
	COMMAND trans9_Limit_ST_REV_read; \
	VARIABLE trans9_Limit_TAG_DESC; \
	MENU trans9_Limit_TAG_DESC_page; \
	COMMAND trans9_Limit_TAG_DESC_read; \
	COMMAND trans9_Limit_TAG_DESC_write; \
	VARIABLE trans9_Limit_STRATEGY; \
	MENU trans9_Limit_STRATEGY_page; \
	COMMAND trans9_Limit_STRATEGY_read; \
	COMMAND trans9_Limit_STRATEGY_write; \
	VARIABLE trans9_Limit_ALERT_KEY; \
	MENU trans9_Limit_ALERT_KEY_page; \
	COMMAND trans9_Limit_ALERT_KEY_read; \
	COMMAND trans9_Limit_ALERT_KEY_write; \
	VARIABLE trans9_Limit_TARGET_MODE; \
	MENU trans9_Limit_TARGET_MODE_page; \
	COMMAND trans9_Limit_TARGET_MODE_read; \
	COMMAND trans9_Limit_TARGET_MODE_write; \
	COLLECTION trans9_Limit_MODE_BLK; \
	VARIABLE trans9_Limit_MODE_BLK_Actual; \
	VARIABLE trans9_Limit_MODE_BLK_Permitted; \
	VARIABLE trans9_Limit_MODE_BLK_Normal; \
	MENU trans9_Limit_MODE_BLK_page; \
	COMMAND trans9_Limit_MODE_BLK_read; \
	COLLECTION trans9_Limit_ALARM_SUM; \
	VARIABLE trans9_Limit_ALARM_SUM_Current; \
	VARIABLE trans9_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans9_Limit_ALARM_SUM_Disabled; \
	MENU trans9_Limit_ALARM_SUM_page; \
	COMMAND trans9_Limit_ALARM_SUM_read; \
	VARIABLE trans9_Limit_CHANNEL; \
	MENU trans9_Limit_CHANNEL_page; \
	COMMAND trans9_Limit_CHANNEL_read; \
	COMMAND trans9_Limit_CHANNEL_write; \
	VARIABLE trans9_Limit_THRESHOLD; \
	MENU trans9_Limit_THRESHOLD_page; \
	COMMAND trans9_Limit_THRESHOLD_read; \
	COMMAND trans9_Limit_THRESHOLD_write; \
	VARIABLE trans9_Limit_HYSTERESIS; \
	MENU trans9_Limit_HYSTERESIS_page; \
	COMMAND trans9_Limit_HYSTERESIS_read; \
	COMMAND trans9_Limit_HYSTERESIS_write; \
	VARIABLE trans9_Limit_DIRECTION; \
	MENU trans9_Limit_DIRECTION_page; \
	COMMAND trans9_Limit_DIRECTION_read; \
	COMMAND trans9_Limit_DIRECTION_write; \
	VARIABLE trans9_Limit_ON_DELAY; \
	MENU trans9_Limit_ON_DELAY_page; \
	COMMAND trans9_Limit_ON_DELAY_read; \
	COMMAND trans9_Limit_ON_DELAY_write; \
	VARIABLE trans9_Limit_OFF_DELAY; \
	MENU trans9_Limit_OFF_DELAY_page; \
	COMMAND trans9_Limit_OFF_DELAY_read; \
	COMMAND trans9_Limit_OFF_DELAY_write; \
	VARIABLE trans9_Limit_RESET; \
	MENU trans9_Limit_RESET_page; \
	COMMAND trans9_Limit_RESET_read; \
	COMMAND trans9_Limit_RESET_write; \
	VARIABLE trans9_Limit_CONFIRMATION; \
	MENU trans9_Limit_CONFIRMATION_page; \
	COMMAND trans9_Limit_CONFIRMATION_read; \
	COMMAND trans9_Limit_CONFIRMATION_write; \
	COLLECTION trans9_Limit_LIMIT_STATUS; \
	VARIABLE trans9_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans9_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans9_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans9_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans9_Limit_LIMIT_STATUS_page; \
	COMMAND trans9_Limit_LIMIT_STATUS_read

#define USE_TRANS9_LIMIT_MANDATORY_A \
	USE_TRANS9_LIMIT_MANDATORY_BOTH; \
	MENU trans9_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS9_LIMIT_MANDATORY_B \
	USE_TRANS9_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans9_Limit_VIEW_1; \
	MENU trans9_Limit_VIEW_1_page; \
	MENU trans9_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS9_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans9_Limit_VIEW_2; \
	MENU trans9_Limit_VIEW_2_page; \
	COLLECTION trans9_Limit_VIEW_3; \
	MENU trans9_Limit_VIEW_3_page

#define USE_TRANS9_LIMIT_OPTIONAL_A \
	USE_TRANS9_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans9_Limit_VIEW_1; \
	MENU trans9_Limit_VIEW_1_page; \
	MENU trans9_Limit_Simple_Dialog_Optional_A

#define USE_TRANS9_LIMIT_OPTIONAL_B \
	USE_TRANS9_LIMIT_OPTIONAL_BOTH; \
	MENU trans9_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans9_Limit_)
#define USE_TRANS9_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans9_Limit_)
#define USE_TRANS9_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans9_Limit_)
#define USE_TRANS9_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans9_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_LIMIT_MANDATORY_BOTH \
	BLOCK trans10_Limit_block; \
	COLLECTION trans10_Limit_BLOCK_OBJECT; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Limit_BLOCK_OBJECT_page; \
	COMMAND trans10_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans10_Limit_ST_REV; \
	MENU trans10_Limit_ST_REV_page; \
	COMMAND trans10_Limit_ST_REV_read; \
	VARIABLE trans10_Limit_TAG_DESC; \
	MENU trans10_Limit_TAG_DESC_page; \
	COMMAND trans10_Limit_TAG_DESC_read; \
	COMMAND trans10_Limit_TAG_DESC_write; \
	VARIABLE trans10_Limit_STRATEGY; \
	MENU trans10_Limit_STRATEGY_page; \
	COMMAND trans10_Limit_STRATEGY_read; \
	COMMAND trans10_Limit_STRATEGY_write; \
	VARIABLE trans10_Limit_ALERT_KEY; \
	MENU trans10_Limit_ALERT_KEY_page; \
	COMMAND trans10_Limit_ALERT_KEY_read; \
	COMMAND trans10_Limit_ALERT_KEY_write; \
	VARIABLE trans10_Limit_TARGET_MODE; \
	MENU trans10_Limit_TARGET_MODE_page; \
	COMMAND trans10_Limit_TARGET_MODE_read; \
	COMMAND trans10_Limit_TARGET_MODE_write; \
	COLLECTION trans10_Limit_MODE_BLK; \
	VARIABLE trans10_Limit_MODE_BLK_Actual; \
	VARIABLE trans10_Limit_MODE_BLK_Permitted; \
	VARIABLE trans10_Limit_MODE_BLK_Normal; \
	MENU trans10_Limit_MODE_BLK_page; \
	COMMAND trans10_Limit_MODE_BLK_read; \
	COLLECTION trans10_Limit_ALARM_SUM; \
	VARIABLE trans10_Limit_ALARM_SUM_Current; \
	VARIABLE trans10_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans10_Limit_ALARM_SUM_Disabled; \
	MENU trans10_Limit_ALARM_SUM_page; \
	COMMAND trans10_Limit_ALARM_SUM_read; \
	VARIABLE trans10_Limit_CHANNEL; \
	MENU trans10_Limit_CHANNEL_page; \
	COMMAND trans10_Limit_CHANNEL_read; \
	COMMAND trans10_Limit_CHANNEL_write; \
	VARIABLE trans10_Limit_THRESHOLD; \
	MENU trans10_Limit_THRESHOLD_page; \
	COMMAND trans10_Limit_THRESHOLD_read; \
	COMMAND trans10_Limit_THRESHOLD_write; \
	VARIABLE trans10_Limit_HYSTERESIS; \
	MENU trans10_Limit_HYSTERESIS_page; \
	COMMAND trans10_Limit_HYSTERESIS_read; \
	COMMAND trans10_Limit_HYSTERESIS_write; \
	VARIABLE trans10_Limit_DIRECTION; \
	MENU trans10_Limit_DIRECTION_page; \
	COMMAND trans10_Limit_DIRECTION_read; \
	COMMAND trans10_Limit_DIRECTION_write; \
	VARIABLE trans10_Limit_ON_DELAY; \
	MENU trans10_Limit_ON_DELAY_page; \
	COMMAND trans10_Limit_ON_DELAY_read; \
	COMMAND trans10_Limit_ON_DELAY_write; \
	VARIABLE trans10_Limit_OFF_DELAY; \
	MENU trans10_Limit_OFF_DELAY_page; \
	COMMAND trans10_Limit_OFF_DELAY_read; \
	COMMAND trans10_Limit_OFF_DELAY_write; \
	VARIABLE trans10_Limit_RESET; \
	MENU trans10_Limit_RESET_page; \
	COMMAND trans10_Limit_RESET_read; \
	COMMAND trans10_Limit_RESET_write; \
	VARIABLE trans10_Limit_CONFIRMATION; \
	MENU trans10_Limit_CONFIRMATION_page; \
	COMMAND trans10_Limit_CONFIRMATION_read; \
	COMMAND trans10_Limit_CONFIRMATION_write; \
	COLLECTION trans10_Limit_LIMIT_STATUS; \
	VARIABLE trans10_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans10_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans10_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans10_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans10_Limit_LIMIT_STATUS_page; \
	COMMAND trans10_Limit_LIMIT_STATUS_read

#define USE_TRANS10_LIMIT_MANDATORY_A \
	USE_TRANS10_LIMIT_MANDATORY_BOTH; \
	MENU trans10_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS10_LIMIT_MANDATORY_B \
	USE_TRANS10_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans10_Limit_VIEW_1; \
	MENU trans10_Limit_VIEW_1_page; \
	MENU trans10_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS10_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans10_Limit_VIEW_2; \
	MENU trans10_Limit_VIEW_2_page; \
	COLLECTION trans10_Limit_VIEW_3; \
	MENU trans10_Limit_VIEW_3_page

#define USE_TRANS10_LIMIT_OPTIONAL_A \
	USE_TRANS10_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans10_Limit_VIEW_1; \
	MENU trans10_Limit_VIEW_1_page; \
	MENU trans10_Limit_Simple_Dialog_Optional_A

#define USE_TRANS10_LIMIT_OPTIONAL_B \
	USE_TRANS10_LIMIT_OPTIONAL_BOTH; \
	MENU trans10_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans10_Limit_)
#define USE_TRANS10_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans10_Limit_)
#define USE_TRANS10_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans10_Limit_)
#define USE_TRANS10_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans10_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_LIMIT_MANDATORY_BOTH \
	BLOCK trans11_Limit_block; \
	COLLECTION trans11_Limit_BLOCK_OBJECT; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Limit_BLOCK_OBJECT_page; \
	COMMAND trans11_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans11_Limit_ST_REV; \
	MENU trans11_Limit_ST_REV_page; \
	COMMAND trans11_Limit_ST_REV_read; \
	VARIABLE trans11_Limit_TAG_DESC; \
	MENU trans11_Limit_TAG_DESC_page; \
	COMMAND trans11_Limit_TAG_DESC_read; \
	COMMAND trans11_Limit_TAG_DESC_write; \
	VARIABLE trans11_Limit_STRATEGY; \
	MENU trans11_Limit_STRATEGY_page; \
	COMMAND trans11_Limit_STRATEGY_read; \
	COMMAND trans11_Limit_STRATEGY_write; \
	VARIABLE trans11_Limit_ALERT_KEY; \
	MENU trans11_Limit_ALERT_KEY_page; \
	COMMAND trans11_Limit_ALERT_KEY_read; \
	COMMAND trans11_Limit_ALERT_KEY_write; \
	VARIABLE trans11_Limit_TARGET_MODE; \
	MENU trans11_Limit_TARGET_MODE_page; \
	COMMAND trans11_Limit_TARGET_MODE_read; \
	COMMAND trans11_Limit_TARGET_MODE_write; \
	COLLECTION trans11_Limit_MODE_BLK; \
	VARIABLE trans11_Limit_MODE_BLK_Actual; \
	VARIABLE trans11_Limit_MODE_BLK_Permitted; \
	VARIABLE trans11_Limit_MODE_BLK_Normal; \
	MENU trans11_Limit_MODE_BLK_page; \
	COMMAND trans11_Limit_MODE_BLK_read; \
	COLLECTION trans11_Limit_ALARM_SUM; \
	VARIABLE trans11_Limit_ALARM_SUM_Current; \
	VARIABLE trans11_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans11_Limit_ALARM_SUM_Disabled; \
	MENU trans11_Limit_ALARM_SUM_page; \
	COMMAND trans11_Limit_ALARM_SUM_read; \
	VARIABLE trans11_Limit_CHANNEL; \
	MENU trans11_Limit_CHANNEL_page; \
	COMMAND trans11_Limit_CHANNEL_read; \
	COMMAND trans11_Limit_CHANNEL_write; \
	VARIABLE trans11_Limit_THRESHOLD; \
	MENU trans11_Limit_THRESHOLD_page; \
	COMMAND trans11_Limit_THRESHOLD_read; \
	COMMAND trans11_Limit_THRESHOLD_write; \
	VARIABLE trans11_Limit_HYSTERESIS; \
	MENU trans11_Limit_HYSTERESIS_page; \
	COMMAND trans11_Limit_HYSTERESIS_read; \
	COMMAND trans11_Limit_HYSTERESIS_write; \
	VARIABLE trans11_Limit_DIRECTION; \
	MENU trans11_Limit_DIRECTION_page; \
	COMMAND trans11_Limit_DIRECTION_read; \
	COMMAND trans11_Limit_DIRECTION_write; \
	VARIABLE trans11_Limit_ON_DELAY; \
	MENU trans11_Limit_ON_DELAY_page; \
	COMMAND trans11_Limit_ON_DELAY_read; \
	COMMAND trans11_Limit_ON_DELAY_write; \
	VARIABLE trans11_Limit_OFF_DELAY; \
	MENU trans11_Limit_OFF_DELAY_page; \
	COMMAND trans11_Limit_OFF_DELAY_read; \
	COMMAND trans11_Limit_OFF_DELAY_write; \
	VARIABLE trans11_Limit_RESET; \
	MENU trans11_Limit_RESET_page; \
	COMMAND trans11_Limit_RESET_read; \
	COMMAND trans11_Limit_RESET_write; \
	VARIABLE trans11_Limit_CONFIRMATION; \
	MENU trans11_Limit_CONFIRMATION_page; \
	COMMAND trans11_Limit_CONFIRMATION_read; \
	COMMAND trans11_Limit_CONFIRMATION_write; \
	COLLECTION trans11_Limit_LIMIT_STATUS; \
	VARIABLE trans11_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans11_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans11_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans11_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans11_Limit_LIMIT_STATUS_page; \
	COMMAND trans11_Limit_LIMIT_STATUS_read

#define USE_TRANS11_LIMIT_MANDATORY_A \
	USE_TRANS11_LIMIT_MANDATORY_BOTH; \
	MENU trans11_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS11_LIMIT_MANDATORY_B \
	USE_TRANS11_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans11_Limit_VIEW_1; \
	MENU trans11_Limit_VIEW_1_page; \
	MENU trans11_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS11_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans11_Limit_VIEW_2; \
	MENU trans11_Limit_VIEW_2_page; \
	COLLECTION trans11_Limit_VIEW_3; \
	MENU trans11_Limit_VIEW_3_page

#define USE_TRANS11_LIMIT_OPTIONAL_A \
	USE_TRANS11_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans11_Limit_VIEW_1; \
	MENU trans11_Limit_VIEW_1_page; \
	MENU trans11_Limit_Simple_Dialog_Optional_A

#define USE_TRANS11_LIMIT_OPTIONAL_B \
	USE_TRANS11_LIMIT_OPTIONAL_BOTH; \
	MENU trans11_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans11_Limit_)
#define USE_TRANS11_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans11_Limit_)
#define USE_TRANS11_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans11_Limit_)
#define USE_TRANS11_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans11_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_LIMIT_MANDATORY_BOTH \
	BLOCK trans12_Limit_block; \
	COLLECTION trans12_Limit_BLOCK_OBJECT; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Limit_BLOCK_OBJECT_page; \
	COMMAND trans12_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans12_Limit_ST_REV; \
	MENU trans12_Limit_ST_REV_page; \
	COMMAND trans12_Limit_ST_REV_read; \
	VARIABLE trans12_Limit_TAG_DESC; \
	MENU trans12_Limit_TAG_DESC_page; \
	COMMAND trans12_Limit_TAG_DESC_read; \
	COMMAND trans12_Limit_TAG_DESC_write; \
	VARIABLE trans12_Limit_STRATEGY; \
	MENU trans12_Limit_STRATEGY_page; \
	COMMAND trans12_Limit_STRATEGY_read; \
	COMMAND trans12_Limit_STRATEGY_write; \
	VARIABLE trans12_Limit_ALERT_KEY; \
	MENU trans12_Limit_ALERT_KEY_page; \
	COMMAND trans12_Limit_ALERT_KEY_read; \
	COMMAND trans12_Limit_ALERT_KEY_write; \
	VARIABLE trans12_Limit_TARGET_MODE; \
	MENU trans12_Limit_TARGET_MODE_page; \
	COMMAND trans12_Limit_TARGET_MODE_read; \
	COMMAND trans12_Limit_TARGET_MODE_write; \
	COLLECTION trans12_Limit_MODE_BLK; \
	VARIABLE trans12_Limit_MODE_BLK_Actual; \
	VARIABLE trans12_Limit_MODE_BLK_Permitted; \
	VARIABLE trans12_Limit_MODE_BLK_Normal; \
	MENU trans12_Limit_MODE_BLK_page; \
	COMMAND trans12_Limit_MODE_BLK_read; \
	COLLECTION trans12_Limit_ALARM_SUM; \
	VARIABLE trans12_Limit_ALARM_SUM_Current; \
	VARIABLE trans12_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans12_Limit_ALARM_SUM_Disabled; \
	MENU trans12_Limit_ALARM_SUM_page; \
	COMMAND trans12_Limit_ALARM_SUM_read; \
	VARIABLE trans12_Limit_CHANNEL; \
	MENU trans12_Limit_CHANNEL_page; \
	COMMAND trans12_Limit_CHANNEL_read; \
	COMMAND trans12_Limit_CHANNEL_write; \
	VARIABLE trans12_Limit_THRESHOLD; \
	MENU trans12_Limit_THRESHOLD_page; \
	COMMAND trans12_Limit_THRESHOLD_read; \
	COMMAND trans12_Limit_THRESHOLD_write; \
	VARIABLE trans12_Limit_HYSTERESIS; \
	MENU trans12_Limit_HYSTERESIS_page; \
	COMMAND trans12_Limit_HYSTERESIS_read; \
	COMMAND trans12_Limit_HYSTERESIS_write; \
	VARIABLE trans12_Limit_DIRECTION; \
	MENU trans12_Limit_DIRECTION_page; \
	COMMAND trans12_Limit_DIRECTION_read; \
	COMMAND trans12_Limit_DIRECTION_write; \
	VARIABLE trans12_Limit_ON_DELAY; \
	MENU trans12_Limit_ON_DELAY_page; \
	COMMAND trans12_Limit_ON_DELAY_read; \
	COMMAND trans12_Limit_ON_DELAY_write; \
	VARIABLE trans12_Limit_OFF_DELAY; \
	MENU trans12_Limit_OFF_DELAY_page; \
	COMMAND trans12_Limit_OFF_DELAY_read; \
	COMMAND trans12_Limit_OFF_DELAY_write; \
	VARIABLE trans12_Limit_RESET; \
	MENU trans12_Limit_RESET_page; \
	COMMAND trans12_Limit_RESET_read; \
	COMMAND trans12_Limit_RESET_write; \
	VARIABLE trans12_Limit_CONFIRMATION; \
	MENU trans12_Limit_CONFIRMATION_page; \
	COMMAND trans12_Limit_CONFIRMATION_read; \
	COMMAND trans12_Limit_CONFIRMATION_write; \
	COLLECTION trans12_Limit_LIMIT_STATUS; \
	VARIABLE trans12_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans12_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans12_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans12_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans12_Limit_LIMIT_STATUS_page; \
	COMMAND trans12_Limit_LIMIT_STATUS_read

#define USE_TRANS12_LIMIT_MANDATORY_A \
	USE_TRANS12_LIMIT_MANDATORY_BOTH; \
	MENU trans12_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS12_LIMIT_MANDATORY_B \
	USE_TRANS12_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans12_Limit_VIEW_1; \
	MENU trans12_Limit_VIEW_1_page; \
	MENU trans12_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS12_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans12_Limit_VIEW_2; \
	MENU trans12_Limit_VIEW_2_page; \
	COLLECTION trans12_Limit_VIEW_3; \
	MENU trans12_Limit_VIEW_3_page

#define USE_TRANS12_LIMIT_OPTIONAL_A \
	USE_TRANS12_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans12_Limit_VIEW_1; \
	MENU trans12_Limit_VIEW_1_page; \
	MENU trans12_Limit_Simple_Dialog_Optional_A

#define USE_TRANS12_LIMIT_OPTIONAL_B \
	USE_TRANS12_LIMIT_OPTIONAL_BOTH; \
	MENU trans12_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans12_Limit_)
#define USE_TRANS12_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans12_Limit_)
#define USE_TRANS12_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans12_Limit_)
#define USE_TRANS12_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans12_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_LIMIT_MANDATORY_BOTH \
	BLOCK trans13_Limit_block; \
	COLLECTION trans13_Limit_BLOCK_OBJECT; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Limit_BLOCK_OBJECT_page; \
	COMMAND trans13_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans13_Limit_ST_REV; \
	MENU trans13_Limit_ST_REV_page; \
	COMMAND trans13_Limit_ST_REV_read; \
	VARIABLE trans13_Limit_TAG_DESC; \
	MENU trans13_Limit_TAG_DESC_page; \
	COMMAND trans13_Limit_TAG_DESC_read; \
	COMMAND trans13_Limit_TAG_DESC_write; \
	VARIABLE trans13_Limit_STRATEGY; \
	MENU trans13_Limit_STRATEGY_page; \
	COMMAND trans13_Limit_STRATEGY_read; \
	COMMAND trans13_Limit_STRATEGY_write; \
	VARIABLE trans13_Limit_ALERT_KEY; \
	MENU trans13_Limit_ALERT_KEY_page; \
	COMMAND trans13_Limit_ALERT_KEY_read; \
	COMMAND trans13_Limit_ALERT_KEY_write; \
	VARIABLE trans13_Limit_TARGET_MODE; \
	MENU trans13_Limit_TARGET_MODE_page; \
	COMMAND trans13_Limit_TARGET_MODE_read; \
	COMMAND trans13_Limit_TARGET_MODE_write; \
	COLLECTION trans13_Limit_MODE_BLK; \
	VARIABLE trans13_Limit_MODE_BLK_Actual; \
	VARIABLE trans13_Limit_MODE_BLK_Permitted; \
	VARIABLE trans13_Limit_MODE_BLK_Normal; \
	MENU trans13_Limit_MODE_BLK_page; \
	COMMAND trans13_Limit_MODE_BLK_read; \
	COLLECTION trans13_Limit_ALARM_SUM; \
	VARIABLE trans13_Limit_ALARM_SUM_Current; \
	VARIABLE trans13_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans13_Limit_ALARM_SUM_Disabled; \
	MENU trans13_Limit_ALARM_SUM_page; \
	COMMAND trans13_Limit_ALARM_SUM_read; \
	VARIABLE trans13_Limit_CHANNEL; \
	MENU trans13_Limit_CHANNEL_page; \
	COMMAND trans13_Limit_CHANNEL_read; \
	COMMAND trans13_Limit_CHANNEL_write; \
	VARIABLE trans13_Limit_THRESHOLD; \
	MENU trans13_Limit_THRESHOLD_page; \
	COMMAND trans13_Limit_THRESHOLD_read; \
	COMMAND trans13_Limit_THRESHOLD_write; \
	VARIABLE trans13_Limit_HYSTERESIS; \
	MENU trans13_Limit_HYSTERESIS_page; \
	COMMAND trans13_Limit_HYSTERESIS_read; \
	COMMAND trans13_Limit_HYSTERESIS_write; \
	VARIABLE trans13_Limit_DIRECTION; \
	MENU trans13_Limit_DIRECTION_page; \
	COMMAND trans13_Limit_DIRECTION_read; \
	COMMAND trans13_Limit_DIRECTION_write; \
	VARIABLE trans13_Limit_ON_DELAY; \
	MENU trans13_Limit_ON_DELAY_page; \
	COMMAND trans13_Limit_ON_DELAY_read; \
	COMMAND trans13_Limit_ON_DELAY_write; \
	VARIABLE trans13_Limit_OFF_DELAY; \
	MENU trans13_Limit_OFF_DELAY_page; \
	COMMAND trans13_Limit_OFF_DELAY_read; \
	COMMAND trans13_Limit_OFF_DELAY_write; \
	VARIABLE trans13_Limit_RESET; \
	MENU trans13_Limit_RESET_page; \
	COMMAND trans13_Limit_RESET_read; \
	COMMAND trans13_Limit_RESET_write; \
	VARIABLE trans13_Limit_CONFIRMATION; \
	MENU trans13_Limit_CONFIRMATION_page; \
	COMMAND trans13_Limit_CONFIRMATION_read; \
	COMMAND trans13_Limit_CONFIRMATION_write; \
	COLLECTION trans13_Limit_LIMIT_STATUS; \
	VARIABLE trans13_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans13_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans13_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans13_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans13_Limit_LIMIT_STATUS_page; \
	COMMAND trans13_Limit_LIMIT_STATUS_read

#define USE_TRANS13_LIMIT_MANDATORY_A \
	USE_TRANS13_LIMIT_MANDATORY_BOTH; \
	MENU trans13_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS13_LIMIT_MANDATORY_B \
	USE_TRANS13_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans13_Limit_VIEW_1; \
	MENU trans13_Limit_VIEW_1_page; \
	MENU trans13_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS13_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans13_Limit_VIEW_2; \
	MENU trans13_Limit_VIEW_2_page; \
	COLLECTION trans13_Limit_VIEW_3; \
	MENU trans13_Limit_VIEW_3_page

#define USE_TRANS13_LIMIT_OPTIONAL_A \
	USE_TRANS13_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans13_Limit_VIEW_1; \
	MENU trans13_Limit_VIEW_1_page; \
	MENU trans13_Limit_Simple_Dialog_Optional_A

#define USE_TRANS13_LIMIT_OPTIONAL_B \
	USE_TRANS13_LIMIT_OPTIONAL_BOTH; \
	MENU trans13_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans13_Limit_)
#define USE_TRANS13_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans13_Limit_)
#define USE_TRANS13_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans13_Limit_)
#define USE_TRANS13_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans13_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_LIMIT_MANDATORY_BOTH \
	BLOCK trans14_Limit_block; \
	COLLECTION trans14_Limit_BLOCK_OBJECT; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Limit_BLOCK_OBJECT_page; \
	COMMAND trans14_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans14_Limit_ST_REV; \
	MENU trans14_Limit_ST_REV_page; \
	COMMAND trans14_Limit_ST_REV_read; \
	VARIABLE trans14_Limit_TAG_DESC; \
	MENU trans14_Limit_TAG_DESC_page; \
	COMMAND trans14_Limit_TAG_DESC_read; \
	COMMAND trans14_Limit_TAG_DESC_write; \
	VARIABLE trans14_Limit_STRATEGY; \
	MENU trans14_Limit_STRATEGY_page; \
	COMMAND trans14_Limit_STRATEGY_read; \
	COMMAND trans14_Limit_STRATEGY_write; \
	VARIABLE trans14_Limit_ALERT_KEY; \
	MENU trans14_Limit_ALERT_KEY_page; \
	COMMAND trans14_Limit_ALERT_KEY_read; \
	COMMAND trans14_Limit_ALERT_KEY_write; \
	VARIABLE trans14_Limit_TARGET_MODE; \
	MENU trans14_Limit_TARGET_MODE_page; \
	COMMAND trans14_Limit_TARGET_MODE_read; \
	COMMAND trans14_Limit_TARGET_MODE_write; \
	COLLECTION trans14_Limit_MODE_BLK; \
	VARIABLE trans14_Limit_MODE_BLK_Actual; \
	VARIABLE trans14_Limit_MODE_BLK_Permitted; \
	VARIABLE trans14_Limit_MODE_BLK_Normal; \
	MENU trans14_Limit_MODE_BLK_page; \
	COMMAND trans14_Limit_MODE_BLK_read; \
	COLLECTION trans14_Limit_ALARM_SUM; \
	VARIABLE trans14_Limit_ALARM_SUM_Current; \
	VARIABLE trans14_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans14_Limit_ALARM_SUM_Disabled; \
	MENU trans14_Limit_ALARM_SUM_page; \
	COMMAND trans14_Limit_ALARM_SUM_read; \
	VARIABLE trans14_Limit_CHANNEL; \
	MENU trans14_Limit_CHANNEL_page; \
	COMMAND trans14_Limit_CHANNEL_read; \
	COMMAND trans14_Limit_CHANNEL_write; \
	VARIABLE trans14_Limit_THRESHOLD; \
	MENU trans14_Limit_THRESHOLD_page; \
	COMMAND trans14_Limit_THRESHOLD_read; \
	COMMAND trans14_Limit_THRESHOLD_write; \
	VARIABLE trans14_Limit_HYSTERESIS; \
	MENU trans14_Limit_HYSTERESIS_page; \
	COMMAND trans14_Limit_HYSTERESIS_read; \
	COMMAND trans14_Limit_HYSTERESIS_write; \
	VARIABLE trans14_Limit_DIRECTION; \
	MENU trans14_Limit_DIRECTION_page; \
	COMMAND trans14_Limit_DIRECTION_read; \
	COMMAND trans14_Limit_DIRECTION_write; \
	VARIABLE trans14_Limit_ON_DELAY; \
	MENU trans14_Limit_ON_DELAY_page; \
	COMMAND trans14_Limit_ON_DELAY_read; \
	COMMAND trans14_Limit_ON_DELAY_write; \
	VARIABLE trans14_Limit_OFF_DELAY; \
	MENU trans14_Limit_OFF_DELAY_page; \
	COMMAND trans14_Limit_OFF_DELAY_read; \
	COMMAND trans14_Limit_OFF_DELAY_write; \
	VARIABLE trans14_Limit_RESET; \
	MENU trans14_Limit_RESET_page; \
	COMMAND trans14_Limit_RESET_read; \
	COMMAND trans14_Limit_RESET_write; \
	VARIABLE trans14_Limit_CONFIRMATION; \
	MENU trans14_Limit_CONFIRMATION_page; \
	COMMAND trans14_Limit_CONFIRMATION_read; \
	COMMAND trans14_Limit_CONFIRMATION_write; \
	COLLECTION trans14_Limit_LIMIT_STATUS; \
	VARIABLE trans14_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans14_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans14_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans14_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans14_Limit_LIMIT_STATUS_page; \
	COMMAND trans14_Limit_LIMIT_STATUS_read

#define USE_TRANS14_LIMIT_MANDATORY_A \
	USE_TRANS14_LIMIT_MANDATORY_BOTH; \
	MENU trans14_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS14_LIMIT_MANDATORY_B \
	USE_TRANS14_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans14_Limit_VIEW_1; \
	MENU trans14_Limit_VIEW_1_page; \
	MENU trans14_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS14_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans14_Limit_VIEW_2; \
	MENU trans14_Limit_VIEW_2_page; \
	COLLECTION trans14_Limit_VIEW_3; \
	MENU trans14_Limit_VIEW_3_page

#define USE_TRANS14_LIMIT_OPTIONAL_A \
	USE_TRANS14_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans14_Limit_VIEW_1; \
	MENU trans14_Limit_VIEW_1_page; \
	MENU trans14_Limit_Simple_Dialog_Optional_A

#define USE_TRANS14_LIMIT_OPTIONAL_B \
	USE_TRANS14_LIMIT_OPTIONAL_BOTH; \
	MENU trans14_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans14_Limit_)
#define USE_TRANS14_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans14_Limit_)
#define USE_TRANS14_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans14_Limit_)
#define USE_TRANS14_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans14_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_LIMIT_MANDATORY_BOTH \
	BLOCK trans15_Limit_block; \
	COLLECTION trans15_Limit_BLOCK_OBJECT; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Limit_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Limit_BLOCK_OBJECT_page; \
	COMMAND trans15_Limit_BLOCK_OBJECT_read; \
	VARIABLE trans15_Limit_ST_REV; \
	MENU trans15_Limit_ST_REV_page; \
	COMMAND trans15_Limit_ST_REV_read; \
	VARIABLE trans15_Limit_TAG_DESC; \
	MENU trans15_Limit_TAG_DESC_page; \
	COMMAND trans15_Limit_TAG_DESC_read; \
	COMMAND trans15_Limit_TAG_DESC_write; \
	VARIABLE trans15_Limit_STRATEGY; \
	MENU trans15_Limit_STRATEGY_page; \
	COMMAND trans15_Limit_STRATEGY_read; \
	COMMAND trans15_Limit_STRATEGY_write; \
	VARIABLE trans15_Limit_ALERT_KEY; \
	MENU trans15_Limit_ALERT_KEY_page; \
	COMMAND trans15_Limit_ALERT_KEY_read; \
	COMMAND trans15_Limit_ALERT_KEY_write; \
	VARIABLE trans15_Limit_TARGET_MODE; \
	MENU trans15_Limit_TARGET_MODE_page; \
	COMMAND trans15_Limit_TARGET_MODE_read; \
	COMMAND trans15_Limit_TARGET_MODE_write; \
	COLLECTION trans15_Limit_MODE_BLK; \
	VARIABLE trans15_Limit_MODE_BLK_Actual; \
	VARIABLE trans15_Limit_MODE_BLK_Permitted; \
	VARIABLE trans15_Limit_MODE_BLK_Normal; \
	MENU trans15_Limit_MODE_BLK_page; \
	COMMAND trans15_Limit_MODE_BLK_read; \
	COLLECTION trans15_Limit_ALARM_SUM; \
	VARIABLE trans15_Limit_ALARM_SUM_Current; \
	VARIABLE trans15_Limit_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Limit_ALARM_SUM_Unreported; \
	VARIABLE trans15_Limit_ALARM_SUM_Disabled; \
	MENU trans15_Limit_ALARM_SUM_page; \
	COMMAND trans15_Limit_ALARM_SUM_read; \
	VARIABLE trans15_Limit_CHANNEL; \
	MENU trans15_Limit_CHANNEL_page; \
	COMMAND trans15_Limit_CHANNEL_read; \
	COMMAND trans15_Limit_CHANNEL_write; \
	VARIABLE trans15_Limit_THRESHOLD; \
	MENU trans15_Limit_THRESHOLD_page; \
	COMMAND trans15_Limit_THRESHOLD_read; \
	COMMAND trans15_Limit_THRESHOLD_write; \
	VARIABLE trans15_Limit_HYSTERESIS; \
	MENU trans15_Limit_HYSTERESIS_page; \
	COMMAND trans15_Limit_HYSTERESIS_read; \
	COMMAND trans15_Limit_HYSTERESIS_write; \
	VARIABLE trans15_Limit_DIRECTION; \
	MENU trans15_Limit_DIRECTION_page; \
	COMMAND trans15_Limit_DIRECTION_read; \
	COMMAND trans15_Limit_DIRECTION_write; \
	VARIABLE trans15_Limit_ON_DELAY; \
	MENU trans15_Limit_ON_DELAY_page; \
	COMMAND trans15_Limit_ON_DELAY_read; \
	COMMAND trans15_Limit_ON_DELAY_write; \
	VARIABLE trans15_Limit_OFF_DELAY; \
	MENU trans15_Limit_OFF_DELAY_page; \
	COMMAND trans15_Limit_OFF_DELAY_read; \
	COMMAND trans15_Limit_OFF_DELAY_write; \
	VARIABLE trans15_Limit_RESET; \
	MENU trans15_Limit_RESET_page; \
	COMMAND trans15_Limit_RESET_read; \
	COMMAND trans15_Limit_RESET_write; \
	VARIABLE trans15_Limit_CONFIRMATION; \
	MENU trans15_Limit_CONFIRMATION_page; \
	COMMAND trans15_Limit_CONFIRMATION_read; \
	COMMAND trans15_Limit_CONFIRMATION_write; \
	COLLECTION trans15_Limit_LIMIT_STATUS; \
	VARIABLE trans15_Limit_LIMIT_STATUS_Value; \
	VARIABLE trans15_Limit_LIMIT_STATUS_Status_Condensed; \
	VARIABLE trans15_Limit_LIMIT_STATUS_Status_Quality; \
	VARIABLE trans15_Limit_LIMIT_STATUS_Status_Limit; \
	MENU trans15_Limit_LIMIT_STATUS_page; \
	COMMAND trans15_Limit_LIMIT_STATUS_read

#define USE_TRANS15_LIMIT_MANDATORY_A \
	USE_TRANS15_LIMIT_MANDATORY_BOTH; \
	MENU trans15_Limit_Simple_Dialog_Mandatory_A

#define USE_TRANS15_LIMIT_MANDATORY_B \
	USE_TRANS15_LIMIT_MANDATORY_BOTH; \
	COLLECTION trans15_Limit_VIEW_1; \
	MENU trans15_Limit_VIEW_1_page; \
	MENU trans15_Limit_Simple_Dialog_Mandatory_B

#define USE_TRANS15_LIMIT_OPTIONAL_BOTH \
	COLLECTION trans15_Limit_VIEW_2; \
	MENU trans15_Limit_VIEW_2_page; \
	COLLECTION trans15_Limit_VIEW_3; \
	MENU trans15_Limit_VIEW_3_page

#define USE_TRANS15_LIMIT_OPTIONAL_A \
	USE_TRANS15_LIMIT_OPTIONAL_BOTH; \
	COLLECTION trans15_Limit_VIEW_1; \
	MENU trans15_Limit_VIEW_1_page; \
	MENU trans15_Limit_Simple_Dialog_Optional_A

#define USE_TRANS15_LIMIT_OPTIONAL_B \
	USE_TRANS15_LIMIT_OPTIONAL_BOTH; \
	MENU trans15_Limit_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_LIMIT_MANDATORY_A USE_TRANS_LIMIT_MANDATORY_A(trans15_Limit_)
#define USE_TRANS15_LIMIT_MANDATORY_B USE_TRANS_LIMIT_MANDATORY_B(trans15_Limit_)
#define USE_TRANS15_LIMIT_OPTIONAL_A  USE_TRANS_LIMIT_OPTIONAL_A(trans15_Limit_)
#define USE_TRANS15_LIMIT_OPTIONAL_B  USE_TRANS_LIMIT_OPTIONAL_B(trans15_Limit_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS1_ALARM_MANDATORY_BOTH \
	BLOCK trans1_Alarm_block; \
	COLLECTION trans1_Alarm_BLOCK_OBJECT; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans1_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans1_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans1_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans1_Alarm_ST_REV; \
	MENU trans1_Alarm_ST_REV_page; \
	COMMAND trans1_Alarm_ST_REV_read; \
	VARIABLE trans1_Alarm_TAG_DESC; \
	MENU trans1_Alarm_TAG_DESC_page; \
	COMMAND trans1_Alarm_TAG_DESC_read; \
	COMMAND trans1_Alarm_TAG_DESC_write; \
	VARIABLE trans1_Alarm_STRATEGY; \
	MENU trans1_Alarm_STRATEGY_page; \
	COMMAND trans1_Alarm_STRATEGY_read; \
	COMMAND trans1_Alarm_STRATEGY_write; \
	VARIABLE trans1_Alarm_ALERT_KEY; \
	MENU trans1_Alarm_ALERT_KEY_page; \
	COMMAND trans1_Alarm_ALERT_KEY_read; \
	COMMAND trans1_Alarm_ALERT_KEY_write; \
	VARIABLE trans1_Alarm_TARGET_MODE; \
	MENU trans1_Alarm_TARGET_MODE_page; \
	COMMAND trans1_Alarm_TARGET_MODE_read; \
	COMMAND trans1_Alarm_TARGET_MODE_write; \
	COLLECTION trans1_Alarm_MODE_BLK; \
	VARIABLE trans1_Alarm_MODE_BLK_Actual; \
	VARIABLE trans1_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans1_Alarm_MODE_BLK_Normal; \
	MENU trans1_Alarm_MODE_BLK_page; \
	COMMAND trans1_Alarm_MODE_BLK_read; \
	COLLECTION trans1_Alarm_ALARM_SUM; \
	VARIABLE trans1_Alarm_ALARM_SUM_Current; \
	VARIABLE trans1_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans1_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans1_Alarm_ALARM_SUM_Disabled; \
	MENU trans1_Alarm_ALARM_SUM_page; \
	COMMAND trans1_Alarm_ALARM_SUM_read; \
	VARIABLE trans1_Alarm_STATUS_CLASSES_type; \
	ARRAY trans1_Alarm_STATUS_CLASSES; \
	MENU trans1_Alarm_STATUS_CLASSES_page; \
	COMMAND trans1_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans1_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans1_Alarm_ACTIVE_MESSAGES; \
	MENU trans1_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans1_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans1_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans1_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans1_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans1_Alarm_BM_1; \
	VARIABLE trans1_Alarm_BM_1_Status_Class; \
	VARIABLE trans1_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans1_Alarm_BM_1_Output_Reference; \
	VARIABLE trans1_Alarm_BM_1_Supervision; \
	VARIABLE trans1_Alarm_BM_1_Text; \
	MENU trans1_Alarm_BM_1_page; \
	COMMAND trans1_Alarm_BM_1_read; \
	COMMAND trans1_Alarm_BM_1_write

#define USE_TRANS1_ALARM_MANDATORY_A \
	USE_TRANS1_ALARM_MANDATORY_BOTH; \
	MENU trans1_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS1_ALARM_MANDATORY_B \
	USE_TRANS1_ALARM_MANDATORY_BOTH; \
	COLLECTION trans1_Alarm_VIEW_1; \
	MENU trans1_Alarm_VIEW_1_page; \
	MENU trans1_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS1_ALARM_OPTIONAL_BOTH \
	COLLECTION trans1_Alarm_VIEW_2; \
	MENU trans1_Alarm_VIEW_2_page; \
	COLLECTION trans1_Alarm_VIEW_3; \
	MENU trans1_Alarm_VIEW_3_page

#define USE_TRANS1_ALARM_OPTIONAL_A \
	USE_TRANS1_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans1_Alarm_VIEW_1; \
	MENU trans1_Alarm_VIEW_1_page; \
	MENU trans1_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS1_ALARM_OPTIONAL_B \
	USE_TRANS1_ALARM_OPTIONAL_BOTH; \
	MENU trans1_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS_ALARM_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	VARIABLE prefix ## STATUS_CLASSES_type; \
	ARRAY prefix ## STATUS_CLASSES; \
	MENU prefix ## STATUS_CLASSES_page; \
	COMMAND prefix ## STATUS_CLASSES_read; \
	VARIABLE prefix ## ACTIVE_MESSAGES_type; \
	ARRAY prefix ## ACTIVE_MESSAGES; \
	MENU prefix ## ACTIVE_MESSAGES_page; \
	COMMAND prefix ## ACTIVE_MESSAGES_read; \
	VARIABLE prefix ## NUMBER_OF_MESSAGES; \
	MENU prefix ## NUMBER_OF_MESSAGES_page; \
	COMMAND prefix ## NUMBER_OF_MESSAGES_read; \
	COLLECTION prefix ## BM_1; \
	VARIABLE prefix ## BM_1_Status_Class; \
	VARIABLE prefix ## BM_1_Logbook_Entry; \
	VARIABLE prefix ## BM_1_Output_Reference; \
	VARIABLE prefix ## BM_1_Supervision; \
	VARIABLE prefix ## BM_1_Text; \
	MENU prefix ## BM_1_page; \
	COMMAND prefix ## BM_1_read; \
	COMMAND prefix ## BM_1_write

#define USE_TRANS_ALARM_MANDATORY_A(prefix) \
	USE_TRANS_ALARM_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_TRANS_ALARM_MANDATORY_B(prefix) \
	USE_TRANS_ALARM_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_TRANS_ALARM_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_TRANS_ALARM_OPTIONAL_A(prefix) \
	USE_TRANS_ALARM_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_TRANS_ALARM_OPTIONAL_B(prefix) \
	USE_TRANS_ALARM_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_TRANS1_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans1_Alarm_)
#define USE_TRANS1_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans1_Alarm_)
#define USE_TRANS1_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans1_Alarm_)
#define USE_TRANS1_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans1_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS2_ALARM_MANDATORY_BOTH \
	BLOCK trans2_Alarm_block; \
	COLLECTION trans2_Alarm_BLOCK_OBJECT; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans2_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans2_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans2_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans2_Alarm_ST_REV; \
	MENU trans2_Alarm_ST_REV_page; \
	COMMAND trans2_Alarm_ST_REV_read; \
	VARIABLE trans2_Alarm_TAG_DESC; \
	MENU trans2_Alarm_TAG_DESC_page; \
	COMMAND trans2_Alarm_TAG_DESC_read; \
	COMMAND trans2_Alarm_TAG_DESC_write; \
	VARIABLE trans2_Alarm_STRATEGY; \
	MENU trans2_Alarm_STRATEGY_page; \
	COMMAND trans2_Alarm_STRATEGY_read; \
	COMMAND trans2_Alarm_STRATEGY_write; \
	VARIABLE trans2_Alarm_ALERT_KEY; \
	MENU trans2_Alarm_ALERT_KEY_page; \
	COMMAND trans2_Alarm_ALERT_KEY_read; \
	COMMAND trans2_Alarm_ALERT_KEY_write; \
	VARIABLE trans2_Alarm_TARGET_MODE; \
	MENU trans2_Alarm_TARGET_MODE_page; \
	COMMAND trans2_Alarm_TARGET_MODE_read; \
	COMMAND trans2_Alarm_TARGET_MODE_write; \
	COLLECTION trans2_Alarm_MODE_BLK; \
	VARIABLE trans2_Alarm_MODE_BLK_Actual; \
	VARIABLE trans2_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans2_Alarm_MODE_BLK_Normal; \
	MENU trans2_Alarm_MODE_BLK_page; \
	COMMAND trans2_Alarm_MODE_BLK_read; \
	COLLECTION trans2_Alarm_ALARM_SUM; \
	VARIABLE trans2_Alarm_ALARM_SUM_Current; \
	VARIABLE trans2_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans2_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans2_Alarm_ALARM_SUM_Disabled; \
	MENU trans2_Alarm_ALARM_SUM_page; \
	COMMAND trans2_Alarm_ALARM_SUM_read; \
	VARIABLE trans2_Alarm_STATUS_CLASSES_type; \
	ARRAY trans2_Alarm_STATUS_CLASSES; \
	MENU trans2_Alarm_STATUS_CLASSES_page; \
	COMMAND trans2_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans2_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans2_Alarm_ACTIVE_MESSAGES; \
	MENU trans2_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans2_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans2_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans2_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans2_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans2_Alarm_BM_1; \
	VARIABLE trans2_Alarm_BM_1_Status_Class; \
	VARIABLE trans2_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans2_Alarm_BM_1_Output_Reference; \
	VARIABLE trans2_Alarm_BM_1_Supervision; \
	VARIABLE trans2_Alarm_BM_1_Text; \
	MENU trans2_Alarm_BM_1_page; \
	COMMAND trans2_Alarm_BM_1_read; \
	COMMAND trans2_Alarm_BM_1_write

#define USE_TRANS2_ALARM_MANDATORY_A \
	USE_TRANS2_ALARM_MANDATORY_BOTH; \
	MENU trans2_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS2_ALARM_MANDATORY_B \
	USE_TRANS2_ALARM_MANDATORY_BOTH; \
	COLLECTION trans2_Alarm_VIEW_1; \
	MENU trans2_Alarm_VIEW_1_page; \
	MENU trans2_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS2_ALARM_OPTIONAL_BOTH \
	COLLECTION trans2_Alarm_VIEW_2; \
	MENU trans2_Alarm_VIEW_2_page; \
	COLLECTION trans2_Alarm_VIEW_3; \
	MENU trans2_Alarm_VIEW_3_page

#define USE_TRANS2_ALARM_OPTIONAL_A \
	USE_TRANS2_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans2_Alarm_VIEW_1; \
	MENU trans2_Alarm_VIEW_1_page; \
	MENU trans2_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS2_ALARM_OPTIONAL_B \
	USE_TRANS2_ALARM_OPTIONAL_BOTH; \
	MENU trans2_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS2_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans2_Alarm_)
#define USE_TRANS2_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans2_Alarm_)
#define USE_TRANS2_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans2_Alarm_)
#define USE_TRANS2_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans2_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS3_ALARM_MANDATORY_BOTH \
	BLOCK trans3_Alarm_block; \
	COLLECTION trans3_Alarm_BLOCK_OBJECT; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans3_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans3_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans3_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans3_Alarm_ST_REV; \
	MENU trans3_Alarm_ST_REV_page; \
	COMMAND trans3_Alarm_ST_REV_read; \
	VARIABLE trans3_Alarm_TAG_DESC; \
	MENU trans3_Alarm_TAG_DESC_page; \
	COMMAND trans3_Alarm_TAG_DESC_read; \
	COMMAND trans3_Alarm_TAG_DESC_write; \
	VARIABLE trans3_Alarm_STRATEGY; \
	MENU trans3_Alarm_STRATEGY_page; \
	COMMAND trans3_Alarm_STRATEGY_read; \
	COMMAND trans3_Alarm_STRATEGY_write; \
	VARIABLE trans3_Alarm_ALERT_KEY; \
	MENU trans3_Alarm_ALERT_KEY_page; \
	COMMAND trans3_Alarm_ALERT_KEY_read; \
	COMMAND trans3_Alarm_ALERT_KEY_write; \
	VARIABLE trans3_Alarm_TARGET_MODE; \
	MENU trans3_Alarm_TARGET_MODE_page; \
	COMMAND trans3_Alarm_TARGET_MODE_read; \
	COMMAND trans3_Alarm_TARGET_MODE_write; \
	COLLECTION trans3_Alarm_MODE_BLK; \
	VARIABLE trans3_Alarm_MODE_BLK_Actual; \
	VARIABLE trans3_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans3_Alarm_MODE_BLK_Normal; \
	MENU trans3_Alarm_MODE_BLK_page; \
	COMMAND trans3_Alarm_MODE_BLK_read; \
	COLLECTION trans3_Alarm_ALARM_SUM; \
	VARIABLE trans3_Alarm_ALARM_SUM_Current; \
	VARIABLE trans3_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans3_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans3_Alarm_ALARM_SUM_Disabled; \
	MENU trans3_Alarm_ALARM_SUM_page; \
	COMMAND trans3_Alarm_ALARM_SUM_read; \
	VARIABLE trans3_Alarm_STATUS_CLASSES_type; \
	ARRAY trans3_Alarm_STATUS_CLASSES; \
	MENU trans3_Alarm_STATUS_CLASSES_page; \
	COMMAND trans3_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans3_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans3_Alarm_ACTIVE_MESSAGES; \
	MENU trans3_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans3_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans3_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans3_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans3_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans3_Alarm_BM_1; \
	VARIABLE trans3_Alarm_BM_1_Status_Class; \
	VARIABLE trans3_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans3_Alarm_BM_1_Output_Reference; \
	VARIABLE trans3_Alarm_BM_1_Supervision; \
	VARIABLE trans3_Alarm_BM_1_Text; \
	MENU trans3_Alarm_BM_1_page; \
	COMMAND trans3_Alarm_BM_1_read; \
	COMMAND trans3_Alarm_BM_1_write

#define USE_TRANS3_ALARM_MANDATORY_A \
	USE_TRANS3_ALARM_MANDATORY_BOTH; \
	MENU trans3_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS3_ALARM_MANDATORY_B \
	USE_TRANS3_ALARM_MANDATORY_BOTH; \
	COLLECTION trans3_Alarm_VIEW_1; \
	MENU trans3_Alarm_VIEW_1_page; \
	MENU trans3_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS3_ALARM_OPTIONAL_BOTH \
	COLLECTION trans3_Alarm_VIEW_2; \
	MENU trans3_Alarm_VIEW_2_page; \
	COLLECTION trans3_Alarm_VIEW_3; \
	MENU trans3_Alarm_VIEW_3_page

#define USE_TRANS3_ALARM_OPTIONAL_A \
	USE_TRANS3_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans3_Alarm_VIEW_1; \
	MENU trans3_Alarm_VIEW_1_page; \
	MENU trans3_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS3_ALARM_OPTIONAL_B \
	USE_TRANS3_ALARM_OPTIONAL_BOTH; \
	MENU trans3_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS3_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans3_Alarm_)
#define USE_TRANS3_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans3_Alarm_)
#define USE_TRANS3_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans3_Alarm_)
#define USE_TRANS3_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans3_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS4_ALARM_MANDATORY_BOTH \
	BLOCK trans4_Alarm_block; \
	COLLECTION trans4_Alarm_BLOCK_OBJECT; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans4_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans4_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans4_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans4_Alarm_ST_REV; \
	MENU trans4_Alarm_ST_REV_page; \
	COMMAND trans4_Alarm_ST_REV_read; \
	VARIABLE trans4_Alarm_TAG_DESC; \
	MENU trans4_Alarm_TAG_DESC_page; \
	COMMAND trans4_Alarm_TAG_DESC_read; \
	COMMAND trans4_Alarm_TAG_DESC_write; \
	VARIABLE trans4_Alarm_STRATEGY; \
	MENU trans4_Alarm_STRATEGY_page; \
	COMMAND trans4_Alarm_STRATEGY_read; \
	COMMAND trans4_Alarm_STRATEGY_write; \
	VARIABLE trans4_Alarm_ALERT_KEY; \
	MENU trans4_Alarm_ALERT_KEY_page; \
	COMMAND trans4_Alarm_ALERT_KEY_read; \
	COMMAND trans4_Alarm_ALERT_KEY_write; \
	VARIABLE trans4_Alarm_TARGET_MODE; \
	MENU trans4_Alarm_TARGET_MODE_page; \
	COMMAND trans4_Alarm_TARGET_MODE_read; \
	COMMAND trans4_Alarm_TARGET_MODE_write; \
	COLLECTION trans4_Alarm_MODE_BLK; \
	VARIABLE trans4_Alarm_MODE_BLK_Actual; \
	VARIABLE trans4_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans4_Alarm_MODE_BLK_Normal; \
	MENU trans4_Alarm_MODE_BLK_page; \
	COMMAND trans4_Alarm_MODE_BLK_read; \
	COLLECTION trans4_Alarm_ALARM_SUM; \
	VARIABLE trans4_Alarm_ALARM_SUM_Current; \
	VARIABLE trans4_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans4_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans4_Alarm_ALARM_SUM_Disabled; \
	MENU trans4_Alarm_ALARM_SUM_page; \
	COMMAND trans4_Alarm_ALARM_SUM_read; \
	VARIABLE trans4_Alarm_STATUS_CLASSES_type; \
	ARRAY trans4_Alarm_STATUS_CLASSES; \
	MENU trans4_Alarm_STATUS_CLASSES_page; \
	COMMAND trans4_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans4_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans4_Alarm_ACTIVE_MESSAGES; \
	MENU trans4_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans4_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans4_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans4_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans4_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans4_Alarm_BM_1; \
	VARIABLE trans4_Alarm_BM_1_Status_Class; \
	VARIABLE trans4_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans4_Alarm_BM_1_Output_Reference; \
	VARIABLE trans4_Alarm_BM_1_Supervision; \
	VARIABLE trans4_Alarm_BM_1_Text; \
	MENU trans4_Alarm_BM_1_page; \
	COMMAND trans4_Alarm_BM_1_read; \
	COMMAND trans4_Alarm_BM_1_write

#define USE_TRANS4_ALARM_MANDATORY_A \
	USE_TRANS4_ALARM_MANDATORY_BOTH; \
	MENU trans4_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS4_ALARM_MANDATORY_B \
	USE_TRANS4_ALARM_MANDATORY_BOTH; \
	COLLECTION trans4_Alarm_VIEW_1; \
	MENU trans4_Alarm_VIEW_1_page; \
	MENU trans4_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS4_ALARM_OPTIONAL_BOTH \
	COLLECTION trans4_Alarm_VIEW_2; \
	MENU trans4_Alarm_VIEW_2_page; \
	COLLECTION trans4_Alarm_VIEW_3; \
	MENU trans4_Alarm_VIEW_3_page

#define USE_TRANS4_ALARM_OPTIONAL_A \
	USE_TRANS4_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans4_Alarm_VIEW_1; \
	MENU trans4_Alarm_VIEW_1_page; \
	MENU trans4_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS4_ALARM_OPTIONAL_B \
	USE_TRANS4_ALARM_OPTIONAL_BOTH; \
	MENU trans4_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS4_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans4_Alarm_)
#define USE_TRANS4_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans4_Alarm_)
#define USE_TRANS4_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans4_Alarm_)
#define USE_TRANS4_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans4_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS5_ALARM_MANDATORY_BOTH \
	BLOCK trans5_Alarm_block; \
	COLLECTION trans5_Alarm_BLOCK_OBJECT; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans5_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans5_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans5_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans5_Alarm_ST_REV; \
	MENU trans5_Alarm_ST_REV_page; \
	COMMAND trans5_Alarm_ST_REV_read; \
	VARIABLE trans5_Alarm_TAG_DESC; \
	MENU trans5_Alarm_TAG_DESC_page; \
	COMMAND trans5_Alarm_TAG_DESC_read; \
	COMMAND trans5_Alarm_TAG_DESC_write; \
	VARIABLE trans5_Alarm_STRATEGY; \
	MENU trans5_Alarm_STRATEGY_page; \
	COMMAND trans5_Alarm_STRATEGY_read; \
	COMMAND trans5_Alarm_STRATEGY_write; \
	VARIABLE trans5_Alarm_ALERT_KEY; \
	MENU trans5_Alarm_ALERT_KEY_page; \
	COMMAND trans5_Alarm_ALERT_KEY_read; \
	COMMAND trans5_Alarm_ALERT_KEY_write; \
	VARIABLE trans5_Alarm_TARGET_MODE; \
	MENU trans5_Alarm_TARGET_MODE_page; \
	COMMAND trans5_Alarm_TARGET_MODE_read; \
	COMMAND trans5_Alarm_TARGET_MODE_write; \
	COLLECTION trans5_Alarm_MODE_BLK; \
	VARIABLE trans5_Alarm_MODE_BLK_Actual; \
	VARIABLE trans5_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans5_Alarm_MODE_BLK_Normal; \
	MENU trans5_Alarm_MODE_BLK_page; \
	COMMAND trans5_Alarm_MODE_BLK_read; \
	COLLECTION trans5_Alarm_ALARM_SUM; \
	VARIABLE trans5_Alarm_ALARM_SUM_Current; \
	VARIABLE trans5_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans5_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans5_Alarm_ALARM_SUM_Disabled; \
	MENU trans5_Alarm_ALARM_SUM_page; \
	COMMAND trans5_Alarm_ALARM_SUM_read; \
	VARIABLE trans5_Alarm_STATUS_CLASSES_type; \
	ARRAY trans5_Alarm_STATUS_CLASSES; \
	MENU trans5_Alarm_STATUS_CLASSES_page; \
	COMMAND trans5_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans5_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans5_Alarm_ACTIVE_MESSAGES; \
	MENU trans5_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans5_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans5_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans5_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans5_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans5_Alarm_BM_1; \
	VARIABLE trans5_Alarm_BM_1_Status_Class; \
	VARIABLE trans5_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans5_Alarm_BM_1_Output_Reference; \
	VARIABLE trans5_Alarm_BM_1_Supervision; \
	VARIABLE trans5_Alarm_BM_1_Text; \
	MENU trans5_Alarm_BM_1_page; \
	COMMAND trans5_Alarm_BM_1_read; \
	COMMAND trans5_Alarm_BM_1_write

#define USE_TRANS5_ALARM_MANDATORY_A \
	USE_TRANS5_ALARM_MANDATORY_BOTH; \
	MENU trans5_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS5_ALARM_MANDATORY_B \
	USE_TRANS5_ALARM_MANDATORY_BOTH; \
	COLLECTION trans5_Alarm_VIEW_1; \
	MENU trans5_Alarm_VIEW_1_page; \
	MENU trans5_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS5_ALARM_OPTIONAL_BOTH \
	COLLECTION trans5_Alarm_VIEW_2; \
	MENU trans5_Alarm_VIEW_2_page; \
	COLLECTION trans5_Alarm_VIEW_3; \
	MENU trans5_Alarm_VIEW_3_page

#define USE_TRANS5_ALARM_OPTIONAL_A \
	USE_TRANS5_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans5_Alarm_VIEW_1; \
	MENU trans5_Alarm_VIEW_1_page; \
	MENU trans5_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS5_ALARM_OPTIONAL_B \
	USE_TRANS5_ALARM_OPTIONAL_BOTH; \
	MENU trans5_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS5_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans5_Alarm_)
#define USE_TRANS5_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans5_Alarm_)
#define USE_TRANS5_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans5_Alarm_)
#define USE_TRANS5_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans5_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS6_ALARM_MANDATORY_BOTH \
	BLOCK trans6_Alarm_block; \
	COLLECTION trans6_Alarm_BLOCK_OBJECT; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans6_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans6_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans6_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans6_Alarm_ST_REV; \
	MENU trans6_Alarm_ST_REV_page; \
	COMMAND trans6_Alarm_ST_REV_read; \
	VARIABLE trans6_Alarm_TAG_DESC; \
	MENU trans6_Alarm_TAG_DESC_page; \
	COMMAND trans6_Alarm_TAG_DESC_read; \
	COMMAND trans6_Alarm_TAG_DESC_write; \
	VARIABLE trans6_Alarm_STRATEGY; \
	MENU trans6_Alarm_STRATEGY_page; \
	COMMAND trans6_Alarm_STRATEGY_read; \
	COMMAND trans6_Alarm_STRATEGY_write; \
	VARIABLE trans6_Alarm_ALERT_KEY; \
	MENU trans6_Alarm_ALERT_KEY_page; \
	COMMAND trans6_Alarm_ALERT_KEY_read; \
	COMMAND trans6_Alarm_ALERT_KEY_write; \
	VARIABLE trans6_Alarm_TARGET_MODE; \
	MENU trans6_Alarm_TARGET_MODE_page; \
	COMMAND trans6_Alarm_TARGET_MODE_read; \
	COMMAND trans6_Alarm_TARGET_MODE_write; \
	COLLECTION trans6_Alarm_MODE_BLK; \
	VARIABLE trans6_Alarm_MODE_BLK_Actual; \
	VARIABLE trans6_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans6_Alarm_MODE_BLK_Normal; \
	MENU trans6_Alarm_MODE_BLK_page; \
	COMMAND trans6_Alarm_MODE_BLK_read; \
	COLLECTION trans6_Alarm_ALARM_SUM; \
	VARIABLE trans6_Alarm_ALARM_SUM_Current; \
	VARIABLE trans6_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans6_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans6_Alarm_ALARM_SUM_Disabled; \
	MENU trans6_Alarm_ALARM_SUM_page; \
	COMMAND trans6_Alarm_ALARM_SUM_read; \
	VARIABLE trans6_Alarm_STATUS_CLASSES_type; \
	ARRAY trans6_Alarm_STATUS_CLASSES; \
	MENU trans6_Alarm_STATUS_CLASSES_page; \
	COMMAND trans6_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans6_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans6_Alarm_ACTIVE_MESSAGES; \
	MENU trans6_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans6_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans6_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans6_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans6_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans6_Alarm_BM_1; \
	VARIABLE trans6_Alarm_BM_1_Status_Class; \
	VARIABLE trans6_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans6_Alarm_BM_1_Output_Reference; \
	VARIABLE trans6_Alarm_BM_1_Supervision; \
	VARIABLE trans6_Alarm_BM_1_Text; \
	MENU trans6_Alarm_BM_1_page; \
	COMMAND trans6_Alarm_BM_1_read; \
	COMMAND trans6_Alarm_BM_1_write

#define USE_TRANS6_ALARM_MANDATORY_A \
	USE_TRANS6_ALARM_MANDATORY_BOTH; \
	MENU trans6_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS6_ALARM_MANDATORY_B \
	USE_TRANS6_ALARM_MANDATORY_BOTH; \
	COLLECTION trans6_Alarm_VIEW_1; \
	MENU trans6_Alarm_VIEW_1_page; \
	MENU trans6_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS6_ALARM_OPTIONAL_BOTH \
	COLLECTION trans6_Alarm_VIEW_2; \
	MENU trans6_Alarm_VIEW_2_page; \
	COLLECTION trans6_Alarm_VIEW_3; \
	MENU trans6_Alarm_VIEW_3_page

#define USE_TRANS6_ALARM_OPTIONAL_A \
	USE_TRANS6_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans6_Alarm_VIEW_1; \
	MENU trans6_Alarm_VIEW_1_page; \
	MENU trans6_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS6_ALARM_OPTIONAL_B \
	USE_TRANS6_ALARM_OPTIONAL_BOTH; \
	MENU trans6_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS6_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans6_Alarm_)
#define USE_TRANS6_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans6_Alarm_)
#define USE_TRANS6_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans6_Alarm_)
#define USE_TRANS6_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans6_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS7_ALARM_MANDATORY_BOTH \
	BLOCK trans7_Alarm_block; \
	COLLECTION trans7_Alarm_BLOCK_OBJECT; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans7_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans7_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans7_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans7_Alarm_ST_REV; \
	MENU trans7_Alarm_ST_REV_page; \
	COMMAND trans7_Alarm_ST_REV_read; \
	VARIABLE trans7_Alarm_TAG_DESC; \
	MENU trans7_Alarm_TAG_DESC_page; \
	COMMAND trans7_Alarm_TAG_DESC_read; \
	COMMAND trans7_Alarm_TAG_DESC_write; \
	VARIABLE trans7_Alarm_STRATEGY; \
	MENU trans7_Alarm_STRATEGY_page; \
	COMMAND trans7_Alarm_STRATEGY_read; \
	COMMAND trans7_Alarm_STRATEGY_write; \
	VARIABLE trans7_Alarm_ALERT_KEY; \
	MENU trans7_Alarm_ALERT_KEY_page; \
	COMMAND trans7_Alarm_ALERT_KEY_read; \
	COMMAND trans7_Alarm_ALERT_KEY_write; \
	VARIABLE trans7_Alarm_TARGET_MODE; \
	MENU trans7_Alarm_TARGET_MODE_page; \
	COMMAND trans7_Alarm_TARGET_MODE_read; \
	COMMAND trans7_Alarm_TARGET_MODE_write; \
	COLLECTION trans7_Alarm_MODE_BLK; \
	VARIABLE trans7_Alarm_MODE_BLK_Actual; \
	VARIABLE trans7_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans7_Alarm_MODE_BLK_Normal; \
	MENU trans7_Alarm_MODE_BLK_page; \
	COMMAND trans7_Alarm_MODE_BLK_read; \
	COLLECTION trans7_Alarm_ALARM_SUM; \
	VARIABLE trans7_Alarm_ALARM_SUM_Current; \
	VARIABLE trans7_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans7_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans7_Alarm_ALARM_SUM_Disabled; \
	MENU trans7_Alarm_ALARM_SUM_page; \
	COMMAND trans7_Alarm_ALARM_SUM_read; \
	VARIABLE trans7_Alarm_STATUS_CLASSES_type; \
	ARRAY trans7_Alarm_STATUS_CLASSES; \
	MENU trans7_Alarm_STATUS_CLASSES_page; \
	COMMAND trans7_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans7_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans7_Alarm_ACTIVE_MESSAGES; \
	MENU trans7_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans7_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans7_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans7_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans7_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans7_Alarm_BM_1; \
	VARIABLE trans7_Alarm_BM_1_Status_Class; \
	VARIABLE trans7_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans7_Alarm_BM_1_Output_Reference; \
	VARIABLE trans7_Alarm_BM_1_Supervision; \
	VARIABLE trans7_Alarm_BM_1_Text; \
	MENU trans7_Alarm_BM_1_page; \
	COMMAND trans7_Alarm_BM_1_read; \
	COMMAND trans7_Alarm_BM_1_write

#define USE_TRANS7_ALARM_MANDATORY_A \
	USE_TRANS7_ALARM_MANDATORY_BOTH; \
	MENU trans7_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS7_ALARM_MANDATORY_B \
	USE_TRANS7_ALARM_MANDATORY_BOTH; \
	COLLECTION trans7_Alarm_VIEW_1; \
	MENU trans7_Alarm_VIEW_1_page; \
	MENU trans7_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS7_ALARM_OPTIONAL_BOTH \
	COLLECTION trans7_Alarm_VIEW_2; \
	MENU trans7_Alarm_VIEW_2_page; \
	COLLECTION trans7_Alarm_VIEW_3; \
	MENU trans7_Alarm_VIEW_3_page

#define USE_TRANS7_ALARM_OPTIONAL_A \
	USE_TRANS7_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans7_Alarm_VIEW_1; \
	MENU trans7_Alarm_VIEW_1_page; \
	MENU trans7_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS7_ALARM_OPTIONAL_B \
	USE_TRANS7_ALARM_OPTIONAL_BOTH; \
	MENU trans7_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS7_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans7_Alarm_)
#define USE_TRANS7_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans7_Alarm_)
#define USE_TRANS7_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans7_Alarm_)
#define USE_TRANS7_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans7_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS8_ALARM_MANDATORY_BOTH \
	BLOCK trans8_Alarm_block; \
	COLLECTION trans8_Alarm_BLOCK_OBJECT; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans8_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans8_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans8_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans8_Alarm_ST_REV; \
	MENU trans8_Alarm_ST_REV_page; \
	COMMAND trans8_Alarm_ST_REV_read; \
	VARIABLE trans8_Alarm_TAG_DESC; \
	MENU trans8_Alarm_TAG_DESC_page; \
	COMMAND trans8_Alarm_TAG_DESC_read; \
	COMMAND trans8_Alarm_TAG_DESC_write; \
	VARIABLE trans8_Alarm_STRATEGY; \
	MENU trans8_Alarm_STRATEGY_page; \
	COMMAND trans8_Alarm_STRATEGY_read; \
	COMMAND trans8_Alarm_STRATEGY_write; \
	VARIABLE trans8_Alarm_ALERT_KEY; \
	MENU trans8_Alarm_ALERT_KEY_page; \
	COMMAND trans8_Alarm_ALERT_KEY_read; \
	COMMAND trans8_Alarm_ALERT_KEY_write; \
	VARIABLE trans8_Alarm_TARGET_MODE; \
	MENU trans8_Alarm_TARGET_MODE_page; \
	COMMAND trans8_Alarm_TARGET_MODE_read; \
	COMMAND trans8_Alarm_TARGET_MODE_write; \
	COLLECTION trans8_Alarm_MODE_BLK; \
	VARIABLE trans8_Alarm_MODE_BLK_Actual; \
	VARIABLE trans8_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans8_Alarm_MODE_BLK_Normal; \
	MENU trans8_Alarm_MODE_BLK_page; \
	COMMAND trans8_Alarm_MODE_BLK_read; \
	COLLECTION trans8_Alarm_ALARM_SUM; \
	VARIABLE trans8_Alarm_ALARM_SUM_Current; \
	VARIABLE trans8_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans8_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans8_Alarm_ALARM_SUM_Disabled; \
	MENU trans8_Alarm_ALARM_SUM_page; \
	COMMAND trans8_Alarm_ALARM_SUM_read; \
	VARIABLE trans8_Alarm_STATUS_CLASSES_type; \
	ARRAY trans8_Alarm_STATUS_CLASSES; \
	MENU trans8_Alarm_STATUS_CLASSES_page; \
	COMMAND trans8_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans8_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans8_Alarm_ACTIVE_MESSAGES; \
	MENU trans8_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans8_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans8_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans8_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans8_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans8_Alarm_BM_1; \
	VARIABLE trans8_Alarm_BM_1_Status_Class; \
	VARIABLE trans8_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans8_Alarm_BM_1_Output_Reference; \
	VARIABLE trans8_Alarm_BM_1_Supervision; \
	VARIABLE trans8_Alarm_BM_1_Text; \
	MENU trans8_Alarm_BM_1_page; \
	COMMAND trans8_Alarm_BM_1_read; \
	COMMAND trans8_Alarm_BM_1_write

#define USE_TRANS8_ALARM_MANDATORY_A \
	USE_TRANS8_ALARM_MANDATORY_BOTH; \
	MENU trans8_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS8_ALARM_MANDATORY_B \
	USE_TRANS8_ALARM_MANDATORY_BOTH; \
	COLLECTION trans8_Alarm_VIEW_1; \
	MENU trans8_Alarm_VIEW_1_page; \
	MENU trans8_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS8_ALARM_OPTIONAL_BOTH \
	COLLECTION trans8_Alarm_VIEW_2; \
	MENU trans8_Alarm_VIEW_2_page; \
	COLLECTION trans8_Alarm_VIEW_3; \
	MENU trans8_Alarm_VIEW_3_page

#define USE_TRANS8_ALARM_OPTIONAL_A \
	USE_TRANS8_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans8_Alarm_VIEW_1; \
	MENU trans8_Alarm_VIEW_1_page; \
	MENU trans8_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS8_ALARM_OPTIONAL_B \
	USE_TRANS8_ALARM_OPTIONAL_BOTH; \
	MENU trans8_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS8_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans8_Alarm_)
#define USE_TRANS8_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans8_Alarm_)
#define USE_TRANS8_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans8_Alarm_)
#define USE_TRANS8_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans8_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS9_ALARM_MANDATORY_BOTH \
	BLOCK trans9_Alarm_block; \
	COLLECTION trans9_Alarm_BLOCK_OBJECT; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans9_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans9_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans9_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans9_Alarm_ST_REV; \
	MENU trans9_Alarm_ST_REV_page; \
	COMMAND trans9_Alarm_ST_REV_read; \
	VARIABLE trans9_Alarm_TAG_DESC; \
	MENU trans9_Alarm_TAG_DESC_page; \
	COMMAND trans9_Alarm_TAG_DESC_read; \
	COMMAND trans9_Alarm_TAG_DESC_write; \
	VARIABLE trans9_Alarm_STRATEGY; \
	MENU trans9_Alarm_STRATEGY_page; \
	COMMAND trans9_Alarm_STRATEGY_read; \
	COMMAND trans9_Alarm_STRATEGY_write; \
	VARIABLE trans9_Alarm_ALERT_KEY; \
	MENU trans9_Alarm_ALERT_KEY_page; \
	COMMAND trans9_Alarm_ALERT_KEY_read; \
	COMMAND trans9_Alarm_ALERT_KEY_write; \
	VARIABLE trans9_Alarm_TARGET_MODE; \
	MENU trans9_Alarm_TARGET_MODE_page; \
	COMMAND trans9_Alarm_TARGET_MODE_read; \
	COMMAND trans9_Alarm_TARGET_MODE_write; \
	COLLECTION trans9_Alarm_MODE_BLK; \
	VARIABLE trans9_Alarm_MODE_BLK_Actual; \
	VARIABLE trans9_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans9_Alarm_MODE_BLK_Normal; \
	MENU trans9_Alarm_MODE_BLK_page; \
	COMMAND trans9_Alarm_MODE_BLK_read; \
	COLLECTION trans9_Alarm_ALARM_SUM; \
	VARIABLE trans9_Alarm_ALARM_SUM_Current; \
	VARIABLE trans9_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans9_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans9_Alarm_ALARM_SUM_Disabled; \
	MENU trans9_Alarm_ALARM_SUM_page; \
	COMMAND trans9_Alarm_ALARM_SUM_read; \
	VARIABLE trans9_Alarm_STATUS_CLASSES_type; \
	ARRAY trans9_Alarm_STATUS_CLASSES; \
	MENU trans9_Alarm_STATUS_CLASSES_page; \
	COMMAND trans9_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans9_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans9_Alarm_ACTIVE_MESSAGES; \
	MENU trans9_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans9_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans9_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans9_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans9_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans9_Alarm_BM_1; \
	VARIABLE trans9_Alarm_BM_1_Status_Class; \
	VARIABLE trans9_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans9_Alarm_BM_1_Output_Reference; \
	VARIABLE trans9_Alarm_BM_1_Supervision; \
	VARIABLE trans9_Alarm_BM_1_Text; \
	MENU trans9_Alarm_BM_1_page; \
	COMMAND trans9_Alarm_BM_1_read; \
	COMMAND trans9_Alarm_BM_1_write

#define USE_TRANS9_ALARM_MANDATORY_A \
	USE_TRANS9_ALARM_MANDATORY_BOTH; \
	MENU trans9_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS9_ALARM_MANDATORY_B \
	USE_TRANS9_ALARM_MANDATORY_BOTH; \
	COLLECTION trans9_Alarm_VIEW_1; \
	MENU trans9_Alarm_VIEW_1_page; \
	MENU trans9_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS9_ALARM_OPTIONAL_BOTH \
	COLLECTION trans9_Alarm_VIEW_2; \
	MENU trans9_Alarm_VIEW_2_page; \
	COLLECTION trans9_Alarm_VIEW_3; \
	MENU trans9_Alarm_VIEW_3_page

#define USE_TRANS9_ALARM_OPTIONAL_A \
	USE_TRANS9_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans9_Alarm_VIEW_1; \
	MENU trans9_Alarm_VIEW_1_page; \
	MENU trans9_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS9_ALARM_OPTIONAL_B \
	USE_TRANS9_ALARM_OPTIONAL_BOTH; \
	MENU trans9_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS9_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans9_Alarm_)
#define USE_TRANS9_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans9_Alarm_)
#define USE_TRANS9_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans9_Alarm_)
#define USE_TRANS9_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans9_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS10_ALARM_MANDATORY_BOTH \
	BLOCK trans10_Alarm_block; \
	COLLECTION trans10_Alarm_BLOCK_OBJECT; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans10_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans10_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans10_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans10_Alarm_ST_REV; \
	MENU trans10_Alarm_ST_REV_page; \
	COMMAND trans10_Alarm_ST_REV_read; \
	VARIABLE trans10_Alarm_TAG_DESC; \
	MENU trans10_Alarm_TAG_DESC_page; \
	COMMAND trans10_Alarm_TAG_DESC_read; \
	COMMAND trans10_Alarm_TAG_DESC_write; \
	VARIABLE trans10_Alarm_STRATEGY; \
	MENU trans10_Alarm_STRATEGY_page; \
	COMMAND trans10_Alarm_STRATEGY_read; \
	COMMAND trans10_Alarm_STRATEGY_write; \
	VARIABLE trans10_Alarm_ALERT_KEY; \
	MENU trans10_Alarm_ALERT_KEY_page; \
	COMMAND trans10_Alarm_ALERT_KEY_read; \
	COMMAND trans10_Alarm_ALERT_KEY_write; \
	VARIABLE trans10_Alarm_TARGET_MODE; \
	MENU trans10_Alarm_TARGET_MODE_page; \
	COMMAND trans10_Alarm_TARGET_MODE_read; \
	COMMAND trans10_Alarm_TARGET_MODE_write; \
	COLLECTION trans10_Alarm_MODE_BLK; \
	VARIABLE trans10_Alarm_MODE_BLK_Actual; \
	VARIABLE trans10_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans10_Alarm_MODE_BLK_Normal; \
	MENU trans10_Alarm_MODE_BLK_page; \
	COMMAND trans10_Alarm_MODE_BLK_read; \
	COLLECTION trans10_Alarm_ALARM_SUM; \
	VARIABLE trans10_Alarm_ALARM_SUM_Current; \
	VARIABLE trans10_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans10_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans10_Alarm_ALARM_SUM_Disabled; \
	MENU trans10_Alarm_ALARM_SUM_page; \
	COMMAND trans10_Alarm_ALARM_SUM_read; \
	VARIABLE trans10_Alarm_STATUS_CLASSES_type; \
	ARRAY trans10_Alarm_STATUS_CLASSES; \
	MENU trans10_Alarm_STATUS_CLASSES_page; \
	COMMAND trans10_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans10_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans10_Alarm_ACTIVE_MESSAGES; \
	MENU trans10_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans10_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans10_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans10_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans10_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans10_Alarm_BM_1; \
	VARIABLE trans10_Alarm_BM_1_Status_Class; \
	VARIABLE trans10_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans10_Alarm_BM_1_Output_Reference; \
	VARIABLE trans10_Alarm_BM_1_Supervision; \
	VARIABLE trans10_Alarm_BM_1_Text; \
	MENU trans10_Alarm_BM_1_page; \
	COMMAND trans10_Alarm_BM_1_read; \
	COMMAND trans10_Alarm_BM_1_write

#define USE_TRANS10_ALARM_MANDATORY_A \
	USE_TRANS10_ALARM_MANDATORY_BOTH; \
	MENU trans10_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS10_ALARM_MANDATORY_B \
	USE_TRANS10_ALARM_MANDATORY_BOTH; \
	COLLECTION trans10_Alarm_VIEW_1; \
	MENU trans10_Alarm_VIEW_1_page; \
	MENU trans10_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS10_ALARM_OPTIONAL_BOTH \
	COLLECTION trans10_Alarm_VIEW_2; \
	MENU trans10_Alarm_VIEW_2_page; \
	COLLECTION trans10_Alarm_VIEW_3; \
	MENU trans10_Alarm_VIEW_3_page

#define USE_TRANS10_ALARM_OPTIONAL_A \
	USE_TRANS10_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans10_Alarm_VIEW_1; \
	MENU trans10_Alarm_VIEW_1_page; \
	MENU trans10_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS10_ALARM_OPTIONAL_B \
	USE_TRANS10_ALARM_OPTIONAL_BOTH; \
	MENU trans10_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS10_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans10_Alarm_)
#define USE_TRANS10_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans10_Alarm_)
#define USE_TRANS10_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans10_Alarm_)
#define USE_TRANS10_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans10_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS11_ALARM_MANDATORY_BOTH \
	BLOCK trans11_Alarm_block; \
	COLLECTION trans11_Alarm_BLOCK_OBJECT; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans11_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans11_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans11_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans11_Alarm_ST_REV; \
	MENU trans11_Alarm_ST_REV_page; \
	COMMAND trans11_Alarm_ST_REV_read; \
	VARIABLE trans11_Alarm_TAG_DESC; \
	MENU trans11_Alarm_TAG_DESC_page; \
	COMMAND trans11_Alarm_TAG_DESC_read; \
	COMMAND trans11_Alarm_TAG_DESC_write; \
	VARIABLE trans11_Alarm_STRATEGY; \
	MENU trans11_Alarm_STRATEGY_page; \
	COMMAND trans11_Alarm_STRATEGY_read; \
	COMMAND trans11_Alarm_STRATEGY_write; \
	VARIABLE trans11_Alarm_ALERT_KEY; \
	MENU trans11_Alarm_ALERT_KEY_page; \
	COMMAND trans11_Alarm_ALERT_KEY_read; \
	COMMAND trans11_Alarm_ALERT_KEY_write; \
	VARIABLE trans11_Alarm_TARGET_MODE; \
	MENU trans11_Alarm_TARGET_MODE_page; \
	COMMAND trans11_Alarm_TARGET_MODE_read; \
	COMMAND trans11_Alarm_TARGET_MODE_write; \
	COLLECTION trans11_Alarm_MODE_BLK; \
	VARIABLE trans11_Alarm_MODE_BLK_Actual; \
	VARIABLE trans11_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans11_Alarm_MODE_BLK_Normal; \
	MENU trans11_Alarm_MODE_BLK_page; \
	COMMAND trans11_Alarm_MODE_BLK_read; \
	COLLECTION trans11_Alarm_ALARM_SUM; \
	VARIABLE trans11_Alarm_ALARM_SUM_Current; \
	VARIABLE trans11_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans11_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans11_Alarm_ALARM_SUM_Disabled; \
	MENU trans11_Alarm_ALARM_SUM_page; \
	COMMAND trans11_Alarm_ALARM_SUM_read; \
	VARIABLE trans11_Alarm_STATUS_CLASSES_type; \
	ARRAY trans11_Alarm_STATUS_CLASSES; \
	MENU trans11_Alarm_STATUS_CLASSES_page; \
	COMMAND trans11_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans11_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans11_Alarm_ACTIVE_MESSAGES; \
	MENU trans11_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans11_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans11_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans11_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans11_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans11_Alarm_BM_1; \
	VARIABLE trans11_Alarm_BM_1_Status_Class; \
	VARIABLE trans11_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans11_Alarm_BM_1_Output_Reference; \
	VARIABLE trans11_Alarm_BM_1_Supervision; \
	VARIABLE trans11_Alarm_BM_1_Text; \
	MENU trans11_Alarm_BM_1_page; \
	COMMAND trans11_Alarm_BM_1_read; \
	COMMAND trans11_Alarm_BM_1_write

#define USE_TRANS11_ALARM_MANDATORY_A \
	USE_TRANS11_ALARM_MANDATORY_BOTH; \
	MENU trans11_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS11_ALARM_MANDATORY_B \
	USE_TRANS11_ALARM_MANDATORY_BOTH; \
	COLLECTION trans11_Alarm_VIEW_1; \
	MENU trans11_Alarm_VIEW_1_page; \
	MENU trans11_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS11_ALARM_OPTIONAL_BOTH \
	COLLECTION trans11_Alarm_VIEW_2; \
	MENU trans11_Alarm_VIEW_2_page; \
	COLLECTION trans11_Alarm_VIEW_3; \
	MENU trans11_Alarm_VIEW_3_page

#define USE_TRANS11_ALARM_OPTIONAL_A \
	USE_TRANS11_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans11_Alarm_VIEW_1; \
	MENU trans11_Alarm_VIEW_1_page; \
	MENU trans11_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS11_ALARM_OPTIONAL_B \
	USE_TRANS11_ALARM_OPTIONAL_BOTH; \
	MENU trans11_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS11_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans11_Alarm_)
#define USE_TRANS11_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans11_Alarm_)
#define USE_TRANS11_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans11_Alarm_)
#define USE_TRANS11_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans11_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS12_ALARM_MANDATORY_BOTH \
	BLOCK trans12_Alarm_block; \
	COLLECTION trans12_Alarm_BLOCK_OBJECT; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans12_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans12_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans12_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans12_Alarm_ST_REV; \
	MENU trans12_Alarm_ST_REV_page; \
	COMMAND trans12_Alarm_ST_REV_read; \
	VARIABLE trans12_Alarm_TAG_DESC; \
	MENU trans12_Alarm_TAG_DESC_page; \
	COMMAND trans12_Alarm_TAG_DESC_read; \
	COMMAND trans12_Alarm_TAG_DESC_write; \
	VARIABLE trans12_Alarm_STRATEGY; \
	MENU trans12_Alarm_STRATEGY_page; \
	COMMAND trans12_Alarm_STRATEGY_read; \
	COMMAND trans12_Alarm_STRATEGY_write; \
	VARIABLE trans12_Alarm_ALERT_KEY; \
	MENU trans12_Alarm_ALERT_KEY_page; \
	COMMAND trans12_Alarm_ALERT_KEY_read; \
	COMMAND trans12_Alarm_ALERT_KEY_write; \
	VARIABLE trans12_Alarm_TARGET_MODE; \
	MENU trans12_Alarm_TARGET_MODE_page; \
	COMMAND trans12_Alarm_TARGET_MODE_read; \
	COMMAND trans12_Alarm_TARGET_MODE_write; \
	COLLECTION trans12_Alarm_MODE_BLK; \
	VARIABLE trans12_Alarm_MODE_BLK_Actual; \
	VARIABLE trans12_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans12_Alarm_MODE_BLK_Normal; \
	MENU trans12_Alarm_MODE_BLK_page; \
	COMMAND trans12_Alarm_MODE_BLK_read; \
	COLLECTION trans12_Alarm_ALARM_SUM; \
	VARIABLE trans12_Alarm_ALARM_SUM_Current; \
	VARIABLE trans12_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans12_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans12_Alarm_ALARM_SUM_Disabled; \
	MENU trans12_Alarm_ALARM_SUM_page; \
	COMMAND trans12_Alarm_ALARM_SUM_read; \
	VARIABLE trans12_Alarm_STATUS_CLASSES_type; \
	ARRAY trans12_Alarm_STATUS_CLASSES; \
	MENU trans12_Alarm_STATUS_CLASSES_page; \
	COMMAND trans12_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans12_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans12_Alarm_ACTIVE_MESSAGES; \
	MENU trans12_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans12_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans12_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans12_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans12_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans12_Alarm_BM_1; \
	VARIABLE trans12_Alarm_BM_1_Status_Class; \
	VARIABLE trans12_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans12_Alarm_BM_1_Output_Reference; \
	VARIABLE trans12_Alarm_BM_1_Supervision; \
	VARIABLE trans12_Alarm_BM_1_Text; \
	MENU trans12_Alarm_BM_1_page; \
	COMMAND trans12_Alarm_BM_1_read; \
	COMMAND trans12_Alarm_BM_1_write

#define USE_TRANS12_ALARM_MANDATORY_A \
	USE_TRANS12_ALARM_MANDATORY_BOTH; \
	MENU trans12_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS12_ALARM_MANDATORY_B \
	USE_TRANS12_ALARM_MANDATORY_BOTH; \
	COLLECTION trans12_Alarm_VIEW_1; \
	MENU trans12_Alarm_VIEW_1_page; \
	MENU trans12_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS12_ALARM_OPTIONAL_BOTH \
	COLLECTION trans12_Alarm_VIEW_2; \
	MENU trans12_Alarm_VIEW_2_page; \
	COLLECTION trans12_Alarm_VIEW_3; \
	MENU trans12_Alarm_VIEW_3_page

#define USE_TRANS12_ALARM_OPTIONAL_A \
	USE_TRANS12_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans12_Alarm_VIEW_1; \
	MENU trans12_Alarm_VIEW_1_page; \
	MENU trans12_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS12_ALARM_OPTIONAL_B \
	USE_TRANS12_ALARM_OPTIONAL_BOTH; \
	MENU trans12_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS12_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans12_Alarm_)
#define USE_TRANS12_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans12_Alarm_)
#define USE_TRANS12_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans12_Alarm_)
#define USE_TRANS12_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans12_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS13_ALARM_MANDATORY_BOTH \
	BLOCK trans13_Alarm_block; \
	COLLECTION trans13_Alarm_BLOCK_OBJECT; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans13_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans13_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans13_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans13_Alarm_ST_REV; \
	MENU trans13_Alarm_ST_REV_page; \
	COMMAND trans13_Alarm_ST_REV_read; \
	VARIABLE trans13_Alarm_TAG_DESC; \
	MENU trans13_Alarm_TAG_DESC_page; \
	COMMAND trans13_Alarm_TAG_DESC_read; \
	COMMAND trans13_Alarm_TAG_DESC_write; \
	VARIABLE trans13_Alarm_STRATEGY; \
	MENU trans13_Alarm_STRATEGY_page; \
	COMMAND trans13_Alarm_STRATEGY_read; \
	COMMAND trans13_Alarm_STRATEGY_write; \
	VARIABLE trans13_Alarm_ALERT_KEY; \
	MENU trans13_Alarm_ALERT_KEY_page; \
	COMMAND trans13_Alarm_ALERT_KEY_read; \
	COMMAND trans13_Alarm_ALERT_KEY_write; \
	VARIABLE trans13_Alarm_TARGET_MODE; \
	MENU trans13_Alarm_TARGET_MODE_page; \
	COMMAND trans13_Alarm_TARGET_MODE_read; \
	COMMAND trans13_Alarm_TARGET_MODE_write; \
	COLLECTION trans13_Alarm_MODE_BLK; \
	VARIABLE trans13_Alarm_MODE_BLK_Actual; \
	VARIABLE trans13_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans13_Alarm_MODE_BLK_Normal; \
	MENU trans13_Alarm_MODE_BLK_page; \
	COMMAND trans13_Alarm_MODE_BLK_read; \
	COLLECTION trans13_Alarm_ALARM_SUM; \
	VARIABLE trans13_Alarm_ALARM_SUM_Current; \
	VARIABLE trans13_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans13_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans13_Alarm_ALARM_SUM_Disabled; \
	MENU trans13_Alarm_ALARM_SUM_page; \
	COMMAND trans13_Alarm_ALARM_SUM_read; \
	VARIABLE trans13_Alarm_STATUS_CLASSES_type; \
	ARRAY trans13_Alarm_STATUS_CLASSES; \
	MENU trans13_Alarm_STATUS_CLASSES_page; \
	COMMAND trans13_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans13_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans13_Alarm_ACTIVE_MESSAGES; \
	MENU trans13_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans13_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans13_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans13_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans13_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans13_Alarm_BM_1; \
	VARIABLE trans13_Alarm_BM_1_Status_Class; \
	VARIABLE trans13_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans13_Alarm_BM_1_Output_Reference; \
	VARIABLE trans13_Alarm_BM_1_Supervision; \
	VARIABLE trans13_Alarm_BM_1_Text; \
	MENU trans13_Alarm_BM_1_page; \
	COMMAND trans13_Alarm_BM_1_read; \
	COMMAND trans13_Alarm_BM_1_write

#define USE_TRANS13_ALARM_MANDATORY_A \
	USE_TRANS13_ALARM_MANDATORY_BOTH; \
	MENU trans13_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS13_ALARM_MANDATORY_B \
	USE_TRANS13_ALARM_MANDATORY_BOTH; \
	COLLECTION trans13_Alarm_VIEW_1; \
	MENU trans13_Alarm_VIEW_1_page; \
	MENU trans13_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS13_ALARM_OPTIONAL_BOTH \
	COLLECTION trans13_Alarm_VIEW_2; \
	MENU trans13_Alarm_VIEW_2_page; \
	COLLECTION trans13_Alarm_VIEW_3; \
	MENU trans13_Alarm_VIEW_3_page

#define USE_TRANS13_ALARM_OPTIONAL_A \
	USE_TRANS13_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans13_Alarm_VIEW_1; \
	MENU trans13_Alarm_VIEW_1_page; \
	MENU trans13_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS13_ALARM_OPTIONAL_B \
	USE_TRANS13_ALARM_OPTIONAL_BOTH; \
	MENU trans13_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS13_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans13_Alarm_)
#define USE_TRANS13_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans13_Alarm_)
#define USE_TRANS13_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans13_Alarm_)
#define USE_TRANS13_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans13_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS14_ALARM_MANDATORY_BOTH \
	BLOCK trans14_Alarm_block; \
	COLLECTION trans14_Alarm_BLOCK_OBJECT; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans14_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans14_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans14_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans14_Alarm_ST_REV; \
	MENU trans14_Alarm_ST_REV_page; \
	COMMAND trans14_Alarm_ST_REV_read; \
	VARIABLE trans14_Alarm_TAG_DESC; \
	MENU trans14_Alarm_TAG_DESC_page; \
	COMMAND trans14_Alarm_TAG_DESC_read; \
	COMMAND trans14_Alarm_TAG_DESC_write; \
	VARIABLE trans14_Alarm_STRATEGY; \
	MENU trans14_Alarm_STRATEGY_page; \
	COMMAND trans14_Alarm_STRATEGY_read; \
	COMMAND trans14_Alarm_STRATEGY_write; \
	VARIABLE trans14_Alarm_ALERT_KEY; \
	MENU trans14_Alarm_ALERT_KEY_page; \
	COMMAND trans14_Alarm_ALERT_KEY_read; \
	COMMAND trans14_Alarm_ALERT_KEY_write; \
	VARIABLE trans14_Alarm_TARGET_MODE; \
	MENU trans14_Alarm_TARGET_MODE_page; \
	COMMAND trans14_Alarm_TARGET_MODE_read; \
	COMMAND trans14_Alarm_TARGET_MODE_write; \
	COLLECTION trans14_Alarm_MODE_BLK; \
	VARIABLE trans14_Alarm_MODE_BLK_Actual; \
	VARIABLE trans14_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans14_Alarm_MODE_BLK_Normal; \
	MENU trans14_Alarm_MODE_BLK_page; \
	COMMAND trans14_Alarm_MODE_BLK_read; \
	COLLECTION trans14_Alarm_ALARM_SUM; \
	VARIABLE trans14_Alarm_ALARM_SUM_Current; \
	VARIABLE trans14_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans14_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans14_Alarm_ALARM_SUM_Disabled; \
	MENU trans14_Alarm_ALARM_SUM_page; \
	COMMAND trans14_Alarm_ALARM_SUM_read; \
	VARIABLE trans14_Alarm_STATUS_CLASSES_type; \
	ARRAY trans14_Alarm_STATUS_CLASSES; \
	MENU trans14_Alarm_STATUS_CLASSES_page; \
	COMMAND trans14_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans14_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans14_Alarm_ACTIVE_MESSAGES; \
	MENU trans14_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans14_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans14_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans14_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans14_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans14_Alarm_BM_1; \
	VARIABLE trans14_Alarm_BM_1_Status_Class; \
	VARIABLE trans14_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans14_Alarm_BM_1_Output_Reference; \
	VARIABLE trans14_Alarm_BM_1_Supervision; \
	VARIABLE trans14_Alarm_BM_1_Text; \
	MENU trans14_Alarm_BM_1_page; \
	COMMAND trans14_Alarm_BM_1_read; \
	COMMAND trans14_Alarm_BM_1_write

#define USE_TRANS14_ALARM_MANDATORY_A \
	USE_TRANS14_ALARM_MANDATORY_BOTH; \
	MENU trans14_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS14_ALARM_MANDATORY_B \
	USE_TRANS14_ALARM_MANDATORY_BOTH; \
	COLLECTION trans14_Alarm_VIEW_1; \
	MENU trans14_Alarm_VIEW_1_page; \
	MENU trans14_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS14_ALARM_OPTIONAL_BOTH \
	COLLECTION trans14_Alarm_VIEW_2; \
	MENU trans14_Alarm_VIEW_2_page; \
	COLLECTION trans14_Alarm_VIEW_3; \
	MENU trans14_Alarm_VIEW_3_page

#define USE_TRANS14_ALARM_OPTIONAL_A \
	USE_TRANS14_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans14_Alarm_VIEW_1; \
	MENU trans14_Alarm_VIEW_1_page; \
	MENU trans14_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS14_ALARM_OPTIONAL_B \
	USE_TRANS14_ALARM_OPTIONAL_BOTH; \
	MENU trans14_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS14_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans14_Alarm_)
#define USE_TRANS14_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans14_Alarm_)
#define USE_TRANS14_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans14_Alarm_)
#define USE_TRANS14_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans14_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_TRANS15_ALARM_MANDATORY_BOTH \
	BLOCK trans15_Alarm_block; \
	COLLECTION trans15_Alarm_BLOCK_OBJECT; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Reserved; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Block_Object; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Parent_Class; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Class; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_DD_Revision; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Profile; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Execution_Time; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE trans15_Alarm_BLOCK_OBJECT_Number_of_Views; \
	MENU trans15_Alarm_BLOCK_OBJECT_page; \
	COMMAND trans15_Alarm_BLOCK_OBJECT_read; \
	VARIABLE trans15_Alarm_ST_REV; \
	MENU trans15_Alarm_ST_REV_page; \
	COMMAND trans15_Alarm_ST_REV_read; \
	VARIABLE trans15_Alarm_TAG_DESC; \
	MENU trans15_Alarm_TAG_DESC_page; \
	COMMAND trans15_Alarm_TAG_DESC_read; \
	COMMAND trans15_Alarm_TAG_DESC_write; \
	VARIABLE trans15_Alarm_STRATEGY; \
	MENU trans15_Alarm_STRATEGY_page; \
	COMMAND trans15_Alarm_STRATEGY_read; \
	COMMAND trans15_Alarm_STRATEGY_write; \
	VARIABLE trans15_Alarm_ALERT_KEY; \
	MENU trans15_Alarm_ALERT_KEY_page; \
	COMMAND trans15_Alarm_ALERT_KEY_read; \
	COMMAND trans15_Alarm_ALERT_KEY_write; \
	VARIABLE trans15_Alarm_TARGET_MODE; \
	MENU trans15_Alarm_TARGET_MODE_page; \
	COMMAND trans15_Alarm_TARGET_MODE_read; \
	COMMAND trans15_Alarm_TARGET_MODE_write; \
	COLLECTION trans15_Alarm_MODE_BLK; \
	VARIABLE trans15_Alarm_MODE_BLK_Actual; \
	VARIABLE trans15_Alarm_MODE_BLK_Permitted; \
	VARIABLE trans15_Alarm_MODE_BLK_Normal; \
	MENU trans15_Alarm_MODE_BLK_page; \
	COMMAND trans15_Alarm_MODE_BLK_read; \
	COLLECTION trans15_Alarm_ALARM_SUM; \
	VARIABLE trans15_Alarm_ALARM_SUM_Current; \
	VARIABLE trans15_Alarm_ALARM_SUM_Unacknowledged; \
	VARIABLE trans15_Alarm_ALARM_SUM_Unreported; \
	VARIABLE trans15_Alarm_ALARM_SUM_Disabled; \
	MENU trans15_Alarm_ALARM_SUM_page; \
	COMMAND trans15_Alarm_ALARM_SUM_read; \
	VARIABLE trans15_Alarm_STATUS_CLASSES_type; \
	ARRAY trans15_Alarm_STATUS_CLASSES; \
	MENU trans15_Alarm_STATUS_CLASSES_page; \
	COMMAND trans15_Alarm_STATUS_CLASSES_read; \
	VARIABLE trans15_Alarm_ACTIVE_MESSAGES_type; \
	ARRAY trans15_Alarm_ACTIVE_MESSAGES; \
	MENU trans15_Alarm_ACTIVE_MESSAGES_page; \
	COMMAND trans15_Alarm_ACTIVE_MESSAGES_read; \
	VARIABLE trans15_Alarm_NUMBER_OF_MESSAGES; \
	MENU trans15_Alarm_NUMBER_OF_MESSAGES_page; \
	COMMAND trans15_Alarm_NUMBER_OF_MESSAGES_read; \
	COLLECTION trans15_Alarm_BM_1; \
	VARIABLE trans15_Alarm_BM_1_Status_Class; \
	VARIABLE trans15_Alarm_BM_1_Logbook_Entry; \
	VARIABLE trans15_Alarm_BM_1_Output_Reference; \
	VARIABLE trans15_Alarm_BM_1_Supervision; \
	VARIABLE trans15_Alarm_BM_1_Text; \
	MENU trans15_Alarm_BM_1_page; \
	COMMAND trans15_Alarm_BM_1_read; \
	COMMAND trans15_Alarm_BM_1_write

#define USE_TRANS15_ALARM_MANDATORY_A \
	USE_TRANS15_ALARM_MANDATORY_BOTH; \
	MENU trans15_Alarm_Simple_Dialog_Mandatory_A

#define USE_TRANS15_ALARM_MANDATORY_B \
	USE_TRANS15_ALARM_MANDATORY_BOTH; \
	COLLECTION trans15_Alarm_VIEW_1; \
	MENU trans15_Alarm_VIEW_1_page; \
	MENU trans15_Alarm_Simple_Dialog_Mandatory_B

#define USE_TRANS15_ALARM_OPTIONAL_BOTH \
	COLLECTION trans15_Alarm_VIEW_2; \
	MENU trans15_Alarm_VIEW_2_page; \
	COLLECTION trans15_Alarm_VIEW_3; \
	MENU trans15_Alarm_VIEW_3_page

#define USE_TRANS15_ALARM_OPTIONAL_A \
	USE_TRANS15_ALARM_OPTIONAL_BOTH; \
	COLLECTION trans15_Alarm_VIEW_1; \
	MENU trans15_Alarm_VIEW_1_page; \
	MENU trans15_Alarm_Simple_Dialog_Optional_A

#define USE_TRANS15_ALARM_OPTIONAL_B \
	USE_TRANS15_ALARM_OPTIONAL_BOTH; \
	MENU trans15_Alarm_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_TRANS15_ALARM_MANDATORY_A USE_TRANS_ALARM_MANDATORY_A(trans15_Alarm_)
#define USE_TRANS15_ALARM_MANDATORY_B USE_TRANS_ALARM_MANDATORY_B(trans15_Alarm_)
#define USE_TRANS15_ALARM_OPTIONAL_A  USE_TRANS_ALARM_OPTIONAL_A(trans15_Alarm_)
#define USE_TRANS15_ALARM_OPTIONAL_B  USE_TRANS_ALARM_OPTIONAL_B(trans15_Alarm_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC1_DI_MANDATORY_BOTH \
	BLOCK func1_DI_block; \
	COLLECTION func1_DI_BLOCK_OBJECT; \
	VARIABLE func1_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func1_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func1_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func1_DI_BLOCK_OBJECT_Class; \
	VARIABLE func1_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func1_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func1_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func1_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func1_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func1_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func1_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func1_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func1_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func1_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func1_DI_BLOCK_OBJECT_page; \
	COMMAND func1_DI_BLOCK_OBJECT_read; \
	VARIABLE func1_DI_ST_REV; \
	MENU func1_DI_ST_REV_page; \
	COMMAND func1_DI_ST_REV_read; \
	VARIABLE func1_DI_TAG_DESC; \
	MENU func1_DI_TAG_DESC_page; \
	COMMAND func1_DI_TAG_DESC_read; \
	COMMAND func1_DI_TAG_DESC_write; \
	VARIABLE func1_DI_STRATEGY; \
	MENU func1_DI_STRATEGY_page; \
	COMMAND func1_DI_STRATEGY_read; \
	COMMAND func1_DI_STRATEGY_write; \
	VARIABLE func1_DI_ALERT_KEY; \
	MENU func1_DI_ALERT_KEY_page; \
	COMMAND func1_DI_ALERT_KEY_read; \
	COMMAND func1_DI_ALERT_KEY_write; \
	VARIABLE func1_DI_TARGET_MODE; \
	MENU func1_DI_TARGET_MODE_page; \
	COMMAND func1_DI_TARGET_MODE_read; \
	COMMAND func1_DI_TARGET_MODE_write; \
	COLLECTION func1_DI_MODE_BLK; \
	VARIABLE func1_DI_MODE_BLK_Actual; \
	VARIABLE func1_DI_MODE_BLK_Permitted; \
	VARIABLE func1_DI_MODE_BLK_Normal; \
	MENU func1_DI_MODE_BLK_page; \
	COMMAND func1_DI_MODE_BLK_read; \
	COLLECTION func1_DI_ALARM_SUM; \
	VARIABLE func1_DI_ALARM_SUM_Current; \
	VARIABLE func1_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func1_DI_ALARM_SUM_Unreported; \
	VARIABLE func1_DI_ALARM_SUM_Disabled; \
	MENU func1_DI_ALARM_SUM_page; \
	COMMAND func1_DI_ALARM_SUM_read; \
	COLLECTION func1_DI_BATCH; \
	VARIABLE func1_DI_BATCH_Batch_ID; \
	VARIABLE func1_DI_BATCH_Rup; \
	VARIABLE func1_DI_BATCH_Operation; \
	VARIABLE func1_DI_BATCH_Phase; \
	MENU func1_DI_BATCH_page; \
	COMMAND func1_DI_BATCH_read; \
	COMMAND func1_DI_BATCH_write; \
	COLLECTION func1_DI_OUT_D; \
	VARIABLE func1_DI_OUT_D_Value; \
	VARIABLE func1_DI_OUT_D_Status_Condensed; \
	VARIABLE func1_DI_OUT_D_Status_Quality; \
	VARIABLE func1_DI_OUT_D_Status_Limit; \
	MENU func1_DI_OUT_D_page; \
	COMMAND func1_DI_OUT_D_read; \
	COMMAND func1_DI_OUT_D_write; \
	VARIABLE func1_DI_INVERT; \
	MENU func1_DI_INVERT_page; \
	COMMAND func1_DI_INVERT_read; \
	COMMAND func1_DI_INVERT_write; \
	VARIABLE func1_DI_FSAFE_VAL_D; \
	MENU func1_DI_FSAFE_VAL_D_page; \
	COMMAND func1_DI_FSAFE_VAL_D_read; \
	COMMAND func1_DI_FSAFE_VAL_D_write

#define USE_FUNC1_DI_MANDATORY_A \
	USE_FUNC1_DI_MANDATORY_BOTH; \
	MENU func1_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC1_DI_MANDATORY_B \
	USE_FUNC1_DI_MANDATORY_BOTH; \
	VARIABLE func1_DI_CHANNEL; \
	MENU func1_DI_CHANNEL_page; \
	COMMAND func1_DI_CHANNEL_read; \
	COMMAND func1_DI_CHANNEL_write; \
	VARIABLE func1_DI_FSAFE_TYPE; \
	MENU func1_DI_FSAFE_TYPE_page; \
	COMMAND func1_DI_FSAFE_TYPE_read; \
	COMMAND func1_DI_FSAFE_TYPE_write; \
	COLLECTION func1_DI_SIMULATE; \
	VARIABLE func1_DI_SIMULATE_Status_Condensed; \
	VARIABLE func1_DI_SIMULATE_Value; \
	VARIABLE func1_DI_SIMULATE_Enabled; \
	VARIABLE func1_DI_SIMULATE_Status_Quality; \
	VARIABLE func1_DI_SIMULATE_Status_Limit; \
	MENU func1_DI_SIMULATE_page; \
	COMMAND func1_DI_SIMULATE_read; \
	COMMAND func1_DI_SIMULATE_write; \
	COLLECTION func1_DI_VIEW_1; \
	MENU func1_DI_VIEW_1_page; \
	MENU func1_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC1_DI_OPTIONAL_BOTH \
	COLLECTION func1_DI_VIEW_2; \
	MENU func1_DI_VIEW_2_page; \
	COLLECTION func1_DI_VIEW_3; \
	MENU func1_DI_VIEW_3_page

#define USE_FUNC1_DI_OPTIONAL_A \
	USE_FUNC1_DI_OPTIONAL_BOTH; \
	VARIABLE func1_DI_CHANNEL; \
	MENU func1_DI_CHANNEL_page; \
	COMMAND func1_DI_CHANNEL_read; \
	COMMAND func1_DI_CHANNEL_write; \
	VARIABLE func1_DI_FSAFE_TYPE; \
	MENU func1_DI_FSAFE_TYPE_page; \
	COMMAND func1_DI_FSAFE_TYPE_read; \
	COMMAND func1_DI_FSAFE_TYPE_write; \
	COLLECTION func1_DI_SIMULATE; \
	VARIABLE func1_DI_SIMULATE_Status_Condensed; \
	VARIABLE func1_DI_SIMULATE_Value; \
	VARIABLE func1_DI_SIMULATE_Enabled; \
	VARIABLE func1_DI_SIMULATE_Status_Quality; \
	VARIABLE func1_DI_SIMULATE_Status_Limit; \
	MENU func1_DI_SIMULATE_page; \
	COMMAND func1_DI_SIMULATE_read; \
	COMMAND func1_DI_SIMULATE_write; \
	COLLECTION func1_DI_VIEW_1; \
	MENU func1_DI_VIEW_1_page; \
	MENU func1_DI_Simple_Dialog_Optional_A

#define USE_FUNC1_DI_OPTIONAL_B \
	USE_FUNC1_DI_OPTIONAL_BOTH; \
	MENU func1_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC_DI_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## BATCH; \
	VARIABLE prefix ## BATCH_Batch_ID; \
	VARIABLE prefix ## BATCH_Rup; \
	VARIABLE prefix ## BATCH_Operation; \
	VARIABLE prefix ## BATCH_Phase; \
	MENU prefix ## BATCH_page; \
	COMMAND prefix ## BATCH_read; \
	COMMAND prefix ## BATCH_write; \
	COLLECTION prefix ## OUT_D; \
	VARIABLE prefix ## OUT_D_Value; \
	VARIABLE prefix ## OUT_D_Status_Condensed; \
	VARIABLE prefix ## OUT_D_Status_Quality; \
	VARIABLE prefix ## OUT_D_Status_Limit; \
	MENU prefix ## OUT_D_page; \
	COMMAND prefix ## OUT_D_read; \
	COMMAND prefix ## OUT_D_write; \
	VARIABLE prefix ## INVERT; \
	MENU prefix ## INVERT_page; \
	COMMAND prefix ## INVERT_read; \
	COMMAND prefix ## INVERT_write; \
	VARIABLE prefix ## FSAFE_VAL_D; \
	MENU prefix ## FSAFE_VAL_D_page; \
	COMMAND prefix ## FSAFE_VAL_D_read; \
	COMMAND prefix ## FSAFE_VAL_D_write

#define USE_FUNC_DI_MANDATORY_A(prefix) \
	USE_FUNC_DI_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_FUNC_DI_MANDATORY_B(prefix) \
	USE_FUNC_DI_MANDATORY_BOTH(prefix); \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_FUNC_DI_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_FUNC_DI_OPTIONAL_A(prefix) \
	USE_FUNC_DI_OPTIONAL_BOTH(prefix); \
	VARIABLE prefix ## CHANNEL; \
	MENU prefix ## CHANNEL_page; \
	COMMAND prefix ## CHANNEL_read; \
	COMMAND prefix ## CHANNEL_write; \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_FUNC_DI_OPTIONAL_B(prefix) \
	USE_FUNC_DI_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_FUNC1_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func1_DI_)
#define USE_FUNC1_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func1_DI_)
#define USE_FUNC1_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func1_DI_)
#define USE_FUNC1_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func1_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC2_DI_MANDATORY_BOTH \
	BLOCK func2_DI_block; \
	COLLECTION func2_DI_BLOCK_OBJECT; \
	VARIABLE func2_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func2_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func2_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func2_DI_BLOCK_OBJECT_Class; \
	VARIABLE func2_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func2_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func2_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func2_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func2_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func2_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func2_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func2_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func2_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func2_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func2_DI_BLOCK_OBJECT_page; \
	COMMAND func2_DI_BLOCK_OBJECT_read; \
	VARIABLE func2_DI_ST_REV; \
	MENU func2_DI_ST_REV_page; \
	COMMAND func2_DI_ST_REV_read; \
	VARIABLE func2_DI_TAG_DESC; \
	MENU func2_DI_TAG_DESC_page; \
	COMMAND func2_DI_TAG_DESC_read; \
	COMMAND func2_DI_TAG_DESC_write; \
	VARIABLE func2_DI_STRATEGY; \
	MENU func2_DI_STRATEGY_page; \
	COMMAND func2_DI_STRATEGY_read; \
	COMMAND func2_DI_STRATEGY_write; \
	VARIABLE func2_DI_ALERT_KEY; \
	MENU func2_DI_ALERT_KEY_page; \
	COMMAND func2_DI_ALERT_KEY_read; \
	COMMAND func2_DI_ALERT_KEY_write; \
	VARIABLE func2_DI_TARGET_MODE; \
	MENU func2_DI_TARGET_MODE_page; \
	COMMAND func2_DI_TARGET_MODE_read; \
	COMMAND func2_DI_TARGET_MODE_write; \
	COLLECTION func2_DI_MODE_BLK; \
	VARIABLE func2_DI_MODE_BLK_Actual; \
	VARIABLE func2_DI_MODE_BLK_Permitted; \
	VARIABLE func2_DI_MODE_BLK_Normal; \
	MENU func2_DI_MODE_BLK_page; \
	COMMAND func2_DI_MODE_BLK_read; \
	COLLECTION func2_DI_ALARM_SUM; \
	VARIABLE func2_DI_ALARM_SUM_Current; \
	VARIABLE func2_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func2_DI_ALARM_SUM_Unreported; \
	VARIABLE func2_DI_ALARM_SUM_Disabled; \
	MENU func2_DI_ALARM_SUM_page; \
	COMMAND func2_DI_ALARM_SUM_read; \
	COLLECTION func2_DI_BATCH; \
	VARIABLE func2_DI_BATCH_Batch_ID; \
	VARIABLE func2_DI_BATCH_Rup; \
	VARIABLE func2_DI_BATCH_Operation; \
	VARIABLE func2_DI_BATCH_Phase; \
	MENU func2_DI_BATCH_page; \
	COMMAND func2_DI_BATCH_read; \
	COMMAND func2_DI_BATCH_write; \
	COLLECTION func2_DI_OUT_D; \
	VARIABLE func2_DI_OUT_D_Value; \
	VARIABLE func2_DI_OUT_D_Status_Condensed; \
	VARIABLE func2_DI_OUT_D_Status_Quality; \
	VARIABLE func2_DI_OUT_D_Status_Limit; \
	MENU func2_DI_OUT_D_page; \
	COMMAND func2_DI_OUT_D_read; \
	COMMAND func2_DI_OUT_D_write; \
	VARIABLE func2_DI_INVERT; \
	MENU func2_DI_INVERT_page; \
	COMMAND func2_DI_INVERT_read; \
	COMMAND func2_DI_INVERT_write; \
	VARIABLE func2_DI_FSAFE_VAL_D; \
	MENU func2_DI_FSAFE_VAL_D_page; \
	COMMAND func2_DI_FSAFE_VAL_D_read; \
	COMMAND func2_DI_FSAFE_VAL_D_write

#define USE_FUNC2_DI_MANDATORY_A \
	USE_FUNC2_DI_MANDATORY_BOTH; \
	MENU func2_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC2_DI_MANDATORY_B \
	USE_FUNC2_DI_MANDATORY_BOTH; \
	VARIABLE func2_DI_CHANNEL; \
	MENU func2_DI_CHANNEL_page; \
	COMMAND func2_DI_CHANNEL_read; \
	COMMAND func2_DI_CHANNEL_write; \
	VARIABLE func2_DI_FSAFE_TYPE; \
	MENU func2_DI_FSAFE_TYPE_page; \
	COMMAND func2_DI_FSAFE_TYPE_read; \
	COMMAND func2_DI_FSAFE_TYPE_write; \
	COLLECTION func2_DI_SIMULATE; \
	VARIABLE func2_DI_SIMULATE_Status_Condensed; \
	VARIABLE func2_DI_SIMULATE_Value; \
	VARIABLE func2_DI_SIMULATE_Enabled; \
	VARIABLE func2_DI_SIMULATE_Status_Quality; \
	VARIABLE func2_DI_SIMULATE_Status_Limit; \
	MENU func2_DI_SIMULATE_page; \
	COMMAND func2_DI_SIMULATE_read; \
	COMMAND func2_DI_SIMULATE_write; \
	COLLECTION func2_DI_VIEW_1; \
	MENU func2_DI_VIEW_1_page; \
	MENU func2_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC2_DI_OPTIONAL_BOTH \
	COLLECTION func2_DI_VIEW_2; \
	MENU func2_DI_VIEW_2_page; \
	COLLECTION func2_DI_VIEW_3; \
	MENU func2_DI_VIEW_3_page

#define USE_FUNC2_DI_OPTIONAL_A \
	USE_FUNC2_DI_OPTIONAL_BOTH; \
	VARIABLE func2_DI_CHANNEL; \
	MENU func2_DI_CHANNEL_page; \
	COMMAND func2_DI_CHANNEL_read; \
	COMMAND func2_DI_CHANNEL_write; \
	VARIABLE func2_DI_FSAFE_TYPE; \
	MENU func2_DI_FSAFE_TYPE_page; \
	COMMAND func2_DI_FSAFE_TYPE_read; \
	COMMAND func2_DI_FSAFE_TYPE_write; \
	COLLECTION func2_DI_SIMULATE; \
	VARIABLE func2_DI_SIMULATE_Status_Condensed; \
	VARIABLE func2_DI_SIMULATE_Value; \
	VARIABLE func2_DI_SIMULATE_Enabled; \
	VARIABLE func2_DI_SIMULATE_Status_Quality; \
	VARIABLE func2_DI_SIMULATE_Status_Limit; \
	MENU func2_DI_SIMULATE_page; \
	COMMAND func2_DI_SIMULATE_read; \
	COMMAND func2_DI_SIMULATE_write; \
	COLLECTION func2_DI_VIEW_1; \
	MENU func2_DI_VIEW_1_page; \
	MENU func2_DI_Simple_Dialog_Optional_A

#define USE_FUNC2_DI_OPTIONAL_B \
	USE_FUNC2_DI_OPTIONAL_BOTH; \
	MENU func2_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC2_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func2_DI_)
#define USE_FUNC2_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func2_DI_)
#define USE_FUNC2_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func2_DI_)
#define USE_FUNC2_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func2_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC3_DI_MANDATORY_BOTH \
	BLOCK func3_DI_block; \
	COLLECTION func3_DI_BLOCK_OBJECT; \
	VARIABLE func3_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func3_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func3_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func3_DI_BLOCK_OBJECT_Class; \
	VARIABLE func3_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func3_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func3_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func3_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func3_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func3_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func3_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func3_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func3_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func3_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func3_DI_BLOCK_OBJECT_page; \
	COMMAND func3_DI_BLOCK_OBJECT_read; \
	VARIABLE func3_DI_ST_REV; \
	MENU func3_DI_ST_REV_page; \
	COMMAND func3_DI_ST_REV_read; \
	VARIABLE func3_DI_TAG_DESC; \
	MENU func3_DI_TAG_DESC_page; \
	COMMAND func3_DI_TAG_DESC_read; \
	COMMAND func3_DI_TAG_DESC_write; \
	VARIABLE func3_DI_STRATEGY; \
	MENU func3_DI_STRATEGY_page; \
	COMMAND func3_DI_STRATEGY_read; \
	COMMAND func3_DI_STRATEGY_write; \
	VARIABLE func3_DI_ALERT_KEY; \
	MENU func3_DI_ALERT_KEY_page; \
	COMMAND func3_DI_ALERT_KEY_read; \
	COMMAND func3_DI_ALERT_KEY_write; \
	VARIABLE func3_DI_TARGET_MODE; \
	MENU func3_DI_TARGET_MODE_page; \
	COMMAND func3_DI_TARGET_MODE_read; \
	COMMAND func3_DI_TARGET_MODE_write; \
	COLLECTION func3_DI_MODE_BLK; \
	VARIABLE func3_DI_MODE_BLK_Actual; \
	VARIABLE func3_DI_MODE_BLK_Permitted; \
	VARIABLE func3_DI_MODE_BLK_Normal; \
	MENU func3_DI_MODE_BLK_page; \
	COMMAND func3_DI_MODE_BLK_read; \
	COLLECTION func3_DI_ALARM_SUM; \
	VARIABLE func3_DI_ALARM_SUM_Current; \
	VARIABLE func3_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func3_DI_ALARM_SUM_Unreported; \
	VARIABLE func3_DI_ALARM_SUM_Disabled; \
	MENU func3_DI_ALARM_SUM_page; \
	COMMAND func3_DI_ALARM_SUM_read; \
	COLLECTION func3_DI_BATCH; \
	VARIABLE func3_DI_BATCH_Batch_ID; \
	VARIABLE func3_DI_BATCH_Rup; \
	VARIABLE func3_DI_BATCH_Operation; \
	VARIABLE func3_DI_BATCH_Phase; \
	MENU func3_DI_BATCH_page; \
	COMMAND func3_DI_BATCH_read; \
	COMMAND func3_DI_BATCH_write; \
	COLLECTION func3_DI_OUT_D; \
	VARIABLE func3_DI_OUT_D_Value; \
	VARIABLE func3_DI_OUT_D_Status_Condensed; \
	VARIABLE func3_DI_OUT_D_Status_Quality; \
	VARIABLE func3_DI_OUT_D_Status_Limit; \
	MENU func3_DI_OUT_D_page; \
	COMMAND func3_DI_OUT_D_read; \
	COMMAND func3_DI_OUT_D_write; \
	VARIABLE func3_DI_INVERT; \
	MENU func3_DI_INVERT_page; \
	COMMAND func3_DI_INVERT_read; \
	COMMAND func3_DI_INVERT_write; \
	VARIABLE func3_DI_FSAFE_VAL_D; \
	MENU func3_DI_FSAFE_VAL_D_page; \
	COMMAND func3_DI_FSAFE_VAL_D_read; \
	COMMAND func3_DI_FSAFE_VAL_D_write

#define USE_FUNC3_DI_MANDATORY_A \
	USE_FUNC3_DI_MANDATORY_BOTH; \
	MENU func3_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC3_DI_MANDATORY_B \
	USE_FUNC3_DI_MANDATORY_BOTH; \
	VARIABLE func3_DI_CHANNEL; \
	MENU func3_DI_CHANNEL_page; \
	COMMAND func3_DI_CHANNEL_read; \
	COMMAND func3_DI_CHANNEL_write; \
	VARIABLE func3_DI_FSAFE_TYPE; \
	MENU func3_DI_FSAFE_TYPE_page; \
	COMMAND func3_DI_FSAFE_TYPE_read; \
	COMMAND func3_DI_FSAFE_TYPE_write; \
	COLLECTION func3_DI_SIMULATE; \
	VARIABLE func3_DI_SIMULATE_Status_Condensed; \
	VARIABLE func3_DI_SIMULATE_Value; \
	VARIABLE func3_DI_SIMULATE_Enabled; \
	VARIABLE func3_DI_SIMULATE_Status_Quality; \
	VARIABLE func3_DI_SIMULATE_Status_Limit; \
	MENU func3_DI_SIMULATE_page; \
	COMMAND func3_DI_SIMULATE_read; \
	COMMAND func3_DI_SIMULATE_write; \
	COLLECTION func3_DI_VIEW_1; \
	MENU func3_DI_VIEW_1_page; \
	MENU func3_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC3_DI_OPTIONAL_BOTH \
	COLLECTION func3_DI_VIEW_2; \
	MENU func3_DI_VIEW_2_page; \
	COLLECTION func3_DI_VIEW_3; \
	MENU func3_DI_VIEW_3_page

#define USE_FUNC3_DI_OPTIONAL_A \
	USE_FUNC3_DI_OPTIONAL_BOTH; \
	VARIABLE func3_DI_CHANNEL; \
	MENU func3_DI_CHANNEL_page; \
	COMMAND func3_DI_CHANNEL_read; \
	COMMAND func3_DI_CHANNEL_write; \
	VARIABLE func3_DI_FSAFE_TYPE; \
	MENU func3_DI_FSAFE_TYPE_page; \
	COMMAND func3_DI_FSAFE_TYPE_read; \
	COMMAND func3_DI_FSAFE_TYPE_write; \
	COLLECTION func3_DI_SIMULATE; \
	VARIABLE func3_DI_SIMULATE_Status_Condensed; \
	VARIABLE func3_DI_SIMULATE_Value; \
	VARIABLE func3_DI_SIMULATE_Enabled; \
	VARIABLE func3_DI_SIMULATE_Status_Quality; \
	VARIABLE func3_DI_SIMULATE_Status_Limit; \
	MENU func3_DI_SIMULATE_page; \
	COMMAND func3_DI_SIMULATE_read; \
	COMMAND func3_DI_SIMULATE_write; \
	COLLECTION func3_DI_VIEW_1; \
	MENU func3_DI_VIEW_1_page; \
	MENU func3_DI_Simple_Dialog_Optional_A

#define USE_FUNC3_DI_OPTIONAL_B \
	USE_FUNC3_DI_OPTIONAL_BOTH; \
	MENU func3_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC3_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func3_DI_)
#define USE_FUNC3_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func3_DI_)
#define USE_FUNC3_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func3_DI_)
#define USE_FUNC3_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func3_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC4_DI_MANDATORY_BOTH \
	BLOCK func4_DI_block; \
	COLLECTION func4_DI_BLOCK_OBJECT; \
	VARIABLE func4_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func4_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func4_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func4_DI_BLOCK_OBJECT_Class; \
	VARIABLE func4_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func4_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func4_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func4_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func4_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func4_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func4_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func4_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func4_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func4_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func4_DI_BLOCK_OBJECT_page; \
	COMMAND func4_DI_BLOCK_OBJECT_read; \
	VARIABLE func4_DI_ST_REV; \
	MENU func4_DI_ST_REV_page; \
	COMMAND func4_DI_ST_REV_read; \
	VARIABLE func4_DI_TAG_DESC; \
	MENU func4_DI_TAG_DESC_page; \
	COMMAND func4_DI_TAG_DESC_read; \
	COMMAND func4_DI_TAG_DESC_write; \
	VARIABLE func4_DI_STRATEGY; \
	MENU func4_DI_STRATEGY_page; \
	COMMAND func4_DI_STRATEGY_read; \
	COMMAND func4_DI_STRATEGY_write; \
	VARIABLE func4_DI_ALERT_KEY; \
	MENU func4_DI_ALERT_KEY_page; \
	COMMAND func4_DI_ALERT_KEY_read; \
	COMMAND func4_DI_ALERT_KEY_write; \
	VARIABLE func4_DI_TARGET_MODE; \
	MENU func4_DI_TARGET_MODE_page; \
	COMMAND func4_DI_TARGET_MODE_read; \
	COMMAND func4_DI_TARGET_MODE_write; \
	COLLECTION func4_DI_MODE_BLK; \
	VARIABLE func4_DI_MODE_BLK_Actual; \
	VARIABLE func4_DI_MODE_BLK_Permitted; \
	VARIABLE func4_DI_MODE_BLK_Normal; \
	MENU func4_DI_MODE_BLK_page; \
	COMMAND func4_DI_MODE_BLK_read; \
	COLLECTION func4_DI_ALARM_SUM; \
	VARIABLE func4_DI_ALARM_SUM_Current; \
	VARIABLE func4_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func4_DI_ALARM_SUM_Unreported; \
	VARIABLE func4_DI_ALARM_SUM_Disabled; \
	MENU func4_DI_ALARM_SUM_page; \
	COMMAND func4_DI_ALARM_SUM_read; \
	COLLECTION func4_DI_BATCH; \
	VARIABLE func4_DI_BATCH_Batch_ID; \
	VARIABLE func4_DI_BATCH_Rup; \
	VARIABLE func4_DI_BATCH_Operation; \
	VARIABLE func4_DI_BATCH_Phase; \
	MENU func4_DI_BATCH_page; \
	COMMAND func4_DI_BATCH_read; \
	COMMAND func4_DI_BATCH_write; \
	COLLECTION func4_DI_OUT_D; \
	VARIABLE func4_DI_OUT_D_Value; \
	VARIABLE func4_DI_OUT_D_Status_Condensed; \
	VARIABLE func4_DI_OUT_D_Status_Quality; \
	VARIABLE func4_DI_OUT_D_Status_Limit; \
	MENU func4_DI_OUT_D_page; \
	COMMAND func4_DI_OUT_D_read; \
	COMMAND func4_DI_OUT_D_write; \
	VARIABLE func4_DI_INVERT; \
	MENU func4_DI_INVERT_page; \
	COMMAND func4_DI_INVERT_read; \
	COMMAND func4_DI_INVERT_write; \
	VARIABLE func4_DI_FSAFE_VAL_D; \
	MENU func4_DI_FSAFE_VAL_D_page; \
	COMMAND func4_DI_FSAFE_VAL_D_read; \
	COMMAND func4_DI_FSAFE_VAL_D_write

#define USE_FUNC4_DI_MANDATORY_A \
	USE_FUNC4_DI_MANDATORY_BOTH; \
	MENU func4_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC4_DI_MANDATORY_B \
	USE_FUNC4_DI_MANDATORY_BOTH; \
	VARIABLE func4_DI_CHANNEL; \
	MENU func4_DI_CHANNEL_page; \
	COMMAND func4_DI_CHANNEL_read; \
	COMMAND func4_DI_CHANNEL_write; \
	VARIABLE func4_DI_FSAFE_TYPE; \
	MENU func4_DI_FSAFE_TYPE_page; \
	COMMAND func4_DI_FSAFE_TYPE_read; \
	COMMAND func4_DI_FSAFE_TYPE_write; \
	COLLECTION func4_DI_SIMULATE; \
	VARIABLE func4_DI_SIMULATE_Status_Condensed; \
	VARIABLE func4_DI_SIMULATE_Value; \
	VARIABLE func4_DI_SIMULATE_Enabled; \
	VARIABLE func4_DI_SIMULATE_Status_Quality; \
	VARIABLE func4_DI_SIMULATE_Status_Limit; \
	MENU func4_DI_SIMULATE_page; \
	COMMAND func4_DI_SIMULATE_read; \
	COMMAND func4_DI_SIMULATE_write; \
	COLLECTION func4_DI_VIEW_1; \
	MENU func4_DI_VIEW_1_page; \
	MENU func4_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC4_DI_OPTIONAL_BOTH \
	COLLECTION func4_DI_VIEW_2; \
	MENU func4_DI_VIEW_2_page; \
	COLLECTION func4_DI_VIEW_3; \
	MENU func4_DI_VIEW_3_page

#define USE_FUNC4_DI_OPTIONAL_A \
	USE_FUNC4_DI_OPTIONAL_BOTH; \
	VARIABLE func4_DI_CHANNEL; \
	MENU func4_DI_CHANNEL_page; \
	COMMAND func4_DI_CHANNEL_read; \
	COMMAND func4_DI_CHANNEL_write; \
	VARIABLE func4_DI_FSAFE_TYPE; \
	MENU func4_DI_FSAFE_TYPE_page; \
	COMMAND func4_DI_FSAFE_TYPE_read; \
	COMMAND func4_DI_FSAFE_TYPE_write; \
	COLLECTION func4_DI_SIMULATE; \
	VARIABLE func4_DI_SIMULATE_Status_Condensed; \
	VARIABLE func4_DI_SIMULATE_Value; \
	VARIABLE func4_DI_SIMULATE_Enabled; \
	VARIABLE func4_DI_SIMULATE_Status_Quality; \
	VARIABLE func4_DI_SIMULATE_Status_Limit; \
	MENU func4_DI_SIMULATE_page; \
	COMMAND func4_DI_SIMULATE_read; \
	COMMAND func4_DI_SIMULATE_write; \
	COLLECTION func4_DI_VIEW_1; \
	MENU func4_DI_VIEW_1_page; \
	MENU func4_DI_Simple_Dialog_Optional_A

#define USE_FUNC4_DI_OPTIONAL_B \
	USE_FUNC4_DI_OPTIONAL_BOTH; \
	MENU func4_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC4_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func4_DI_)
#define USE_FUNC4_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func4_DI_)
#define USE_FUNC4_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func4_DI_)
#define USE_FUNC4_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func4_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC5_DI_MANDATORY_BOTH \
	BLOCK func5_DI_block; \
	COLLECTION func5_DI_BLOCK_OBJECT; \
	VARIABLE func5_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func5_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func5_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func5_DI_BLOCK_OBJECT_Class; \
	VARIABLE func5_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func5_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func5_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func5_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func5_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func5_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func5_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func5_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func5_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func5_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func5_DI_BLOCK_OBJECT_page; \
	COMMAND func5_DI_BLOCK_OBJECT_read; \
	VARIABLE func5_DI_ST_REV; \
	MENU func5_DI_ST_REV_page; \
	COMMAND func5_DI_ST_REV_read; \
	VARIABLE func5_DI_TAG_DESC; \
	MENU func5_DI_TAG_DESC_page; \
	COMMAND func5_DI_TAG_DESC_read; \
	COMMAND func5_DI_TAG_DESC_write; \
	VARIABLE func5_DI_STRATEGY; \
	MENU func5_DI_STRATEGY_page; \
	COMMAND func5_DI_STRATEGY_read; \
	COMMAND func5_DI_STRATEGY_write; \
	VARIABLE func5_DI_ALERT_KEY; \
	MENU func5_DI_ALERT_KEY_page; \
	COMMAND func5_DI_ALERT_KEY_read; \
	COMMAND func5_DI_ALERT_KEY_write; \
	VARIABLE func5_DI_TARGET_MODE; \
	MENU func5_DI_TARGET_MODE_page; \
	COMMAND func5_DI_TARGET_MODE_read; \
	COMMAND func5_DI_TARGET_MODE_write; \
	COLLECTION func5_DI_MODE_BLK; \
	VARIABLE func5_DI_MODE_BLK_Actual; \
	VARIABLE func5_DI_MODE_BLK_Permitted; \
	VARIABLE func5_DI_MODE_BLK_Normal; \
	MENU func5_DI_MODE_BLK_page; \
	COMMAND func5_DI_MODE_BLK_read; \
	COLLECTION func5_DI_ALARM_SUM; \
	VARIABLE func5_DI_ALARM_SUM_Current; \
	VARIABLE func5_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func5_DI_ALARM_SUM_Unreported; \
	VARIABLE func5_DI_ALARM_SUM_Disabled; \
	MENU func5_DI_ALARM_SUM_page; \
	COMMAND func5_DI_ALARM_SUM_read; \
	COLLECTION func5_DI_BATCH; \
	VARIABLE func5_DI_BATCH_Batch_ID; \
	VARIABLE func5_DI_BATCH_Rup; \
	VARIABLE func5_DI_BATCH_Operation; \
	VARIABLE func5_DI_BATCH_Phase; \
	MENU func5_DI_BATCH_page; \
	COMMAND func5_DI_BATCH_read; \
	COMMAND func5_DI_BATCH_write; \
	COLLECTION func5_DI_OUT_D; \
	VARIABLE func5_DI_OUT_D_Value; \
	VARIABLE func5_DI_OUT_D_Status_Condensed; \
	VARIABLE func5_DI_OUT_D_Status_Quality; \
	VARIABLE func5_DI_OUT_D_Status_Limit; \
	MENU func5_DI_OUT_D_page; \
	COMMAND func5_DI_OUT_D_read; \
	COMMAND func5_DI_OUT_D_write; \
	VARIABLE func5_DI_INVERT; \
	MENU func5_DI_INVERT_page; \
	COMMAND func5_DI_INVERT_read; \
	COMMAND func5_DI_INVERT_write; \
	VARIABLE func5_DI_FSAFE_VAL_D; \
	MENU func5_DI_FSAFE_VAL_D_page; \
	COMMAND func5_DI_FSAFE_VAL_D_read; \
	COMMAND func5_DI_FSAFE_VAL_D_write

#define USE_FUNC5_DI_MANDATORY_A \
	USE_FUNC5_DI_MANDATORY_BOTH; \
	MENU func5_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC5_DI_MANDATORY_B \
	USE_FUNC5_DI_MANDATORY_BOTH; \
	VARIABLE func5_DI_CHANNEL; \
	MENU func5_DI_CHANNEL_page; \
	COMMAND func5_DI_CHANNEL_read; \
	COMMAND func5_DI_CHANNEL_write; \
	VARIABLE func5_DI_FSAFE_TYPE; \
	MENU func5_DI_FSAFE_TYPE_page; \
	COMMAND func5_DI_FSAFE_TYPE_read; \
	COMMAND func5_DI_FSAFE_TYPE_write; \
	COLLECTION func5_DI_SIMULATE; \
	VARIABLE func5_DI_SIMULATE_Status_Condensed; \
	VARIABLE func5_DI_SIMULATE_Value; \
	VARIABLE func5_DI_SIMULATE_Enabled; \
	VARIABLE func5_DI_SIMULATE_Status_Quality; \
	VARIABLE func5_DI_SIMULATE_Status_Limit; \
	MENU func5_DI_SIMULATE_page; \
	COMMAND func5_DI_SIMULATE_read; \
	COMMAND func5_DI_SIMULATE_write; \
	COLLECTION func5_DI_VIEW_1; \
	MENU func5_DI_VIEW_1_page; \
	MENU func5_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC5_DI_OPTIONAL_BOTH \
	COLLECTION func5_DI_VIEW_2; \
	MENU func5_DI_VIEW_2_page; \
	COLLECTION func5_DI_VIEW_3; \
	MENU func5_DI_VIEW_3_page

#define USE_FUNC5_DI_OPTIONAL_A \
	USE_FUNC5_DI_OPTIONAL_BOTH; \
	VARIABLE func5_DI_CHANNEL; \
	MENU func5_DI_CHANNEL_page; \
	COMMAND func5_DI_CHANNEL_read; \
	COMMAND func5_DI_CHANNEL_write; \
	VARIABLE func5_DI_FSAFE_TYPE; \
	MENU func5_DI_FSAFE_TYPE_page; \
	COMMAND func5_DI_FSAFE_TYPE_read; \
	COMMAND func5_DI_FSAFE_TYPE_write; \
	COLLECTION func5_DI_SIMULATE; \
	VARIABLE func5_DI_SIMULATE_Status_Condensed; \
	VARIABLE func5_DI_SIMULATE_Value; \
	VARIABLE func5_DI_SIMULATE_Enabled; \
	VARIABLE func5_DI_SIMULATE_Status_Quality; \
	VARIABLE func5_DI_SIMULATE_Status_Limit; \
	MENU func5_DI_SIMULATE_page; \
	COMMAND func5_DI_SIMULATE_read; \
	COMMAND func5_DI_SIMULATE_write; \
	COLLECTION func5_DI_VIEW_1; \
	MENU func5_DI_VIEW_1_page; \
	MENU func5_DI_Simple_Dialog_Optional_A

#define USE_FUNC5_DI_OPTIONAL_B \
	USE_FUNC5_DI_OPTIONAL_BOTH; \
	MENU func5_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC5_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func5_DI_)
#define USE_FUNC5_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func5_DI_)
#define USE_FUNC5_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func5_DI_)
#define USE_FUNC5_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func5_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC6_DI_MANDATORY_BOTH \
	BLOCK func6_DI_block; \
	COLLECTION func6_DI_BLOCK_OBJECT; \
	VARIABLE func6_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func6_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func6_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func6_DI_BLOCK_OBJECT_Class; \
	VARIABLE func6_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func6_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func6_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func6_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func6_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func6_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func6_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func6_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func6_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func6_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func6_DI_BLOCK_OBJECT_page; \
	COMMAND func6_DI_BLOCK_OBJECT_read; \
	VARIABLE func6_DI_ST_REV; \
	MENU func6_DI_ST_REV_page; \
	COMMAND func6_DI_ST_REV_read; \
	VARIABLE func6_DI_TAG_DESC; \
	MENU func6_DI_TAG_DESC_page; \
	COMMAND func6_DI_TAG_DESC_read; \
	COMMAND func6_DI_TAG_DESC_write; \
	VARIABLE func6_DI_STRATEGY; \
	MENU func6_DI_STRATEGY_page; \
	COMMAND func6_DI_STRATEGY_read; \
	COMMAND func6_DI_STRATEGY_write; \
	VARIABLE func6_DI_ALERT_KEY; \
	MENU func6_DI_ALERT_KEY_page; \
	COMMAND func6_DI_ALERT_KEY_read; \
	COMMAND func6_DI_ALERT_KEY_write; \
	VARIABLE func6_DI_TARGET_MODE; \
	MENU func6_DI_TARGET_MODE_page; \
	COMMAND func6_DI_TARGET_MODE_read; \
	COMMAND func6_DI_TARGET_MODE_write; \
	COLLECTION func6_DI_MODE_BLK; \
	VARIABLE func6_DI_MODE_BLK_Actual; \
	VARIABLE func6_DI_MODE_BLK_Permitted; \
	VARIABLE func6_DI_MODE_BLK_Normal; \
	MENU func6_DI_MODE_BLK_page; \
	COMMAND func6_DI_MODE_BLK_read; \
	COLLECTION func6_DI_ALARM_SUM; \
	VARIABLE func6_DI_ALARM_SUM_Current; \
	VARIABLE func6_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func6_DI_ALARM_SUM_Unreported; \
	VARIABLE func6_DI_ALARM_SUM_Disabled; \
	MENU func6_DI_ALARM_SUM_page; \
	COMMAND func6_DI_ALARM_SUM_read; \
	COLLECTION func6_DI_BATCH; \
	VARIABLE func6_DI_BATCH_Batch_ID; \
	VARIABLE func6_DI_BATCH_Rup; \
	VARIABLE func6_DI_BATCH_Operation; \
	VARIABLE func6_DI_BATCH_Phase; \
	MENU func6_DI_BATCH_page; \
	COMMAND func6_DI_BATCH_read; \
	COMMAND func6_DI_BATCH_write; \
	COLLECTION func6_DI_OUT_D; \
	VARIABLE func6_DI_OUT_D_Value; \
	VARIABLE func6_DI_OUT_D_Status_Condensed; \
	VARIABLE func6_DI_OUT_D_Status_Quality; \
	VARIABLE func6_DI_OUT_D_Status_Limit; \
	MENU func6_DI_OUT_D_page; \
	COMMAND func6_DI_OUT_D_read; \
	COMMAND func6_DI_OUT_D_write; \
	VARIABLE func6_DI_INVERT; \
	MENU func6_DI_INVERT_page; \
	COMMAND func6_DI_INVERT_read; \
	COMMAND func6_DI_INVERT_write; \
	VARIABLE func6_DI_FSAFE_VAL_D; \
	MENU func6_DI_FSAFE_VAL_D_page; \
	COMMAND func6_DI_FSAFE_VAL_D_read; \
	COMMAND func6_DI_FSAFE_VAL_D_write

#define USE_FUNC6_DI_MANDATORY_A \
	USE_FUNC6_DI_MANDATORY_BOTH; \
	MENU func6_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC6_DI_MANDATORY_B \
	USE_FUNC6_DI_MANDATORY_BOTH; \
	VARIABLE func6_DI_CHANNEL; \
	MENU func6_DI_CHANNEL_page; \
	COMMAND func6_DI_CHANNEL_read; \
	COMMAND func6_DI_CHANNEL_write; \
	VARIABLE func6_DI_FSAFE_TYPE; \
	MENU func6_DI_FSAFE_TYPE_page; \
	COMMAND func6_DI_FSAFE_TYPE_read; \
	COMMAND func6_DI_FSAFE_TYPE_write; \
	COLLECTION func6_DI_SIMULATE; \
	VARIABLE func6_DI_SIMULATE_Status_Condensed; \
	VARIABLE func6_DI_SIMULATE_Value; \
	VARIABLE func6_DI_SIMULATE_Enabled; \
	VARIABLE func6_DI_SIMULATE_Status_Quality; \
	VARIABLE func6_DI_SIMULATE_Status_Limit; \
	MENU func6_DI_SIMULATE_page; \
	COMMAND func6_DI_SIMULATE_read; \
	COMMAND func6_DI_SIMULATE_write; \
	COLLECTION func6_DI_VIEW_1; \
	MENU func6_DI_VIEW_1_page; \
	MENU func6_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC6_DI_OPTIONAL_BOTH \
	COLLECTION func6_DI_VIEW_2; \
	MENU func6_DI_VIEW_2_page; \
	COLLECTION func6_DI_VIEW_3; \
	MENU func6_DI_VIEW_3_page

#define USE_FUNC6_DI_OPTIONAL_A \
	USE_FUNC6_DI_OPTIONAL_BOTH; \
	VARIABLE func6_DI_CHANNEL; \
	MENU func6_DI_CHANNEL_page; \
	COMMAND func6_DI_CHANNEL_read; \
	COMMAND func6_DI_CHANNEL_write; \
	VARIABLE func6_DI_FSAFE_TYPE; \
	MENU func6_DI_FSAFE_TYPE_page; \
	COMMAND func6_DI_FSAFE_TYPE_read; \
	COMMAND func6_DI_FSAFE_TYPE_write; \
	COLLECTION func6_DI_SIMULATE; \
	VARIABLE func6_DI_SIMULATE_Status_Condensed; \
	VARIABLE func6_DI_SIMULATE_Value; \
	VARIABLE func6_DI_SIMULATE_Enabled; \
	VARIABLE func6_DI_SIMULATE_Status_Quality; \
	VARIABLE func6_DI_SIMULATE_Status_Limit; \
	MENU func6_DI_SIMULATE_page; \
	COMMAND func6_DI_SIMULATE_read; \
	COMMAND func6_DI_SIMULATE_write; \
	COLLECTION func6_DI_VIEW_1; \
	MENU func6_DI_VIEW_1_page; \
	MENU func6_DI_Simple_Dialog_Optional_A

#define USE_FUNC6_DI_OPTIONAL_B \
	USE_FUNC6_DI_OPTIONAL_BOTH; \
	MENU func6_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC6_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func6_DI_)
#define USE_FUNC6_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func6_DI_)
#define USE_FUNC6_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func6_DI_)
#define USE_FUNC6_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func6_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC7_DI_MANDATORY_BOTH \
	BLOCK func7_DI_block; \
	COLLECTION func7_DI_BLOCK_OBJECT; \
	VARIABLE func7_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func7_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func7_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func7_DI_BLOCK_OBJECT_Class; \
	VARIABLE func7_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func7_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func7_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func7_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func7_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func7_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func7_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func7_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func7_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func7_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func7_DI_BLOCK_OBJECT_page; \
	COMMAND func7_DI_BLOCK_OBJECT_read; \
	VARIABLE func7_DI_ST_REV; \
	MENU func7_DI_ST_REV_page; \
	COMMAND func7_DI_ST_REV_read; \
	VARIABLE func7_DI_TAG_DESC; \
	MENU func7_DI_TAG_DESC_page; \
	COMMAND func7_DI_TAG_DESC_read; \
	COMMAND func7_DI_TAG_DESC_write; \
	VARIABLE func7_DI_STRATEGY; \
	MENU func7_DI_STRATEGY_page; \
	COMMAND func7_DI_STRATEGY_read; \
	COMMAND func7_DI_STRATEGY_write; \
	VARIABLE func7_DI_ALERT_KEY; \
	MENU func7_DI_ALERT_KEY_page; \
	COMMAND func7_DI_ALERT_KEY_read; \
	COMMAND func7_DI_ALERT_KEY_write; \
	VARIABLE func7_DI_TARGET_MODE; \
	MENU func7_DI_TARGET_MODE_page; \
	COMMAND func7_DI_TARGET_MODE_read; \
	COMMAND func7_DI_TARGET_MODE_write; \
	COLLECTION func7_DI_MODE_BLK; \
	VARIABLE func7_DI_MODE_BLK_Actual; \
	VARIABLE func7_DI_MODE_BLK_Permitted; \
	VARIABLE func7_DI_MODE_BLK_Normal; \
	MENU func7_DI_MODE_BLK_page; \
	COMMAND func7_DI_MODE_BLK_read; \
	COLLECTION func7_DI_ALARM_SUM; \
	VARIABLE func7_DI_ALARM_SUM_Current; \
	VARIABLE func7_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func7_DI_ALARM_SUM_Unreported; \
	VARIABLE func7_DI_ALARM_SUM_Disabled; \
	MENU func7_DI_ALARM_SUM_page; \
	COMMAND func7_DI_ALARM_SUM_read; \
	COLLECTION func7_DI_BATCH; \
	VARIABLE func7_DI_BATCH_Batch_ID; \
	VARIABLE func7_DI_BATCH_Rup; \
	VARIABLE func7_DI_BATCH_Operation; \
	VARIABLE func7_DI_BATCH_Phase; \
	MENU func7_DI_BATCH_page; \
	COMMAND func7_DI_BATCH_read; \
	COMMAND func7_DI_BATCH_write; \
	COLLECTION func7_DI_OUT_D; \
	VARIABLE func7_DI_OUT_D_Value; \
	VARIABLE func7_DI_OUT_D_Status_Condensed; \
	VARIABLE func7_DI_OUT_D_Status_Quality; \
	VARIABLE func7_DI_OUT_D_Status_Limit; \
	MENU func7_DI_OUT_D_page; \
	COMMAND func7_DI_OUT_D_read; \
	COMMAND func7_DI_OUT_D_write; \
	VARIABLE func7_DI_INVERT; \
	MENU func7_DI_INVERT_page; \
	COMMAND func7_DI_INVERT_read; \
	COMMAND func7_DI_INVERT_write; \
	VARIABLE func7_DI_FSAFE_VAL_D; \
	MENU func7_DI_FSAFE_VAL_D_page; \
	COMMAND func7_DI_FSAFE_VAL_D_read; \
	COMMAND func7_DI_FSAFE_VAL_D_write

#define USE_FUNC7_DI_MANDATORY_A \
	USE_FUNC7_DI_MANDATORY_BOTH; \
	MENU func7_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC7_DI_MANDATORY_B \
	USE_FUNC7_DI_MANDATORY_BOTH; \
	VARIABLE func7_DI_CHANNEL; \
	MENU func7_DI_CHANNEL_page; \
	COMMAND func7_DI_CHANNEL_read; \
	COMMAND func7_DI_CHANNEL_write; \
	VARIABLE func7_DI_FSAFE_TYPE; \
	MENU func7_DI_FSAFE_TYPE_page; \
	COMMAND func7_DI_FSAFE_TYPE_read; \
	COMMAND func7_DI_FSAFE_TYPE_write; \
	COLLECTION func7_DI_SIMULATE; \
	VARIABLE func7_DI_SIMULATE_Status_Condensed; \
	VARIABLE func7_DI_SIMULATE_Value; \
	VARIABLE func7_DI_SIMULATE_Enabled; \
	VARIABLE func7_DI_SIMULATE_Status_Quality; \
	VARIABLE func7_DI_SIMULATE_Status_Limit; \
	MENU func7_DI_SIMULATE_page; \
	COMMAND func7_DI_SIMULATE_read; \
	COMMAND func7_DI_SIMULATE_write; \
	COLLECTION func7_DI_VIEW_1; \
	MENU func7_DI_VIEW_1_page; \
	MENU func7_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC7_DI_OPTIONAL_BOTH \
	COLLECTION func7_DI_VIEW_2; \
	MENU func7_DI_VIEW_2_page; \
	COLLECTION func7_DI_VIEW_3; \
	MENU func7_DI_VIEW_3_page

#define USE_FUNC7_DI_OPTIONAL_A \
	USE_FUNC7_DI_OPTIONAL_BOTH; \
	VARIABLE func7_DI_CHANNEL; \
	MENU func7_DI_CHANNEL_page; \
	COMMAND func7_DI_CHANNEL_read; \
	COMMAND func7_DI_CHANNEL_write; \
	VARIABLE func7_DI_FSAFE_TYPE; \
	MENU func7_DI_FSAFE_TYPE_page; \
	COMMAND func7_DI_FSAFE_TYPE_read; \
	COMMAND func7_DI_FSAFE_TYPE_write; \
	COLLECTION func7_DI_SIMULATE; \
	VARIABLE func7_DI_SIMULATE_Status_Condensed; \
	VARIABLE func7_DI_SIMULATE_Value; \
	VARIABLE func7_DI_SIMULATE_Enabled; \
	VARIABLE func7_DI_SIMULATE_Status_Quality; \
	VARIABLE func7_DI_SIMULATE_Status_Limit; \
	MENU func7_DI_SIMULATE_page; \
	COMMAND func7_DI_SIMULATE_read; \
	COMMAND func7_DI_SIMULATE_write; \
	COLLECTION func7_DI_VIEW_1; \
	MENU func7_DI_VIEW_1_page; \
	MENU func7_DI_Simple_Dialog_Optional_A

#define USE_FUNC7_DI_OPTIONAL_B \
	USE_FUNC7_DI_OPTIONAL_BOTH; \
	MENU func7_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC7_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func7_DI_)
#define USE_FUNC7_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func7_DI_)
#define USE_FUNC7_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func7_DI_)
#define USE_FUNC7_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func7_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC8_DI_MANDATORY_BOTH \
	BLOCK func8_DI_block; \
	COLLECTION func8_DI_BLOCK_OBJECT; \
	VARIABLE func8_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func8_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func8_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func8_DI_BLOCK_OBJECT_Class; \
	VARIABLE func8_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func8_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func8_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func8_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func8_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func8_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func8_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func8_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func8_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func8_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func8_DI_BLOCK_OBJECT_page; \
	COMMAND func8_DI_BLOCK_OBJECT_read; \
	VARIABLE func8_DI_ST_REV; \
	MENU func8_DI_ST_REV_page; \
	COMMAND func8_DI_ST_REV_read; \
	VARIABLE func8_DI_TAG_DESC; \
	MENU func8_DI_TAG_DESC_page; \
	COMMAND func8_DI_TAG_DESC_read; \
	COMMAND func8_DI_TAG_DESC_write; \
	VARIABLE func8_DI_STRATEGY; \
	MENU func8_DI_STRATEGY_page; \
	COMMAND func8_DI_STRATEGY_read; \
	COMMAND func8_DI_STRATEGY_write; \
	VARIABLE func8_DI_ALERT_KEY; \
	MENU func8_DI_ALERT_KEY_page; \
	COMMAND func8_DI_ALERT_KEY_read; \
	COMMAND func8_DI_ALERT_KEY_write; \
	VARIABLE func8_DI_TARGET_MODE; \
	MENU func8_DI_TARGET_MODE_page; \
	COMMAND func8_DI_TARGET_MODE_read; \
	COMMAND func8_DI_TARGET_MODE_write; \
	COLLECTION func8_DI_MODE_BLK; \
	VARIABLE func8_DI_MODE_BLK_Actual; \
	VARIABLE func8_DI_MODE_BLK_Permitted; \
	VARIABLE func8_DI_MODE_BLK_Normal; \
	MENU func8_DI_MODE_BLK_page; \
	COMMAND func8_DI_MODE_BLK_read; \
	COLLECTION func8_DI_ALARM_SUM; \
	VARIABLE func8_DI_ALARM_SUM_Current; \
	VARIABLE func8_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func8_DI_ALARM_SUM_Unreported; \
	VARIABLE func8_DI_ALARM_SUM_Disabled; \
	MENU func8_DI_ALARM_SUM_page; \
	COMMAND func8_DI_ALARM_SUM_read; \
	COLLECTION func8_DI_BATCH; \
	VARIABLE func8_DI_BATCH_Batch_ID; \
	VARIABLE func8_DI_BATCH_Rup; \
	VARIABLE func8_DI_BATCH_Operation; \
	VARIABLE func8_DI_BATCH_Phase; \
	MENU func8_DI_BATCH_page; \
	COMMAND func8_DI_BATCH_read; \
	COMMAND func8_DI_BATCH_write; \
	COLLECTION func8_DI_OUT_D; \
	VARIABLE func8_DI_OUT_D_Value; \
	VARIABLE func8_DI_OUT_D_Status_Condensed; \
	VARIABLE func8_DI_OUT_D_Status_Quality; \
	VARIABLE func8_DI_OUT_D_Status_Limit; \
	MENU func8_DI_OUT_D_page; \
	COMMAND func8_DI_OUT_D_read; \
	COMMAND func8_DI_OUT_D_write; \
	VARIABLE func8_DI_INVERT; \
	MENU func8_DI_INVERT_page; \
	COMMAND func8_DI_INVERT_read; \
	COMMAND func8_DI_INVERT_write; \
	VARIABLE func8_DI_FSAFE_VAL_D; \
	MENU func8_DI_FSAFE_VAL_D_page; \
	COMMAND func8_DI_FSAFE_VAL_D_read; \
	COMMAND func8_DI_FSAFE_VAL_D_write

#define USE_FUNC8_DI_MANDATORY_A \
	USE_FUNC8_DI_MANDATORY_BOTH; \
	MENU func8_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC8_DI_MANDATORY_B \
	USE_FUNC8_DI_MANDATORY_BOTH; \
	VARIABLE func8_DI_CHANNEL; \
	MENU func8_DI_CHANNEL_page; \
	COMMAND func8_DI_CHANNEL_read; \
	COMMAND func8_DI_CHANNEL_write; \
	VARIABLE func8_DI_FSAFE_TYPE; \
	MENU func8_DI_FSAFE_TYPE_page; \
	COMMAND func8_DI_FSAFE_TYPE_read; \
	COMMAND func8_DI_FSAFE_TYPE_write; \
	COLLECTION func8_DI_SIMULATE; \
	VARIABLE func8_DI_SIMULATE_Status_Condensed; \
	VARIABLE func8_DI_SIMULATE_Value; \
	VARIABLE func8_DI_SIMULATE_Enabled; \
	VARIABLE func8_DI_SIMULATE_Status_Quality; \
	VARIABLE func8_DI_SIMULATE_Status_Limit; \
	MENU func8_DI_SIMULATE_page; \
	COMMAND func8_DI_SIMULATE_read; \
	COMMAND func8_DI_SIMULATE_write; \
	COLLECTION func8_DI_VIEW_1; \
	MENU func8_DI_VIEW_1_page; \
	MENU func8_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC8_DI_OPTIONAL_BOTH \
	COLLECTION func8_DI_VIEW_2; \
	MENU func8_DI_VIEW_2_page; \
	COLLECTION func8_DI_VIEW_3; \
	MENU func8_DI_VIEW_3_page

#define USE_FUNC8_DI_OPTIONAL_A \
	USE_FUNC8_DI_OPTIONAL_BOTH; \
	VARIABLE func8_DI_CHANNEL; \
	MENU func8_DI_CHANNEL_page; \
	COMMAND func8_DI_CHANNEL_read; \
	COMMAND func8_DI_CHANNEL_write; \
	VARIABLE func8_DI_FSAFE_TYPE; \
	MENU func8_DI_FSAFE_TYPE_page; \
	COMMAND func8_DI_FSAFE_TYPE_read; \
	COMMAND func8_DI_FSAFE_TYPE_write; \
	COLLECTION func8_DI_SIMULATE; \
	VARIABLE func8_DI_SIMULATE_Status_Condensed; \
	VARIABLE func8_DI_SIMULATE_Value; \
	VARIABLE func8_DI_SIMULATE_Enabled; \
	VARIABLE func8_DI_SIMULATE_Status_Quality; \
	VARIABLE func8_DI_SIMULATE_Status_Limit; \
	MENU func8_DI_SIMULATE_page; \
	COMMAND func8_DI_SIMULATE_read; \
	COMMAND func8_DI_SIMULATE_write; \
	COLLECTION func8_DI_VIEW_1; \
	MENU func8_DI_VIEW_1_page; \
	MENU func8_DI_Simple_Dialog_Optional_A

#define USE_FUNC8_DI_OPTIONAL_B \
	USE_FUNC8_DI_OPTIONAL_BOTH; \
	MENU func8_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC8_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func8_DI_)
#define USE_FUNC8_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func8_DI_)
#define USE_FUNC8_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func8_DI_)
#define USE_FUNC8_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func8_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC9_DI_MANDATORY_BOTH \
	BLOCK func9_DI_block; \
	COLLECTION func9_DI_BLOCK_OBJECT; \
	VARIABLE func9_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func9_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func9_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func9_DI_BLOCK_OBJECT_Class; \
	VARIABLE func9_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func9_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func9_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func9_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func9_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func9_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func9_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func9_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func9_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func9_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func9_DI_BLOCK_OBJECT_page; \
	COMMAND func9_DI_BLOCK_OBJECT_read; \
	VARIABLE func9_DI_ST_REV; \
	MENU func9_DI_ST_REV_page; \
	COMMAND func9_DI_ST_REV_read; \
	VARIABLE func9_DI_TAG_DESC; \
	MENU func9_DI_TAG_DESC_page; \
	COMMAND func9_DI_TAG_DESC_read; \
	COMMAND func9_DI_TAG_DESC_write; \
	VARIABLE func9_DI_STRATEGY; \
	MENU func9_DI_STRATEGY_page; \
	COMMAND func9_DI_STRATEGY_read; \
	COMMAND func9_DI_STRATEGY_write; \
	VARIABLE func9_DI_ALERT_KEY; \
	MENU func9_DI_ALERT_KEY_page; \
	COMMAND func9_DI_ALERT_KEY_read; \
	COMMAND func9_DI_ALERT_KEY_write; \
	VARIABLE func9_DI_TARGET_MODE; \
	MENU func9_DI_TARGET_MODE_page; \
	COMMAND func9_DI_TARGET_MODE_read; \
	COMMAND func9_DI_TARGET_MODE_write; \
	COLLECTION func9_DI_MODE_BLK; \
	VARIABLE func9_DI_MODE_BLK_Actual; \
	VARIABLE func9_DI_MODE_BLK_Permitted; \
	VARIABLE func9_DI_MODE_BLK_Normal; \
	MENU func9_DI_MODE_BLK_page; \
	COMMAND func9_DI_MODE_BLK_read; \
	COLLECTION func9_DI_ALARM_SUM; \
	VARIABLE func9_DI_ALARM_SUM_Current; \
	VARIABLE func9_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func9_DI_ALARM_SUM_Unreported; \
	VARIABLE func9_DI_ALARM_SUM_Disabled; \
	MENU func9_DI_ALARM_SUM_page; \
	COMMAND func9_DI_ALARM_SUM_read; \
	COLLECTION func9_DI_BATCH; \
	VARIABLE func9_DI_BATCH_Batch_ID; \
	VARIABLE func9_DI_BATCH_Rup; \
	VARIABLE func9_DI_BATCH_Operation; \
	VARIABLE func9_DI_BATCH_Phase; \
	MENU func9_DI_BATCH_page; \
	COMMAND func9_DI_BATCH_read; \
	COMMAND func9_DI_BATCH_write; \
	COLLECTION func9_DI_OUT_D; \
	VARIABLE func9_DI_OUT_D_Value; \
	VARIABLE func9_DI_OUT_D_Status_Condensed; \
	VARIABLE func9_DI_OUT_D_Status_Quality; \
	VARIABLE func9_DI_OUT_D_Status_Limit; \
	MENU func9_DI_OUT_D_page; \
	COMMAND func9_DI_OUT_D_read; \
	COMMAND func9_DI_OUT_D_write; \
	VARIABLE func9_DI_INVERT; \
	MENU func9_DI_INVERT_page; \
	COMMAND func9_DI_INVERT_read; \
	COMMAND func9_DI_INVERT_write; \
	VARIABLE func9_DI_FSAFE_VAL_D; \
	MENU func9_DI_FSAFE_VAL_D_page; \
	COMMAND func9_DI_FSAFE_VAL_D_read; \
	COMMAND func9_DI_FSAFE_VAL_D_write

#define USE_FUNC9_DI_MANDATORY_A \
	USE_FUNC9_DI_MANDATORY_BOTH; \
	MENU func9_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC9_DI_MANDATORY_B \
	USE_FUNC9_DI_MANDATORY_BOTH; \
	VARIABLE func9_DI_CHANNEL; \
	MENU func9_DI_CHANNEL_page; \
	COMMAND func9_DI_CHANNEL_read; \
	COMMAND func9_DI_CHANNEL_write; \
	VARIABLE func9_DI_FSAFE_TYPE; \
	MENU func9_DI_FSAFE_TYPE_page; \
	COMMAND func9_DI_FSAFE_TYPE_read; \
	COMMAND func9_DI_FSAFE_TYPE_write; \
	COLLECTION func9_DI_SIMULATE; \
	VARIABLE func9_DI_SIMULATE_Status_Condensed; \
	VARIABLE func9_DI_SIMULATE_Value; \
	VARIABLE func9_DI_SIMULATE_Enabled; \
	VARIABLE func9_DI_SIMULATE_Status_Quality; \
	VARIABLE func9_DI_SIMULATE_Status_Limit; \
	MENU func9_DI_SIMULATE_page; \
	COMMAND func9_DI_SIMULATE_read; \
	COMMAND func9_DI_SIMULATE_write; \
	COLLECTION func9_DI_VIEW_1; \
	MENU func9_DI_VIEW_1_page; \
	MENU func9_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC9_DI_OPTIONAL_BOTH \
	COLLECTION func9_DI_VIEW_2; \
	MENU func9_DI_VIEW_2_page; \
	COLLECTION func9_DI_VIEW_3; \
	MENU func9_DI_VIEW_3_page

#define USE_FUNC9_DI_OPTIONAL_A \
	USE_FUNC9_DI_OPTIONAL_BOTH; \
	VARIABLE func9_DI_CHANNEL; \
	MENU func9_DI_CHANNEL_page; \
	COMMAND func9_DI_CHANNEL_read; \
	COMMAND func9_DI_CHANNEL_write; \
	VARIABLE func9_DI_FSAFE_TYPE; \
	MENU func9_DI_FSAFE_TYPE_page; \
	COMMAND func9_DI_FSAFE_TYPE_read; \
	COMMAND func9_DI_FSAFE_TYPE_write; \
	COLLECTION func9_DI_SIMULATE; \
	VARIABLE func9_DI_SIMULATE_Status_Condensed; \
	VARIABLE func9_DI_SIMULATE_Value; \
	VARIABLE func9_DI_SIMULATE_Enabled; \
	VARIABLE func9_DI_SIMULATE_Status_Quality; \
	VARIABLE func9_DI_SIMULATE_Status_Limit; \
	MENU func9_DI_SIMULATE_page; \
	COMMAND func9_DI_SIMULATE_read; \
	COMMAND func9_DI_SIMULATE_write; \
	COLLECTION func9_DI_VIEW_1; \
	MENU func9_DI_VIEW_1_page; \
	MENU func9_DI_Simple_Dialog_Optional_A

#define USE_FUNC9_DI_OPTIONAL_B \
	USE_FUNC9_DI_OPTIONAL_BOTH; \
	MENU func9_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC9_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func9_DI_)
#define USE_FUNC9_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func9_DI_)
#define USE_FUNC9_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func9_DI_)
#define USE_FUNC9_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func9_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC10_DI_MANDATORY_BOTH \
	BLOCK func10_DI_block; \
	COLLECTION func10_DI_BLOCK_OBJECT; \
	VARIABLE func10_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func10_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func10_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func10_DI_BLOCK_OBJECT_Class; \
	VARIABLE func10_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func10_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func10_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func10_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func10_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func10_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func10_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func10_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func10_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func10_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func10_DI_BLOCK_OBJECT_page; \
	COMMAND func10_DI_BLOCK_OBJECT_read; \
	VARIABLE func10_DI_ST_REV; \
	MENU func10_DI_ST_REV_page; \
	COMMAND func10_DI_ST_REV_read; \
	VARIABLE func10_DI_TAG_DESC; \
	MENU func10_DI_TAG_DESC_page; \
	COMMAND func10_DI_TAG_DESC_read; \
	COMMAND func10_DI_TAG_DESC_write; \
	VARIABLE func10_DI_STRATEGY; \
	MENU func10_DI_STRATEGY_page; \
	COMMAND func10_DI_STRATEGY_read; \
	COMMAND func10_DI_STRATEGY_write; \
	VARIABLE func10_DI_ALERT_KEY; \
	MENU func10_DI_ALERT_KEY_page; \
	COMMAND func10_DI_ALERT_KEY_read; \
	COMMAND func10_DI_ALERT_KEY_write; \
	VARIABLE func10_DI_TARGET_MODE; \
	MENU func10_DI_TARGET_MODE_page; \
	COMMAND func10_DI_TARGET_MODE_read; \
	COMMAND func10_DI_TARGET_MODE_write; \
	COLLECTION func10_DI_MODE_BLK; \
	VARIABLE func10_DI_MODE_BLK_Actual; \
	VARIABLE func10_DI_MODE_BLK_Permitted; \
	VARIABLE func10_DI_MODE_BLK_Normal; \
	MENU func10_DI_MODE_BLK_page; \
	COMMAND func10_DI_MODE_BLK_read; \
	COLLECTION func10_DI_ALARM_SUM; \
	VARIABLE func10_DI_ALARM_SUM_Current; \
	VARIABLE func10_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func10_DI_ALARM_SUM_Unreported; \
	VARIABLE func10_DI_ALARM_SUM_Disabled; \
	MENU func10_DI_ALARM_SUM_page; \
	COMMAND func10_DI_ALARM_SUM_read; \
	COLLECTION func10_DI_BATCH; \
	VARIABLE func10_DI_BATCH_Batch_ID; \
	VARIABLE func10_DI_BATCH_Rup; \
	VARIABLE func10_DI_BATCH_Operation; \
	VARIABLE func10_DI_BATCH_Phase; \
	MENU func10_DI_BATCH_page; \
	COMMAND func10_DI_BATCH_read; \
	COMMAND func10_DI_BATCH_write; \
	COLLECTION func10_DI_OUT_D; \
	VARIABLE func10_DI_OUT_D_Value; \
	VARIABLE func10_DI_OUT_D_Status_Condensed; \
	VARIABLE func10_DI_OUT_D_Status_Quality; \
	VARIABLE func10_DI_OUT_D_Status_Limit; \
	MENU func10_DI_OUT_D_page; \
	COMMAND func10_DI_OUT_D_read; \
	COMMAND func10_DI_OUT_D_write; \
	VARIABLE func10_DI_INVERT; \
	MENU func10_DI_INVERT_page; \
	COMMAND func10_DI_INVERT_read; \
	COMMAND func10_DI_INVERT_write; \
	VARIABLE func10_DI_FSAFE_VAL_D; \
	MENU func10_DI_FSAFE_VAL_D_page; \
	COMMAND func10_DI_FSAFE_VAL_D_read; \
	COMMAND func10_DI_FSAFE_VAL_D_write

#define USE_FUNC10_DI_MANDATORY_A \
	USE_FUNC10_DI_MANDATORY_BOTH; \
	MENU func10_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC10_DI_MANDATORY_B \
	USE_FUNC10_DI_MANDATORY_BOTH; \
	VARIABLE func10_DI_CHANNEL; \
	MENU func10_DI_CHANNEL_page; \
	COMMAND func10_DI_CHANNEL_read; \
	COMMAND func10_DI_CHANNEL_write; \
	VARIABLE func10_DI_FSAFE_TYPE; \
	MENU func10_DI_FSAFE_TYPE_page; \
	COMMAND func10_DI_FSAFE_TYPE_read; \
	COMMAND func10_DI_FSAFE_TYPE_write; \
	COLLECTION func10_DI_SIMULATE; \
	VARIABLE func10_DI_SIMULATE_Status_Condensed; \
	VARIABLE func10_DI_SIMULATE_Value; \
	VARIABLE func10_DI_SIMULATE_Enabled; \
	VARIABLE func10_DI_SIMULATE_Status_Quality; \
	VARIABLE func10_DI_SIMULATE_Status_Limit; \
	MENU func10_DI_SIMULATE_page; \
	COMMAND func10_DI_SIMULATE_read; \
	COMMAND func10_DI_SIMULATE_write; \
	COLLECTION func10_DI_VIEW_1; \
	MENU func10_DI_VIEW_1_page; \
	MENU func10_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC10_DI_OPTIONAL_BOTH \
	COLLECTION func10_DI_VIEW_2; \
	MENU func10_DI_VIEW_2_page; \
	COLLECTION func10_DI_VIEW_3; \
	MENU func10_DI_VIEW_3_page

#define USE_FUNC10_DI_OPTIONAL_A \
	USE_FUNC10_DI_OPTIONAL_BOTH; \
	VARIABLE func10_DI_CHANNEL; \
	MENU func10_DI_CHANNEL_page; \
	COMMAND func10_DI_CHANNEL_read; \
	COMMAND func10_DI_CHANNEL_write; \
	VARIABLE func10_DI_FSAFE_TYPE; \
	MENU func10_DI_FSAFE_TYPE_page; \
	COMMAND func10_DI_FSAFE_TYPE_read; \
	COMMAND func10_DI_FSAFE_TYPE_write; \
	COLLECTION func10_DI_SIMULATE; \
	VARIABLE func10_DI_SIMULATE_Status_Condensed; \
	VARIABLE func10_DI_SIMULATE_Value; \
	VARIABLE func10_DI_SIMULATE_Enabled; \
	VARIABLE func10_DI_SIMULATE_Status_Quality; \
	VARIABLE func10_DI_SIMULATE_Status_Limit; \
	MENU func10_DI_SIMULATE_page; \
	COMMAND func10_DI_SIMULATE_read; \
	COMMAND func10_DI_SIMULATE_write; \
	COLLECTION func10_DI_VIEW_1; \
	MENU func10_DI_VIEW_1_page; \
	MENU func10_DI_Simple_Dialog_Optional_A

#define USE_FUNC10_DI_OPTIONAL_B \
	USE_FUNC10_DI_OPTIONAL_BOTH; \
	MENU func10_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC10_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func10_DI_)
#define USE_FUNC10_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func10_DI_)
#define USE_FUNC10_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func10_DI_)
#define USE_FUNC10_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func10_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC11_DI_MANDATORY_BOTH \
	BLOCK func11_DI_block; \
	COLLECTION func11_DI_BLOCK_OBJECT; \
	VARIABLE func11_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func11_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func11_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func11_DI_BLOCK_OBJECT_Class; \
	VARIABLE func11_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func11_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func11_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func11_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func11_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func11_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func11_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func11_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func11_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func11_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func11_DI_BLOCK_OBJECT_page; \
	COMMAND func11_DI_BLOCK_OBJECT_read; \
	VARIABLE func11_DI_ST_REV; \
	MENU func11_DI_ST_REV_page; \
	COMMAND func11_DI_ST_REV_read; \
	VARIABLE func11_DI_TAG_DESC; \
	MENU func11_DI_TAG_DESC_page; \
	COMMAND func11_DI_TAG_DESC_read; \
	COMMAND func11_DI_TAG_DESC_write; \
	VARIABLE func11_DI_STRATEGY; \
	MENU func11_DI_STRATEGY_page; \
	COMMAND func11_DI_STRATEGY_read; \
	COMMAND func11_DI_STRATEGY_write; \
	VARIABLE func11_DI_ALERT_KEY; \
	MENU func11_DI_ALERT_KEY_page; \
	COMMAND func11_DI_ALERT_KEY_read; \
	COMMAND func11_DI_ALERT_KEY_write; \
	VARIABLE func11_DI_TARGET_MODE; \
	MENU func11_DI_TARGET_MODE_page; \
	COMMAND func11_DI_TARGET_MODE_read; \
	COMMAND func11_DI_TARGET_MODE_write; \
	COLLECTION func11_DI_MODE_BLK; \
	VARIABLE func11_DI_MODE_BLK_Actual; \
	VARIABLE func11_DI_MODE_BLK_Permitted; \
	VARIABLE func11_DI_MODE_BLK_Normal; \
	MENU func11_DI_MODE_BLK_page; \
	COMMAND func11_DI_MODE_BLK_read; \
	COLLECTION func11_DI_ALARM_SUM; \
	VARIABLE func11_DI_ALARM_SUM_Current; \
	VARIABLE func11_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func11_DI_ALARM_SUM_Unreported; \
	VARIABLE func11_DI_ALARM_SUM_Disabled; \
	MENU func11_DI_ALARM_SUM_page; \
	COMMAND func11_DI_ALARM_SUM_read; \
	COLLECTION func11_DI_BATCH; \
	VARIABLE func11_DI_BATCH_Batch_ID; \
	VARIABLE func11_DI_BATCH_Rup; \
	VARIABLE func11_DI_BATCH_Operation; \
	VARIABLE func11_DI_BATCH_Phase; \
	MENU func11_DI_BATCH_page; \
	COMMAND func11_DI_BATCH_read; \
	COMMAND func11_DI_BATCH_write; \
	COLLECTION func11_DI_OUT_D; \
	VARIABLE func11_DI_OUT_D_Value; \
	VARIABLE func11_DI_OUT_D_Status_Condensed; \
	VARIABLE func11_DI_OUT_D_Status_Quality; \
	VARIABLE func11_DI_OUT_D_Status_Limit; \
	MENU func11_DI_OUT_D_page; \
	COMMAND func11_DI_OUT_D_read; \
	COMMAND func11_DI_OUT_D_write; \
	VARIABLE func11_DI_INVERT; \
	MENU func11_DI_INVERT_page; \
	COMMAND func11_DI_INVERT_read; \
	COMMAND func11_DI_INVERT_write; \
	VARIABLE func11_DI_FSAFE_VAL_D; \
	MENU func11_DI_FSAFE_VAL_D_page; \
	COMMAND func11_DI_FSAFE_VAL_D_read; \
	COMMAND func11_DI_FSAFE_VAL_D_write

#define USE_FUNC11_DI_MANDATORY_A \
	USE_FUNC11_DI_MANDATORY_BOTH; \
	MENU func11_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC11_DI_MANDATORY_B \
	USE_FUNC11_DI_MANDATORY_BOTH; \
	VARIABLE func11_DI_CHANNEL; \
	MENU func11_DI_CHANNEL_page; \
	COMMAND func11_DI_CHANNEL_read; \
	COMMAND func11_DI_CHANNEL_write; \
	VARIABLE func11_DI_FSAFE_TYPE; \
	MENU func11_DI_FSAFE_TYPE_page; \
	COMMAND func11_DI_FSAFE_TYPE_read; \
	COMMAND func11_DI_FSAFE_TYPE_write; \
	COLLECTION func11_DI_SIMULATE; \
	VARIABLE func11_DI_SIMULATE_Status_Condensed; \
	VARIABLE func11_DI_SIMULATE_Value; \
	VARIABLE func11_DI_SIMULATE_Enabled; \
	VARIABLE func11_DI_SIMULATE_Status_Quality; \
	VARIABLE func11_DI_SIMULATE_Status_Limit; \
	MENU func11_DI_SIMULATE_page; \
	COMMAND func11_DI_SIMULATE_read; \
	COMMAND func11_DI_SIMULATE_write; \
	COLLECTION func11_DI_VIEW_1; \
	MENU func11_DI_VIEW_1_page; \
	MENU func11_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC11_DI_OPTIONAL_BOTH \
	COLLECTION func11_DI_VIEW_2; \
	MENU func11_DI_VIEW_2_page; \
	COLLECTION func11_DI_VIEW_3; \
	MENU func11_DI_VIEW_3_page

#define USE_FUNC11_DI_OPTIONAL_A \
	USE_FUNC11_DI_OPTIONAL_BOTH; \
	VARIABLE func11_DI_CHANNEL; \
	MENU func11_DI_CHANNEL_page; \
	COMMAND func11_DI_CHANNEL_read; \
	COMMAND func11_DI_CHANNEL_write; \
	VARIABLE func11_DI_FSAFE_TYPE; \
	MENU func11_DI_FSAFE_TYPE_page; \
	COMMAND func11_DI_FSAFE_TYPE_read; \
	COMMAND func11_DI_FSAFE_TYPE_write; \
	COLLECTION func11_DI_SIMULATE; \
	VARIABLE func11_DI_SIMULATE_Status_Condensed; \
	VARIABLE func11_DI_SIMULATE_Value; \
	VARIABLE func11_DI_SIMULATE_Enabled; \
	VARIABLE func11_DI_SIMULATE_Status_Quality; \
	VARIABLE func11_DI_SIMULATE_Status_Limit; \
	MENU func11_DI_SIMULATE_page; \
	COMMAND func11_DI_SIMULATE_read; \
	COMMAND func11_DI_SIMULATE_write; \
	COLLECTION func11_DI_VIEW_1; \
	MENU func11_DI_VIEW_1_page; \
	MENU func11_DI_Simple_Dialog_Optional_A

#define USE_FUNC11_DI_OPTIONAL_B \
	USE_FUNC11_DI_OPTIONAL_BOTH; \
	MENU func11_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC11_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func11_DI_)
#define USE_FUNC11_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func11_DI_)
#define USE_FUNC11_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func11_DI_)
#define USE_FUNC11_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func11_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC12_DI_MANDATORY_BOTH \
	BLOCK func12_DI_block; \
	COLLECTION func12_DI_BLOCK_OBJECT; \
	VARIABLE func12_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func12_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func12_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func12_DI_BLOCK_OBJECT_Class; \
	VARIABLE func12_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func12_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func12_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func12_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func12_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func12_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func12_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func12_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func12_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func12_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func12_DI_BLOCK_OBJECT_page; \
	COMMAND func12_DI_BLOCK_OBJECT_read; \
	VARIABLE func12_DI_ST_REV; \
	MENU func12_DI_ST_REV_page; \
	COMMAND func12_DI_ST_REV_read; \
	VARIABLE func12_DI_TAG_DESC; \
	MENU func12_DI_TAG_DESC_page; \
	COMMAND func12_DI_TAG_DESC_read; \
	COMMAND func12_DI_TAG_DESC_write; \
	VARIABLE func12_DI_STRATEGY; \
	MENU func12_DI_STRATEGY_page; \
	COMMAND func12_DI_STRATEGY_read; \
	COMMAND func12_DI_STRATEGY_write; \
	VARIABLE func12_DI_ALERT_KEY; \
	MENU func12_DI_ALERT_KEY_page; \
	COMMAND func12_DI_ALERT_KEY_read; \
	COMMAND func12_DI_ALERT_KEY_write; \
	VARIABLE func12_DI_TARGET_MODE; \
	MENU func12_DI_TARGET_MODE_page; \
	COMMAND func12_DI_TARGET_MODE_read; \
	COMMAND func12_DI_TARGET_MODE_write; \
	COLLECTION func12_DI_MODE_BLK; \
	VARIABLE func12_DI_MODE_BLK_Actual; \
	VARIABLE func12_DI_MODE_BLK_Permitted; \
	VARIABLE func12_DI_MODE_BLK_Normal; \
	MENU func12_DI_MODE_BLK_page; \
	COMMAND func12_DI_MODE_BLK_read; \
	COLLECTION func12_DI_ALARM_SUM; \
	VARIABLE func12_DI_ALARM_SUM_Current; \
	VARIABLE func12_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func12_DI_ALARM_SUM_Unreported; \
	VARIABLE func12_DI_ALARM_SUM_Disabled; \
	MENU func12_DI_ALARM_SUM_page; \
	COMMAND func12_DI_ALARM_SUM_read; \
	COLLECTION func12_DI_BATCH; \
	VARIABLE func12_DI_BATCH_Batch_ID; \
	VARIABLE func12_DI_BATCH_Rup; \
	VARIABLE func12_DI_BATCH_Operation; \
	VARIABLE func12_DI_BATCH_Phase; \
	MENU func12_DI_BATCH_page; \
	COMMAND func12_DI_BATCH_read; \
	COMMAND func12_DI_BATCH_write; \
	COLLECTION func12_DI_OUT_D; \
	VARIABLE func12_DI_OUT_D_Value; \
	VARIABLE func12_DI_OUT_D_Status_Condensed; \
	VARIABLE func12_DI_OUT_D_Status_Quality; \
	VARIABLE func12_DI_OUT_D_Status_Limit; \
	MENU func12_DI_OUT_D_page; \
	COMMAND func12_DI_OUT_D_read; \
	COMMAND func12_DI_OUT_D_write; \
	VARIABLE func12_DI_INVERT; \
	MENU func12_DI_INVERT_page; \
	COMMAND func12_DI_INVERT_read; \
	COMMAND func12_DI_INVERT_write; \
	VARIABLE func12_DI_FSAFE_VAL_D; \
	MENU func12_DI_FSAFE_VAL_D_page; \
	COMMAND func12_DI_FSAFE_VAL_D_read; \
	COMMAND func12_DI_FSAFE_VAL_D_write

#define USE_FUNC12_DI_MANDATORY_A \
	USE_FUNC12_DI_MANDATORY_BOTH; \
	MENU func12_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC12_DI_MANDATORY_B \
	USE_FUNC12_DI_MANDATORY_BOTH; \
	VARIABLE func12_DI_CHANNEL; \
	MENU func12_DI_CHANNEL_page; \
	COMMAND func12_DI_CHANNEL_read; \
	COMMAND func12_DI_CHANNEL_write; \
	VARIABLE func12_DI_FSAFE_TYPE; \
	MENU func12_DI_FSAFE_TYPE_page; \
	COMMAND func12_DI_FSAFE_TYPE_read; \
	COMMAND func12_DI_FSAFE_TYPE_write; \
	COLLECTION func12_DI_SIMULATE; \
	VARIABLE func12_DI_SIMULATE_Status_Condensed; \
	VARIABLE func12_DI_SIMULATE_Value; \
	VARIABLE func12_DI_SIMULATE_Enabled; \
	VARIABLE func12_DI_SIMULATE_Status_Quality; \
	VARIABLE func12_DI_SIMULATE_Status_Limit; \
	MENU func12_DI_SIMULATE_page; \
	COMMAND func12_DI_SIMULATE_read; \
	COMMAND func12_DI_SIMULATE_write; \
	COLLECTION func12_DI_VIEW_1; \
	MENU func12_DI_VIEW_1_page; \
	MENU func12_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC12_DI_OPTIONAL_BOTH \
	COLLECTION func12_DI_VIEW_2; \
	MENU func12_DI_VIEW_2_page; \
	COLLECTION func12_DI_VIEW_3; \
	MENU func12_DI_VIEW_3_page

#define USE_FUNC12_DI_OPTIONAL_A \
	USE_FUNC12_DI_OPTIONAL_BOTH; \
	VARIABLE func12_DI_CHANNEL; \
	MENU func12_DI_CHANNEL_page; \
	COMMAND func12_DI_CHANNEL_read; \
	COMMAND func12_DI_CHANNEL_write; \
	VARIABLE func12_DI_FSAFE_TYPE; \
	MENU func12_DI_FSAFE_TYPE_page; \
	COMMAND func12_DI_FSAFE_TYPE_read; \
	COMMAND func12_DI_FSAFE_TYPE_write; \
	COLLECTION func12_DI_SIMULATE; \
	VARIABLE func12_DI_SIMULATE_Status_Condensed; \
	VARIABLE func12_DI_SIMULATE_Value; \
	VARIABLE func12_DI_SIMULATE_Enabled; \
	VARIABLE func12_DI_SIMULATE_Status_Quality; \
	VARIABLE func12_DI_SIMULATE_Status_Limit; \
	MENU func12_DI_SIMULATE_page; \
	COMMAND func12_DI_SIMULATE_read; \
	COMMAND func12_DI_SIMULATE_write; \
	COLLECTION func12_DI_VIEW_1; \
	MENU func12_DI_VIEW_1_page; \
	MENU func12_DI_Simple_Dialog_Optional_A

#define USE_FUNC12_DI_OPTIONAL_B \
	USE_FUNC12_DI_OPTIONAL_BOTH; \
	MENU func12_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC12_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func12_DI_)
#define USE_FUNC12_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func12_DI_)
#define USE_FUNC12_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func12_DI_)
#define USE_FUNC12_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func12_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC13_DI_MANDATORY_BOTH \
	BLOCK func13_DI_block; \
	COLLECTION func13_DI_BLOCK_OBJECT; \
	VARIABLE func13_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func13_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func13_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func13_DI_BLOCK_OBJECT_Class; \
	VARIABLE func13_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func13_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func13_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func13_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func13_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func13_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func13_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func13_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func13_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func13_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func13_DI_BLOCK_OBJECT_page; \
	COMMAND func13_DI_BLOCK_OBJECT_read; \
	VARIABLE func13_DI_ST_REV; \
	MENU func13_DI_ST_REV_page; \
	COMMAND func13_DI_ST_REV_read; \
	VARIABLE func13_DI_TAG_DESC; \
	MENU func13_DI_TAG_DESC_page; \
	COMMAND func13_DI_TAG_DESC_read; \
	COMMAND func13_DI_TAG_DESC_write; \
	VARIABLE func13_DI_STRATEGY; \
	MENU func13_DI_STRATEGY_page; \
	COMMAND func13_DI_STRATEGY_read; \
	COMMAND func13_DI_STRATEGY_write; \
	VARIABLE func13_DI_ALERT_KEY; \
	MENU func13_DI_ALERT_KEY_page; \
	COMMAND func13_DI_ALERT_KEY_read; \
	COMMAND func13_DI_ALERT_KEY_write; \
	VARIABLE func13_DI_TARGET_MODE; \
	MENU func13_DI_TARGET_MODE_page; \
	COMMAND func13_DI_TARGET_MODE_read; \
	COMMAND func13_DI_TARGET_MODE_write; \
	COLLECTION func13_DI_MODE_BLK; \
	VARIABLE func13_DI_MODE_BLK_Actual; \
	VARIABLE func13_DI_MODE_BLK_Permitted; \
	VARIABLE func13_DI_MODE_BLK_Normal; \
	MENU func13_DI_MODE_BLK_page; \
	COMMAND func13_DI_MODE_BLK_read; \
	COLLECTION func13_DI_ALARM_SUM; \
	VARIABLE func13_DI_ALARM_SUM_Current; \
	VARIABLE func13_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func13_DI_ALARM_SUM_Unreported; \
	VARIABLE func13_DI_ALARM_SUM_Disabled; \
	MENU func13_DI_ALARM_SUM_page; \
	COMMAND func13_DI_ALARM_SUM_read; \
	COLLECTION func13_DI_BATCH; \
	VARIABLE func13_DI_BATCH_Batch_ID; \
	VARIABLE func13_DI_BATCH_Rup; \
	VARIABLE func13_DI_BATCH_Operation; \
	VARIABLE func13_DI_BATCH_Phase; \
	MENU func13_DI_BATCH_page; \
	COMMAND func13_DI_BATCH_read; \
	COMMAND func13_DI_BATCH_write; \
	COLLECTION func13_DI_OUT_D; \
	VARIABLE func13_DI_OUT_D_Value; \
	VARIABLE func13_DI_OUT_D_Status_Condensed; \
	VARIABLE func13_DI_OUT_D_Status_Quality; \
	VARIABLE func13_DI_OUT_D_Status_Limit; \
	MENU func13_DI_OUT_D_page; \
	COMMAND func13_DI_OUT_D_read; \
	COMMAND func13_DI_OUT_D_write; \
	VARIABLE func13_DI_INVERT; \
	MENU func13_DI_INVERT_page; \
	COMMAND func13_DI_INVERT_read; \
	COMMAND func13_DI_INVERT_write; \
	VARIABLE func13_DI_FSAFE_VAL_D; \
	MENU func13_DI_FSAFE_VAL_D_page; \
	COMMAND func13_DI_FSAFE_VAL_D_read; \
	COMMAND func13_DI_FSAFE_VAL_D_write

#define USE_FUNC13_DI_MANDATORY_A \
	USE_FUNC13_DI_MANDATORY_BOTH; \
	MENU func13_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC13_DI_MANDATORY_B \
	USE_FUNC13_DI_MANDATORY_BOTH; \
	VARIABLE func13_DI_CHANNEL; \
	MENU func13_DI_CHANNEL_page; \
	COMMAND func13_DI_CHANNEL_read; \
	COMMAND func13_DI_CHANNEL_write; \
	VARIABLE func13_DI_FSAFE_TYPE; \
	MENU func13_DI_FSAFE_TYPE_page; \
	COMMAND func13_DI_FSAFE_TYPE_read; \
	COMMAND func13_DI_FSAFE_TYPE_write; \
	COLLECTION func13_DI_SIMULATE; \
	VARIABLE func13_DI_SIMULATE_Status_Condensed; \
	VARIABLE func13_DI_SIMULATE_Value; \
	VARIABLE func13_DI_SIMULATE_Enabled; \
	VARIABLE func13_DI_SIMULATE_Status_Quality; \
	VARIABLE func13_DI_SIMULATE_Status_Limit; \
	MENU func13_DI_SIMULATE_page; \
	COMMAND func13_DI_SIMULATE_read; \
	COMMAND func13_DI_SIMULATE_write; \
	COLLECTION func13_DI_VIEW_1; \
	MENU func13_DI_VIEW_1_page; \
	MENU func13_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC13_DI_OPTIONAL_BOTH \
	COLLECTION func13_DI_VIEW_2; \
	MENU func13_DI_VIEW_2_page; \
	COLLECTION func13_DI_VIEW_3; \
	MENU func13_DI_VIEW_3_page

#define USE_FUNC13_DI_OPTIONAL_A \
	USE_FUNC13_DI_OPTIONAL_BOTH; \
	VARIABLE func13_DI_CHANNEL; \
	MENU func13_DI_CHANNEL_page; \
	COMMAND func13_DI_CHANNEL_read; \
	COMMAND func13_DI_CHANNEL_write; \
	VARIABLE func13_DI_FSAFE_TYPE; \
	MENU func13_DI_FSAFE_TYPE_page; \
	COMMAND func13_DI_FSAFE_TYPE_read; \
	COMMAND func13_DI_FSAFE_TYPE_write; \
	COLLECTION func13_DI_SIMULATE; \
	VARIABLE func13_DI_SIMULATE_Status_Condensed; \
	VARIABLE func13_DI_SIMULATE_Value; \
	VARIABLE func13_DI_SIMULATE_Enabled; \
	VARIABLE func13_DI_SIMULATE_Status_Quality; \
	VARIABLE func13_DI_SIMULATE_Status_Limit; \
	MENU func13_DI_SIMULATE_page; \
	COMMAND func13_DI_SIMULATE_read; \
	COMMAND func13_DI_SIMULATE_write; \
	COLLECTION func13_DI_VIEW_1; \
	MENU func13_DI_VIEW_1_page; \
	MENU func13_DI_Simple_Dialog_Optional_A

#define USE_FUNC13_DI_OPTIONAL_B \
	USE_FUNC13_DI_OPTIONAL_BOTH; \
	MENU func13_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC13_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func13_DI_)
#define USE_FUNC13_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func13_DI_)
#define USE_FUNC13_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func13_DI_)
#define USE_FUNC13_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func13_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC14_DI_MANDATORY_BOTH \
	BLOCK func14_DI_block; \
	COLLECTION func14_DI_BLOCK_OBJECT; \
	VARIABLE func14_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func14_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func14_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func14_DI_BLOCK_OBJECT_Class; \
	VARIABLE func14_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func14_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func14_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func14_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func14_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func14_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func14_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func14_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func14_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func14_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func14_DI_BLOCK_OBJECT_page; \
	COMMAND func14_DI_BLOCK_OBJECT_read; \
	VARIABLE func14_DI_ST_REV; \
	MENU func14_DI_ST_REV_page; \
	COMMAND func14_DI_ST_REV_read; \
	VARIABLE func14_DI_TAG_DESC; \
	MENU func14_DI_TAG_DESC_page; \
	COMMAND func14_DI_TAG_DESC_read; \
	COMMAND func14_DI_TAG_DESC_write; \
	VARIABLE func14_DI_STRATEGY; \
	MENU func14_DI_STRATEGY_page; \
	COMMAND func14_DI_STRATEGY_read; \
	COMMAND func14_DI_STRATEGY_write; \
	VARIABLE func14_DI_ALERT_KEY; \
	MENU func14_DI_ALERT_KEY_page; \
	COMMAND func14_DI_ALERT_KEY_read; \
	COMMAND func14_DI_ALERT_KEY_write; \
	VARIABLE func14_DI_TARGET_MODE; \
	MENU func14_DI_TARGET_MODE_page; \
	COMMAND func14_DI_TARGET_MODE_read; \
	COMMAND func14_DI_TARGET_MODE_write; \
	COLLECTION func14_DI_MODE_BLK; \
	VARIABLE func14_DI_MODE_BLK_Actual; \
	VARIABLE func14_DI_MODE_BLK_Permitted; \
	VARIABLE func14_DI_MODE_BLK_Normal; \
	MENU func14_DI_MODE_BLK_page; \
	COMMAND func14_DI_MODE_BLK_read; \
	COLLECTION func14_DI_ALARM_SUM; \
	VARIABLE func14_DI_ALARM_SUM_Current; \
	VARIABLE func14_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func14_DI_ALARM_SUM_Unreported; \
	VARIABLE func14_DI_ALARM_SUM_Disabled; \
	MENU func14_DI_ALARM_SUM_page; \
	COMMAND func14_DI_ALARM_SUM_read; \
	COLLECTION func14_DI_BATCH; \
	VARIABLE func14_DI_BATCH_Batch_ID; \
	VARIABLE func14_DI_BATCH_Rup; \
	VARIABLE func14_DI_BATCH_Operation; \
	VARIABLE func14_DI_BATCH_Phase; \
	MENU func14_DI_BATCH_page; \
	COMMAND func14_DI_BATCH_read; \
	COMMAND func14_DI_BATCH_write; \
	COLLECTION func14_DI_OUT_D; \
	VARIABLE func14_DI_OUT_D_Value; \
	VARIABLE func14_DI_OUT_D_Status_Condensed; \
	VARIABLE func14_DI_OUT_D_Status_Quality; \
	VARIABLE func14_DI_OUT_D_Status_Limit; \
	MENU func14_DI_OUT_D_page; \
	COMMAND func14_DI_OUT_D_read; \
	COMMAND func14_DI_OUT_D_write; \
	VARIABLE func14_DI_INVERT; \
	MENU func14_DI_INVERT_page; \
	COMMAND func14_DI_INVERT_read; \
	COMMAND func14_DI_INVERT_write; \
	VARIABLE func14_DI_FSAFE_VAL_D; \
	MENU func14_DI_FSAFE_VAL_D_page; \
	COMMAND func14_DI_FSAFE_VAL_D_read; \
	COMMAND func14_DI_FSAFE_VAL_D_write

#define USE_FUNC14_DI_MANDATORY_A \
	USE_FUNC14_DI_MANDATORY_BOTH; \
	MENU func14_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC14_DI_MANDATORY_B \
	USE_FUNC14_DI_MANDATORY_BOTH; \
	VARIABLE func14_DI_CHANNEL; \
	MENU func14_DI_CHANNEL_page; \
	COMMAND func14_DI_CHANNEL_read; \
	COMMAND func14_DI_CHANNEL_write; \
	VARIABLE func14_DI_FSAFE_TYPE; \
	MENU func14_DI_FSAFE_TYPE_page; \
	COMMAND func14_DI_FSAFE_TYPE_read; \
	COMMAND func14_DI_FSAFE_TYPE_write; \
	COLLECTION func14_DI_SIMULATE; \
	VARIABLE func14_DI_SIMULATE_Status_Condensed; \
	VARIABLE func14_DI_SIMULATE_Value; \
	VARIABLE func14_DI_SIMULATE_Enabled; \
	VARIABLE func14_DI_SIMULATE_Status_Quality; \
	VARIABLE func14_DI_SIMULATE_Status_Limit; \
	MENU func14_DI_SIMULATE_page; \
	COMMAND func14_DI_SIMULATE_read; \
	COMMAND func14_DI_SIMULATE_write; \
	COLLECTION func14_DI_VIEW_1; \
	MENU func14_DI_VIEW_1_page; \
	MENU func14_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC14_DI_OPTIONAL_BOTH \
	COLLECTION func14_DI_VIEW_2; \
	MENU func14_DI_VIEW_2_page; \
	COLLECTION func14_DI_VIEW_3; \
	MENU func14_DI_VIEW_3_page

#define USE_FUNC14_DI_OPTIONAL_A \
	USE_FUNC14_DI_OPTIONAL_BOTH; \
	VARIABLE func14_DI_CHANNEL; \
	MENU func14_DI_CHANNEL_page; \
	COMMAND func14_DI_CHANNEL_read; \
	COMMAND func14_DI_CHANNEL_write; \
	VARIABLE func14_DI_FSAFE_TYPE; \
	MENU func14_DI_FSAFE_TYPE_page; \
	COMMAND func14_DI_FSAFE_TYPE_read; \
	COMMAND func14_DI_FSAFE_TYPE_write; \
	COLLECTION func14_DI_SIMULATE; \
	VARIABLE func14_DI_SIMULATE_Status_Condensed; \
	VARIABLE func14_DI_SIMULATE_Value; \
	VARIABLE func14_DI_SIMULATE_Enabled; \
	VARIABLE func14_DI_SIMULATE_Status_Quality; \
	VARIABLE func14_DI_SIMULATE_Status_Limit; \
	MENU func14_DI_SIMULATE_page; \
	COMMAND func14_DI_SIMULATE_read; \
	COMMAND func14_DI_SIMULATE_write; \
	COLLECTION func14_DI_VIEW_1; \
	MENU func14_DI_VIEW_1_page; \
	MENU func14_DI_Simple_Dialog_Optional_A

#define USE_FUNC14_DI_OPTIONAL_B \
	USE_FUNC14_DI_OPTIONAL_BOTH; \
	MENU func14_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC14_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func14_DI_)
#define USE_FUNC14_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func14_DI_)
#define USE_FUNC14_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func14_DI_)
#define USE_FUNC14_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func14_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC15_DI_MANDATORY_BOTH \
	BLOCK func15_DI_block; \
	COLLECTION func15_DI_BLOCK_OBJECT; \
	VARIABLE func15_DI_BLOCK_OBJECT_Reserved; \
	VARIABLE func15_DI_BLOCK_OBJECT_Block_Object; \
	VARIABLE func15_DI_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func15_DI_BLOCK_OBJECT_Class; \
	VARIABLE func15_DI_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func15_DI_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func15_DI_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func15_DI_BLOCK_OBJECT_Profile; \
	VARIABLE func15_DI_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func15_DI_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func15_DI_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func15_DI_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func15_DI_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func15_DI_BLOCK_OBJECT_Number_of_Views; \
	MENU func15_DI_BLOCK_OBJECT_page; \
	COMMAND func15_DI_BLOCK_OBJECT_read; \
	VARIABLE func15_DI_ST_REV; \
	MENU func15_DI_ST_REV_page; \
	COMMAND func15_DI_ST_REV_read; \
	VARIABLE func15_DI_TAG_DESC; \
	MENU func15_DI_TAG_DESC_page; \
	COMMAND func15_DI_TAG_DESC_read; \
	COMMAND func15_DI_TAG_DESC_write; \
	VARIABLE func15_DI_STRATEGY; \
	MENU func15_DI_STRATEGY_page; \
	COMMAND func15_DI_STRATEGY_read; \
	COMMAND func15_DI_STRATEGY_write; \
	VARIABLE func15_DI_ALERT_KEY; \
	MENU func15_DI_ALERT_KEY_page; \
	COMMAND func15_DI_ALERT_KEY_read; \
	COMMAND func15_DI_ALERT_KEY_write; \
	VARIABLE func15_DI_TARGET_MODE; \
	MENU func15_DI_TARGET_MODE_page; \
	COMMAND func15_DI_TARGET_MODE_read; \
	COMMAND func15_DI_TARGET_MODE_write; \
	COLLECTION func15_DI_MODE_BLK; \
	VARIABLE func15_DI_MODE_BLK_Actual; \
	VARIABLE func15_DI_MODE_BLK_Permitted; \
	VARIABLE func15_DI_MODE_BLK_Normal; \
	MENU func15_DI_MODE_BLK_page; \
	COMMAND func15_DI_MODE_BLK_read; \
	COLLECTION func15_DI_ALARM_SUM; \
	VARIABLE func15_DI_ALARM_SUM_Current; \
	VARIABLE func15_DI_ALARM_SUM_Unacknowledged; \
	VARIABLE func15_DI_ALARM_SUM_Unreported; \
	VARIABLE func15_DI_ALARM_SUM_Disabled; \
	MENU func15_DI_ALARM_SUM_page; \
	COMMAND func15_DI_ALARM_SUM_read; \
	COLLECTION func15_DI_BATCH; \
	VARIABLE func15_DI_BATCH_Batch_ID; \
	VARIABLE func15_DI_BATCH_Rup; \
	VARIABLE func15_DI_BATCH_Operation; \
	VARIABLE func15_DI_BATCH_Phase; \
	MENU func15_DI_BATCH_page; \
	COMMAND func15_DI_BATCH_read; \
	COMMAND func15_DI_BATCH_write; \
	COLLECTION func15_DI_OUT_D; \
	VARIABLE func15_DI_OUT_D_Value; \
	VARIABLE func15_DI_OUT_D_Status_Condensed; \
	VARIABLE func15_DI_OUT_D_Status_Quality; \
	VARIABLE func15_DI_OUT_D_Status_Limit; \
	MENU func15_DI_OUT_D_page; \
	COMMAND func15_DI_OUT_D_read; \
	COMMAND func15_DI_OUT_D_write; \
	VARIABLE func15_DI_INVERT; \
	MENU func15_DI_INVERT_page; \
	COMMAND func15_DI_INVERT_read; \
	COMMAND func15_DI_INVERT_write; \
	VARIABLE func15_DI_FSAFE_VAL_D; \
	MENU func15_DI_FSAFE_VAL_D_page; \
	COMMAND func15_DI_FSAFE_VAL_D_read; \
	COMMAND func15_DI_FSAFE_VAL_D_write

#define USE_FUNC15_DI_MANDATORY_A \
	USE_FUNC15_DI_MANDATORY_BOTH; \
	MENU func15_DI_Simple_Dialog_Mandatory_A

#define USE_FUNC15_DI_MANDATORY_B \
	USE_FUNC15_DI_MANDATORY_BOTH; \
	VARIABLE func15_DI_CHANNEL; \
	MENU func15_DI_CHANNEL_page; \
	COMMAND func15_DI_CHANNEL_read; \
	COMMAND func15_DI_CHANNEL_write; \
	VARIABLE func15_DI_FSAFE_TYPE; \
	MENU func15_DI_FSAFE_TYPE_page; \
	COMMAND func15_DI_FSAFE_TYPE_read; \
	COMMAND func15_DI_FSAFE_TYPE_write; \
	COLLECTION func15_DI_SIMULATE; \
	VARIABLE func15_DI_SIMULATE_Status_Condensed; \
	VARIABLE func15_DI_SIMULATE_Value; \
	VARIABLE func15_DI_SIMULATE_Enabled; \
	VARIABLE func15_DI_SIMULATE_Status_Quality; \
	VARIABLE func15_DI_SIMULATE_Status_Limit; \
	MENU func15_DI_SIMULATE_page; \
	COMMAND func15_DI_SIMULATE_read; \
	COMMAND func15_DI_SIMULATE_write; \
	COLLECTION func15_DI_VIEW_1; \
	MENU func15_DI_VIEW_1_page; \
	MENU func15_DI_Simple_Dialog_Mandatory_B

#define USE_FUNC15_DI_OPTIONAL_BOTH \
	COLLECTION func15_DI_VIEW_2; \
	MENU func15_DI_VIEW_2_page; \
	COLLECTION func15_DI_VIEW_3; \
	MENU func15_DI_VIEW_3_page

#define USE_FUNC15_DI_OPTIONAL_A \
	USE_FUNC15_DI_OPTIONAL_BOTH; \
	VARIABLE func15_DI_CHANNEL; \
	MENU func15_DI_CHANNEL_page; \
	COMMAND func15_DI_CHANNEL_read; \
	COMMAND func15_DI_CHANNEL_write; \
	VARIABLE func15_DI_FSAFE_TYPE; \
	MENU func15_DI_FSAFE_TYPE_page; \
	COMMAND func15_DI_FSAFE_TYPE_read; \
	COMMAND func15_DI_FSAFE_TYPE_write; \
	COLLECTION func15_DI_SIMULATE; \
	VARIABLE func15_DI_SIMULATE_Status_Condensed; \
	VARIABLE func15_DI_SIMULATE_Value; \
	VARIABLE func15_DI_SIMULATE_Enabled; \
	VARIABLE func15_DI_SIMULATE_Status_Quality; \
	VARIABLE func15_DI_SIMULATE_Status_Limit; \
	MENU func15_DI_SIMULATE_page; \
	COMMAND func15_DI_SIMULATE_read; \
	COMMAND func15_DI_SIMULATE_write; \
	COLLECTION func15_DI_VIEW_1; \
	MENU func15_DI_VIEW_1_page; \
	MENU func15_DI_Simple_Dialog_Optional_A

#define USE_FUNC15_DI_OPTIONAL_B \
	USE_FUNC15_DI_OPTIONAL_BOTH; \
	MENU func15_DI_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC15_DI_MANDATORY_A USE_FUNC_DI_MANDATORY_A(func15_DI_)
#define USE_FUNC15_DI_MANDATORY_B USE_FUNC_DI_MANDATORY_B(func15_DI_)
#define USE_FUNC15_DI_OPTIONAL_A  USE_FUNC_DI_OPTIONAL_A(func15_DI_)
#define USE_FUNC15_DI_OPTIONAL_B  USE_FUNC_DI_OPTIONAL_B(func15_DI_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC1_DO_MANDATORY_BOTH \
	BLOCK func1_DO_block; \
	COLLECTION func1_DO_BLOCK_OBJECT; \
	VARIABLE func1_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func1_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func1_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func1_DO_BLOCK_OBJECT_Class; \
	VARIABLE func1_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func1_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func1_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func1_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func1_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func1_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func1_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func1_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func1_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func1_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func1_DO_BLOCK_OBJECT_page; \
	COMMAND func1_DO_BLOCK_OBJECT_read; \
	VARIABLE func1_DO_ST_REV; \
	MENU func1_DO_ST_REV_page; \
	COMMAND func1_DO_ST_REV_read; \
	VARIABLE func1_DO_TAG_DESC; \
	MENU func1_DO_TAG_DESC_page; \
	COMMAND func1_DO_TAG_DESC_read; \
	COMMAND func1_DO_TAG_DESC_write; \
	VARIABLE func1_DO_STRATEGY; \
	MENU func1_DO_STRATEGY_page; \
	COMMAND func1_DO_STRATEGY_read; \
	COMMAND func1_DO_STRATEGY_write; \
	VARIABLE func1_DO_ALERT_KEY; \
	MENU func1_DO_ALERT_KEY_page; \
	COMMAND func1_DO_ALERT_KEY_read; \
	COMMAND func1_DO_ALERT_KEY_write; \
	VARIABLE func1_DO_TARGET_MODE; \
	MENU func1_DO_TARGET_MODE_page; \
	COMMAND func1_DO_TARGET_MODE_read; \
	COMMAND func1_DO_TARGET_MODE_write; \
	COLLECTION func1_DO_MODE_BLK; \
	VARIABLE func1_DO_MODE_BLK_Actual; \
	VARIABLE func1_DO_MODE_BLK_Permitted; \
	VARIABLE func1_DO_MODE_BLK_Normal; \
	MENU func1_DO_MODE_BLK_page; \
	COMMAND func1_DO_MODE_BLK_read; \
	COLLECTION func1_DO_ALARM_SUM; \
	VARIABLE func1_DO_ALARM_SUM_Current; \
	VARIABLE func1_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func1_DO_ALARM_SUM_Unreported; \
	VARIABLE func1_DO_ALARM_SUM_Disabled; \
	MENU func1_DO_ALARM_SUM_page; \
	COMMAND func1_DO_ALARM_SUM_read; \
	COLLECTION func1_DO_BATCH; \
	VARIABLE func1_DO_BATCH_Batch_ID; \
	VARIABLE func1_DO_BATCH_Rup; \
	VARIABLE func1_DO_BATCH_Operation; \
	VARIABLE func1_DO_BATCH_Phase; \
	MENU func1_DO_BATCH_page; \
	COMMAND func1_DO_BATCH_read; \
	COMMAND func1_DO_BATCH_write; \
	COLLECTION func1_DO_SP_D; \
	VARIABLE func1_DO_SP_D_Value; \
	VARIABLE func1_DO_SP_D_Status_Condensed; \
	VARIABLE func1_DO_SP_D_Status_Quality; \
	VARIABLE func1_DO_SP_D_Status_Limit; \
	MENU func1_DO_SP_D_page; \
	COMMAND func1_DO_SP_D_read; \
	COMMAND func1_DO_SP_D_write; \
	VARIABLE func1_DO_INVERT; \
	MENU func1_DO_INVERT_page; \
	COMMAND func1_DO_INVERT_read; \
	COMMAND func1_DO_INVERT_write; \
	VARIABLE func1_DO_CHECK_BACK; \
	MENU func1_DO_CHECK_BACK_page; \
	COMMAND func1_DO_CHECK_BACK_read; \
	VARIABLE func1_DO_CHECK_BACK_MASK; \
	MENU func1_DO_CHECK_BACK_MASK_page; \
	COMMAND func1_DO_CHECK_BACK_MASK_read

#define USE_FUNC1_DO_MANDATORY_A \
	USE_FUNC1_DO_MANDATORY_BOTH; \
	MENU func1_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC1_DO_MANDATORY_B \
	USE_FUNC1_DO_MANDATORY_BOTH; \
	COLLECTION func1_DO_OUT_D; \
	VARIABLE func1_DO_OUT_D_Value; \
	VARIABLE func1_DO_OUT_D_Status_Condensed; \
	VARIABLE func1_DO_OUT_D_Status_Quality; \
	VARIABLE func1_DO_OUT_D_Status_Limit; \
	MENU func1_DO_OUT_D_page; \
	COMMAND func1_DO_OUT_D_read; \
	COMMAND func1_DO_OUT_D_write; \
	VARIABLE func1_DO_IN_CHANNEL; \
	MENU func1_DO_IN_CHANNEL_page; \
	COMMAND func1_DO_IN_CHANNEL_read; \
	COMMAND func1_DO_IN_CHANNEL_write; \
	VARIABLE func1_DO_FSAFE_TIME; \
	MENU func1_DO_FSAFE_TIME_page; \
	COMMAND func1_DO_FSAFE_TIME_read; \
	COMMAND func1_DO_FSAFE_TIME_write; \
	VARIABLE func1_DO_FSAFE_TYPE; \
	MENU func1_DO_FSAFE_TYPE_page; \
	COMMAND func1_DO_FSAFE_TYPE_read; \
	COMMAND func1_DO_FSAFE_TYPE_write; \
	VARIABLE func1_DO_FSAFE_VAL_D; \
	MENU func1_DO_FSAFE_VAL_D_page; \
	COMMAND func1_DO_FSAFE_VAL_D_read; \
	COMMAND func1_DO_FSAFE_VAL_D_write; \
	COLLECTION func1_DO_SIMULATE; \
	VARIABLE func1_DO_SIMULATE_Status_Condensed; \
	VARIABLE func1_DO_SIMULATE_Value; \
	VARIABLE func1_DO_SIMULATE_Enabled; \
	VARIABLE func1_DO_SIMULATE_Status_Quality; \
	VARIABLE func1_DO_SIMULATE_Status_Limit; \
	MENU func1_DO_SIMULATE_page; \
	COMMAND func1_DO_SIMULATE_read; \
	COMMAND func1_DO_SIMULATE_write; \
	COLLECTION func1_DO_VIEW_1; \
	MENU func1_DO_VIEW_1_page; \
	MENU func1_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC1_DO_OPTIONAL_BOTH \
	COLLECTION func1_DO_READBACK_D; \
	VARIABLE func1_DO_READBACK_D_Value; \
	VARIABLE func1_DO_READBACK_D_Status_Condensed; \
	VARIABLE func1_DO_READBACK_D_Status_Quality; \
	VARIABLE func1_DO_READBACK_D_Status_Limit; \
	MENU func1_DO_READBACK_D_page; \
	COMMAND func1_DO_READBACK_D_read; \
	COLLECTION func1_DO_RCAS_IN_D; \
	VARIABLE func1_DO_RCAS_IN_D_Value; \
	VARIABLE func1_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func1_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func1_DO_RCAS_IN_D_Status_Limit; \
	MENU func1_DO_RCAS_IN_D_page; \
	COMMAND func1_DO_RCAS_IN_D_read; \
	COMMAND func1_DO_RCAS_IN_D_write; \
	COLLECTION func1_DO_RCAS_OUT_D; \
	VARIABLE func1_DO_RCAS_OUT_D_Value; \
	VARIABLE func1_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func1_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func1_DO_RCAS_OUT_D_Status_Limit; \
	MENU func1_DO_RCAS_OUT_D_page; \
	COMMAND func1_DO_RCAS_OUT_D_read; \
	VARIABLE func1_DO_OUT_CHANNEL; \
	MENU func1_DO_OUT_CHANNEL_page; \
	COMMAND func1_DO_OUT_CHANNEL_read; \
	COMMAND func1_DO_OUT_CHANNEL_write; \
	COLLECTION func1_DO_VIEW_2; \
	MENU func1_DO_VIEW_2_page; \
	COLLECTION func1_DO_VIEW_3; \
	MENU func1_DO_VIEW_3_page

#define USE_FUNC1_DO_OPTIONAL_A \
	USE_FUNC1_DO_OPTIONAL_BOTH; \
	COLLECTION func1_DO_OUT_D; \
	VARIABLE func1_DO_OUT_D_Value; \
	VARIABLE func1_DO_OUT_D_Status_Condensed; \
	VARIABLE func1_DO_OUT_D_Status_Quality; \
	VARIABLE func1_DO_OUT_D_Status_Limit; \
	MENU func1_DO_OUT_D_page; \
	COMMAND func1_DO_OUT_D_read; \
	COMMAND func1_DO_OUT_D_write; \
	VARIABLE func1_DO_IN_CHANNEL; \
	MENU func1_DO_IN_CHANNEL_page; \
	COMMAND func1_DO_IN_CHANNEL_read; \
	COMMAND func1_DO_IN_CHANNEL_write; \
	VARIABLE func1_DO_FSAFE_TIME; \
	MENU func1_DO_FSAFE_TIME_page; \
	COMMAND func1_DO_FSAFE_TIME_read; \
	COMMAND func1_DO_FSAFE_TIME_write; \
	VARIABLE func1_DO_FSAFE_TYPE; \
	MENU func1_DO_FSAFE_TYPE_page; \
	COMMAND func1_DO_FSAFE_TYPE_read; \
	COMMAND func1_DO_FSAFE_TYPE_write; \
	VARIABLE func1_DO_FSAFE_VAL_D; \
	MENU func1_DO_FSAFE_VAL_D_page; \
	COMMAND func1_DO_FSAFE_VAL_D_read; \
	COMMAND func1_DO_FSAFE_VAL_D_write; \
	COLLECTION func1_DO_SIMULATE; \
	VARIABLE func1_DO_SIMULATE_Status_Condensed; \
	VARIABLE func1_DO_SIMULATE_Value; \
	VARIABLE func1_DO_SIMULATE_Enabled; \
	VARIABLE func1_DO_SIMULATE_Status_Quality; \
	VARIABLE func1_DO_SIMULATE_Status_Limit; \
	MENU func1_DO_SIMULATE_page; \
	COMMAND func1_DO_SIMULATE_read; \
	COMMAND func1_DO_SIMULATE_write; \
	COLLECTION func1_DO_VIEW_1; \
	MENU func1_DO_VIEW_1_page; \
	MENU func1_DO_Simple_Dialog_Optional_A

#define USE_FUNC1_DO_OPTIONAL_B \
	USE_FUNC1_DO_OPTIONAL_BOTH; \
	MENU func1_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC_DO_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## BATCH; \
	VARIABLE prefix ## BATCH_Batch_ID; \
	VARIABLE prefix ## BATCH_Rup; \
	VARIABLE prefix ## BATCH_Operation; \
	VARIABLE prefix ## BATCH_Phase; \
	MENU prefix ## BATCH_page; \
	COMMAND prefix ## BATCH_read; \
	COMMAND prefix ## BATCH_write; \
	COLLECTION prefix ## SP_D; \
	VARIABLE prefix ## SP_D_Value; \
	VARIABLE prefix ## SP_D_Status_Condensed; \
	VARIABLE prefix ## SP_D_Status_Quality; \
	VARIABLE prefix ## SP_D_Status_Limit; \
	MENU prefix ## SP_D_page; \
	COMMAND prefix ## SP_D_read; \
	COMMAND prefix ## SP_D_write; \
	VARIABLE prefix ## INVERT; \
	MENU prefix ## INVERT_page; \
	COMMAND prefix ## INVERT_read; \
	COMMAND prefix ## INVERT_write; \
	VARIABLE prefix ## CHECK_BACK; \
	MENU prefix ## CHECK_BACK_page; \
	COMMAND prefix ## CHECK_BACK_read; \
	VARIABLE prefix ## CHECK_BACK_MASK; \
	MENU prefix ## CHECK_BACK_MASK_page; \
	COMMAND prefix ## CHECK_BACK_MASK_read

#define USE_FUNC_DO_MANDATORY_A(prefix) \
	USE_FUNC_DO_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_FUNC_DO_MANDATORY_B(prefix) \
	USE_FUNC_DO_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## OUT_D; \
	VARIABLE prefix ## OUT_D_Value; \
	VARIABLE prefix ## OUT_D_Status_Condensed; \
	VARIABLE prefix ## OUT_D_Status_Quality; \
	VARIABLE prefix ## OUT_D_Status_Limit; \
	MENU prefix ## OUT_D_page; \
	COMMAND prefix ## OUT_D_read; \
	COMMAND prefix ## OUT_D_write; \
	VARIABLE prefix ## IN_CHANNEL; \
	MENU prefix ## IN_CHANNEL_page; \
	COMMAND prefix ## IN_CHANNEL_read; \
	COMMAND prefix ## IN_CHANNEL_write; \
	VARIABLE prefix ## FSAFE_TIME; \
	MENU prefix ## FSAFE_TIME_page; \
	COMMAND prefix ## FSAFE_TIME_read; \
	COMMAND prefix ## FSAFE_TIME_write; \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	VARIABLE prefix ## FSAFE_VAL_D; \
	MENU prefix ## FSAFE_VAL_D_page; \
	COMMAND prefix ## FSAFE_VAL_D_read; \
	COMMAND prefix ## FSAFE_VAL_D_write; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_FUNC_DO_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## READBACK_D; \
	VARIABLE prefix ## READBACK_D_Value; \
	VARIABLE prefix ## READBACK_D_Status_Condensed; \
	VARIABLE prefix ## READBACK_D_Status_Quality; \
	VARIABLE prefix ## READBACK_D_Status_Limit; \
	MENU prefix ## READBACK_D_page; \
	COMMAND prefix ## READBACK_D_read; \
	COLLECTION prefix ## RCAS_IN_D; \
	VARIABLE prefix ## RCAS_IN_D_Value; \
	VARIABLE prefix ## RCAS_IN_D_Status_Condensed; \
	VARIABLE prefix ## RCAS_IN_D_Status_Quality; \
	VARIABLE prefix ## RCAS_IN_D_Status_Limit; \
	MENU prefix ## RCAS_IN_D_page; \
	COMMAND prefix ## RCAS_IN_D_read; \
	COMMAND prefix ## RCAS_IN_D_write; \
	COLLECTION prefix ## RCAS_OUT_D; \
	VARIABLE prefix ## RCAS_OUT_D_Value; \
	VARIABLE prefix ## RCAS_OUT_D_Status_Condensed; \
	VARIABLE prefix ## RCAS_OUT_D_Status_Quality; \
	VARIABLE prefix ## RCAS_OUT_D_Status_Limit; \
	MENU prefix ## RCAS_OUT_D_page; \
	COMMAND prefix ## RCAS_OUT_D_read; \
	VARIABLE prefix ## OUT_CHANNEL; \
	MENU prefix ## OUT_CHANNEL_page; \
	COMMAND prefix ## OUT_CHANNEL_read; \
	COMMAND prefix ## OUT_CHANNEL_write; \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_FUNC_DO_OPTIONAL_A(prefix) \
	USE_FUNC_DO_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## OUT_D; \
	VARIABLE prefix ## OUT_D_Value; \
	VARIABLE prefix ## OUT_D_Status_Condensed; \
	VARIABLE prefix ## OUT_D_Status_Quality; \
	VARIABLE prefix ## OUT_D_Status_Limit; \
	MENU prefix ## OUT_D_page; \
	COMMAND prefix ## OUT_D_read; \
	COMMAND prefix ## OUT_D_write; \
	VARIABLE prefix ## IN_CHANNEL; \
	MENU prefix ## IN_CHANNEL_page; \
	COMMAND prefix ## IN_CHANNEL_read; \
	COMMAND prefix ## IN_CHANNEL_write; \
	VARIABLE prefix ## FSAFE_TIME; \
	MENU prefix ## FSAFE_TIME_page; \
	COMMAND prefix ## FSAFE_TIME_read; \
	COMMAND prefix ## FSAFE_TIME_write; \
	VARIABLE prefix ## FSAFE_TYPE; \
	MENU prefix ## FSAFE_TYPE_page; \
	COMMAND prefix ## FSAFE_TYPE_read; \
	COMMAND prefix ## FSAFE_TYPE_write; \
	VARIABLE prefix ## FSAFE_VAL_D; \
	MENU prefix ## FSAFE_VAL_D_page; \
	COMMAND prefix ## FSAFE_VAL_D_read; \
	COMMAND prefix ## FSAFE_VAL_D_write; \
	COLLECTION prefix ## SIMULATE; \
	VARIABLE prefix ## SIMULATE_Status_Condensed; \
	VARIABLE prefix ## SIMULATE_Value; \
	VARIABLE prefix ## SIMULATE_Enabled; \
	VARIABLE prefix ## SIMULATE_Status_Quality; \
	VARIABLE prefix ## SIMULATE_Status_Limit; \
	MENU prefix ## SIMULATE_page; \
	COMMAND prefix ## SIMULATE_read; \
	COMMAND prefix ## SIMULATE_write; \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_FUNC_DO_OPTIONAL_B(prefix) \
	USE_FUNC_DO_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_FUNC1_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func1_DO_)
#define USE_FUNC1_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func1_DO_)
#define USE_FUNC1_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func1_DO_)
#define USE_FUNC1_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func1_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC2_DO_MANDATORY_BOTH \
	BLOCK func2_DO_block; \
	COLLECTION func2_DO_BLOCK_OBJECT; \
	VARIABLE func2_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func2_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func2_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func2_DO_BLOCK_OBJECT_Class; \
	VARIABLE func2_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func2_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func2_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func2_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func2_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func2_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func2_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func2_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func2_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func2_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func2_DO_BLOCK_OBJECT_page; \
	COMMAND func2_DO_BLOCK_OBJECT_read; \
	VARIABLE func2_DO_ST_REV; \
	MENU func2_DO_ST_REV_page; \
	COMMAND func2_DO_ST_REV_read; \
	VARIABLE func2_DO_TAG_DESC; \
	MENU func2_DO_TAG_DESC_page; \
	COMMAND func2_DO_TAG_DESC_read; \
	COMMAND func2_DO_TAG_DESC_write; \
	VARIABLE func2_DO_STRATEGY; \
	MENU func2_DO_STRATEGY_page; \
	COMMAND func2_DO_STRATEGY_read; \
	COMMAND func2_DO_STRATEGY_write; \
	VARIABLE func2_DO_ALERT_KEY; \
	MENU func2_DO_ALERT_KEY_page; \
	COMMAND func2_DO_ALERT_KEY_read; \
	COMMAND func2_DO_ALERT_KEY_write; \
	VARIABLE func2_DO_TARGET_MODE; \
	MENU func2_DO_TARGET_MODE_page; \
	COMMAND func2_DO_TARGET_MODE_read; \
	COMMAND func2_DO_TARGET_MODE_write; \
	COLLECTION func2_DO_MODE_BLK; \
	VARIABLE func2_DO_MODE_BLK_Actual; \
	VARIABLE func2_DO_MODE_BLK_Permitted; \
	VARIABLE func2_DO_MODE_BLK_Normal; \
	MENU func2_DO_MODE_BLK_page; \
	COMMAND func2_DO_MODE_BLK_read; \
	COLLECTION func2_DO_ALARM_SUM; \
	VARIABLE func2_DO_ALARM_SUM_Current; \
	VARIABLE func2_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func2_DO_ALARM_SUM_Unreported; \
	VARIABLE func2_DO_ALARM_SUM_Disabled; \
	MENU func2_DO_ALARM_SUM_page; \
	COMMAND func2_DO_ALARM_SUM_read; \
	COLLECTION func2_DO_BATCH; \
	VARIABLE func2_DO_BATCH_Batch_ID; \
	VARIABLE func2_DO_BATCH_Rup; \
	VARIABLE func2_DO_BATCH_Operation; \
	VARIABLE func2_DO_BATCH_Phase; \
	MENU func2_DO_BATCH_page; \
	COMMAND func2_DO_BATCH_read; \
	COMMAND func2_DO_BATCH_write; \
	COLLECTION func2_DO_SP_D; \
	VARIABLE func2_DO_SP_D_Value; \
	VARIABLE func2_DO_SP_D_Status_Condensed; \
	VARIABLE func2_DO_SP_D_Status_Quality; \
	VARIABLE func2_DO_SP_D_Status_Limit; \
	MENU func2_DO_SP_D_page; \
	COMMAND func2_DO_SP_D_read; \
	COMMAND func2_DO_SP_D_write; \
	VARIABLE func2_DO_INVERT; \
	MENU func2_DO_INVERT_page; \
	COMMAND func2_DO_INVERT_read; \
	COMMAND func2_DO_INVERT_write; \
	VARIABLE func2_DO_CHECK_BACK; \
	MENU func2_DO_CHECK_BACK_page; \
	COMMAND func2_DO_CHECK_BACK_read; \
	VARIABLE func2_DO_CHECK_BACK_MASK; \
	MENU func2_DO_CHECK_BACK_MASK_page; \
	COMMAND func2_DO_CHECK_BACK_MASK_read

#define USE_FUNC2_DO_MANDATORY_A \
	USE_FUNC2_DO_MANDATORY_BOTH; \
	MENU func2_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC2_DO_MANDATORY_B \
	USE_FUNC2_DO_MANDATORY_BOTH; \
	COLLECTION func2_DO_OUT_D; \
	VARIABLE func2_DO_OUT_D_Value; \
	VARIABLE func2_DO_OUT_D_Status_Condensed; \
	VARIABLE func2_DO_OUT_D_Status_Quality; \
	VARIABLE func2_DO_OUT_D_Status_Limit; \
	MENU func2_DO_OUT_D_page; \
	COMMAND func2_DO_OUT_D_read; \
	COMMAND func2_DO_OUT_D_write; \
	VARIABLE func2_DO_IN_CHANNEL; \
	MENU func2_DO_IN_CHANNEL_page; \
	COMMAND func2_DO_IN_CHANNEL_read; \
	COMMAND func2_DO_IN_CHANNEL_write; \
	VARIABLE func2_DO_FSAFE_TIME; \
	MENU func2_DO_FSAFE_TIME_page; \
	COMMAND func2_DO_FSAFE_TIME_read; \
	COMMAND func2_DO_FSAFE_TIME_write; \
	VARIABLE func2_DO_FSAFE_TYPE; \
	MENU func2_DO_FSAFE_TYPE_page; \
	COMMAND func2_DO_FSAFE_TYPE_read; \
	COMMAND func2_DO_FSAFE_TYPE_write; \
	VARIABLE func2_DO_FSAFE_VAL_D; \
	MENU func2_DO_FSAFE_VAL_D_page; \
	COMMAND func2_DO_FSAFE_VAL_D_read; \
	COMMAND func2_DO_FSAFE_VAL_D_write; \
	COLLECTION func2_DO_SIMULATE; \
	VARIABLE func2_DO_SIMULATE_Status_Condensed; \
	VARIABLE func2_DO_SIMULATE_Value; \
	VARIABLE func2_DO_SIMULATE_Enabled; \
	VARIABLE func2_DO_SIMULATE_Status_Quality; \
	VARIABLE func2_DO_SIMULATE_Status_Limit; \
	MENU func2_DO_SIMULATE_page; \
	COMMAND func2_DO_SIMULATE_read; \
	COMMAND func2_DO_SIMULATE_write; \
	COLLECTION func2_DO_VIEW_1; \
	MENU func2_DO_VIEW_1_page; \
	MENU func2_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC2_DO_OPTIONAL_BOTH \
	COLLECTION func2_DO_READBACK_D; \
	VARIABLE func2_DO_READBACK_D_Value; \
	VARIABLE func2_DO_READBACK_D_Status_Condensed; \
	VARIABLE func2_DO_READBACK_D_Status_Quality; \
	VARIABLE func2_DO_READBACK_D_Status_Limit; \
	MENU func2_DO_READBACK_D_page; \
	COMMAND func2_DO_READBACK_D_read; \
	COLLECTION func2_DO_RCAS_IN_D; \
	VARIABLE func2_DO_RCAS_IN_D_Value; \
	VARIABLE func2_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func2_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func2_DO_RCAS_IN_D_Status_Limit; \
	MENU func2_DO_RCAS_IN_D_page; \
	COMMAND func2_DO_RCAS_IN_D_read; \
	COMMAND func2_DO_RCAS_IN_D_write; \
	COLLECTION func2_DO_RCAS_OUT_D; \
	VARIABLE func2_DO_RCAS_OUT_D_Value; \
	VARIABLE func2_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func2_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func2_DO_RCAS_OUT_D_Status_Limit; \
	MENU func2_DO_RCAS_OUT_D_page; \
	COMMAND func2_DO_RCAS_OUT_D_read; \
	VARIABLE func2_DO_OUT_CHANNEL; \
	MENU func2_DO_OUT_CHANNEL_page; \
	COMMAND func2_DO_OUT_CHANNEL_read; \
	COMMAND func2_DO_OUT_CHANNEL_write; \
	COLLECTION func2_DO_VIEW_2; \
	MENU func2_DO_VIEW_2_page; \
	COLLECTION func2_DO_VIEW_3; \
	MENU func2_DO_VIEW_3_page

#define USE_FUNC2_DO_OPTIONAL_A \
	USE_FUNC2_DO_OPTIONAL_BOTH; \
	COLLECTION func2_DO_OUT_D; \
	VARIABLE func2_DO_OUT_D_Value; \
	VARIABLE func2_DO_OUT_D_Status_Condensed; \
	VARIABLE func2_DO_OUT_D_Status_Quality; \
	VARIABLE func2_DO_OUT_D_Status_Limit; \
	MENU func2_DO_OUT_D_page; \
	COMMAND func2_DO_OUT_D_read; \
	COMMAND func2_DO_OUT_D_write; \
	VARIABLE func2_DO_IN_CHANNEL; \
	MENU func2_DO_IN_CHANNEL_page; \
	COMMAND func2_DO_IN_CHANNEL_read; \
	COMMAND func2_DO_IN_CHANNEL_write; \
	VARIABLE func2_DO_FSAFE_TIME; \
	MENU func2_DO_FSAFE_TIME_page; \
	COMMAND func2_DO_FSAFE_TIME_read; \
	COMMAND func2_DO_FSAFE_TIME_write; \
	VARIABLE func2_DO_FSAFE_TYPE; \
	MENU func2_DO_FSAFE_TYPE_page; \
	COMMAND func2_DO_FSAFE_TYPE_read; \
	COMMAND func2_DO_FSAFE_TYPE_write; \
	VARIABLE func2_DO_FSAFE_VAL_D; \
	MENU func2_DO_FSAFE_VAL_D_page; \
	COMMAND func2_DO_FSAFE_VAL_D_read; \
	COMMAND func2_DO_FSAFE_VAL_D_write; \
	COLLECTION func2_DO_SIMULATE; \
	VARIABLE func2_DO_SIMULATE_Status_Condensed; \
	VARIABLE func2_DO_SIMULATE_Value; \
	VARIABLE func2_DO_SIMULATE_Enabled; \
	VARIABLE func2_DO_SIMULATE_Status_Quality; \
	VARIABLE func2_DO_SIMULATE_Status_Limit; \
	MENU func2_DO_SIMULATE_page; \
	COMMAND func2_DO_SIMULATE_read; \
	COMMAND func2_DO_SIMULATE_write; \
	COLLECTION func2_DO_VIEW_1; \
	MENU func2_DO_VIEW_1_page; \
	MENU func2_DO_Simple_Dialog_Optional_A

#define USE_FUNC2_DO_OPTIONAL_B \
	USE_FUNC2_DO_OPTIONAL_BOTH; \
	MENU func2_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC2_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func2_DO_)
#define USE_FUNC2_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func2_DO_)
#define USE_FUNC2_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func2_DO_)
#define USE_FUNC2_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func2_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC3_DO_MANDATORY_BOTH \
	BLOCK func3_DO_block; \
	COLLECTION func3_DO_BLOCK_OBJECT; \
	VARIABLE func3_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func3_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func3_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func3_DO_BLOCK_OBJECT_Class; \
	VARIABLE func3_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func3_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func3_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func3_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func3_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func3_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func3_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func3_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func3_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func3_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func3_DO_BLOCK_OBJECT_page; \
	COMMAND func3_DO_BLOCK_OBJECT_read; \
	VARIABLE func3_DO_ST_REV; \
	MENU func3_DO_ST_REV_page; \
	COMMAND func3_DO_ST_REV_read; \
	VARIABLE func3_DO_TAG_DESC; \
	MENU func3_DO_TAG_DESC_page; \
	COMMAND func3_DO_TAG_DESC_read; \
	COMMAND func3_DO_TAG_DESC_write; \
	VARIABLE func3_DO_STRATEGY; \
	MENU func3_DO_STRATEGY_page; \
	COMMAND func3_DO_STRATEGY_read; \
	COMMAND func3_DO_STRATEGY_write; \
	VARIABLE func3_DO_ALERT_KEY; \
	MENU func3_DO_ALERT_KEY_page; \
	COMMAND func3_DO_ALERT_KEY_read; \
	COMMAND func3_DO_ALERT_KEY_write; \
	VARIABLE func3_DO_TARGET_MODE; \
	MENU func3_DO_TARGET_MODE_page; \
	COMMAND func3_DO_TARGET_MODE_read; \
	COMMAND func3_DO_TARGET_MODE_write; \
	COLLECTION func3_DO_MODE_BLK; \
	VARIABLE func3_DO_MODE_BLK_Actual; \
	VARIABLE func3_DO_MODE_BLK_Permitted; \
	VARIABLE func3_DO_MODE_BLK_Normal; \
	MENU func3_DO_MODE_BLK_page; \
	COMMAND func3_DO_MODE_BLK_read; \
	COLLECTION func3_DO_ALARM_SUM; \
	VARIABLE func3_DO_ALARM_SUM_Current; \
	VARIABLE func3_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func3_DO_ALARM_SUM_Unreported; \
	VARIABLE func3_DO_ALARM_SUM_Disabled; \
	MENU func3_DO_ALARM_SUM_page; \
	COMMAND func3_DO_ALARM_SUM_read; \
	COLLECTION func3_DO_BATCH; \
	VARIABLE func3_DO_BATCH_Batch_ID; \
	VARIABLE func3_DO_BATCH_Rup; \
	VARIABLE func3_DO_BATCH_Operation; \
	VARIABLE func3_DO_BATCH_Phase; \
	MENU func3_DO_BATCH_page; \
	COMMAND func3_DO_BATCH_read; \
	COMMAND func3_DO_BATCH_write; \
	COLLECTION func3_DO_SP_D; \
	VARIABLE func3_DO_SP_D_Value; \
	VARIABLE func3_DO_SP_D_Status_Condensed; \
	VARIABLE func3_DO_SP_D_Status_Quality; \
	VARIABLE func3_DO_SP_D_Status_Limit; \
	MENU func3_DO_SP_D_page; \
	COMMAND func3_DO_SP_D_read; \
	COMMAND func3_DO_SP_D_write; \
	VARIABLE func3_DO_INVERT; \
	MENU func3_DO_INVERT_page; \
	COMMAND func3_DO_INVERT_read; \
	COMMAND func3_DO_INVERT_write; \
	VARIABLE func3_DO_CHECK_BACK; \
	MENU func3_DO_CHECK_BACK_page; \
	COMMAND func3_DO_CHECK_BACK_read; \
	VARIABLE func3_DO_CHECK_BACK_MASK; \
	MENU func3_DO_CHECK_BACK_MASK_page; \
	COMMAND func3_DO_CHECK_BACK_MASK_read

#define USE_FUNC3_DO_MANDATORY_A \
	USE_FUNC3_DO_MANDATORY_BOTH; \
	MENU func3_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC3_DO_MANDATORY_B \
	USE_FUNC3_DO_MANDATORY_BOTH; \
	COLLECTION func3_DO_OUT_D; \
	VARIABLE func3_DO_OUT_D_Value; \
	VARIABLE func3_DO_OUT_D_Status_Condensed; \
	VARIABLE func3_DO_OUT_D_Status_Quality; \
	VARIABLE func3_DO_OUT_D_Status_Limit; \
	MENU func3_DO_OUT_D_page; \
	COMMAND func3_DO_OUT_D_read; \
	COMMAND func3_DO_OUT_D_write; \
	VARIABLE func3_DO_IN_CHANNEL; \
	MENU func3_DO_IN_CHANNEL_page; \
	COMMAND func3_DO_IN_CHANNEL_read; \
	COMMAND func3_DO_IN_CHANNEL_write; \
	VARIABLE func3_DO_FSAFE_TIME; \
	MENU func3_DO_FSAFE_TIME_page; \
	COMMAND func3_DO_FSAFE_TIME_read; \
	COMMAND func3_DO_FSAFE_TIME_write; \
	VARIABLE func3_DO_FSAFE_TYPE; \
	MENU func3_DO_FSAFE_TYPE_page; \
	COMMAND func3_DO_FSAFE_TYPE_read; \
	COMMAND func3_DO_FSAFE_TYPE_write; \
	VARIABLE func3_DO_FSAFE_VAL_D; \
	MENU func3_DO_FSAFE_VAL_D_page; \
	COMMAND func3_DO_FSAFE_VAL_D_read; \
	COMMAND func3_DO_FSAFE_VAL_D_write; \
	COLLECTION func3_DO_SIMULATE; \
	VARIABLE func3_DO_SIMULATE_Status_Condensed; \
	VARIABLE func3_DO_SIMULATE_Value; \
	VARIABLE func3_DO_SIMULATE_Enabled; \
	VARIABLE func3_DO_SIMULATE_Status_Quality; \
	VARIABLE func3_DO_SIMULATE_Status_Limit; \
	MENU func3_DO_SIMULATE_page; \
	COMMAND func3_DO_SIMULATE_read; \
	COMMAND func3_DO_SIMULATE_write; \
	COLLECTION func3_DO_VIEW_1; \
	MENU func3_DO_VIEW_1_page; \
	MENU func3_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC3_DO_OPTIONAL_BOTH \
	COLLECTION func3_DO_READBACK_D; \
	VARIABLE func3_DO_READBACK_D_Value; \
	VARIABLE func3_DO_READBACK_D_Status_Condensed; \
	VARIABLE func3_DO_READBACK_D_Status_Quality; \
	VARIABLE func3_DO_READBACK_D_Status_Limit; \
	MENU func3_DO_READBACK_D_page; \
	COMMAND func3_DO_READBACK_D_read; \
	COLLECTION func3_DO_RCAS_IN_D; \
	VARIABLE func3_DO_RCAS_IN_D_Value; \
	VARIABLE func3_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func3_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func3_DO_RCAS_IN_D_Status_Limit; \
	MENU func3_DO_RCAS_IN_D_page; \
	COMMAND func3_DO_RCAS_IN_D_read; \
	COMMAND func3_DO_RCAS_IN_D_write; \
	COLLECTION func3_DO_RCAS_OUT_D; \
	VARIABLE func3_DO_RCAS_OUT_D_Value; \
	VARIABLE func3_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func3_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func3_DO_RCAS_OUT_D_Status_Limit; \
	MENU func3_DO_RCAS_OUT_D_page; \
	COMMAND func3_DO_RCAS_OUT_D_read; \
	VARIABLE func3_DO_OUT_CHANNEL; \
	MENU func3_DO_OUT_CHANNEL_page; \
	COMMAND func3_DO_OUT_CHANNEL_read; \
	COMMAND func3_DO_OUT_CHANNEL_write; \
	COLLECTION func3_DO_VIEW_2; \
	MENU func3_DO_VIEW_2_page; \
	COLLECTION func3_DO_VIEW_3; \
	MENU func3_DO_VIEW_3_page

#define USE_FUNC3_DO_OPTIONAL_A \
	USE_FUNC3_DO_OPTIONAL_BOTH; \
	COLLECTION func3_DO_OUT_D; \
	VARIABLE func3_DO_OUT_D_Value; \
	VARIABLE func3_DO_OUT_D_Status_Condensed; \
	VARIABLE func3_DO_OUT_D_Status_Quality; \
	VARIABLE func3_DO_OUT_D_Status_Limit; \
	MENU func3_DO_OUT_D_page; \
	COMMAND func3_DO_OUT_D_read; \
	COMMAND func3_DO_OUT_D_write; \
	VARIABLE func3_DO_IN_CHANNEL; \
	MENU func3_DO_IN_CHANNEL_page; \
	COMMAND func3_DO_IN_CHANNEL_read; \
	COMMAND func3_DO_IN_CHANNEL_write; \
	VARIABLE func3_DO_FSAFE_TIME; \
	MENU func3_DO_FSAFE_TIME_page; \
	COMMAND func3_DO_FSAFE_TIME_read; \
	COMMAND func3_DO_FSAFE_TIME_write; \
	VARIABLE func3_DO_FSAFE_TYPE; \
	MENU func3_DO_FSAFE_TYPE_page; \
	COMMAND func3_DO_FSAFE_TYPE_read; \
	COMMAND func3_DO_FSAFE_TYPE_write; \
	VARIABLE func3_DO_FSAFE_VAL_D; \
	MENU func3_DO_FSAFE_VAL_D_page; \
	COMMAND func3_DO_FSAFE_VAL_D_read; \
	COMMAND func3_DO_FSAFE_VAL_D_write; \
	COLLECTION func3_DO_SIMULATE; \
	VARIABLE func3_DO_SIMULATE_Status_Condensed; \
	VARIABLE func3_DO_SIMULATE_Value; \
	VARIABLE func3_DO_SIMULATE_Enabled; \
	VARIABLE func3_DO_SIMULATE_Status_Quality; \
	VARIABLE func3_DO_SIMULATE_Status_Limit; \
	MENU func3_DO_SIMULATE_page; \
	COMMAND func3_DO_SIMULATE_read; \
	COMMAND func3_DO_SIMULATE_write; \
	COLLECTION func3_DO_VIEW_1; \
	MENU func3_DO_VIEW_1_page; \
	MENU func3_DO_Simple_Dialog_Optional_A

#define USE_FUNC3_DO_OPTIONAL_B \
	USE_FUNC3_DO_OPTIONAL_BOTH; \
	MENU func3_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC3_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func3_DO_)
#define USE_FUNC3_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func3_DO_)
#define USE_FUNC3_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func3_DO_)
#define USE_FUNC3_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func3_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC4_DO_MANDATORY_BOTH \
	BLOCK func4_DO_block; \
	COLLECTION func4_DO_BLOCK_OBJECT; \
	VARIABLE func4_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func4_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func4_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func4_DO_BLOCK_OBJECT_Class; \
	VARIABLE func4_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func4_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func4_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func4_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func4_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func4_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func4_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func4_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func4_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func4_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func4_DO_BLOCK_OBJECT_page; \
	COMMAND func4_DO_BLOCK_OBJECT_read; \
	VARIABLE func4_DO_ST_REV; \
	MENU func4_DO_ST_REV_page; \
	COMMAND func4_DO_ST_REV_read; \
	VARIABLE func4_DO_TAG_DESC; \
	MENU func4_DO_TAG_DESC_page; \
	COMMAND func4_DO_TAG_DESC_read; \
	COMMAND func4_DO_TAG_DESC_write; \
	VARIABLE func4_DO_STRATEGY; \
	MENU func4_DO_STRATEGY_page; \
	COMMAND func4_DO_STRATEGY_read; \
	COMMAND func4_DO_STRATEGY_write; \
	VARIABLE func4_DO_ALERT_KEY; \
	MENU func4_DO_ALERT_KEY_page; \
	COMMAND func4_DO_ALERT_KEY_read; \
	COMMAND func4_DO_ALERT_KEY_write; \
	VARIABLE func4_DO_TARGET_MODE; \
	MENU func4_DO_TARGET_MODE_page; \
	COMMAND func4_DO_TARGET_MODE_read; \
	COMMAND func4_DO_TARGET_MODE_write; \
	COLLECTION func4_DO_MODE_BLK; \
	VARIABLE func4_DO_MODE_BLK_Actual; \
	VARIABLE func4_DO_MODE_BLK_Permitted; \
	VARIABLE func4_DO_MODE_BLK_Normal; \
	MENU func4_DO_MODE_BLK_page; \
	COMMAND func4_DO_MODE_BLK_read; \
	COLLECTION func4_DO_ALARM_SUM; \
	VARIABLE func4_DO_ALARM_SUM_Current; \
	VARIABLE func4_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func4_DO_ALARM_SUM_Unreported; \
	VARIABLE func4_DO_ALARM_SUM_Disabled; \
	MENU func4_DO_ALARM_SUM_page; \
	COMMAND func4_DO_ALARM_SUM_read; \
	COLLECTION func4_DO_BATCH; \
	VARIABLE func4_DO_BATCH_Batch_ID; \
	VARIABLE func4_DO_BATCH_Rup; \
	VARIABLE func4_DO_BATCH_Operation; \
	VARIABLE func4_DO_BATCH_Phase; \
	MENU func4_DO_BATCH_page; \
	COMMAND func4_DO_BATCH_read; \
	COMMAND func4_DO_BATCH_write; \
	COLLECTION func4_DO_SP_D; \
	VARIABLE func4_DO_SP_D_Value; \
	VARIABLE func4_DO_SP_D_Status_Condensed; \
	VARIABLE func4_DO_SP_D_Status_Quality; \
	VARIABLE func4_DO_SP_D_Status_Limit; \
	MENU func4_DO_SP_D_page; \
	COMMAND func4_DO_SP_D_read; \
	COMMAND func4_DO_SP_D_write; \
	VARIABLE func4_DO_INVERT; \
	MENU func4_DO_INVERT_page; \
	COMMAND func4_DO_INVERT_read; \
	COMMAND func4_DO_INVERT_write; \
	VARIABLE func4_DO_CHECK_BACK; \
	MENU func4_DO_CHECK_BACK_page; \
	COMMAND func4_DO_CHECK_BACK_read; \
	VARIABLE func4_DO_CHECK_BACK_MASK; \
	MENU func4_DO_CHECK_BACK_MASK_page; \
	COMMAND func4_DO_CHECK_BACK_MASK_read

#define USE_FUNC4_DO_MANDATORY_A \
	USE_FUNC4_DO_MANDATORY_BOTH; \
	MENU func4_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC4_DO_MANDATORY_B \
	USE_FUNC4_DO_MANDATORY_BOTH; \
	COLLECTION func4_DO_OUT_D; \
	VARIABLE func4_DO_OUT_D_Value; \
	VARIABLE func4_DO_OUT_D_Status_Condensed; \
	VARIABLE func4_DO_OUT_D_Status_Quality; \
	VARIABLE func4_DO_OUT_D_Status_Limit; \
	MENU func4_DO_OUT_D_page; \
	COMMAND func4_DO_OUT_D_read; \
	COMMAND func4_DO_OUT_D_write; \
	VARIABLE func4_DO_IN_CHANNEL; \
	MENU func4_DO_IN_CHANNEL_page; \
	COMMAND func4_DO_IN_CHANNEL_read; \
	COMMAND func4_DO_IN_CHANNEL_write; \
	VARIABLE func4_DO_FSAFE_TIME; \
	MENU func4_DO_FSAFE_TIME_page; \
	COMMAND func4_DO_FSAFE_TIME_read; \
	COMMAND func4_DO_FSAFE_TIME_write; \
	VARIABLE func4_DO_FSAFE_TYPE; \
	MENU func4_DO_FSAFE_TYPE_page; \
	COMMAND func4_DO_FSAFE_TYPE_read; \
	COMMAND func4_DO_FSAFE_TYPE_write; \
	VARIABLE func4_DO_FSAFE_VAL_D; \
	MENU func4_DO_FSAFE_VAL_D_page; \
	COMMAND func4_DO_FSAFE_VAL_D_read; \
	COMMAND func4_DO_FSAFE_VAL_D_write; \
	COLLECTION func4_DO_SIMULATE; \
	VARIABLE func4_DO_SIMULATE_Status_Condensed; \
	VARIABLE func4_DO_SIMULATE_Value; \
	VARIABLE func4_DO_SIMULATE_Enabled; \
	VARIABLE func4_DO_SIMULATE_Status_Quality; \
	VARIABLE func4_DO_SIMULATE_Status_Limit; \
	MENU func4_DO_SIMULATE_page; \
	COMMAND func4_DO_SIMULATE_read; \
	COMMAND func4_DO_SIMULATE_write; \
	COLLECTION func4_DO_VIEW_1; \
	MENU func4_DO_VIEW_1_page; \
	MENU func4_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC4_DO_OPTIONAL_BOTH \
	COLLECTION func4_DO_READBACK_D; \
	VARIABLE func4_DO_READBACK_D_Value; \
	VARIABLE func4_DO_READBACK_D_Status_Condensed; \
	VARIABLE func4_DO_READBACK_D_Status_Quality; \
	VARIABLE func4_DO_READBACK_D_Status_Limit; \
	MENU func4_DO_READBACK_D_page; \
	COMMAND func4_DO_READBACK_D_read; \
	COLLECTION func4_DO_RCAS_IN_D; \
	VARIABLE func4_DO_RCAS_IN_D_Value; \
	VARIABLE func4_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func4_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func4_DO_RCAS_IN_D_Status_Limit; \
	MENU func4_DO_RCAS_IN_D_page; \
	COMMAND func4_DO_RCAS_IN_D_read; \
	COMMAND func4_DO_RCAS_IN_D_write; \
	COLLECTION func4_DO_RCAS_OUT_D; \
	VARIABLE func4_DO_RCAS_OUT_D_Value; \
	VARIABLE func4_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func4_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func4_DO_RCAS_OUT_D_Status_Limit; \
	MENU func4_DO_RCAS_OUT_D_page; \
	COMMAND func4_DO_RCAS_OUT_D_read; \
	VARIABLE func4_DO_OUT_CHANNEL; \
	MENU func4_DO_OUT_CHANNEL_page; \
	COMMAND func4_DO_OUT_CHANNEL_read; \
	COMMAND func4_DO_OUT_CHANNEL_write; \
	COLLECTION func4_DO_VIEW_2; \
	MENU func4_DO_VIEW_2_page; \
	COLLECTION func4_DO_VIEW_3; \
	MENU func4_DO_VIEW_3_page

#define USE_FUNC4_DO_OPTIONAL_A \
	USE_FUNC4_DO_OPTIONAL_BOTH; \
	COLLECTION func4_DO_OUT_D; \
	VARIABLE func4_DO_OUT_D_Value; \
	VARIABLE func4_DO_OUT_D_Status_Condensed; \
	VARIABLE func4_DO_OUT_D_Status_Quality; \
	VARIABLE func4_DO_OUT_D_Status_Limit; \
	MENU func4_DO_OUT_D_page; \
	COMMAND func4_DO_OUT_D_read; \
	COMMAND func4_DO_OUT_D_write; \
	VARIABLE func4_DO_IN_CHANNEL; \
	MENU func4_DO_IN_CHANNEL_page; \
	COMMAND func4_DO_IN_CHANNEL_read; \
	COMMAND func4_DO_IN_CHANNEL_write; \
	VARIABLE func4_DO_FSAFE_TIME; \
	MENU func4_DO_FSAFE_TIME_page; \
	COMMAND func4_DO_FSAFE_TIME_read; \
	COMMAND func4_DO_FSAFE_TIME_write; \
	VARIABLE func4_DO_FSAFE_TYPE; \
	MENU func4_DO_FSAFE_TYPE_page; \
	COMMAND func4_DO_FSAFE_TYPE_read; \
	COMMAND func4_DO_FSAFE_TYPE_write; \
	VARIABLE func4_DO_FSAFE_VAL_D; \
	MENU func4_DO_FSAFE_VAL_D_page; \
	COMMAND func4_DO_FSAFE_VAL_D_read; \
	COMMAND func4_DO_FSAFE_VAL_D_write; \
	COLLECTION func4_DO_SIMULATE; \
	VARIABLE func4_DO_SIMULATE_Status_Condensed; \
	VARIABLE func4_DO_SIMULATE_Value; \
	VARIABLE func4_DO_SIMULATE_Enabled; \
	VARIABLE func4_DO_SIMULATE_Status_Quality; \
	VARIABLE func4_DO_SIMULATE_Status_Limit; \
	MENU func4_DO_SIMULATE_page; \
	COMMAND func4_DO_SIMULATE_read; \
	COMMAND func4_DO_SIMULATE_write; \
	COLLECTION func4_DO_VIEW_1; \
	MENU func4_DO_VIEW_1_page; \
	MENU func4_DO_Simple_Dialog_Optional_A

#define USE_FUNC4_DO_OPTIONAL_B \
	USE_FUNC4_DO_OPTIONAL_BOTH; \
	MENU func4_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC4_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func4_DO_)
#define USE_FUNC4_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func4_DO_)
#define USE_FUNC4_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func4_DO_)
#define USE_FUNC4_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func4_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC5_DO_MANDATORY_BOTH \
	BLOCK func5_DO_block; \
	COLLECTION func5_DO_BLOCK_OBJECT; \
	VARIABLE func5_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func5_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func5_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func5_DO_BLOCK_OBJECT_Class; \
	VARIABLE func5_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func5_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func5_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func5_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func5_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func5_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func5_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func5_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func5_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func5_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func5_DO_BLOCK_OBJECT_page; \
	COMMAND func5_DO_BLOCK_OBJECT_read; \
	VARIABLE func5_DO_ST_REV; \
	MENU func5_DO_ST_REV_page; \
	COMMAND func5_DO_ST_REV_read; \
	VARIABLE func5_DO_TAG_DESC; \
	MENU func5_DO_TAG_DESC_page; \
	COMMAND func5_DO_TAG_DESC_read; \
	COMMAND func5_DO_TAG_DESC_write; \
	VARIABLE func5_DO_STRATEGY; \
	MENU func5_DO_STRATEGY_page; \
	COMMAND func5_DO_STRATEGY_read; \
	COMMAND func5_DO_STRATEGY_write; \
	VARIABLE func5_DO_ALERT_KEY; \
	MENU func5_DO_ALERT_KEY_page; \
	COMMAND func5_DO_ALERT_KEY_read; \
	COMMAND func5_DO_ALERT_KEY_write; \
	VARIABLE func5_DO_TARGET_MODE; \
	MENU func5_DO_TARGET_MODE_page; \
	COMMAND func5_DO_TARGET_MODE_read; \
	COMMAND func5_DO_TARGET_MODE_write; \
	COLLECTION func5_DO_MODE_BLK; \
	VARIABLE func5_DO_MODE_BLK_Actual; \
	VARIABLE func5_DO_MODE_BLK_Permitted; \
	VARIABLE func5_DO_MODE_BLK_Normal; \
	MENU func5_DO_MODE_BLK_page; \
	COMMAND func5_DO_MODE_BLK_read; \
	COLLECTION func5_DO_ALARM_SUM; \
	VARIABLE func5_DO_ALARM_SUM_Current; \
	VARIABLE func5_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func5_DO_ALARM_SUM_Unreported; \
	VARIABLE func5_DO_ALARM_SUM_Disabled; \
	MENU func5_DO_ALARM_SUM_page; \
	COMMAND func5_DO_ALARM_SUM_read; \
	COLLECTION func5_DO_BATCH; \
	VARIABLE func5_DO_BATCH_Batch_ID; \
	VARIABLE func5_DO_BATCH_Rup; \
	VARIABLE func5_DO_BATCH_Operation; \
	VARIABLE func5_DO_BATCH_Phase; \
	MENU func5_DO_BATCH_page; \
	COMMAND func5_DO_BATCH_read; \
	COMMAND func5_DO_BATCH_write; \
	COLLECTION func5_DO_SP_D; \
	VARIABLE func5_DO_SP_D_Value; \
	VARIABLE func5_DO_SP_D_Status_Condensed; \
	VARIABLE func5_DO_SP_D_Status_Quality; \
	VARIABLE func5_DO_SP_D_Status_Limit; \
	MENU func5_DO_SP_D_page; \
	COMMAND func5_DO_SP_D_read; \
	COMMAND func5_DO_SP_D_write; \
	VARIABLE func5_DO_INVERT; \
	MENU func5_DO_INVERT_page; \
	COMMAND func5_DO_INVERT_read; \
	COMMAND func5_DO_INVERT_write; \
	VARIABLE func5_DO_CHECK_BACK; \
	MENU func5_DO_CHECK_BACK_page; \
	COMMAND func5_DO_CHECK_BACK_read; \
	VARIABLE func5_DO_CHECK_BACK_MASK; \
	MENU func5_DO_CHECK_BACK_MASK_page; \
	COMMAND func5_DO_CHECK_BACK_MASK_read

#define USE_FUNC5_DO_MANDATORY_A \
	USE_FUNC5_DO_MANDATORY_BOTH; \
	MENU func5_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC5_DO_MANDATORY_B \
	USE_FUNC5_DO_MANDATORY_BOTH; \
	COLLECTION func5_DO_OUT_D; \
	VARIABLE func5_DO_OUT_D_Value; \
	VARIABLE func5_DO_OUT_D_Status_Condensed; \
	VARIABLE func5_DO_OUT_D_Status_Quality; \
	VARIABLE func5_DO_OUT_D_Status_Limit; \
	MENU func5_DO_OUT_D_page; \
	COMMAND func5_DO_OUT_D_read; \
	COMMAND func5_DO_OUT_D_write; \
	VARIABLE func5_DO_IN_CHANNEL; \
	MENU func5_DO_IN_CHANNEL_page; \
	COMMAND func5_DO_IN_CHANNEL_read; \
	COMMAND func5_DO_IN_CHANNEL_write; \
	VARIABLE func5_DO_FSAFE_TIME; \
	MENU func5_DO_FSAFE_TIME_page; \
	COMMAND func5_DO_FSAFE_TIME_read; \
	COMMAND func5_DO_FSAFE_TIME_write; \
	VARIABLE func5_DO_FSAFE_TYPE; \
	MENU func5_DO_FSAFE_TYPE_page; \
	COMMAND func5_DO_FSAFE_TYPE_read; \
	COMMAND func5_DO_FSAFE_TYPE_write; \
	VARIABLE func5_DO_FSAFE_VAL_D; \
	MENU func5_DO_FSAFE_VAL_D_page; \
	COMMAND func5_DO_FSAFE_VAL_D_read; \
	COMMAND func5_DO_FSAFE_VAL_D_write; \
	COLLECTION func5_DO_SIMULATE; \
	VARIABLE func5_DO_SIMULATE_Status_Condensed; \
	VARIABLE func5_DO_SIMULATE_Value; \
	VARIABLE func5_DO_SIMULATE_Enabled; \
	VARIABLE func5_DO_SIMULATE_Status_Quality; \
	VARIABLE func5_DO_SIMULATE_Status_Limit; \
	MENU func5_DO_SIMULATE_page; \
	COMMAND func5_DO_SIMULATE_read; \
	COMMAND func5_DO_SIMULATE_write; \
	COLLECTION func5_DO_VIEW_1; \
	MENU func5_DO_VIEW_1_page; \
	MENU func5_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC5_DO_OPTIONAL_BOTH \
	COLLECTION func5_DO_READBACK_D; \
	VARIABLE func5_DO_READBACK_D_Value; \
	VARIABLE func5_DO_READBACK_D_Status_Condensed; \
	VARIABLE func5_DO_READBACK_D_Status_Quality; \
	VARIABLE func5_DO_READBACK_D_Status_Limit; \
	MENU func5_DO_READBACK_D_page; \
	COMMAND func5_DO_READBACK_D_read; \
	COLLECTION func5_DO_RCAS_IN_D; \
	VARIABLE func5_DO_RCAS_IN_D_Value; \
	VARIABLE func5_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func5_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func5_DO_RCAS_IN_D_Status_Limit; \
	MENU func5_DO_RCAS_IN_D_page; \
	COMMAND func5_DO_RCAS_IN_D_read; \
	COMMAND func5_DO_RCAS_IN_D_write; \
	COLLECTION func5_DO_RCAS_OUT_D; \
	VARIABLE func5_DO_RCAS_OUT_D_Value; \
	VARIABLE func5_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func5_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func5_DO_RCAS_OUT_D_Status_Limit; \
	MENU func5_DO_RCAS_OUT_D_page; \
	COMMAND func5_DO_RCAS_OUT_D_read; \
	VARIABLE func5_DO_OUT_CHANNEL; \
	MENU func5_DO_OUT_CHANNEL_page; \
	COMMAND func5_DO_OUT_CHANNEL_read; \
	COMMAND func5_DO_OUT_CHANNEL_write; \
	COLLECTION func5_DO_VIEW_2; \
	MENU func5_DO_VIEW_2_page; \
	COLLECTION func5_DO_VIEW_3; \
	MENU func5_DO_VIEW_3_page

#define USE_FUNC5_DO_OPTIONAL_A \
	USE_FUNC5_DO_OPTIONAL_BOTH; \
	COLLECTION func5_DO_OUT_D; \
	VARIABLE func5_DO_OUT_D_Value; \
	VARIABLE func5_DO_OUT_D_Status_Condensed; \
	VARIABLE func5_DO_OUT_D_Status_Quality; \
	VARIABLE func5_DO_OUT_D_Status_Limit; \
	MENU func5_DO_OUT_D_page; \
	COMMAND func5_DO_OUT_D_read; \
	COMMAND func5_DO_OUT_D_write; \
	VARIABLE func5_DO_IN_CHANNEL; \
	MENU func5_DO_IN_CHANNEL_page; \
	COMMAND func5_DO_IN_CHANNEL_read; \
	COMMAND func5_DO_IN_CHANNEL_write; \
	VARIABLE func5_DO_FSAFE_TIME; \
	MENU func5_DO_FSAFE_TIME_page; \
	COMMAND func5_DO_FSAFE_TIME_read; \
	COMMAND func5_DO_FSAFE_TIME_write; \
	VARIABLE func5_DO_FSAFE_TYPE; \
	MENU func5_DO_FSAFE_TYPE_page; \
	COMMAND func5_DO_FSAFE_TYPE_read; \
	COMMAND func5_DO_FSAFE_TYPE_write; \
	VARIABLE func5_DO_FSAFE_VAL_D; \
	MENU func5_DO_FSAFE_VAL_D_page; \
	COMMAND func5_DO_FSAFE_VAL_D_read; \
	COMMAND func5_DO_FSAFE_VAL_D_write; \
	COLLECTION func5_DO_SIMULATE; \
	VARIABLE func5_DO_SIMULATE_Status_Condensed; \
	VARIABLE func5_DO_SIMULATE_Value; \
	VARIABLE func5_DO_SIMULATE_Enabled; \
	VARIABLE func5_DO_SIMULATE_Status_Quality; \
	VARIABLE func5_DO_SIMULATE_Status_Limit; \
	MENU func5_DO_SIMULATE_page; \
	COMMAND func5_DO_SIMULATE_read; \
	COMMAND func5_DO_SIMULATE_write; \
	COLLECTION func5_DO_VIEW_1; \
	MENU func5_DO_VIEW_1_page; \
	MENU func5_DO_Simple_Dialog_Optional_A

#define USE_FUNC5_DO_OPTIONAL_B \
	USE_FUNC5_DO_OPTIONAL_BOTH; \
	MENU func5_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC5_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func5_DO_)
#define USE_FUNC5_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func5_DO_)
#define USE_FUNC5_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func5_DO_)
#define USE_FUNC5_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func5_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC6_DO_MANDATORY_BOTH \
	BLOCK func6_DO_block; \
	COLLECTION func6_DO_BLOCK_OBJECT; \
	VARIABLE func6_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func6_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func6_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func6_DO_BLOCK_OBJECT_Class; \
	VARIABLE func6_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func6_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func6_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func6_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func6_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func6_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func6_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func6_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func6_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func6_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func6_DO_BLOCK_OBJECT_page; \
	COMMAND func6_DO_BLOCK_OBJECT_read; \
	VARIABLE func6_DO_ST_REV; \
	MENU func6_DO_ST_REV_page; \
	COMMAND func6_DO_ST_REV_read; \
	VARIABLE func6_DO_TAG_DESC; \
	MENU func6_DO_TAG_DESC_page; \
	COMMAND func6_DO_TAG_DESC_read; \
	COMMAND func6_DO_TAG_DESC_write; \
	VARIABLE func6_DO_STRATEGY; \
	MENU func6_DO_STRATEGY_page; \
	COMMAND func6_DO_STRATEGY_read; \
	COMMAND func6_DO_STRATEGY_write; \
	VARIABLE func6_DO_ALERT_KEY; \
	MENU func6_DO_ALERT_KEY_page; \
	COMMAND func6_DO_ALERT_KEY_read; \
	COMMAND func6_DO_ALERT_KEY_write; \
	VARIABLE func6_DO_TARGET_MODE; \
	MENU func6_DO_TARGET_MODE_page; \
	COMMAND func6_DO_TARGET_MODE_read; \
	COMMAND func6_DO_TARGET_MODE_write; \
	COLLECTION func6_DO_MODE_BLK; \
	VARIABLE func6_DO_MODE_BLK_Actual; \
	VARIABLE func6_DO_MODE_BLK_Permitted; \
	VARIABLE func6_DO_MODE_BLK_Normal; \
	MENU func6_DO_MODE_BLK_page; \
	COMMAND func6_DO_MODE_BLK_read; \
	COLLECTION func6_DO_ALARM_SUM; \
	VARIABLE func6_DO_ALARM_SUM_Current; \
	VARIABLE func6_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func6_DO_ALARM_SUM_Unreported; \
	VARIABLE func6_DO_ALARM_SUM_Disabled; \
	MENU func6_DO_ALARM_SUM_page; \
	COMMAND func6_DO_ALARM_SUM_read; \
	COLLECTION func6_DO_BATCH; \
	VARIABLE func6_DO_BATCH_Batch_ID; \
	VARIABLE func6_DO_BATCH_Rup; \
	VARIABLE func6_DO_BATCH_Operation; \
	VARIABLE func6_DO_BATCH_Phase; \
	MENU func6_DO_BATCH_page; \
	COMMAND func6_DO_BATCH_read; \
	COMMAND func6_DO_BATCH_write; \
	COLLECTION func6_DO_SP_D; \
	VARIABLE func6_DO_SP_D_Value; \
	VARIABLE func6_DO_SP_D_Status_Condensed; \
	VARIABLE func6_DO_SP_D_Status_Quality; \
	VARIABLE func6_DO_SP_D_Status_Limit; \
	MENU func6_DO_SP_D_page; \
	COMMAND func6_DO_SP_D_read; \
	COMMAND func6_DO_SP_D_write; \
	VARIABLE func6_DO_INVERT; \
	MENU func6_DO_INVERT_page; \
	COMMAND func6_DO_INVERT_read; \
	COMMAND func6_DO_INVERT_write; \
	VARIABLE func6_DO_CHECK_BACK; \
	MENU func6_DO_CHECK_BACK_page; \
	COMMAND func6_DO_CHECK_BACK_read; \
	VARIABLE func6_DO_CHECK_BACK_MASK; \
	MENU func6_DO_CHECK_BACK_MASK_page; \
	COMMAND func6_DO_CHECK_BACK_MASK_read

#define USE_FUNC6_DO_MANDATORY_A \
	USE_FUNC6_DO_MANDATORY_BOTH; \
	MENU func6_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC6_DO_MANDATORY_B \
	USE_FUNC6_DO_MANDATORY_BOTH; \
	COLLECTION func6_DO_OUT_D; \
	VARIABLE func6_DO_OUT_D_Value; \
	VARIABLE func6_DO_OUT_D_Status_Condensed; \
	VARIABLE func6_DO_OUT_D_Status_Quality; \
	VARIABLE func6_DO_OUT_D_Status_Limit; \
	MENU func6_DO_OUT_D_page; \
	COMMAND func6_DO_OUT_D_read; \
	COMMAND func6_DO_OUT_D_write; \
	VARIABLE func6_DO_IN_CHANNEL; \
	MENU func6_DO_IN_CHANNEL_page; \
	COMMAND func6_DO_IN_CHANNEL_read; \
	COMMAND func6_DO_IN_CHANNEL_write; \
	VARIABLE func6_DO_FSAFE_TIME; \
	MENU func6_DO_FSAFE_TIME_page; \
	COMMAND func6_DO_FSAFE_TIME_read; \
	COMMAND func6_DO_FSAFE_TIME_write; \
	VARIABLE func6_DO_FSAFE_TYPE; \
	MENU func6_DO_FSAFE_TYPE_page; \
	COMMAND func6_DO_FSAFE_TYPE_read; \
	COMMAND func6_DO_FSAFE_TYPE_write; \
	VARIABLE func6_DO_FSAFE_VAL_D; \
	MENU func6_DO_FSAFE_VAL_D_page; \
	COMMAND func6_DO_FSAFE_VAL_D_read; \
	COMMAND func6_DO_FSAFE_VAL_D_write; \
	COLLECTION func6_DO_SIMULATE; \
	VARIABLE func6_DO_SIMULATE_Status_Condensed; \
	VARIABLE func6_DO_SIMULATE_Value; \
	VARIABLE func6_DO_SIMULATE_Enabled; \
	VARIABLE func6_DO_SIMULATE_Status_Quality; \
	VARIABLE func6_DO_SIMULATE_Status_Limit; \
	MENU func6_DO_SIMULATE_page; \
	COMMAND func6_DO_SIMULATE_read; \
	COMMAND func6_DO_SIMULATE_write; \
	COLLECTION func6_DO_VIEW_1; \
	MENU func6_DO_VIEW_1_page; \
	MENU func6_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC6_DO_OPTIONAL_BOTH \
	COLLECTION func6_DO_READBACK_D; \
	VARIABLE func6_DO_READBACK_D_Value; \
	VARIABLE func6_DO_READBACK_D_Status_Condensed; \
	VARIABLE func6_DO_READBACK_D_Status_Quality; \
	VARIABLE func6_DO_READBACK_D_Status_Limit; \
	MENU func6_DO_READBACK_D_page; \
	COMMAND func6_DO_READBACK_D_read; \
	COLLECTION func6_DO_RCAS_IN_D; \
	VARIABLE func6_DO_RCAS_IN_D_Value; \
	VARIABLE func6_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func6_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func6_DO_RCAS_IN_D_Status_Limit; \
	MENU func6_DO_RCAS_IN_D_page; \
	COMMAND func6_DO_RCAS_IN_D_read; \
	COMMAND func6_DO_RCAS_IN_D_write; \
	COLLECTION func6_DO_RCAS_OUT_D; \
	VARIABLE func6_DO_RCAS_OUT_D_Value; \
	VARIABLE func6_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func6_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func6_DO_RCAS_OUT_D_Status_Limit; \
	MENU func6_DO_RCAS_OUT_D_page; \
	COMMAND func6_DO_RCAS_OUT_D_read; \
	VARIABLE func6_DO_OUT_CHANNEL; \
	MENU func6_DO_OUT_CHANNEL_page; \
	COMMAND func6_DO_OUT_CHANNEL_read; \
	COMMAND func6_DO_OUT_CHANNEL_write; \
	COLLECTION func6_DO_VIEW_2; \
	MENU func6_DO_VIEW_2_page; \
	COLLECTION func6_DO_VIEW_3; \
	MENU func6_DO_VIEW_3_page

#define USE_FUNC6_DO_OPTIONAL_A \
	USE_FUNC6_DO_OPTIONAL_BOTH; \
	COLLECTION func6_DO_OUT_D; \
	VARIABLE func6_DO_OUT_D_Value; \
	VARIABLE func6_DO_OUT_D_Status_Condensed; \
	VARIABLE func6_DO_OUT_D_Status_Quality; \
	VARIABLE func6_DO_OUT_D_Status_Limit; \
	MENU func6_DO_OUT_D_page; \
	COMMAND func6_DO_OUT_D_read; \
	COMMAND func6_DO_OUT_D_write; \
	VARIABLE func6_DO_IN_CHANNEL; \
	MENU func6_DO_IN_CHANNEL_page; \
	COMMAND func6_DO_IN_CHANNEL_read; \
	COMMAND func6_DO_IN_CHANNEL_write; \
	VARIABLE func6_DO_FSAFE_TIME; \
	MENU func6_DO_FSAFE_TIME_page; \
	COMMAND func6_DO_FSAFE_TIME_read; \
	COMMAND func6_DO_FSAFE_TIME_write; \
	VARIABLE func6_DO_FSAFE_TYPE; \
	MENU func6_DO_FSAFE_TYPE_page; \
	COMMAND func6_DO_FSAFE_TYPE_read; \
	COMMAND func6_DO_FSAFE_TYPE_write; \
	VARIABLE func6_DO_FSAFE_VAL_D; \
	MENU func6_DO_FSAFE_VAL_D_page; \
	COMMAND func6_DO_FSAFE_VAL_D_read; \
	COMMAND func6_DO_FSAFE_VAL_D_write; \
	COLLECTION func6_DO_SIMULATE; \
	VARIABLE func6_DO_SIMULATE_Status_Condensed; \
	VARIABLE func6_DO_SIMULATE_Value; \
	VARIABLE func6_DO_SIMULATE_Enabled; \
	VARIABLE func6_DO_SIMULATE_Status_Quality; \
	VARIABLE func6_DO_SIMULATE_Status_Limit; \
	MENU func6_DO_SIMULATE_page; \
	COMMAND func6_DO_SIMULATE_read; \
	COMMAND func6_DO_SIMULATE_write; \
	COLLECTION func6_DO_VIEW_1; \
	MENU func6_DO_VIEW_1_page; \
	MENU func6_DO_Simple_Dialog_Optional_A

#define USE_FUNC6_DO_OPTIONAL_B \
	USE_FUNC6_DO_OPTIONAL_BOTH; \
	MENU func6_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC6_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func6_DO_)
#define USE_FUNC6_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func6_DO_)
#define USE_FUNC6_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func6_DO_)
#define USE_FUNC6_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func6_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC7_DO_MANDATORY_BOTH \
	BLOCK func7_DO_block; \
	COLLECTION func7_DO_BLOCK_OBJECT; \
	VARIABLE func7_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func7_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func7_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func7_DO_BLOCK_OBJECT_Class; \
	VARIABLE func7_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func7_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func7_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func7_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func7_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func7_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func7_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func7_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func7_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func7_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func7_DO_BLOCK_OBJECT_page; \
	COMMAND func7_DO_BLOCK_OBJECT_read; \
	VARIABLE func7_DO_ST_REV; \
	MENU func7_DO_ST_REV_page; \
	COMMAND func7_DO_ST_REV_read; \
	VARIABLE func7_DO_TAG_DESC; \
	MENU func7_DO_TAG_DESC_page; \
	COMMAND func7_DO_TAG_DESC_read; \
	COMMAND func7_DO_TAG_DESC_write; \
	VARIABLE func7_DO_STRATEGY; \
	MENU func7_DO_STRATEGY_page; \
	COMMAND func7_DO_STRATEGY_read; \
	COMMAND func7_DO_STRATEGY_write; \
	VARIABLE func7_DO_ALERT_KEY; \
	MENU func7_DO_ALERT_KEY_page; \
	COMMAND func7_DO_ALERT_KEY_read; \
	COMMAND func7_DO_ALERT_KEY_write; \
	VARIABLE func7_DO_TARGET_MODE; \
	MENU func7_DO_TARGET_MODE_page; \
	COMMAND func7_DO_TARGET_MODE_read; \
	COMMAND func7_DO_TARGET_MODE_write; \
	COLLECTION func7_DO_MODE_BLK; \
	VARIABLE func7_DO_MODE_BLK_Actual; \
	VARIABLE func7_DO_MODE_BLK_Permitted; \
	VARIABLE func7_DO_MODE_BLK_Normal; \
	MENU func7_DO_MODE_BLK_page; \
	COMMAND func7_DO_MODE_BLK_read; \
	COLLECTION func7_DO_ALARM_SUM; \
	VARIABLE func7_DO_ALARM_SUM_Current; \
	VARIABLE func7_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func7_DO_ALARM_SUM_Unreported; \
	VARIABLE func7_DO_ALARM_SUM_Disabled; \
	MENU func7_DO_ALARM_SUM_page; \
	COMMAND func7_DO_ALARM_SUM_read; \
	COLLECTION func7_DO_BATCH; \
	VARIABLE func7_DO_BATCH_Batch_ID; \
	VARIABLE func7_DO_BATCH_Rup; \
	VARIABLE func7_DO_BATCH_Operation; \
	VARIABLE func7_DO_BATCH_Phase; \
	MENU func7_DO_BATCH_page; \
	COMMAND func7_DO_BATCH_read; \
	COMMAND func7_DO_BATCH_write; \
	COLLECTION func7_DO_SP_D; \
	VARIABLE func7_DO_SP_D_Value; \
	VARIABLE func7_DO_SP_D_Status_Condensed; \
	VARIABLE func7_DO_SP_D_Status_Quality; \
	VARIABLE func7_DO_SP_D_Status_Limit; \
	MENU func7_DO_SP_D_page; \
	COMMAND func7_DO_SP_D_read; \
	COMMAND func7_DO_SP_D_write; \
	VARIABLE func7_DO_INVERT; \
	MENU func7_DO_INVERT_page; \
	COMMAND func7_DO_INVERT_read; \
	COMMAND func7_DO_INVERT_write; \
	VARIABLE func7_DO_CHECK_BACK; \
	MENU func7_DO_CHECK_BACK_page; \
	COMMAND func7_DO_CHECK_BACK_read; \
	VARIABLE func7_DO_CHECK_BACK_MASK; \
	MENU func7_DO_CHECK_BACK_MASK_page; \
	COMMAND func7_DO_CHECK_BACK_MASK_read

#define USE_FUNC7_DO_MANDATORY_A \
	USE_FUNC7_DO_MANDATORY_BOTH; \
	MENU func7_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC7_DO_MANDATORY_B \
	USE_FUNC7_DO_MANDATORY_BOTH; \
	COLLECTION func7_DO_OUT_D; \
	VARIABLE func7_DO_OUT_D_Value; \
	VARIABLE func7_DO_OUT_D_Status_Condensed; \
	VARIABLE func7_DO_OUT_D_Status_Quality; \
	VARIABLE func7_DO_OUT_D_Status_Limit; \
	MENU func7_DO_OUT_D_page; \
	COMMAND func7_DO_OUT_D_read; \
	COMMAND func7_DO_OUT_D_write; \
	VARIABLE func7_DO_IN_CHANNEL; \
	MENU func7_DO_IN_CHANNEL_page; \
	COMMAND func7_DO_IN_CHANNEL_read; \
	COMMAND func7_DO_IN_CHANNEL_write; \
	VARIABLE func7_DO_FSAFE_TIME; \
	MENU func7_DO_FSAFE_TIME_page; \
	COMMAND func7_DO_FSAFE_TIME_read; \
	COMMAND func7_DO_FSAFE_TIME_write; \
	VARIABLE func7_DO_FSAFE_TYPE; \
	MENU func7_DO_FSAFE_TYPE_page; \
	COMMAND func7_DO_FSAFE_TYPE_read; \
	COMMAND func7_DO_FSAFE_TYPE_write; \
	VARIABLE func7_DO_FSAFE_VAL_D; \
	MENU func7_DO_FSAFE_VAL_D_page; \
	COMMAND func7_DO_FSAFE_VAL_D_read; \
	COMMAND func7_DO_FSAFE_VAL_D_write; \
	COLLECTION func7_DO_SIMULATE; \
	VARIABLE func7_DO_SIMULATE_Status_Condensed; \
	VARIABLE func7_DO_SIMULATE_Value; \
	VARIABLE func7_DO_SIMULATE_Enabled; \
	VARIABLE func7_DO_SIMULATE_Status_Quality; \
	VARIABLE func7_DO_SIMULATE_Status_Limit; \
	MENU func7_DO_SIMULATE_page; \
	COMMAND func7_DO_SIMULATE_read; \
	COMMAND func7_DO_SIMULATE_write; \
	COLLECTION func7_DO_VIEW_1; \
	MENU func7_DO_VIEW_1_page; \
	MENU func7_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC7_DO_OPTIONAL_BOTH \
	COLLECTION func7_DO_READBACK_D; \
	VARIABLE func7_DO_READBACK_D_Value; \
	VARIABLE func7_DO_READBACK_D_Status_Condensed; \
	VARIABLE func7_DO_READBACK_D_Status_Quality; \
	VARIABLE func7_DO_READBACK_D_Status_Limit; \
	MENU func7_DO_READBACK_D_page; \
	COMMAND func7_DO_READBACK_D_read; \
	COLLECTION func7_DO_RCAS_IN_D; \
	VARIABLE func7_DO_RCAS_IN_D_Value; \
	VARIABLE func7_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func7_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func7_DO_RCAS_IN_D_Status_Limit; \
	MENU func7_DO_RCAS_IN_D_page; \
	COMMAND func7_DO_RCAS_IN_D_read; \
	COMMAND func7_DO_RCAS_IN_D_write; \
	COLLECTION func7_DO_RCAS_OUT_D; \
	VARIABLE func7_DO_RCAS_OUT_D_Value; \
	VARIABLE func7_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func7_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func7_DO_RCAS_OUT_D_Status_Limit; \
	MENU func7_DO_RCAS_OUT_D_page; \
	COMMAND func7_DO_RCAS_OUT_D_read; \
	VARIABLE func7_DO_OUT_CHANNEL; \
	MENU func7_DO_OUT_CHANNEL_page; \
	COMMAND func7_DO_OUT_CHANNEL_read; \
	COMMAND func7_DO_OUT_CHANNEL_write; \
	COLLECTION func7_DO_VIEW_2; \
	MENU func7_DO_VIEW_2_page; \
	COLLECTION func7_DO_VIEW_3; \
	MENU func7_DO_VIEW_3_page

#define USE_FUNC7_DO_OPTIONAL_A \
	USE_FUNC7_DO_OPTIONAL_BOTH; \
	COLLECTION func7_DO_OUT_D; \
	VARIABLE func7_DO_OUT_D_Value; \
	VARIABLE func7_DO_OUT_D_Status_Condensed; \
	VARIABLE func7_DO_OUT_D_Status_Quality; \
	VARIABLE func7_DO_OUT_D_Status_Limit; \
	MENU func7_DO_OUT_D_page; \
	COMMAND func7_DO_OUT_D_read; \
	COMMAND func7_DO_OUT_D_write; \
	VARIABLE func7_DO_IN_CHANNEL; \
	MENU func7_DO_IN_CHANNEL_page; \
	COMMAND func7_DO_IN_CHANNEL_read; \
	COMMAND func7_DO_IN_CHANNEL_write; \
	VARIABLE func7_DO_FSAFE_TIME; \
	MENU func7_DO_FSAFE_TIME_page; \
	COMMAND func7_DO_FSAFE_TIME_read; \
	COMMAND func7_DO_FSAFE_TIME_write; \
	VARIABLE func7_DO_FSAFE_TYPE; \
	MENU func7_DO_FSAFE_TYPE_page; \
	COMMAND func7_DO_FSAFE_TYPE_read; \
	COMMAND func7_DO_FSAFE_TYPE_write; \
	VARIABLE func7_DO_FSAFE_VAL_D; \
	MENU func7_DO_FSAFE_VAL_D_page; \
	COMMAND func7_DO_FSAFE_VAL_D_read; \
	COMMAND func7_DO_FSAFE_VAL_D_write; \
	COLLECTION func7_DO_SIMULATE; \
	VARIABLE func7_DO_SIMULATE_Status_Condensed; \
	VARIABLE func7_DO_SIMULATE_Value; \
	VARIABLE func7_DO_SIMULATE_Enabled; \
	VARIABLE func7_DO_SIMULATE_Status_Quality; \
	VARIABLE func7_DO_SIMULATE_Status_Limit; \
	MENU func7_DO_SIMULATE_page; \
	COMMAND func7_DO_SIMULATE_read; \
	COMMAND func7_DO_SIMULATE_write; \
	COLLECTION func7_DO_VIEW_1; \
	MENU func7_DO_VIEW_1_page; \
	MENU func7_DO_Simple_Dialog_Optional_A

#define USE_FUNC7_DO_OPTIONAL_B \
	USE_FUNC7_DO_OPTIONAL_BOTH; \
	MENU func7_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC7_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func7_DO_)
#define USE_FUNC7_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func7_DO_)
#define USE_FUNC7_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func7_DO_)
#define USE_FUNC7_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func7_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC8_DO_MANDATORY_BOTH \
	BLOCK func8_DO_block; \
	COLLECTION func8_DO_BLOCK_OBJECT; \
	VARIABLE func8_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func8_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func8_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func8_DO_BLOCK_OBJECT_Class; \
	VARIABLE func8_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func8_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func8_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func8_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func8_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func8_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func8_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func8_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func8_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func8_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func8_DO_BLOCK_OBJECT_page; \
	COMMAND func8_DO_BLOCK_OBJECT_read; \
	VARIABLE func8_DO_ST_REV; \
	MENU func8_DO_ST_REV_page; \
	COMMAND func8_DO_ST_REV_read; \
	VARIABLE func8_DO_TAG_DESC; \
	MENU func8_DO_TAG_DESC_page; \
	COMMAND func8_DO_TAG_DESC_read; \
	COMMAND func8_DO_TAG_DESC_write; \
	VARIABLE func8_DO_STRATEGY; \
	MENU func8_DO_STRATEGY_page; \
	COMMAND func8_DO_STRATEGY_read; \
	COMMAND func8_DO_STRATEGY_write; \
	VARIABLE func8_DO_ALERT_KEY; \
	MENU func8_DO_ALERT_KEY_page; \
	COMMAND func8_DO_ALERT_KEY_read; \
	COMMAND func8_DO_ALERT_KEY_write; \
	VARIABLE func8_DO_TARGET_MODE; \
	MENU func8_DO_TARGET_MODE_page; \
	COMMAND func8_DO_TARGET_MODE_read; \
	COMMAND func8_DO_TARGET_MODE_write; \
	COLLECTION func8_DO_MODE_BLK; \
	VARIABLE func8_DO_MODE_BLK_Actual; \
	VARIABLE func8_DO_MODE_BLK_Permitted; \
	VARIABLE func8_DO_MODE_BLK_Normal; \
	MENU func8_DO_MODE_BLK_page; \
	COMMAND func8_DO_MODE_BLK_read; \
	COLLECTION func8_DO_ALARM_SUM; \
	VARIABLE func8_DO_ALARM_SUM_Current; \
	VARIABLE func8_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func8_DO_ALARM_SUM_Unreported; \
	VARIABLE func8_DO_ALARM_SUM_Disabled; \
	MENU func8_DO_ALARM_SUM_page; \
	COMMAND func8_DO_ALARM_SUM_read; \
	COLLECTION func8_DO_BATCH; \
	VARIABLE func8_DO_BATCH_Batch_ID; \
	VARIABLE func8_DO_BATCH_Rup; \
	VARIABLE func8_DO_BATCH_Operation; \
	VARIABLE func8_DO_BATCH_Phase; \
	MENU func8_DO_BATCH_page; \
	COMMAND func8_DO_BATCH_read; \
	COMMAND func8_DO_BATCH_write; \
	COLLECTION func8_DO_SP_D; \
	VARIABLE func8_DO_SP_D_Value; \
	VARIABLE func8_DO_SP_D_Status_Condensed; \
	VARIABLE func8_DO_SP_D_Status_Quality; \
	VARIABLE func8_DO_SP_D_Status_Limit; \
	MENU func8_DO_SP_D_page; \
	COMMAND func8_DO_SP_D_read; \
	COMMAND func8_DO_SP_D_write; \
	VARIABLE func8_DO_INVERT; \
	MENU func8_DO_INVERT_page; \
	COMMAND func8_DO_INVERT_read; \
	COMMAND func8_DO_INVERT_write; \
	VARIABLE func8_DO_CHECK_BACK; \
	MENU func8_DO_CHECK_BACK_page; \
	COMMAND func8_DO_CHECK_BACK_read; \
	VARIABLE func8_DO_CHECK_BACK_MASK; \
	MENU func8_DO_CHECK_BACK_MASK_page; \
	COMMAND func8_DO_CHECK_BACK_MASK_read

#define USE_FUNC8_DO_MANDATORY_A \
	USE_FUNC8_DO_MANDATORY_BOTH; \
	MENU func8_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC8_DO_MANDATORY_B \
	USE_FUNC8_DO_MANDATORY_BOTH; \
	COLLECTION func8_DO_OUT_D; \
	VARIABLE func8_DO_OUT_D_Value; \
	VARIABLE func8_DO_OUT_D_Status_Condensed; \
	VARIABLE func8_DO_OUT_D_Status_Quality; \
	VARIABLE func8_DO_OUT_D_Status_Limit; \
	MENU func8_DO_OUT_D_page; \
	COMMAND func8_DO_OUT_D_read; \
	COMMAND func8_DO_OUT_D_write; \
	VARIABLE func8_DO_IN_CHANNEL; \
	MENU func8_DO_IN_CHANNEL_page; \
	COMMAND func8_DO_IN_CHANNEL_read; \
	COMMAND func8_DO_IN_CHANNEL_write; \
	VARIABLE func8_DO_FSAFE_TIME; \
	MENU func8_DO_FSAFE_TIME_page; \
	COMMAND func8_DO_FSAFE_TIME_read; \
	COMMAND func8_DO_FSAFE_TIME_write; \
	VARIABLE func8_DO_FSAFE_TYPE; \
	MENU func8_DO_FSAFE_TYPE_page; \
	COMMAND func8_DO_FSAFE_TYPE_read; \
	COMMAND func8_DO_FSAFE_TYPE_write; \
	VARIABLE func8_DO_FSAFE_VAL_D; \
	MENU func8_DO_FSAFE_VAL_D_page; \
	COMMAND func8_DO_FSAFE_VAL_D_read; \
	COMMAND func8_DO_FSAFE_VAL_D_write; \
	COLLECTION func8_DO_SIMULATE; \
	VARIABLE func8_DO_SIMULATE_Status_Condensed; \
	VARIABLE func8_DO_SIMULATE_Value; \
	VARIABLE func8_DO_SIMULATE_Enabled; \
	VARIABLE func8_DO_SIMULATE_Status_Quality; \
	VARIABLE func8_DO_SIMULATE_Status_Limit; \
	MENU func8_DO_SIMULATE_page; \
	COMMAND func8_DO_SIMULATE_read; \
	COMMAND func8_DO_SIMULATE_write; \
	COLLECTION func8_DO_VIEW_1; \
	MENU func8_DO_VIEW_1_page; \
	MENU func8_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC8_DO_OPTIONAL_BOTH \
	COLLECTION func8_DO_READBACK_D; \
	VARIABLE func8_DO_READBACK_D_Value; \
	VARIABLE func8_DO_READBACK_D_Status_Condensed; \
	VARIABLE func8_DO_READBACK_D_Status_Quality; \
	VARIABLE func8_DO_READBACK_D_Status_Limit; \
	MENU func8_DO_READBACK_D_page; \
	COMMAND func8_DO_READBACK_D_read; \
	COLLECTION func8_DO_RCAS_IN_D; \
	VARIABLE func8_DO_RCAS_IN_D_Value; \
	VARIABLE func8_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func8_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func8_DO_RCAS_IN_D_Status_Limit; \
	MENU func8_DO_RCAS_IN_D_page; \
	COMMAND func8_DO_RCAS_IN_D_read; \
	COMMAND func8_DO_RCAS_IN_D_write; \
	COLLECTION func8_DO_RCAS_OUT_D; \
	VARIABLE func8_DO_RCAS_OUT_D_Value; \
	VARIABLE func8_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func8_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func8_DO_RCAS_OUT_D_Status_Limit; \
	MENU func8_DO_RCAS_OUT_D_page; \
	COMMAND func8_DO_RCAS_OUT_D_read; \
	VARIABLE func8_DO_OUT_CHANNEL; \
	MENU func8_DO_OUT_CHANNEL_page; \
	COMMAND func8_DO_OUT_CHANNEL_read; \
	COMMAND func8_DO_OUT_CHANNEL_write; \
	COLLECTION func8_DO_VIEW_2; \
	MENU func8_DO_VIEW_2_page; \
	COLLECTION func8_DO_VIEW_3; \
	MENU func8_DO_VIEW_3_page

#define USE_FUNC8_DO_OPTIONAL_A \
	USE_FUNC8_DO_OPTIONAL_BOTH; \
	COLLECTION func8_DO_OUT_D; \
	VARIABLE func8_DO_OUT_D_Value; \
	VARIABLE func8_DO_OUT_D_Status_Condensed; \
	VARIABLE func8_DO_OUT_D_Status_Quality; \
	VARIABLE func8_DO_OUT_D_Status_Limit; \
	MENU func8_DO_OUT_D_page; \
	COMMAND func8_DO_OUT_D_read; \
	COMMAND func8_DO_OUT_D_write; \
	VARIABLE func8_DO_IN_CHANNEL; \
	MENU func8_DO_IN_CHANNEL_page; \
	COMMAND func8_DO_IN_CHANNEL_read; \
	COMMAND func8_DO_IN_CHANNEL_write; \
	VARIABLE func8_DO_FSAFE_TIME; \
	MENU func8_DO_FSAFE_TIME_page; \
	COMMAND func8_DO_FSAFE_TIME_read; \
	COMMAND func8_DO_FSAFE_TIME_write; \
	VARIABLE func8_DO_FSAFE_TYPE; \
	MENU func8_DO_FSAFE_TYPE_page; \
	COMMAND func8_DO_FSAFE_TYPE_read; \
	COMMAND func8_DO_FSAFE_TYPE_write; \
	VARIABLE func8_DO_FSAFE_VAL_D; \
	MENU func8_DO_FSAFE_VAL_D_page; \
	COMMAND func8_DO_FSAFE_VAL_D_read; \
	COMMAND func8_DO_FSAFE_VAL_D_write; \
	COLLECTION func8_DO_SIMULATE; \
	VARIABLE func8_DO_SIMULATE_Status_Condensed; \
	VARIABLE func8_DO_SIMULATE_Value; \
	VARIABLE func8_DO_SIMULATE_Enabled; \
	VARIABLE func8_DO_SIMULATE_Status_Quality; \
	VARIABLE func8_DO_SIMULATE_Status_Limit; \
	MENU func8_DO_SIMULATE_page; \
	COMMAND func8_DO_SIMULATE_read; \
	COMMAND func8_DO_SIMULATE_write; \
	COLLECTION func8_DO_VIEW_1; \
	MENU func8_DO_VIEW_1_page; \
	MENU func8_DO_Simple_Dialog_Optional_A

#define USE_FUNC8_DO_OPTIONAL_B \
	USE_FUNC8_DO_OPTIONAL_BOTH; \
	MENU func8_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC8_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func8_DO_)
#define USE_FUNC8_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func8_DO_)
#define USE_FUNC8_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func8_DO_)
#define USE_FUNC8_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func8_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC9_DO_MANDATORY_BOTH \
	BLOCK func9_DO_block; \
	COLLECTION func9_DO_BLOCK_OBJECT; \
	VARIABLE func9_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func9_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func9_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func9_DO_BLOCK_OBJECT_Class; \
	VARIABLE func9_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func9_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func9_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func9_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func9_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func9_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func9_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func9_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func9_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func9_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func9_DO_BLOCK_OBJECT_page; \
	COMMAND func9_DO_BLOCK_OBJECT_read; \
	VARIABLE func9_DO_ST_REV; \
	MENU func9_DO_ST_REV_page; \
	COMMAND func9_DO_ST_REV_read; \
	VARIABLE func9_DO_TAG_DESC; \
	MENU func9_DO_TAG_DESC_page; \
	COMMAND func9_DO_TAG_DESC_read; \
	COMMAND func9_DO_TAG_DESC_write; \
	VARIABLE func9_DO_STRATEGY; \
	MENU func9_DO_STRATEGY_page; \
	COMMAND func9_DO_STRATEGY_read; \
	COMMAND func9_DO_STRATEGY_write; \
	VARIABLE func9_DO_ALERT_KEY; \
	MENU func9_DO_ALERT_KEY_page; \
	COMMAND func9_DO_ALERT_KEY_read; \
	COMMAND func9_DO_ALERT_KEY_write; \
	VARIABLE func9_DO_TARGET_MODE; \
	MENU func9_DO_TARGET_MODE_page; \
	COMMAND func9_DO_TARGET_MODE_read; \
	COMMAND func9_DO_TARGET_MODE_write; \
	COLLECTION func9_DO_MODE_BLK; \
	VARIABLE func9_DO_MODE_BLK_Actual; \
	VARIABLE func9_DO_MODE_BLK_Permitted; \
	VARIABLE func9_DO_MODE_BLK_Normal; \
	MENU func9_DO_MODE_BLK_page; \
	COMMAND func9_DO_MODE_BLK_read; \
	COLLECTION func9_DO_ALARM_SUM; \
	VARIABLE func9_DO_ALARM_SUM_Current; \
	VARIABLE func9_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func9_DO_ALARM_SUM_Unreported; \
	VARIABLE func9_DO_ALARM_SUM_Disabled; \
	MENU func9_DO_ALARM_SUM_page; \
	COMMAND func9_DO_ALARM_SUM_read; \
	COLLECTION func9_DO_BATCH; \
	VARIABLE func9_DO_BATCH_Batch_ID; \
	VARIABLE func9_DO_BATCH_Rup; \
	VARIABLE func9_DO_BATCH_Operation; \
	VARIABLE func9_DO_BATCH_Phase; \
	MENU func9_DO_BATCH_page; \
	COMMAND func9_DO_BATCH_read; \
	COMMAND func9_DO_BATCH_write; \
	COLLECTION func9_DO_SP_D; \
	VARIABLE func9_DO_SP_D_Value; \
	VARIABLE func9_DO_SP_D_Status_Condensed; \
	VARIABLE func9_DO_SP_D_Status_Quality; \
	VARIABLE func9_DO_SP_D_Status_Limit; \
	MENU func9_DO_SP_D_page; \
	COMMAND func9_DO_SP_D_read; \
	COMMAND func9_DO_SP_D_write; \
	VARIABLE func9_DO_INVERT; \
	MENU func9_DO_INVERT_page; \
	COMMAND func9_DO_INVERT_read; \
	COMMAND func9_DO_INVERT_write; \
	VARIABLE func9_DO_CHECK_BACK; \
	MENU func9_DO_CHECK_BACK_page; \
	COMMAND func9_DO_CHECK_BACK_read; \
	VARIABLE func9_DO_CHECK_BACK_MASK; \
	MENU func9_DO_CHECK_BACK_MASK_page; \
	COMMAND func9_DO_CHECK_BACK_MASK_read

#define USE_FUNC9_DO_MANDATORY_A \
	USE_FUNC9_DO_MANDATORY_BOTH; \
	MENU func9_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC9_DO_MANDATORY_B \
	USE_FUNC9_DO_MANDATORY_BOTH; \
	COLLECTION func9_DO_OUT_D; \
	VARIABLE func9_DO_OUT_D_Value; \
	VARIABLE func9_DO_OUT_D_Status_Condensed; \
	VARIABLE func9_DO_OUT_D_Status_Quality; \
	VARIABLE func9_DO_OUT_D_Status_Limit; \
	MENU func9_DO_OUT_D_page; \
	COMMAND func9_DO_OUT_D_read; \
	COMMAND func9_DO_OUT_D_write; \
	VARIABLE func9_DO_IN_CHANNEL; \
	MENU func9_DO_IN_CHANNEL_page; \
	COMMAND func9_DO_IN_CHANNEL_read; \
	COMMAND func9_DO_IN_CHANNEL_write; \
	VARIABLE func9_DO_FSAFE_TIME; \
	MENU func9_DO_FSAFE_TIME_page; \
	COMMAND func9_DO_FSAFE_TIME_read; \
	COMMAND func9_DO_FSAFE_TIME_write; \
	VARIABLE func9_DO_FSAFE_TYPE; \
	MENU func9_DO_FSAFE_TYPE_page; \
	COMMAND func9_DO_FSAFE_TYPE_read; \
	COMMAND func9_DO_FSAFE_TYPE_write; \
	VARIABLE func9_DO_FSAFE_VAL_D; \
	MENU func9_DO_FSAFE_VAL_D_page; \
	COMMAND func9_DO_FSAFE_VAL_D_read; \
	COMMAND func9_DO_FSAFE_VAL_D_write; \
	COLLECTION func9_DO_SIMULATE; \
	VARIABLE func9_DO_SIMULATE_Status_Condensed; \
	VARIABLE func9_DO_SIMULATE_Value; \
	VARIABLE func9_DO_SIMULATE_Enabled; \
	VARIABLE func9_DO_SIMULATE_Status_Quality; \
	VARIABLE func9_DO_SIMULATE_Status_Limit; \
	MENU func9_DO_SIMULATE_page; \
	COMMAND func9_DO_SIMULATE_read; \
	COMMAND func9_DO_SIMULATE_write; \
	COLLECTION func9_DO_VIEW_1; \
	MENU func9_DO_VIEW_1_page; \
	MENU func9_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC9_DO_OPTIONAL_BOTH \
	COLLECTION func9_DO_READBACK_D; \
	VARIABLE func9_DO_READBACK_D_Value; \
	VARIABLE func9_DO_READBACK_D_Status_Condensed; \
	VARIABLE func9_DO_READBACK_D_Status_Quality; \
	VARIABLE func9_DO_READBACK_D_Status_Limit; \
	MENU func9_DO_READBACK_D_page; \
	COMMAND func9_DO_READBACK_D_read; \
	COLLECTION func9_DO_RCAS_IN_D; \
	VARIABLE func9_DO_RCAS_IN_D_Value; \
	VARIABLE func9_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func9_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func9_DO_RCAS_IN_D_Status_Limit; \
	MENU func9_DO_RCAS_IN_D_page; \
	COMMAND func9_DO_RCAS_IN_D_read; \
	COMMAND func9_DO_RCAS_IN_D_write; \
	COLLECTION func9_DO_RCAS_OUT_D; \
	VARIABLE func9_DO_RCAS_OUT_D_Value; \
	VARIABLE func9_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func9_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func9_DO_RCAS_OUT_D_Status_Limit; \
	MENU func9_DO_RCAS_OUT_D_page; \
	COMMAND func9_DO_RCAS_OUT_D_read; \
	VARIABLE func9_DO_OUT_CHANNEL; \
	MENU func9_DO_OUT_CHANNEL_page; \
	COMMAND func9_DO_OUT_CHANNEL_read; \
	COMMAND func9_DO_OUT_CHANNEL_write; \
	COLLECTION func9_DO_VIEW_2; \
	MENU func9_DO_VIEW_2_page; \
	COLLECTION func9_DO_VIEW_3; \
	MENU func9_DO_VIEW_3_page

#define USE_FUNC9_DO_OPTIONAL_A \
	USE_FUNC9_DO_OPTIONAL_BOTH; \
	COLLECTION func9_DO_OUT_D; \
	VARIABLE func9_DO_OUT_D_Value; \
	VARIABLE func9_DO_OUT_D_Status_Condensed; \
	VARIABLE func9_DO_OUT_D_Status_Quality; \
	VARIABLE func9_DO_OUT_D_Status_Limit; \
	MENU func9_DO_OUT_D_page; \
	COMMAND func9_DO_OUT_D_read; \
	COMMAND func9_DO_OUT_D_write; \
	VARIABLE func9_DO_IN_CHANNEL; \
	MENU func9_DO_IN_CHANNEL_page; \
	COMMAND func9_DO_IN_CHANNEL_read; \
	COMMAND func9_DO_IN_CHANNEL_write; \
	VARIABLE func9_DO_FSAFE_TIME; \
	MENU func9_DO_FSAFE_TIME_page; \
	COMMAND func9_DO_FSAFE_TIME_read; \
	COMMAND func9_DO_FSAFE_TIME_write; \
	VARIABLE func9_DO_FSAFE_TYPE; \
	MENU func9_DO_FSAFE_TYPE_page; \
	COMMAND func9_DO_FSAFE_TYPE_read; \
	COMMAND func9_DO_FSAFE_TYPE_write; \
	VARIABLE func9_DO_FSAFE_VAL_D; \
	MENU func9_DO_FSAFE_VAL_D_page; \
	COMMAND func9_DO_FSAFE_VAL_D_read; \
	COMMAND func9_DO_FSAFE_VAL_D_write; \
	COLLECTION func9_DO_SIMULATE; \
	VARIABLE func9_DO_SIMULATE_Status_Condensed; \
	VARIABLE func9_DO_SIMULATE_Value; \
	VARIABLE func9_DO_SIMULATE_Enabled; \
	VARIABLE func9_DO_SIMULATE_Status_Quality; \
	VARIABLE func9_DO_SIMULATE_Status_Limit; \
	MENU func9_DO_SIMULATE_page; \
	COMMAND func9_DO_SIMULATE_read; \
	COMMAND func9_DO_SIMULATE_write; \
	COLLECTION func9_DO_VIEW_1; \
	MENU func9_DO_VIEW_1_page; \
	MENU func9_DO_Simple_Dialog_Optional_A

#define USE_FUNC9_DO_OPTIONAL_B \
	USE_FUNC9_DO_OPTIONAL_BOTH; \
	MENU func9_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC9_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func9_DO_)
#define USE_FUNC9_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func9_DO_)
#define USE_FUNC9_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func9_DO_)
#define USE_FUNC9_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func9_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC10_DO_MANDATORY_BOTH \
	BLOCK func10_DO_block; \
	COLLECTION func10_DO_BLOCK_OBJECT; \
	VARIABLE func10_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func10_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func10_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func10_DO_BLOCK_OBJECT_Class; \
	VARIABLE func10_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func10_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func10_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func10_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func10_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func10_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func10_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func10_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func10_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func10_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func10_DO_BLOCK_OBJECT_page; \
	COMMAND func10_DO_BLOCK_OBJECT_read; \
	VARIABLE func10_DO_ST_REV; \
	MENU func10_DO_ST_REV_page; \
	COMMAND func10_DO_ST_REV_read; \
	VARIABLE func10_DO_TAG_DESC; \
	MENU func10_DO_TAG_DESC_page; \
	COMMAND func10_DO_TAG_DESC_read; \
	COMMAND func10_DO_TAG_DESC_write; \
	VARIABLE func10_DO_STRATEGY; \
	MENU func10_DO_STRATEGY_page; \
	COMMAND func10_DO_STRATEGY_read; \
	COMMAND func10_DO_STRATEGY_write; \
	VARIABLE func10_DO_ALERT_KEY; \
	MENU func10_DO_ALERT_KEY_page; \
	COMMAND func10_DO_ALERT_KEY_read; \
	COMMAND func10_DO_ALERT_KEY_write; \
	VARIABLE func10_DO_TARGET_MODE; \
	MENU func10_DO_TARGET_MODE_page; \
	COMMAND func10_DO_TARGET_MODE_read; \
	COMMAND func10_DO_TARGET_MODE_write; \
	COLLECTION func10_DO_MODE_BLK; \
	VARIABLE func10_DO_MODE_BLK_Actual; \
	VARIABLE func10_DO_MODE_BLK_Permitted; \
	VARIABLE func10_DO_MODE_BLK_Normal; \
	MENU func10_DO_MODE_BLK_page; \
	COMMAND func10_DO_MODE_BLK_read; \
	COLLECTION func10_DO_ALARM_SUM; \
	VARIABLE func10_DO_ALARM_SUM_Current; \
	VARIABLE func10_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func10_DO_ALARM_SUM_Unreported; \
	VARIABLE func10_DO_ALARM_SUM_Disabled; \
	MENU func10_DO_ALARM_SUM_page; \
	COMMAND func10_DO_ALARM_SUM_read; \
	COLLECTION func10_DO_BATCH; \
	VARIABLE func10_DO_BATCH_Batch_ID; \
	VARIABLE func10_DO_BATCH_Rup; \
	VARIABLE func10_DO_BATCH_Operation; \
	VARIABLE func10_DO_BATCH_Phase; \
	MENU func10_DO_BATCH_page; \
	COMMAND func10_DO_BATCH_read; \
	COMMAND func10_DO_BATCH_write; \
	COLLECTION func10_DO_SP_D; \
	VARIABLE func10_DO_SP_D_Value; \
	VARIABLE func10_DO_SP_D_Status_Condensed; \
	VARIABLE func10_DO_SP_D_Status_Quality; \
	VARIABLE func10_DO_SP_D_Status_Limit; \
	MENU func10_DO_SP_D_page; \
	COMMAND func10_DO_SP_D_read; \
	COMMAND func10_DO_SP_D_write; \
	VARIABLE func10_DO_INVERT; \
	MENU func10_DO_INVERT_page; \
	COMMAND func10_DO_INVERT_read; \
	COMMAND func10_DO_INVERT_write; \
	VARIABLE func10_DO_CHECK_BACK; \
	MENU func10_DO_CHECK_BACK_page; \
	COMMAND func10_DO_CHECK_BACK_read; \
	VARIABLE func10_DO_CHECK_BACK_MASK; \
	MENU func10_DO_CHECK_BACK_MASK_page; \
	COMMAND func10_DO_CHECK_BACK_MASK_read

#define USE_FUNC10_DO_MANDATORY_A \
	USE_FUNC10_DO_MANDATORY_BOTH; \
	MENU func10_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC10_DO_MANDATORY_B \
	USE_FUNC10_DO_MANDATORY_BOTH; \
	COLLECTION func10_DO_OUT_D; \
	VARIABLE func10_DO_OUT_D_Value; \
	VARIABLE func10_DO_OUT_D_Status_Condensed; \
	VARIABLE func10_DO_OUT_D_Status_Quality; \
	VARIABLE func10_DO_OUT_D_Status_Limit; \
	MENU func10_DO_OUT_D_page; \
	COMMAND func10_DO_OUT_D_read; \
	COMMAND func10_DO_OUT_D_write; \
	VARIABLE func10_DO_IN_CHANNEL; \
	MENU func10_DO_IN_CHANNEL_page; \
	COMMAND func10_DO_IN_CHANNEL_read; \
	COMMAND func10_DO_IN_CHANNEL_write; \
	VARIABLE func10_DO_FSAFE_TIME; \
	MENU func10_DO_FSAFE_TIME_page; \
	COMMAND func10_DO_FSAFE_TIME_read; \
	COMMAND func10_DO_FSAFE_TIME_write; \
	VARIABLE func10_DO_FSAFE_TYPE; \
	MENU func10_DO_FSAFE_TYPE_page; \
	COMMAND func10_DO_FSAFE_TYPE_read; \
	COMMAND func10_DO_FSAFE_TYPE_write; \
	VARIABLE func10_DO_FSAFE_VAL_D; \
	MENU func10_DO_FSAFE_VAL_D_page; \
	COMMAND func10_DO_FSAFE_VAL_D_read; \
	COMMAND func10_DO_FSAFE_VAL_D_write; \
	COLLECTION func10_DO_SIMULATE; \
	VARIABLE func10_DO_SIMULATE_Status_Condensed; \
	VARIABLE func10_DO_SIMULATE_Value; \
	VARIABLE func10_DO_SIMULATE_Enabled; \
	VARIABLE func10_DO_SIMULATE_Status_Quality; \
	VARIABLE func10_DO_SIMULATE_Status_Limit; \
	MENU func10_DO_SIMULATE_page; \
	COMMAND func10_DO_SIMULATE_read; \
	COMMAND func10_DO_SIMULATE_write; \
	COLLECTION func10_DO_VIEW_1; \
	MENU func10_DO_VIEW_1_page; \
	MENU func10_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC10_DO_OPTIONAL_BOTH \
	COLLECTION func10_DO_READBACK_D; \
	VARIABLE func10_DO_READBACK_D_Value; \
	VARIABLE func10_DO_READBACK_D_Status_Condensed; \
	VARIABLE func10_DO_READBACK_D_Status_Quality; \
	VARIABLE func10_DO_READBACK_D_Status_Limit; \
	MENU func10_DO_READBACK_D_page; \
	COMMAND func10_DO_READBACK_D_read; \
	COLLECTION func10_DO_RCAS_IN_D; \
	VARIABLE func10_DO_RCAS_IN_D_Value; \
	VARIABLE func10_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func10_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func10_DO_RCAS_IN_D_Status_Limit; \
	MENU func10_DO_RCAS_IN_D_page; \
	COMMAND func10_DO_RCAS_IN_D_read; \
	COMMAND func10_DO_RCAS_IN_D_write; \
	COLLECTION func10_DO_RCAS_OUT_D; \
	VARIABLE func10_DO_RCAS_OUT_D_Value; \
	VARIABLE func10_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func10_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func10_DO_RCAS_OUT_D_Status_Limit; \
	MENU func10_DO_RCAS_OUT_D_page; \
	COMMAND func10_DO_RCAS_OUT_D_read; \
	VARIABLE func10_DO_OUT_CHANNEL; \
	MENU func10_DO_OUT_CHANNEL_page; \
	COMMAND func10_DO_OUT_CHANNEL_read; \
	COMMAND func10_DO_OUT_CHANNEL_write; \
	COLLECTION func10_DO_VIEW_2; \
	MENU func10_DO_VIEW_2_page; \
	COLLECTION func10_DO_VIEW_3; \
	MENU func10_DO_VIEW_3_page

#define USE_FUNC10_DO_OPTIONAL_A \
	USE_FUNC10_DO_OPTIONAL_BOTH; \
	COLLECTION func10_DO_OUT_D; \
	VARIABLE func10_DO_OUT_D_Value; \
	VARIABLE func10_DO_OUT_D_Status_Condensed; \
	VARIABLE func10_DO_OUT_D_Status_Quality; \
	VARIABLE func10_DO_OUT_D_Status_Limit; \
	MENU func10_DO_OUT_D_page; \
	COMMAND func10_DO_OUT_D_read; \
	COMMAND func10_DO_OUT_D_write; \
	VARIABLE func10_DO_IN_CHANNEL; \
	MENU func10_DO_IN_CHANNEL_page; \
	COMMAND func10_DO_IN_CHANNEL_read; \
	COMMAND func10_DO_IN_CHANNEL_write; \
	VARIABLE func10_DO_FSAFE_TIME; \
	MENU func10_DO_FSAFE_TIME_page; \
	COMMAND func10_DO_FSAFE_TIME_read; \
	COMMAND func10_DO_FSAFE_TIME_write; \
	VARIABLE func10_DO_FSAFE_TYPE; \
	MENU func10_DO_FSAFE_TYPE_page; \
	COMMAND func10_DO_FSAFE_TYPE_read; \
	COMMAND func10_DO_FSAFE_TYPE_write; \
	VARIABLE func10_DO_FSAFE_VAL_D; \
	MENU func10_DO_FSAFE_VAL_D_page; \
	COMMAND func10_DO_FSAFE_VAL_D_read; \
	COMMAND func10_DO_FSAFE_VAL_D_write; \
	COLLECTION func10_DO_SIMULATE; \
	VARIABLE func10_DO_SIMULATE_Status_Condensed; \
	VARIABLE func10_DO_SIMULATE_Value; \
	VARIABLE func10_DO_SIMULATE_Enabled; \
	VARIABLE func10_DO_SIMULATE_Status_Quality; \
	VARIABLE func10_DO_SIMULATE_Status_Limit; \
	MENU func10_DO_SIMULATE_page; \
	COMMAND func10_DO_SIMULATE_read; \
	COMMAND func10_DO_SIMULATE_write; \
	COLLECTION func10_DO_VIEW_1; \
	MENU func10_DO_VIEW_1_page; \
	MENU func10_DO_Simple_Dialog_Optional_A

#define USE_FUNC10_DO_OPTIONAL_B \
	USE_FUNC10_DO_OPTIONAL_BOTH; \
	MENU func10_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC10_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func10_DO_)
#define USE_FUNC10_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func10_DO_)
#define USE_FUNC10_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func10_DO_)
#define USE_FUNC10_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func10_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC11_DO_MANDATORY_BOTH \
	BLOCK func11_DO_block; \
	COLLECTION func11_DO_BLOCK_OBJECT; \
	VARIABLE func11_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func11_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func11_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func11_DO_BLOCK_OBJECT_Class; \
	VARIABLE func11_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func11_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func11_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func11_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func11_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func11_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func11_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func11_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func11_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func11_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func11_DO_BLOCK_OBJECT_page; \
	COMMAND func11_DO_BLOCK_OBJECT_read; \
	VARIABLE func11_DO_ST_REV; \
	MENU func11_DO_ST_REV_page; \
	COMMAND func11_DO_ST_REV_read; \
	VARIABLE func11_DO_TAG_DESC; \
	MENU func11_DO_TAG_DESC_page; \
	COMMAND func11_DO_TAG_DESC_read; \
	COMMAND func11_DO_TAG_DESC_write; \
	VARIABLE func11_DO_STRATEGY; \
	MENU func11_DO_STRATEGY_page; \
	COMMAND func11_DO_STRATEGY_read; \
	COMMAND func11_DO_STRATEGY_write; \
	VARIABLE func11_DO_ALERT_KEY; \
	MENU func11_DO_ALERT_KEY_page; \
	COMMAND func11_DO_ALERT_KEY_read; \
	COMMAND func11_DO_ALERT_KEY_write; \
	VARIABLE func11_DO_TARGET_MODE; \
	MENU func11_DO_TARGET_MODE_page; \
	COMMAND func11_DO_TARGET_MODE_read; \
	COMMAND func11_DO_TARGET_MODE_write; \
	COLLECTION func11_DO_MODE_BLK; \
	VARIABLE func11_DO_MODE_BLK_Actual; \
	VARIABLE func11_DO_MODE_BLK_Permitted; \
	VARIABLE func11_DO_MODE_BLK_Normal; \
	MENU func11_DO_MODE_BLK_page; \
	COMMAND func11_DO_MODE_BLK_read; \
	COLLECTION func11_DO_ALARM_SUM; \
	VARIABLE func11_DO_ALARM_SUM_Current; \
	VARIABLE func11_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func11_DO_ALARM_SUM_Unreported; \
	VARIABLE func11_DO_ALARM_SUM_Disabled; \
	MENU func11_DO_ALARM_SUM_page; \
	COMMAND func11_DO_ALARM_SUM_read; \
	COLLECTION func11_DO_BATCH; \
	VARIABLE func11_DO_BATCH_Batch_ID; \
	VARIABLE func11_DO_BATCH_Rup; \
	VARIABLE func11_DO_BATCH_Operation; \
	VARIABLE func11_DO_BATCH_Phase; \
	MENU func11_DO_BATCH_page; \
	COMMAND func11_DO_BATCH_read; \
	COMMAND func11_DO_BATCH_write; \
	COLLECTION func11_DO_SP_D; \
	VARIABLE func11_DO_SP_D_Value; \
	VARIABLE func11_DO_SP_D_Status_Condensed; \
	VARIABLE func11_DO_SP_D_Status_Quality; \
	VARIABLE func11_DO_SP_D_Status_Limit; \
	MENU func11_DO_SP_D_page; \
	COMMAND func11_DO_SP_D_read; \
	COMMAND func11_DO_SP_D_write; \
	VARIABLE func11_DO_INVERT; \
	MENU func11_DO_INVERT_page; \
	COMMAND func11_DO_INVERT_read; \
	COMMAND func11_DO_INVERT_write; \
	VARIABLE func11_DO_CHECK_BACK; \
	MENU func11_DO_CHECK_BACK_page; \
	COMMAND func11_DO_CHECK_BACK_read; \
	VARIABLE func11_DO_CHECK_BACK_MASK; \
	MENU func11_DO_CHECK_BACK_MASK_page; \
	COMMAND func11_DO_CHECK_BACK_MASK_read

#define USE_FUNC11_DO_MANDATORY_A \
	USE_FUNC11_DO_MANDATORY_BOTH; \
	MENU func11_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC11_DO_MANDATORY_B \
	USE_FUNC11_DO_MANDATORY_BOTH; \
	COLLECTION func11_DO_OUT_D; \
	VARIABLE func11_DO_OUT_D_Value; \
	VARIABLE func11_DO_OUT_D_Status_Condensed; \
	VARIABLE func11_DO_OUT_D_Status_Quality; \
	VARIABLE func11_DO_OUT_D_Status_Limit; \
	MENU func11_DO_OUT_D_page; \
	COMMAND func11_DO_OUT_D_read; \
	COMMAND func11_DO_OUT_D_write; \
	VARIABLE func11_DO_IN_CHANNEL; \
	MENU func11_DO_IN_CHANNEL_page; \
	COMMAND func11_DO_IN_CHANNEL_read; \
	COMMAND func11_DO_IN_CHANNEL_write; \
	VARIABLE func11_DO_FSAFE_TIME; \
	MENU func11_DO_FSAFE_TIME_page; \
	COMMAND func11_DO_FSAFE_TIME_read; \
	COMMAND func11_DO_FSAFE_TIME_write; \
	VARIABLE func11_DO_FSAFE_TYPE; \
	MENU func11_DO_FSAFE_TYPE_page; \
	COMMAND func11_DO_FSAFE_TYPE_read; \
	COMMAND func11_DO_FSAFE_TYPE_write; \
	VARIABLE func11_DO_FSAFE_VAL_D; \
	MENU func11_DO_FSAFE_VAL_D_page; \
	COMMAND func11_DO_FSAFE_VAL_D_read; \
	COMMAND func11_DO_FSAFE_VAL_D_write; \
	COLLECTION func11_DO_SIMULATE; \
	VARIABLE func11_DO_SIMULATE_Status_Condensed; \
	VARIABLE func11_DO_SIMULATE_Value; \
	VARIABLE func11_DO_SIMULATE_Enabled; \
	VARIABLE func11_DO_SIMULATE_Status_Quality; \
	VARIABLE func11_DO_SIMULATE_Status_Limit; \
	MENU func11_DO_SIMULATE_page; \
	COMMAND func11_DO_SIMULATE_read; \
	COMMAND func11_DO_SIMULATE_write; \
	COLLECTION func11_DO_VIEW_1; \
	MENU func11_DO_VIEW_1_page; \
	MENU func11_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC11_DO_OPTIONAL_BOTH \
	COLLECTION func11_DO_READBACK_D; \
	VARIABLE func11_DO_READBACK_D_Value; \
	VARIABLE func11_DO_READBACK_D_Status_Condensed; \
	VARIABLE func11_DO_READBACK_D_Status_Quality; \
	VARIABLE func11_DO_READBACK_D_Status_Limit; \
	MENU func11_DO_READBACK_D_page; \
	COMMAND func11_DO_READBACK_D_read; \
	COLLECTION func11_DO_RCAS_IN_D; \
	VARIABLE func11_DO_RCAS_IN_D_Value; \
	VARIABLE func11_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func11_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func11_DO_RCAS_IN_D_Status_Limit; \
	MENU func11_DO_RCAS_IN_D_page; \
	COMMAND func11_DO_RCAS_IN_D_read; \
	COMMAND func11_DO_RCAS_IN_D_write; \
	COLLECTION func11_DO_RCAS_OUT_D; \
	VARIABLE func11_DO_RCAS_OUT_D_Value; \
	VARIABLE func11_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func11_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func11_DO_RCAS_OUT_D_Status_Limit; \
	MENU func11_DO_RCAS_OUT_D_page; \
	COMMAND func11_DO_RCAS_OUT_D_read; \
	VARIABLE func11_DO_OUT_CHANNEL; \
	MENU func11_DO_OUT_CHANNEL_page; \
	COMMAND func11_DO_OUT_CHANNEL_read; \
	COMMAND func11_DO_OUT_CHANNEL_write; \
	COLLECTION func11_DO_VIEW_2; \
	MENU func11_DO_VIEW_2_page; \
	COLLECTION func11_DO_VIEW_3; \
	MENU func11_DO_VIEW_3_page

#define USE_FUNC11_DO_OPTIONAL_A \
	USE_FUNC11_DO_OPTIONAL_BOTH; \
	COLLECTION func11_DO_OUT_D; \
	VARIABLE func11_DO_OUT_D_Value; \
	VARIABLE func11_DO_OUT_D_Status_Condensed; \
	VARIABLE func11_DO_OUT_D_Status_Quality; \
	VARIABLE func11_DO_OUT_D_Status_Limit; \
	MENU func11_DO_OUT_D_page; \
	COMMAND func11_DO_OUT_D_read; \
	COMMAND func11_DO_OUT_D_write; \
	VARIABLE func11_DO_IN_CHANNEL; \
	MENU func11_DO_IN_CHANNEL_page; \
	COMMAND func11_DO_IN_CHANNEL_read; \
	COMMAND func11_DO_IN_CHANNEL_write; \
	VARIABLE func11_DO_FSAFE_TIME; \
	MENU func11_DO_FSAFE_TIME_page; \
	COMMAND func11_DO_FSAFE_TIME_read; \
	COMMAND func11_DO_FSAFE_TIME_write; \
	VARIABLE func11_DO_FSAFE_TYPE; \
	MENU func11_DO_FSAFE_TYPE_page; \
	COMMAND func11_DO_FSAFE_TYPE_read; \
	COMMAND func11_DO_FSAFE_TYPE_write; \
	VARIABLE func11_DO_FSAFE_VAL_D; \
	MENU func11_DO_FSAFE_VAL_D_page; \
	COMMAND func11_DO_FSAFE_VAL_D_read; \
	COMMAND func11_DO_FSAFE_VAL_D_write; \
	COLLECTION func11_DO_SIMULATE; \
	VARIABLE func11_DO_SIMULATE_Status_Condensed; \
	VARIABLE func11_DO_SIMULATE_Value; \
	VARIABLE func11_DO_SIMULATE_Enabled; \
	VARIABLE func11_DO_SIMULATE_Status_Quality; \
	VARIABLE func11_DO_SIMULATE_Status_Limit; \
	MENU func11_DO_SIMULATE_page; \
	COMMAND func11_DO_SIMULATE_read; \
	COMMAND func11_DO_SIMULATE_write; \
	COLLECTION func11_DO_VIEW_1; \
	MENU func11_DO_VIEW_1_page; \
	MENU func11_DO_Simple_Dialog_Optional_A

#define USE_FUNC11_DO_OPTIONAL_B \
	USE_FUNC11_DO_OPTIONAL_BOTH; \
	MENU func11_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC11_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func11_DO_)
#define USE_FUNC11_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func11_DO_)
#define USE_FUNC11_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func11_DO_)
#define USE_FUNC11_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func11_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC12_DO_MANDATORY_BOTH \
	BLOCK func12_DO_block; \
	COLLECTION func12_DO_BLOCK_OBJECT; \
	VARIABLE func12_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func12_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func12_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func12_DO_BLOCK_OBJECT_Class; \
	VARIABLE func12_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func12_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func12_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func12_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func12_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func12_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func12_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func12_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func12_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func12_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func12_DO_BLOCK_OBJECT_page; \
	COMMAND func12_DO_BLOCK_OBJECT_read; \
	VARIABLE func12_DO_ST_REV; \
	MENU func12_DO_ST_REV_page; \
	COMMAND func12_DO_ST_REV_read; \
	VARIABLE func12_DO_TAG_DESC; \
	MENU func12_DO_TAG_DESC_page; \
	COMMAND func12_DO_TAG_DESC_read; \
	COMMAND func12_DO_TAG_DESC_write; \
	VARIABLE func12_DO_STRATEGY; \
	MENU func12_DO_STRATEGY_page; \
	COMMAND func12_DO_STRATEGY_read; \
	COMMAND func12_DO_STRATEGY_write; \
	VARIABLE func12_DO_ALERT_KEY; \
	MENU func12_DO_ALERT_KEY_page; \
	COMMAND func12_DO_ALERT_KEY_read; \
	COMMAND func12_DO_ALERT_KEY_write; \
	VARIABLE func12_DO_TARGET_MODE; \
	MENU func12_DO_TARGET_MODE_page; \
	COMMAND func12_DO_TARGET_MODE_read; \
	COMMAND func12_DO_TARGET_MODE_write; \
	COLLECTION func12_DO_MODE_BLK; \
	VARIABLE func12_DO_MODE_BLK_Actual; \
	VARIABLE func12_DO_MODE_BLK_Permitted; \
	VARIABLE func12_DO_MODE_BLK_Normal; \
	MENU func12_DO_MODE_BLK_page; \
	COMMAND func12_DO_MODE_BLK_read; \
	COLLECTION func12_DO_ALARM_SUM; \
	VARIABLE func12_DO_ALARM_SUM_Current; \
	VARIABLE func12_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func12_DO_ALARM_SUM_Unreported; \
	VARIABLE func12_DO_ALARM_SUM_Disabled; \
	MENU func12_DO_ALARM_SUM_page; \
	COMMAND func12_DO_ALARM_SUM_read; \
	COLLECTION func12_DO_BATCH; \
	VARIABLE func12_DO_BATCH_Batch_ID; \
	VARIABLE func12_DO_BATCH_Rup; \
	VARIABLE func12_DO_BATCH_Operation; \
	VARIABLE func12_DO_BATCH_Phase; \
	MENU func12_DO_BATCH_page; \
	COMMAND func12_DO_BATCH_read; \
	COMMAND func12_DO_BATCH_write; \
	COLLECTION func12_DO_SP_D; \
	VARIABLE func12_DO_SP_D_Value; \
	VARIABLE func12_DO_SP_D_Status_Condensed; \
	VARIABLE func12_DO_SP_D_Status_Quality; \
	VARIABLE func12_DO_SP_D_Status_Limit; \
	MENU func12_DO_SP_D_page; \
	COMMAND func12_DO_SP_D_read; \
	COMMAND func12_DO_SP_D_write; \
	VARIABLE func12_DO_INVERT; \
	MENU func12_DO_INVERT_page; \
	COMMAND func12_DO_INVERT_read; \
	COMMAND func12_DO_INVERT_write; \
	VARIABLE func12_DO_CHECK_BACK; \
	MENU func12_DO_CHECK_BACK_page; \
	COMMAND func12_DO_CHECK_BACK_read; \
	VARIABLE func12_DO_CHECK_BACK_MASK; \
	MENU func12_DO_CHECK_BACK_MASK_page; \
	COMMAND func12_DO_CHECK_BACK_MASK_read

#define USE_FUNC12_DO_MANDATORY_A \
	USE_FUNC12_DO_MANDATORY_BOTH; \
	MENU func12_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC12_DO_MANDATORY_B \
	USE_FUNC12_DO_MANDATORY_BOTH; \
	COLLECTION func12_DO_OUT_D; \
	VARIABLE func12_DO_OUT_D_Value; \
	VARIABLE func12_DO_OUT_D_Status_Condensed; \
	VARIABLE func12_DO_OUT_D_Status_Quality; \
	VARIABLE func12_DO_OUT_D_Status_Limit; \
	MENU func12_DO_OUT_D_page; \
	COMMAND func12_DO_OUT_D_read; \
	COMMAND func12_DO_OUT_D_write; \
	VARIABLE func12_DO_IN_CHANNEL; \
	MENU func12_DO_IN_CHANNEL_page; \
	COMMAND func12_DO_IN_CHANNEL_read; \
	COMMAND func12_DO_IN_CHANNEL_write; \
	VARIABLE func12_DO_FSAFE_TIME; \
	MENU func12_DO_FSAFE_TIME_page; \
	COMMAND func12_DO_FSAFE_TIME_read; \
	COMMAND func12_DO_FSAFE_TIME_write; \
	VARIABLE func12_DO_FSAFE_TYPE; \
	MENU func12_DO_FSAFE_TYPE_page; \
	COMMAND func12_DO_FSAFE_TYPE_read; \
	COMMAND func12_DO_FSAFE_TYPE_write; \
	VARIABLE func12_DO_FSAFE_VAL_D; \
	MENU func12_DO_FSAFE_VAL_D_page; \
	COMMAND func12_DO_FSAFE_VAL_D_read; \
	COMMAND func12_DO_FSAFE_VAL_D_write; \
	COLLECTION func12_DO_SIMULATE; \
	VARIABLE func12_DO_SIMULATE_Status_Condensed; \
	VARIABLE func12_DO_SIMULATE_Value; \
	VARIABLE func12_DO_SIMULATE_Enabled; \
	VARIABLE func12_DO_SIMULATE_Status_Quality; \
	VARIABLE func12_DO_SIMULATE_Status_Limit; \
	MENU func12_DO_SIMULATE_page; \
	COMMAND func12_DO_SIMULATE_read; \
	COMMAND func12_DO_SIMULATE_write; \
	COLLECTION func12_DO_VIEW_1; \
	MENU func12_DO_VIEW_1_page; \
	MENU func12_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC12_DO_OPTIONAL_BOTH \
	COLLECTION func12_DO_READBACK_D; \
	VARIABLE func12_DO_READBACK_D_Value; \
	VARIABLE func12_DO_READBACK_D_Status_Condensed; \
	VARIABLE func12_DO_READBACK_D_Status_Quality; \
	VARIABLE func12_DO_READBACK_D_Status_Limit; \
	MENU func12_DO_READBACK_D_page; \
	COMMAND func12_DO_READBACK_D_read; \
	COLLECTION func12_DO_RCAS_IN_D; \
	VARIABLE func12_DO_RCAS_IN_D_Value; \
	VARIABLE func12_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func12_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func12_DO_RCAS_IN_D_Status_Limit; \
	MENU func12_DO_RCAS_IN_D_page; \
	COMMAND func12_DO_RCAS_IN_D_read; \
	COMMAND func12_DO_RCAS_IN_D_write; \
	COLLECTION func12_DO_RCAS_OUT_D; \
	VARIABLE func12_DO_RCAS_OUT_D_Value; \
	VARIABLE func12_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func12_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func12_DO_RCAS_OUT_D_Status_Limit; \
	MENU func12_DO_RCAS_OUT_D_page; \
	COMMAND func12_DO_RCAS_OUT_D_read; \
	VARIABLE func12_DO_OUT_CHANNEL; \
	MENU func12_DO_OUT_CHANNEL_page; \
	COMMAND func12_DO_OUT_CHANNEL_read; \
	COMMAND func12_DO_OUT_CHANNEL_write; \
	COLLECTION func12_DO_VIEW_2; \
	MENU func12_DO_VIEW_2_page; \
	COLLECTION func12_DO_VIEW_3; \
	MENU func12_DO_VIEW_3_page

#define USE_FUNC12_DO_OPTIONAL_A \
	USE_FUNC12_DO_OPTIONAL_BOTH; \
	COLLECTION func12_DO_OUT_D; \
	VARIABLE func12_DO_OUT_D_Value; \
	VARIABLE func12_DO_OUT_D_Status_Condensed; \
	VARIABLE func12_DO_OUT_D_Status_Quality; \
	VARIABLE func12_DO_OUT_D_Status_Limit; \
	MENU func12_DO_OUT_D_page; \
	COMMAND func12_DO_OUT_D_read; \
	COMMAND func12_DO_OUT_D_write; \
	VARIABLE func12_DO_IN_CHANNEL; \
	MENU func12_DO_IN_CHANNEL_page; \
	COMMAND func12_DO_IN_CHANNEL_read; \
	COMMAND func12_DO_IN_CHANNEL_write; \
	VARIABLE func12_DO_FSAFE_TIME; \
	MENU func12_DO_FSAFE_TIME_page; \
	COMMAND func12_DO_FSAFE_TIME_read; \
	COMMAND func12_DO_FSAFE_TIME_write; \
	VARIABLE func12_DO_FSAFE_TYPE; \
	MENU func12_DO_FSAFE_TYPE_page; \
	COMMAND func12_DO_FSAFE_TYPE_read; \
	COMMAND func12_DO_FSAFE_TYPE_write; \
	VARIABLE func12_DO_FSAFE_VAL_D; \
	MENU func12_DO_FSAFE_VAL_D_page; \
	COMMAND func12_DO_FSAFE_VAL_D_read; \
	COMMAND func12_DO_FSAFE_VAL_D_write; \
	COLLECTION func12_DO_SIMULATE; \
	VARIABLE func12_DO_SIMULATE_Status_Condensed; \
	VARIABLE func12_DO_SIMULATE_Value; \
	VARIABLE func12_DO_SIMULATE_Enabled; \
	VARIABLE func12_DO_SIMULATE_Status_Quality; \
	VARIABLE func12_DO_SIMULATE_Status_Limit; \
	MENU func12_DO_SIMULATE_page; \
	COMMAND func12_DO_SIMULATE_read; \
	COMMAND func12_DO_SIMULATE_write; \
	COLLECTION func12_DO_VIEW_1; \
	MENU func12_DO_VIEW_1_page; \
	MENU func12_DO_Simple_Dialog_Optional_A

#define USE_FUNC12_DO_OPTIONAL_B \
	USE_FUNC12_DO_OPTIONAL_BOTH; \
	MENU func12_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC12_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func12_DO_)
#define USE_FUNC12_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func12_DO_)
#define USE_FUNC12_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func12_DO_)
#define USE_FUNC12_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func12_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC13_DO_MANDATORY_BOTH \
	BLOCK func13_DO_block; \
	COLLECTION func13_DO_BLOCK_OBJECT; \
	VARIABLE func13_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func13_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func13_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func13_DO_BLOCK_OBJECT_Class; \
	VARIABLE func13_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func13_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func13_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func13_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func13_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func13_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func13_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func13_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func13_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func13_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func13_DO_BLOCK_OBJECT_page; \
	COMMAND func13_DO_BLOCK_OBJECT_read; \
	VARIABLE func13_DO_ST_REV; \
	MENU func13_DO_ST_REV_page; \
	COMMAND func13_DO_ST_REV_read; \
	VARIABLE func13_DO_TAG_DESC; \
	MENU func13_DO_TAG_DESC_page; \
	COMMAND func13_DO_TAG_DESC_read; \
	COMMAND func13_DO_TAG_DESC_write; \
	VARIABLE func13_DO_STRATEGY; \
	MENU func13_DO_STRATEGY_page; \
	COMMAND func13_DO_STRATEGY_read; \
	COMMAND func13_DO_STRATEGY_write; \
	VARIABLE func13_DO_ALERT_KEY; \
	MENU func13_DO_ALERT_KEY_page; \
	COMMAND func13_DO_ALERT_KEY_read; \
	COMMAND func13_DO_ALERT_KEY_write; \
	VARIABLE func13_DO_TARGET_MODE; \
	MENU func13_DO_TARGET_MODE_page; \
	COMMAND func13_DO_TARGET_MODE_read; \
	COMMAND func13_DO_TARGET_MODE_write; \
	COLLECTION func13_DO_MODE_BLK; \
	VARIABLE func13_DO_MODE_BLK_Actual; \
	VARIABLE func13_DO_MODE_BLK_Permitted; \
	VARIABLE func13_DO_MODE_BLK_Normal; \
	MENU func13_DO_MODE_BLK_page; \
	COMMAND func13_DO_MODE_BLK_read; \
	COLLECTION func13_DO_ALARM_SUM; \
	VARIABLE func13_DO_ALARM_SUM_Current; \
	VARIABLE func13_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func13_DO_ALARM_SUM_Unreported; \
	VARIABLE func13_DO_ALARM_SUM_Disabled; \
	MENU func13_DO_ALARM_SUM_page; \
	COMMAND func13_DO_ALARM_SUM_read; \
	COLLECTION func13_DO_BATCH; \
	VARIABLE func13_DO_BATCH_Batch_ID; \
	VARIABLE func13_DO_BATCH_Rup; \
	VARIABLE func13_DO_BATCH_Operation; \
	VARIABLE func13_DO_BATCH_Phase; \
	MENU func13_DO_BATCH_page; \
	COMMAND func13_DO_BATCH_read; \
	COMMAND func13_DO_BATCH_write; \
	COLLECTION func13_DO_SP_D; \
	VARIABLE func13_DO_SP_D_Value; \
	VARIABLE func13_DO_SP_D_Status_Condensed; \
	VARIABLE func13_DO_SP_D_Status_Quality; \
	VARIABLE func13_DO_SP_D_Status_Limit; \
	MENU func13_DO_SP_D_page; \
	COMMAND func13_DO_SP_D_read; \
	COMMAND func13_DO_SP_D_write; \
	VARIABLE func13_DO_INVERT; \
	MENU func13_DO_INVERT_page; \
	COMMAND func13_DO_INVERT_read; \
	COMMAND func13_DO_INVERT_write; \
	VARIABLE func13_DO_CHECK_BACK; \
	MENU func13_DO_CHECK_BACK_page; \
	COMMAND func13_DO_CHECK_BACK_read; \
	VARIABLE func13_DO_CHECK_BACK_MASK; \
	MENU func13_DO_CHECK_BACK_MASK_page; \
	COMMAND func13_DO_CHECK_BACK_MASK_read

#define USE_FUNC13_DO_MANDATORY_A \
	USE_FUNC13_DO_MANDATORY_BOTH; \
	MENU func13_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC13_DO_MANDATORY_B \
	USE_FUNC13_DO_MANDATORY_BOTH; \
	COLLECTION func13_DO_OUT_D; \
	VARIABLE func13_DO_OUT_D_Value; \
	VARIABLE func13_DO_OUT_D_Status_Condensed; \
	VARIABLE func13_DO_OUT_D_Status_Quality; \
	VARIABLE func13_DO_OUT_D_Status_Limit; \
	MENU func13_DO_OUT_D_page; \
	COMMAND func13_DO_OUT_D_read; \
	COMMAND func13_DO_OUT_D_write; \
	VARIABLE func13_DO_IN_CHANNEL; \
	MENU func13_DO_IN_CHANNEL_page; \
	COMMAND func13_DO_IN_CHANNEL_read; \
	COMMAND func13_DO_IN_CHANNEL_write; \
	VARIABLE func13_DO_FSAFE_TIME; \
	MENU func13_DO_FSAFE_TIME_page; \
	COMMAND func13_DO_FSAFE_TIME_read; \
	COMMAND func13_DO_FSAFE_TIME_write; \
	VARIABLE func13_DO_FSAFE_TYPE; \
	MENU func13_DO_FSAFE_TYPE_page; \
	COMMAND func13_DO_FSAFE_TYPE_read; \
	COMMAND func13_DO_FSAFE_TYPE_write; \
	VARIABLE func13_DO_FSAFE_VAL_D; \
	MENU func13_DO_FSAFE_VAL_D_page; \
	COMMAND func13_DO_FSAFE_VAL_D_read; \
	COMMAND func13_DO_FSAFE_VAL_D_write; \
	COLLECTION func13_DO_SIMULATE; \
	VARIABLE func13_DO_SIMULATE_Status_Condensed; \
	VARIABLE func13_DO_SIMULATE_Value; \
	VARIABLE func13_DO_SIMULATE_Enabled; \
	VARIABLE func13_DO_SIMULATE_Status_Quality; \
	VARIABLE func13_DO_SIMULATE_Status_Limit; \
	MENU func13_DO_SIMULATE_page; \
	COMMAND func13_DO_SIMULATE_read; \
	COMMAND func13_DO_SIMULATE_write; \
	COLLECTION func13_DO_VIEW_1; \
	MENU func13_DO_VIEW_1_page; \
	MENU func13_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC13_DO_OPTIONAL_BOTH \
	COLLECTION func13_DO_READBACK_D; \
	VARIABLE func13_DO_READBACK_D_Value; \
	VARIABLE func13_DO_READBACK_D_Status_Condensed; \
	VARIABLE func13_DO_READBACK_D_Status_Quality; \
	VARIABLE func13_DO_READBACK_D_Status_Limit; \
	MENU func13_DO_READBACK_D_page; \
	COMMAND func13_DO_READBACK_D_read; \
	COLLECTION func13_DO_RCAS_IN_D; \
	VARIABLE func13_DO_RCAS_IN_D_Value; \
	VARIABLE func13_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func13_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func13_DO_RCAS_IN_D_Status_Limit; \
	MENU func13_DO_RCAS_IN_D_page; \
	COMMAND func13_DO_RCAS_IN_D_read; \
	COMMAND func13_DO_RCAS_IN_D_write; \
	COLLECTION func13_DO_RCAS_OUT_D; \
	VARIABLE func13_DO_RCAS_OUT_D_Value; \
	VARIABLE func13_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func13_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func13_DO_RCAS_OUT_D_Status_Limit; \
	MENU func13_DO_RCAS_OUT_D_page; \
	COMMAND func13_DO_RCAS_OUT_D_read; \
	VARIABLE func13_DO_OUT_CHANNEL; \
	MENU func13_DO_OUT_CHANNEL_page; \
	COMMAND func13_DO_OUT_CHANNEL_read; \
	COMMAND func13_DO_OUT_CHANNEL_write; \
	COLLECTION func13_DO_VIEW_2; \
	MENU func13_DO_VIEW_2_page; \
	COLLECTION func13_DO_VIEW_3; \
	MENU func13_DO_VIEW_3_page

#define USE_FUNC13_DO_OPTIONAL_A \
	USE_FUNC13_DO_OPTIONAL_BOTH; \
	COLLECTION func13_DO_OUT_D; \
	VARIABLE func13_DO_OUT_D_Value; \
	VARIABLE func13_DO_OUT_D_Status_Condensed; \
	VARIABLE func13_DO_OUT_D_Status_Quality; \
	VARIABLE func13_DO_OUT_D_Status_Limit; \
	MENU func13_DO_OUT_D_page; \
	COMMAND func13_DO_OUT_D_read; \
	COMMAND func13_DO_OUT_D_write; \
	VARIABLE func13_DO_IN_CHANNEL; \
	MENU func13_DO_IN_CHANNEL_page; \
	COMMAND func13_DO_IN_CHANNEL_read; \
	COMMAND func13_DO_IN_CHANNEL_write; \
	VARIABLE func13_DO_FSAFE_TIME; \
	MENU func13_DO_FSAFE_TIME_page; \
	COMMAND func13_DO_FSAFE_TIME_read; \
	COMMAND func13_DO_FSAFE_TIME_write; \
	VARIABLE func13_DO_FSAFE_TYPE; \
	MENU func13_DO_FSAFE_TYPE_page; \
	COMMAND func13_DO_FSAFE_TYPE_read; \
	COMMAND func13_DO_FSAFE_TYPE_write; \
	VARIABLE func13_DO_FSAFE_VAL_D; \
	MENU func13_DO_FSAFE_VAL_D_page; \
	COMMAND func13_DO_FSAFE_VAL_D_read; \
	COMMAND func13_DO_FSAFE_VAL_D_write; \
	COLLECTION func13_DO_SIMULATE; \
	VARIABLE func13_DO_SIMULATE_Status_Condensed; \
	VARIABLE func13_DO_SIMULATE_Value; \
	VARIABLE func13_DO_SIMULATE_Enabled; \
	VARIABLE func13_DO_SIMULATE_Status_Quality; \
	VARIABLE func13_DO_SIMULATE_Status_Limit; \
	MENU func13_DO_SIMULATE_page; \
	COMMAND func13_DO_SIMULATE_read; \
	COMMAND func13_DO_SIMULATE_write; \
	COLLECTION func13_DO_VIEW_1; \
	MENU func13_DO_VIEW_1_page; \
	MENU func13_DO_Simple_Dialog_Optional_A

#define USE_FUNC13_DO_OPTIONAL_B \
	USE_FUNC13_DO_OPTIONAL_BOTH; \
	MENU func13_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC13_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func13_DO_)
#define USE_FUNC13_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func13_DO_)
#define USE_FUNC13_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func13_DO_)
#define USE_FUNC13_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func13_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC14_DO_MANDATORY_BOTH \
	BLOCK func14_DO_block; \
	COLLECTION func14_DO_BLOCK_OBJECT; \
	VARIABLE func14_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func14_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func14_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func14_DO_BLOCK_OBJECT_Class; \
	VARIABLE func14_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func14_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func14_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func14_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func14_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func14_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func14_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func14_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func14_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func14_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func14_DO_BLOCK_OBJECT_page; \
	COMMAND func14_DO_BLOCK_OBJECT_read; \
	VARIABLE func14_DO_ST_REV; \
	MENU func14_DO_ST_REV_page; \
	COMMAND func14_DO_ST_REV_read; \
	VARIABLE func14_DO_TAG_DESC; \
	MENU func14_DO_TAG_DESC_page; \
	COMMAND func14_DO_TAG_DESC_read; \
	COMMAND func14_DO_TAG_DESC_write; \
	VARIABLE func14_DO_STRATEGY; \
	MENU func14_DO_STRATEGY_page; \
	COMMAND func14_DO_STRATEGY_read; \
	COMMAND func14_DO_STRATEGY_write; \
	VARIABLE func14_DO_ALERT_KEY; \
	MENU func14_DO_ALERT_KEY_page; \
	COMMAND func14_DO_ALERT_KEY_read; \
	COMMAND func14_DO_ALERT_KEY_write; \
	VARIABLE func14_DO_TARGET_MODE; \
	MENU func14_DO_TARGET_MODE_page; \
	COMMAND func14_DO_TARGET_MODE_read; \
	COMMAND func14_DO_TARGET_MODE_write; \
	COLLECTION func14_DO_MODE_BLK; \
	VARIABLE func14_DO_MODE_BLK_Actual; \
	VARIABLE func14_DO_MODE_BLK_Permitted; \
	VARIABLE func14_DO_MODE_BLK_Normal; \
	MENU func14_DO_MODE_BLK_page; \
	COMMAND func14_DO_MODE_BLK_read; \
	COLLECTION func14_DO_ALARM_SUM; \
	VARIABLE func14_DO_ALARM_SUM_Current; \
	VARIABLE func14_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func14_DO_ALARM_SUM_Unreported; \
	VARIABLE func14_DO_ALARM_SUM_Disabled; \
	MENU func14_DO_ALARM_SUM_page; \
	COMMAND func14_DO_ALARM_SUM_read; \
	COLLECTION func14_DO_BATCH; \
	VARIABLE func14_DO_BATCH_Batch_ID; \
	VARIABLE func14_DO_BATCH_Rup; \
	VARIABLE func14_DO_BATCH_Operation; \
	VARIABLE func14_DO_BATCH_Phase; \
	MENU func14_DO_BATCH_page; \
	COMMAND func14_DO_BATCH_read; \
	COMMAND func14_DO_BATCH_write; \
	COLLECTION func14_DO_SP_D; \
	VARIABLE func14_DO_SP_D_Value; \
	VARIABLE func14_DO_SP_D_Status_Condensed; \
	VARIABLE func14_DO_SP_D_Status_Quality; \
	VARIABLE func14_DO_SP_D_Status_Limit; \
	MENU func14_DO_SP_D_page; \
	COMMAND func14_DO_SP_D_read; \
	COMMAND func14_DO_SP_D_write; \
	VARIABLE func14_DO_INVERT; \
	MENU func14_DO_INVERT_page; \
	COMMAND func14_DO_INVERT_read; \
	COMMAND func14_DO_INVERT_write; \
	VARIABLE func14_DO_CHECK_BACK; \
	MENU func14_DO_CHECK_BACK_page; \
	COMMAND func14_DO_CHECK_BACK_read; \
	VARIABLE func14_DO_CHECK_BACK_MASK; \
	MENU func14_DO_CHECK_BACK_MASK_page; \
	COMMAND func14_DO_CHECK_BACK_MASK_read

#define USE_FUNC14_DO_MANDATORY_A \
	USE_FUNC14_DO_MANDATORY_BOTH; \
	MENU func14_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC14_DO_MANDATORY_B \
	USE_FUNC14_DO_MANDATORY_BOTH; \
	COLLECTION func14_DO_OUT_D; \
	VARIABLE func14_DO_OUT_D_Value; \
	VARIABLE func14_DO_OUT_D_Status_Condensed; \
	VARIABLE func14_DO_OUT_D_Status_Quality; \
	VARIABLE func14_DO_OUT_D_Status_Limit; \
	MENU func14_DO_OUT_D_page; \
	COMMAND func14_DO_OUT_D_read; \
	COMMAND func14_DO_OUT_D_write; \
	VARIABLE func14_DO_IN_CHANNEL; \
	MENU func14_DO_IN_CHANNEL_page; \
	COMMAND func14_DO_IN_CHANNEL_read; \
	COMMAND func14_DO_IN_CHANNEL_write; \
	VARIABLE func14_DO_FSAFE_TIME; \
	MENU func14_DO_FSAFE_TIME_page; \
	COMMAND func14_DO_FSAFE_TIME_read; \
	COMMAND func14_DO_FSAFE_TIME_write; \
	VARIABLE func14_DO_FSAFE_TYPE; \
	MENU func14_DO_FSAFE_TYPE_page; \
	COMMAND func14_DO_FSAFE_TYPE_read; \
	COMMAND func14_DO_FSAFE_TYPE_write; \
	VARIABLE func14_DO_FSAFE_VAL_D; \
	MENU func14_DO_FSAFE_VAL_D_page; \
	COMMAND func14_DO_FSAFE_VAL_D_read; \
	COMMAND func14_DO_FSAFE_VAL_D_write; \
	COLLECTION func14_DO_SIMULATE; \
	VARIABLE func14_DO_SIMULATE_Status_Condensed; \
	VARIABLE func14_DO_SIMULATE_Value; \
	VARIABLE func14_DO_SIMULATE_Enabled; \
	VARIABLE func14_DO_SIMULATE_Status_Quality; \
	VARIABLE func14_DO_SIMULATE_Status_Limit; \
	MENU func14_DO_SIMULATE_page; \
	COMMAND func14_DO_SIMULATE_read; \
	COMMAND func14_DO_SIMULATE_write; \
	COLLECTION func14_DO_VIEW_1; \
	MENU func14_DO_VIEW_1_page; \
	MENU func14_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC14_DO_OPTIONAL_BOTH \
	COLLECTION func14_DO_READBACK_D; \
	VARIABLE func14_DO_READBACK_D_Value; \
	VARIABLE func14_DO_READBACK_D_Status_Condensed; \
	VARIABLE func14_DO_READBACK_D_Status_Quality; \
	VARIABLE func14_DO_READBACK_D_Status_Limit; \
	MENU func14_DO_READBACK_D_page; \
	COMMAND func14_DO_READBACK_D_read; \
	COLLECTION func14_DO_RCAS_IN_D; \
	VARIABLE func14_DO_RCAS_IN_D_Value; \
	VARIABLE func14_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func14_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func14_DO_RCAS_IN_D_Status_Limit; \
	MENU func14_DO_RCAS_IN_D_page; \
	COMMAND func14_DO_RCAS_IN_D_read; \
	COMMAND func14_DO_RCAS_IN_D_write; \
	COLLECTION func14_DO_RCAS_OUT_D; \
	VARIABLE func14_DO_RCAS_OUT_D_Value; \
	VARIABLE func14_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func14_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func14_DO_RCAS_OUT_D_Status_Limit; \
	MENU func14_DO_RCAS_OUT_D_page; \
	COMMAND func14_DO_RCAS_OUT_D_read; \
	VARIABLE func14_DO_OUT_CHANNEL; \
	MENU func14_DO_OUT_CHANNEL_page; \
	COMMAND func14_DO_OUT_CHANNEL_read; \
	COMMAND func14_DO_OUT_CHANNEL_write; \
	COLLECTION func14_DO_VIEW_2; \
	MENU func14_DO_VIEW_2_page; \
	COLLECTION func14_DO_VIEW_3; \
	MENU func14_DO_VIEW_3_page

#define USE_FUNC14_DO_OPTIONAL_A \
	USE_FUNC14_DO_OPTIONAL_BOTH; \
	COLLECTION func14_DO_OUT_D; \
	VARIABLE func14_DO_OUT_D_Value; \
	VARIABLE func14_DO_OUT_D_Status_Condensed; \
	VARIABLE func14_DO_OUT_D_Status_Quality; \
	VARIABLE func14_DO_OUT_D_Status_Limit; \
	MENU func14_DO_OUT_D_page; \
	COMMAND func14_DO_OUT_D_read; \
	COMMAND func14_DO_OUT_D_write; \
	VARIABLE func14_DO_IN_CHANNEL; \
	MENU func14_DO_IN_CHANNEL_page; \
	COMMAND func14_DO_IN_CHANNEL_read; \
	COMMAND func14_DO_IN_CHANNEL_write; \
	VARIABLE func14_DO_FSAFE_TIME; \
	MENU func14_DO_FSAFE_TIME_page; \
	COMMAND func14_DO_FSAFE_TIME_read; \
	COMMAND func14_DO_FSAFE_TIME_write; \
	VARIABLE func14_DO_FSAFE_TYPE; \
	MENU func14_DO_FSAFE_TYPE_page; \
	COMMAND func14_DO_FSAFE_TYPE_read; \
	COMMAND func14_DO_FSAFE_TYPE_write; \
	VARIABLE func14_DO_FSAFE_VAL_D; \
	MENU func14_DO_FSAFE_VAL_D_page; \
	COMMAND func14_DO_FSAFE_VAL_D_read; \
	COMMAND func14_DO_FSAFE_VAL_D_write; \
	COLLECTION func14_DO_SIMULATE; \
	VARIABLE func14_DO_SIMULATE_Status_Condensed; \
	VARIABLE func14_DO_SIMULATE_Value; \
	VARIABLE func14_DO_SIMULATE_Enabled; \
	VARIABLE func14_DO_SIMULATE_Status_Quality; \
	VARIABLE func14_DO_SIMULATE_Status_Limit; \
	MENU func14_DO_SIMULATE_page; \
	COMMAND func14_DO_SIMULATE_read; \
	COMMAND func14_DO_SIMULATE_write; \
	COLLECTION func14_DO_VIEW_1; \
	MENU func14_DO_VIEW_1_page; \
	MENU func14_DO_Simple_Dialog_Optional_A

#define USE_FUNC14_DO_OPTIONAL_B \
	USE_FUNC14_DO_OPTIONAL_BOTH; \
	MENU func14_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC14_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func14_DO_)
#define USE_FUNC14_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func14_DO_)
#define USE_FUNC14_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func14_DO_)
#define USE_FUNC14_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func14_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC15_DO_MANDATORY_BOTH \
	BLOCK func15_DO_block; \
	COLLECTION func15_DO_BLOCK_OBJECT; \
	VARIABLE func15_DO_BLOCK_OBJECT_Reserved; \
	VARIABLE func15_DO_BLOCK_OBJECT_Block_Object; \
	VARIABLE func15_DO_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func15_DO_BLOCK_OBJECT_Class; \
	VARIABLE func15_DO_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func15_DO_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func15_DO_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func15_DO_BLOCK_OBJECT_Profile; \
	VARIABLE func15_DO_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func15_DO_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func15_DO_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func15_DO_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func15_DO_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func15_DO_BLOCK_OBJECT_Number_of_Views; \
	MENU func15_DO_BLOCK_OBJECT_page; \
	COMMAND func15_DO_BLOCK_OBJECT_read; \
	VARIABLE func15_DO_ST_REV; \
	MENU func15_DO_ST_REV_page; \
	COMMAND func15_DO_ST_REV_read; \
	VARIABLE func15_DO_TAG_DESC; \
	MENU func15_DO_TAG_DESC_page; \
	COMMAND func15_DO_TAG_DESC_read; \
	COMMAND func15_DO_TAG_DESC_write; \
	VARIABLE func15_DO_STRATEGY; \
	MENU func15_DO_STRATEGY_page; \
	COMMAND func15_DO_STRATEGY_read; \
	COMMAND func15_DO_STRATEGY_write; \
	VARIABLE func15_DO_ALERT_KEY; \
	MENU func15_DO_ALERT_KEY_page; \
	COMMAND func15_DO_ALERT_KEY_read; \
	COMMAND func15_DO_ALERT_KEY_write; \
	VARIABLE func15_DO_TARGET_MODE; \
	MENU func15_DO_TARGET_MODE_page; \
	COMMAND func15_DO_TARGET_MODE_read; \
	COMMAND func15_DO_TARGET_MODE_write; \
	COLLECTION func15_DO_MODE_BLK; \
	VARIABLE func15_DO_MODE_BLK_Actual; \
	VARIABLE func15_DO_MODE_BLK_Permitted; \
	VARIABLE func15_DO_MODE_BLK_Normal; \
	MENU func15_DO_MODE_BLK_page; \
	COMMAND func15_DO_MODE_BLK_read; \
	COLLECTION func15_DO_ALARM_SUM; \
	VARIABLE func15_DO_ALARM_SUM_Current; \
	VARIABLE func15_DO_ALARM_SUM_Unacknowledged; \
	VARIABLE func15_DO_ALARM_SUM_Unreported; \
	VARIABLE func15_DO_ALARM_SUM_Disabled; \
	MENU func15_DO_ALARM_SUM_page; \
	COMMAND func15_DO_ALARM_SUM_read; \
	COLLECTION func15_DO_BATCH; \
	VARIABLE func15_DO_BATCH_Batch_ID; \
	VARIABLE func15_DO_BATCH_Rup; \
	VARIABLE func15_DO_BATCH_Operation; \
	VARIABLE func15_DO_BATCH_Phase; \
	MENU func15_DO_BATCH_page; \
	COMMAND func15_DO_BATCH_read; \
	COMMAND func15_DO_BATCH_write; \
	COLLECTION func15_DO_SP_D; \
	VARIABLE func15_DO_SP_D_Value; \
	VARIABLE func15_DO_SP_D_Status_Condensed; \
	VARIABLE func15_DO_SP_D_Status_Quality; \
	VARIABLE func15_DO_SP_D_Status_Limit; \
	MENU func15_DO_SP_D_page; \
	COMMAND func15_DO_SP_D_read; \
	COMMAND func15_DO_SP_D_write; \
	VARIABLE func15_DO_INVERT; \
	MENU func15_DO_INVERT_page; \
	COMMAND func15_DO_INVERT_read; \
	COMMAND func15_DO_INVERT_write; \
	VARIABLE func15_DO_CHECK_BACK; \
	MENU func15_DO_CHECK_BACK_page; \
	COMMAND func15_DO_CHECK_BACK_read; \
	VARIABLE func15_DO_CHECK_BACK_MASK; \
	MENU func15_DO_CHECK_BACK_MASK_page; \
	COMMAND func15_DO_CHECK_BACK_MASK_read

#define USE_FUNC15_DO_MANDATORY_A \
	USE_FUNC15_DO_MANDATORY_BOTH; \
	MENU func15_DO_Simple_Dialog_Mandatory_A

#define USE_FUNC15_DO_MANDATORY_B \
	USE_FUNC15_DO_MANDATORY_BOTH; \
	COLLECTION func15_DO_OUT_D; \
	VARIABLE func15_DO_OUT_D_Value; \
	VARIABLE func15_DO_OUT_D_Status_Condensed; \
	VARIABLE func15_DO_OUT_D_Status_Quality; \
	VARIABLE func15_DO_OUT_D_Status_Limit; \
	MENU func15_DO_OUT_D_page; \
	COMMAND func15_DO_OUT_D_read; \
	COMMAND func15_DO_OUT_D_write; \
	VARIABLE func15_DO_IN_CHANNEL; \
	MENU func15_DO_IN_CHANNEL_page; \
	COMMAND func15_DO_IN_CHANNEL_read; \
	COMMAND func15_DO_IN_CHANNEL_write; \
	VARIABLE func15_DO_FSAFE_TIME; \
	MENU func15_DO_FSAFE_TIME_page; \
	COMMAND func15_DO_FSAFE_TIME_read; \
	COMMAND func15_DO_FSAFE_TIME_write; \
	VARIABLE func15_DO_FSAFE_TYPE; \
	MENU func15_DO_FSAFE_TYPE_page; \
	COMMAND func15_DO_FSAFE_TYPE_read; \
	COMMAND func15_DO_FSAFE_TYPE_write; \
	VARIABLE func15_DO_FSAFE_VAL_D; \
	MENU func15_DO_FSAFE_VAL_D_page; \
	COMMAND func15_DO_FSAFE_VAL_D_read; \
	COMMAND func15_DO_FSAFE_VAL_D_write; \
	COLLECTION func15_DO_SIMULATE; \
	VARIABLE func15_DO_SIMULATE_Status_Condensed; \
	VARIABLE func15_DO_SIMULATE_Value; \
	VARIABLE func15_DO_SIMULATE_Enabled; \
	VARIABLE func15_DO_SIMULATE_Status_Quality; \
	VARIABLE func15_DO_SIMULATE_Status_Limit; \
	MENU func15_DO_SIMULATE_page; \
	COMMAND func15_DO_SIMULATE_read; \
	COMMAND func15_DO_SIMULATE_write; \
	COLLECTION func15_DO_VIEW_1; \
	MENU func15_DO_VIEW_1_page; \
	MENU func15_DO_Simple_Dialog_Mandatory_B

#define USE_FUNC15_DO_OPTIONAL_BOTH \
	COLLECTION func15_DO_READBACK_D; \
	VARIABLE func15_DO_READBACK_D_Value; \
	VARIABLE func15_DO_READBACK_D_Status_Condensed; \
	VARIABLE func15_DO_READBACK_D_Status_Quality; \
	VARIABLE func15_DO_READBACK_D_Status_Limit; \
	MENU func15_DO_READBACK_D_page; \
	COMMAND func15_DO_READBACK_D_read; \
	COLLECTION func15_DO_RCAS_IN_D; \
	VARIABLE func15_DO_RCAS_IN_D_Value; \
	VARIABLE func15_DO_RCAS_IN_D_Status_Condensed; \
	VARIABLE func15_DO_RCAS_IN_D_Status_Quality; \
	VARIABLE func15_DO_RCAS_IN_D_Status_Limit; \
	MENU func15_DO_RCAS_IN_D_page; \
	COMMAND func15_DO_RCAS_IN_D_read; \
	COMMAND func15_DO_RCAS_IN_D_write; \
	COLLECTION func15_DO_RCAS_OUT_D; \
	VARIABLE func15_DO_RCAS_OUT_D_Value; \
	VARIABLE func15_DO_RCAS_OUT_D_Status_Condensed; \
	VARIABLE func15_DO_RCAS_OUT_D_Status_Quality; \
	VARIABLE func15_DO_RCAS_OUT_D_Status_Limit; \
	MENU func15_DO_RCAS_OUT_D_page; \
	COMMAND func15_DO_RCAS_OUT_D_read; \
	VARIABLE func15_DO_OUT_CHANNEL; \
	MENU func15_DO_OUT_CHANNEL_page; \
	COMMAND func15_DO_OUT_CHANNEL_read; \
	COMMAND func15_DO_OUT_CHANNEL_write; \
	COLLECTION func15_DO_VIEW_2; \
	MENU func15_DO_VIEW_2_page; \
	COLLECTION func15_DO_VIEW_3; \
	MENU func15_DO_VIEW_3_page

#define USE_FUNC15_DO_OPTIONAL_A \
	USE_FUNC15_DO_OPTIONAL_BOTH; \
	COLLECTION func15_DO_OUT_D; \
	VARIABLE func15_DO_OUT_D_Value; \
	VARIABLE func15_DO_OUT_D_Status_Condensed; \
	VARIABLE func15_DO_OUT_D_Status_Quality; \
	VARIABLE func15_DO_OUT_D_Status_Limit; \
	MENU func15_DO_OUT_D_page; \
	COMMAND func15_DO_OUT_D_read; \
	COMMAND func15_DO_OUT_D_write; \
	VARIABLE func15_DO_IN_CHANNEL; \
	MENU func15_DO_IN_CHANNEL_page; \
	COMMAND func15_DO_IN_CHANNEL_read; \
	COMMAND func15_DO_IN_CHANNEL_write; \
	VARIABLE func15_DO_FSAFE_TIME; \
	MENU func15_DO_FSAFE_TIME_page; \
	COMMAND func15_DO_FSAFE_TIME_read; \
	COMMAND func15_DO_FSAFE_TIME_write; \
	VARIABLE func15_DO_FSAFE_TYPE; \
	MENU func15_DO_FSAFE_TYPE_page; \
	COMMAND func15_DO_FSAFE_TYPE_read; \
	COMMAND func15_DO_FSAFE_TYPE_write; \
	VARIABLE func15_DO_FSAFE_VAL_D; \
	MENU func15_DO_FSAFE_VAL_D_page; \
	COMMAND func15_DO_FSAFE_VAL_D_read; \
	COMMAND func15_DO_FSAFE_VAL_D_write; \
	COLLECTION func15_DO_SIMULATE; \
	VARIABLE func15_DO_SIMULATE_Status_Condensed; \
	VARIABLE func15_DO_SIMULATE_Value; \
	VARIABLE func15_DO_SIMULATE_Enabled; \
	VARIABLE func15_DO_SIMULATE_Status_Quality; \
	VARIABLE func15_DO_SIMULATE_Status_Limit; \
	MENU func15_DO_SIMULATE_page; \
	COMMAND func15_DO_SIMULATE_read; \
	COMMAND func15_DO_SIMULATE_write; \
	COLLECTION func15_DO_VIEW_1; \
	MENU func15_DO_VIEW_1_page; \
	MENU func15_DO_Simple_Dialog_Optional_A

#define USE_FUNC15_DO_OPTIONAL_B \
	USE_FUNC15_DO_OPTIONAL_BOTH; \
	MENU func15_DO_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC15_DO_MANDATORY_A USE_FUNC_DO_MANDATORY_A(func15_DO_)
#define USE_FUNC15_DO_MANDATORY_B USE_FUNC_DO_MANDATORY_B(func15_DO_)
#define USE_FUNC15_DO_OPTIONAL_A  USE_FUNC_DO_OPTIONAL_A(func15_DO_)
#define USE_FUNC15_DO_OPTIONAL_B  USE_FUNC_DO_OPTIONAL_B(func15_DO_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC1_LOGBOOK_MANDATORY_BOTH \
	BLOCK func1_Logbook_block; \
	COLLECTION func1_Logbook_BLOCK_OBJECT; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func1_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func1_Logbook_BLOCK_OBJECT_page; \
	COMMAND func1_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func1_Logbook_ST_REV; \
	MENU func1_Logbook_ST_REV_page; \
	COMMAND func1_Logbook_ST_REV_read; \
	VARIABLE func1_Logbook_TAG_DESC; \
	MENU func1_Logbook_TAG_DESC_page; \
	COMMAND func1_Logbook_TAG_DESC_read; \
	COMMAND func1_Logbook_TAG_DESC_write; \
	VARIABLE func1_Logbook_STRATEGY; \
	MENU func1_Logbook_STRATEGY_page; \
	COMMAND func1_Logbook_STRATEGY_read; \
	COMMAND func1_Logbook_STRATEGY_write; \
	VARIABLE func1_Logbook_ALERT_KEY; \
	MENU func1_Logbook_ALERT_KEY_page; \
	COMMAND func1_Logbook_ALERT_KEY_read; \
	COMMAND func1_Logbook_ALERT_KEY_write; \
	VARIABLE func1_Logbook_TARGET_MODE; \
	MENU func1_Logbook_TARGET_MODE_page; \
	COMMAND func1_Logbook_TARGET_MODE_read; \
	COMMAND func1_Logbook_TARGET_MODE_write; \
	COLLECTION func1_Logbook_MODE_BLK; \
	VARIABLE func1_Logbook_MODE_BLK_Actual; \
	VARIABLE func1_Logbook_MODE_BLK_Permitted; \
	VARIABLE func1_Logbook_MODE_BLK_Normal; \
	MENU func1_Logbook_MODE_BLK_page; \
	COMMAND func1_Logbook_MODE_BLK_read; \
	COLLECTION func1_Logbook_ALARM_SUM; \
	VARIABLE func1_Logbook_ALARM_SUM_Current; \
	VARIABLE func1_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func1_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func1_Logbook_ALARM_SUM_Disabled; \
	MENU func1_Logbook_ALARM_SUM_page; \
	COMMAND func1_Logbook_ALARM_SUM_read; \
	COLLECTION func1_Logbook_BATCH; \
	VARIABLE func1_Logbook_BATCH_Batch_ID; \
	VARIABLE func1_Logbook_BATCH_Rup; \
	VARIABLE func1_Logbook_BATCH_Operation; \
	VARIABLE func1_Logbook_BATCH_Phase; \
	MENU func1_Logbook_BATCH_page; \
	COMMAND func1_Logbook_BATCH_read; \
	COMMAND func1_Logbook_BATCH_write; \
	VARIABLE func1_Logbook_COMMAND; \
	MENU func1_Logbook_COMMAND_page; \
	COMMAND func1_Logbook_COMMAND_read; \
	COMMAND func1_Logbook_COMMAND_write; \
	VARIABLE func1_Logbook_STATUS; \
	MENU func1_Logbook_STATUS_page; \
	COMMAND func1_Logbook_STATUS_read; \
	VARIABLE func1_Logbook_SIZE_OF_ENTRIES; \
	MENU func1_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func1_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func1_Logbook_NUMBER_OF_ENTRIES; \
	MENU func1_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func1_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func1_Logbook_TURN_NUMBER; \
	MENU func1_Logbook_TURN_NUMBER_page; \
	COMMAND func1_Logbook_TURN_NUMBER_read; \
	COLLECTION func1_Logbook_NEWEST_ENTRY; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func1_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func1_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func1_Logbook_NEWEST_ENTRY_page; \
	COMMAND func1_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func1_Logbook_OLDEST_ENTRY; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func1_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func1_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func1_Logbook_OLDEST_ENTRY_page; \
	COMMAND func1_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func1_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func1_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func1_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func1_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func1_Logbook_POST_READ_ENTRY; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func1_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func1_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func1_Logbook_POST_READ_ENTRY_page; \
	COMMAND func1_Logbook_POST_READ_ENTRY_read

#define USE_FUNC1_LOGBOOK_MANDATORY_A \
	USE_FUNC1_LOGBOOK_MANDATORY_BOTH; \
	MENU func1_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC1_LOGBOOK_MANDATORY_B \
	USE_FUNC1_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func1_Logbook_VIEW_1; \
	MENU func1_Logbook_VIEW_1_page; \
	MENU func1_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC1_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func1_Logbook_VIEW_2; \
	MENU func1_Logbook_VIEW_2_page; \
	COLLECTION func1_Logbook_VIEW_3; \
	MENU func1_Logbook_VIEW_3_page

#define USE_FUNC1_LOGBOOK_OPTIONAL_A \
	USE_FUNC1_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func1_Logbook_VIEW_1; \
	MENU func1_Logbook_VIEW_1_page; \
	MENU func1_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC1_LOGBOOK_OPTIONAL_B \
	USE_FUNC1_LOGBOOK_OPTIONAL_BOTH; \
	MENU func1_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC_LOGBOOK_MANDATORY_BOTH(prefix) \
	BLOCK prefix ## block; \
	COLLECTION prefix ## BLOCK_OBJECT; \
	VARIABLE prefix ## BLOCK_OBJECT_Reserved; \
	VARIABLE prefix ## BLOCK_OBJECT_Block_Object; \
	VARIABLE prefix ## BLOCK_OBJECT_Parent_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Class; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev; \
	VARIABLE prefix ## BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE prefix ## BLOCK_OBJECT_DD_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile; \
	VARIABLE prefix ## BLOCK_OBJECT_Profile_Revision; \
	VARIABLE prefix ## BLOCK_OBJECT_Execution_Time; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE prefix ## BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE prefix ## BLOCK_OBJECT_Number_of_Views; \
	MENU prefix ## BLOCK_OBJECT_page; \
	COMMAND prefix ## BLOCK_OBJECT_read; \
	VARIABLE prefix ## ST_REV; \
	MENU prefix ## ST_REV_page; \
	COMMAND prefix ## ST_REV_read; \
	VARIABLE prefix ## TAG_DESC; \
	MENU prefix ## TAG_DESC_page; \
	COMMAND prefix ## TAG_DESC_read; \
	COMMAND prefix ## TAG_DESC_write; \
	VARIABLE prefix ## STRATEGY; \
	MENU prefix ## STRATEGY_page; \
	COMMAND prefix ## STRATEGY_read; \
	COMMAND prefix ## STRATEGY_write; \
	VARIABLE prefix ## ALERT_KEY; \
	MENU prefix ## ALERT_KEY_page; \
	COMMAND prefix ## ALERT_KEY_read; \
	COMMAND prefix ## ALERT_KEY_write; \
	VARIABLE prefix ## TARGET_MODE; \
	MENU prefix ## TARGET_MODE_page; \
	COMMAND prefix ## TARGET_MODE_read; \
	COMMAND prefix ## TARGET_MODE_write; \
	COLLECTION prefix ## MODE_BLK; \
	VARIABLE prefix ## MODE_BLK_Actual; \
	VARIABLE prefix ## MODE_BLK_Permitted; \
	VARIABLE prefix ## MODE_BLK_Normal; \
	MENU prefix ## MODE_BLK_page; \
	COMMAND prefix ## MODE_BLK_read; \
	COLLECTION prefix ## ALARM_SUM; \
	VARIABLE prefix ## ALARM_SUM_Current; \
	VARIABLE prefix ## ALARM_SUM_Unacknowledged; \
	VARIABLE prefix ## ALARM_SUM_Unreported; \
	VARIABLE prefix ## ALARM_SUM_Disabled; \
	MENU prefix ## ALARM_SUM_page; \
	COMMAND prefix ## ALARM_SUM_read; \
	COLLECTION prefix ## BATCH; \
	VARIABLE prefix ## BATCH_Batch_ID; \
	VARIABLE prefix ## BATCH_Rup; \
	VARIABLE prefix ## BATCH_Operation; \
	VARIABLE prefix ## BATCH_Phase; \
	MENU prefix ## BATCH_page; \
	COMMAND prefix ## BATCH_read; \
	COMMAND prefix ## BATCH_write; \
	VARIABLE prefix ## COMMAND; \
	MENU prefix ## COMMAND_page; \
	COMMAND prefix ## COMMAND_read; \
	COMMAND prefix ## COMMAND_write; \
	VARIABLE prefix ## STATUS; \
	MENU prefix ## STATUS_page; \
	COMMAND prefix ## STATUS_read; \
	VARIABLE prefix ## SIZE_OF_ENTRIES; \
	MENU prefix ## SIZE_OF_ENTRIES_page; \
	COMMAND prefix ## SIZE_OF_ENTRIES_read; \
	VARIABLE prefix ## NUMBER_OF_ENTRIES; \
	MENU prefix ## NUMBER_OF_ENTRIES_page; \
	COMMAND prefix ## NUMBER_OF_ENTRIES_read; \
	VARIABLE prefix ## TURN_NUMBER; \
	MENU prefix ## TURN_NUMBER_page; \
	COMMAND prefix ## TURN_NUMBER_read; \
	COLLECTION prefix ## NEWEST_ENTRY; \
	VARIABLE prefix ## NEWEST_ENTRY_Type; \
	VARIABLE prefix ## NEWEST_ENTRY_Value; \
	VARIABLE prefix ## NEWEST_ENTRY_Active; \
	COLLECTION prefix ## NEWEST_ENTRY_Time; \
	VARIABLE prefix ## NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE prefix ## NEWEST_ENTRY_Time_Minutes; \
	VARIABLE prefix ## NEWEST_ENTRY_Time_Hours; \
	VARIABLE prefix ## NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE prefix ## NEWEST_ENTRY_Time_Month; \
	VARIABLE prefix ## NEWEST_ENTRY_Time_Years; \
	MENU prefix ## NEWEST_ENTRY_page; \
	COMMAND prefix ## NEWEST_ENTRY_read; \
	COLLECTION prefix ## OLDEST_ENTRY; \
	VARIABLE prefix ## OLDEST_ENTRY_Type; \
	VARIABLE prefix ## OLDEST_ENTRY_Value; \
	VARIABLE prefix ## OLDEST_ENTRY_Active; \
	COLLECTION prefix ## OLDEST_ENTRY_Time; \
	VARIABLE prefix ## OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE prefix ## OLDEST_ENTRY_Time_Minutes; \
	VARIABLE prefix ## OLDEST_ENTRY_Time_Hours; \
	VARIABLE prefix ## OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE prefix ## OLDEST_ENTRY_Time_Month; \
	VARIABLE prefix ## OLDEST_ENTRY_Time_Years; \
	MENU prefix ## OLDEST_ENTRY_page; \
	COMMAND prefix ## OLDEST_ENTRY_read; \
	VARIABLE prefix ## ACTUAL_POST_READ_NUMBER; \
	MENU prefix ## ACTUAL_POST_READ_NUMBER_page; \
	COMMAND prefix ## ACTUAL_POST_READ_NUMBER_read; \
	COMMAND prefix ## ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION prefix ## POST_READ_ENTRY; \
	VARIABLE prefix ## POST_READ_ENTRY_Type; \
	VARIABLE prefix ## POST_READ_ENTRY_Value; \
	VARIABLE prefix ## POST_READ_ENTRY_Active; \
	COLLECTION prefix ## POST_READ_ENTRY_Time; \
	VARIABLE prefix ## POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE prefix ## POST_READ_ENTRY_Time_Minutes; \
	VARIABLE prefix ## POST_READ_ENTRY_Time_Hours; \
	VARIABLE prefix ## POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE prefix ## POST_READ_ENTRY_Time_Month; \
	VARIABLE prefix ## POST_READ_ENTRY_Time_Years; \
	MENU prefix ## POST_READ_ENTRY_page; \
	COMMAND prefix ## POST_READ_ENTRY_read

#define USE_FUNC_LOGBOOK_MANDATORY_A(prefix) \
	USE_FUNC_LOGBOOK_MANDATORY_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Mandatory_A

#define USE_FUNC_LOGBOOK_MANDATORY_B(prefix) \
	USE_FUNC_LOGBOOK_MANDATORY_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Mandatory_B

#define USE_FUNC_LOGBOOK_OPTIONAL_BOTH(prefix) \
	COLLECTION prefix ## VIEW_2; \
	MENU prefix ## VIEW_2_page; \
	COLLECTION prefix ## VIEW_3; \
	MENU prefix ## VIEW_3_page

#define USE_FUNC_LOGBOOK_OPTIONAL_A(prefix) \
	USE_FUNC_LOGBOOK_OPTIONAL_BOTH(prefix); \
	COLLECTION prefix ## VIEW_1; \
	MENU prefix ## VIEW_1_page; \
	MENU prefix ## Simple_Dialog_Optional_A

#define USE_FUNC_LOGBOOK_OPTIONAL_B(prefix) \
	USE_FUNC_LOGBOOK_OPTIONAL_BOTH(prefix); \
	MENU prefix ## Simple_Dialog_Optional_B

#define USE_FUNC1_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func1_Logbook_)
#define USE_FUNC1_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func1_Logbook_)
#define USE_FUNC1_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func1_Logbook_)
#define USE_FUNC1_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func1_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC2_LOGBOOK_MANDATORY_BOTH \
	BLOCK func2_Logbook_block; \
	COLLECTION func2_Logbook_BLOCK_OBJECT; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func2_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func2_Logbook_BLOCK_OBJECT_page; \
	COMMAND func2_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func2_Logbook_ST_REV; \
	MENU func2_Logbook_ST_REV_page; \
	COMMAND func2_Logbook_ST_REV_read; \
	VARIABLE func2_Logbook_TAG_DESC; \
	MENU func2_Logbook_TAG_DESC_page; \
	COMMAND func2_Logbook_TAG_DESC_read; \
	COMMAND func2_Logbook_TAG_DESC_write; \
	VARIABLE func2_Logbook_STRATEGY; \
	MENU func2_Logbook_STRATEGY_page; \
	COMMAND func2_Logbook_STRATEGY_read; \
	COMMAND func2_Logbook_STRATEGY_write; \
	VARIABLE func2_Logbook_ALERT_KEY; \
	MENU func2_Logbook_ALERT_KEY_page; \
	COMMAND func2_Logbook_ALERT_KEY_read; \
	COMMAND func2_Logbook_ALERT_KEY_write; \
	VARIABLE func2_Logbook_TARGET_MODE; \
	MENU func2_Logbook_TARGET_MODE_page; \
	COMMAND func2_Logbook_TARGET_MODE_read; \
	COMMAND func2_Logbook_TARGET_MODE_write; \
	COLLECTION func2_Logbook_MODE_BLK; \
	VARIABLE func2_Logbook_MODE_BLK_Actual; \
	VARIABLE func2_Logbook_MODE_BLK_Permitted; \
	VARIABLE func2_Logbook_MODE_BLK_Normal; \
	MENU func2_Logbook_MODE_BLK_page; \
	COMMAND func2_Logbook_MODE_BLK_read; \
	COLLECTION func2_Logbook_ALARM_SUM; \
	VARIABLE func2_Logbook_ALARM_SUM_Current; \
	VARIABLE func2_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func2_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func2_Logbook_ALARM_SUM_Disabled; \
	MENU func2_Logbook_ALARM_SUM_page; \
	COMMAND func2_Logbook_ALARM_SUM_read; \
	COLLECTION func2_Logbook_BATCH; \
	VARIABLE func2_Logbook_BATCH_Batch_ID; \
	VARIABLE func2_Logbook_BATCH_Rup; \
	VARIABLE func2_Logbook_BATCH_Operation; \
	VARIABLE func2_Logbook_BATCH_Phase; \
	MENU func2_Logbook_BATCH_page; \
	COMMAND func2_Logbook_BATCH_read; \
	COMMAND func2_Logbook_BATCH_write; \
	VARIABLE func2_Logbook_COMMAND; \
	MENU func2_Logbook_COMMAND_page; \
	COMMAND func2_Logbook_COMMAND_read; \
	COMMAND func2_Logbook_COMMAND_write; \
	VARIABLE func2_Logbook_STATUS; \
	MENU func2_Logbook_STATUS_page; \
	COMMAND func2_Logbook_STATUS_read; \
	VARIABLE func2_Logbook_SIZE_OF_ENTRIES; \
	MENU func2_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func2_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func2_Logbook_NUMBER_OF_ENTRIES; \
	MENU func2_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func2_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func2_Logbook_TURN_NUMBER; \
	MENU func2_Logbook_TURN_NUMBER_page; \
	COMMAND func2_Logbook_TURN_NUMBER_read; \
	COLLECTION func2_Logbook_NEWEST_ENTRY; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func2_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func2_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func2_Logbook_NEWEST_ENTRY_page; \
	COMMAND func2_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func2_Logbook_OLDEST_ENTRY; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func2_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func2_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func2_Logbook_OLDEST_ENTRY_page; \
	COMMAND func2_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func2_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func2_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func2_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func2_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func2_Logbook_POST_READ_ENTRY; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func2_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func2_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func2_Logbook_POST_READ_ENTRY_page; \
	COMMAND func2_Logbook_POST_READ_ENTRY_read

#define USE_FUNC2_LOGBOOK_MANDATORY_A \
	USE_FUNC2_LOGBOOK_MANDATORY_BOTH; \
	MENU func2_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC2_LOGBOOK_MANDATORY_B \
	USE_FUNC2_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func2_Logbook_VIEW_1; \
	MENU func2_Logbook_VIEW_1_page; \
	MENU func2_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC2_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func2_Logbook_VIEW_2; \
	MENU func2_Logbook_VIEW_2_page; \
	COLLECTION func2_Logbook_VIEW_3; \
	MENU func2_Logbook_VIEW_3_page

#define USE_FUNC2_LOGBOOK_OPTIONAL_A \
	USE_FUNC2_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func2_Logbook_VIEW_1; \
	MENU func2_Logbook_VIEW_1_page; \
	MENU func2_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC2_LOGBOOK_OPTIONAL_B \
	USE_FUNC2_LOGBOOK_OPTIONAL_BOTH; \
	MENU func2_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC2_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func2_Logbook_)
#define USE_FUNC2_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func2_Logbook_)
#define USE_FUNC2_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func2_Logbook_)
#define USE_FUNC2_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func2_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC3_LOGBOOK_MANDATORY_BOTH \
	BLOCK func3_Logbook_block; \
	COLLECTION func3_Logbook_BLOCK_OBJECT; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func3_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func3_Logbook_BLOCK_OBJECT_page; \
	COMMAND func3_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func3_Logbook_ST_REV; \
	MENU func3_Logbook_ST_REV_page; \
	COMMAND func3_Logbook_ST_REV_read; \
	VARIABLE func3_Logbook_TAG_DESC; \
	MENU func3_Logbook_TAG_DESC_page; \
	COMMAND func3_Logbook_TAG_DESC_read; \
	COMMAND func3_Logbook_TAG_DESC_write; \
	VARIABLE func3_Logbook_STRATEGY; \
	MENU func3_Logbook_STRATEGY_page; \
	COMMAND func3_Logbook_STRATEGY_read; \
	COMMAND func3_Logbook_STRATEGY_write; \
	VARIABLE func3_Logbook_ALERT_KEY; \
	MENU func3_Logbook_ALERT_KEY_page; \
	COMMAND func3_Logbook_ALERT_KEY_read; \
	COMMAND func3_Logbook_ALERT_KEY_write; \
	VARIABLE func3_Logbook_TARGET_MODE; \
	MENU func3_Logbook_TARGET_MODE_page; \
	COMMAND func3_Logbook_TARGET_MODE_read; \
	COMMAND func3_Logbook_TARGET_MODE_write; \
	COLLECTION func3_Logbook_MODE_BLK; \
	VARIABLE func3_Logbook_MODE_BLK_Actual; \
	VARIABLE func3_Logbook_MODE_BLK_Permitted; \
	VARIABLE func3_Logbook_MODE_BLK_Normal; \
	MENU func3_Logbook_MODE_BLK_page; \
	COMMAND func3_Logbook_MODE_BLK_read; \
	COLLECTION func3_Logbook_ALARM_SUM; \
	VARIABLE func3_Logbook_ALARM_SUM_Current; \
	VARIABLE func3_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func3_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func3_Logbook_ALARM_SUM_Disabled; \
	MENU func3_Logbook_ALARM_SUM_page; \
	COMMAND func3_Logbook_ALARM_SUM_read; \
	COLLECTION func3_Logbook_BATCH; \
	VARIABLE func3_Logbook_BATCH_Batch_ID; \
	VARIABLE func3_Logbook_BATCH_Rup; \
	VARIABLE func3_Logbook_BATCH_Operation; \
	VARIABLE func3_Logbook_BATCH_Phase; \
	MENU func3_Logbook_BATCH_page; \
	COMMAND func3_Logbook_BATCH_read; \
	COMMAND func3_Logbook_BATCH_write; \
	VARIABLE func3_Logbook_COMMAND; \
	MENU func3_Logbook_COMMAND_page; \
	COMMAND func3_Logbook_COMMAND_read; \
	COMMAND func3_Logbook_COMMAND_write; \
	VARIABLE func3_Logbook_STATUS; \
	MENU func3_Logbook_STATUS_page; \
	COMMAND func3_Logbook_STATUS_read; \
	VARIABLE func3_Logbook_SIZE_OF_ENTRIES; \
	MENU func3_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func3_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func3_Logbook_NUMBER_OF_ENTRIES; \
	MENU func3_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func3_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func3_Logbook_TURN_NUMBER; \
	MENU func3_Logbook_TURN_NUMBER_page; \
	COMMAND func3_Logbook_TURN_NUMBER_read; \
	COLLECTION func3_Logbook_NEWEST_ENTRY; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func3_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func3_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func3_Logbook_NEWEST_ENTRY_page; \
	COMMAND func3_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func3_Logbook_OLDEST_ENTRY; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func3_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func3_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func3_Logbook_OLDEST_ENTRY_page; \
	COMMAND func3_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func3_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func3_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func3_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func3_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func3_Logbook_POST_READ_ENTRY; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func3_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func3_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func3_Logbook_POST_READ_ENTRY_page; \
	COMMAND func3_Logbook_POST_READ_ENTRY_read

#define USE_FUNC3_LOGBOOK_MANDATORY_A \
	USE_FUNC3_LOGBOOK_MANDATORY_BOTH; \
	MENU func3_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC3_LOGBOOK_MANDATORY_B \
	USE_FUNC3_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func3_Logbook_VIEW_1; \
	MENU func3_Logbook_VIEW_1_page; \
	MENU func3_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC3_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func3_Logbook_VIEW_2; \
	MENU func3_Logbook_VIEW_2_page; \
	COLLECTION func3_Logbook_VIEW_3; \
	MENU func3_Logbook_VIEW_3_page

#define USE_FUNC3_LOGBOOK_OPTIONAL_A \
	USE_FUNC3_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func3_Logbook_VIEW_1; \
	MENU func3_Logbook_VIEW_1_page; \
	MENU func3_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC3_LOGBOOK_OPTIONAL_B \
	USE_FUNC3_LOGBOOK_OPTIONAL_BOTH; \
	MENU func3_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC3_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func3_Logbook_)
#define USE_FUNC3_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func3_Logbook_)
#define USE_FUNC3_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func3_Logbook_)
#define USE_FUNC3_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func3_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC4_LOGBOOK_MANDATORY_BOTH \
	BLOCK func4_Logbook_block; \
	COLLECTION func4_Logbook_BLOCK_OBJECT; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func4_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func4_Logbook_BLOCK_OBJECT_page; \
	COMMAND func4_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func4_Logbook_ST_REV; \
	MENU func4_Logbook_ST_REV_page; \
	COMMAND func4_Logbook_ST_REV_read; \
	VARIABLE func4_Logbook_TAG_DESC; \
	MENU func4_Logbook_TAG_DESC_page; \
	COMMAND func4_Logbook_TAG_DESC_read; \
	COMMAND func4_Logbook_TAG_DESC_write; \
	VARIABLE func4_Logbook_STRATEGY; \
	MENU func4_Logbook_STRATEGY_page; \
	COMMAND func4_Logbook_STRATEGY_read; \
	COMMAND func4_Logbook_STRATEGY_write; \
	VARIABLE func4_Logbook_ALERT_KEY; \
	MENU func4_Logbook_ALERT_KEY_page; \
	COMMAND func4_Logbook_ALERT_KEY_read; \
	COMMAND func4_Logbook_ALERT_KEY_write; \
	VARIABLE func4_Logbook_TARGET_MODE; \
	MENU func4_Logbook_TARGET_MODE_page; \
	COMMAND func4_Logbook_TARGET_MODE_read; \
	COMMAND func4_Logbook_TARGET_MODE_write; \
	COLLECTION func4_Logbook_MODE_BLK; \
	VARIABLE func4_Logbook_MODE_BLK_Actual; \
	VARIABLE func4_Logbook_MODE_BLK_Permitted; \
	VARIABLE func4_Logbook_MODE_BLK_Normal; \
	MENU func4_Logbook_MODE_BLK_page; \
	COMMAND func4_Logbook_MODE_BLK_read; \
	COLLECTION func4_Logbook_ALARM_SUM; \
	VARIABLE func4_Logbook_ALARM_SUM_Current; \
	VARIABLE func4_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func4_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func4_Logbook_ALARM_SUM_Disabled; \
	MENU func4_Logbook_ALARM_SUM_page; \
	COMMAND func4_Logbook_ALARM_SUM_read; \
	COLLECTION func4_Logbook_BATCH; \
	VARIABLE func4_Logbook_BATCH_Batch_ID; \
	VARIABLE func4_Logbook_BATCH_Rup; \
	VARIABLE func4_Logbook_BATCH_Operation; \
	VARIABLE func4_Logbook_BATCH_Phase; \
	MENU func4_Logbook_BATCH_page; \
	COMMAND func4_Logbook_BATCH_read; \
	COMMAND func4_Logbook_BATCH_write; \
	VARIABLE func4_Logbook_COMMAND; \
	MENU func4_Logbook_COMMAND_page; \
	COMMAND func4_Logbook_COMMAND_read; \
	COMMAND func4_Logbook_COMMAND_write; \
	VARIABLE func4_Logbook_STATUS; \
	MENU func4_Logbook_STATUS_page; \
	COMMAND func4_Logbook_STATUS_read; \
	VARIABLE func4_Logbook_SIZE_OF_ENTRIES; \
	MENU func4_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func4_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func4_Logbook_NUMBER_OF_ENTRIES; \
	MENU func4_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func4_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func4_Logbook_TURN_NUMBER; \
	MENU func4_Logbook_TURN_NUMBER_page; \
	COMMAND func4_Logbook_TURN_NUMBER_read; \
	COLLECTION func4_Logbook_NEWEST_ENTRY; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func4_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func4_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func4_Logbook_NEWEST_ENTRY_page; \
	COMMAND func4_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func4_Logbook_OLDEST_ENTRY; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func4_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func4_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func4_Logbook_OLDEST_ENTRY_page; \
	COMMAND func4_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func4_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func4_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func4_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func4_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func4_Logbook_POST_READ_ENTRY; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func4_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func4_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func4_Logbook_POST_READ_ENTRY_page; \
	COMMAND func4_Logbook_POST_READ_ENTRY_read

#define USE_FUNC4_LOGBOOK_MANDATORY_A \
	USE_FUNC4_LOGBOOK_MANDATORY_BOTH; \
	MENU func4_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC4_LOGBOOK_MANDATORY_B \
	USE_FUNC4_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func4_Logbook_VIEW_1; \
	MENU func4_Logbook_VIEW_1_page; \
	MENU func4_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC4_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func4_Logbook_VIEW_2; \
	MENU func4_Logbook_VIEW_2_page; \
	COLLECTION func4_Logbook_VIEW_3; \
	MENU func4_Logbook_VIEW_3_page

#define USE_FUNC4_LOGBOOK_OPTIONAL_A \
	USE_FUNC4_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func4_Logbook_VIEW_1; \
	MENU func4_Logbook_VIEW_1_page; \
	MENU func4_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC4_LOGBOOK_OPTIONAL_B \
	USE_FUNC4_LOGBOOK_OPTIONAL_BOTH; \
	MENU func4_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC4_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func4_Logbook_)
#define USE_FUNC4_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func4_Logbook_)
#define USE_FUNC4_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func4_Logbook_)
#define USE_FUNC4_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func4_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC5_LOGBOOK_MANDATORY_BOTH \
	BLOCK func5_Logbook_block; \
	COLLECTION func5_Logbook_BLOCK_OBJECT; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func5_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func5_Logbook_BLOCK_OBJECT_page; \
	COMMAND func5_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func5_Logbook_ST_REV; \
	MENU func5_Logbook_ST_REV_page; \
	COMMAND func5_Logbook_ST_REV_read; \
	VARIABLE func5_Logbook_TAG_DESC; \
	MENU func5_Logbook_TAG_DESC_page; \
	COMMAND func5_Logbook_TAG_DESC_read; \
	COMMAND func5_Logbook_TAG_DESC_write; \
	VARIABLE func5_Logbook_STRATEGY; \
	MENU func5_Logbook_STRATEGY_page; \
	COMMAND func5_Logbook_STRATEGY_read; \
	COMMAND func5_Logbook_STRATEGY_write; \
	VARIABLE func5_Logbook_ALERT_KEY; \
	MENU func5_Logbook_ALERT_KEY_page; \
	COMMAND func5_Logbook_ALERT_KEY_read; \
	COMMAND func5_Logbook_ALERT_KEY_write; \
	VARIABLE func5_Logbook_TARGET_MODE; \
	MENU func5_Logbook_TARGET_MODE_page; \
	COMMAND func5_Logbook_TARGET_MODE_read; \
	COMMAND func5_Logbook_TARGET_MODE_write; \
	COLLECTION func5_Logbook_MODE_BLK; \
	VARIABLE func5_Logbook_MODE_BLK_Actual; \
	VARIABLE func5_Logbook_MODE_BLK_Permitted; \
	VARIABLE func5_Logbook_MODE_BLK_Normal; \
	MENU func5_Logbook_MODE_BLK_page; \
	COMMAND func5_Logbook_MODE_BLK_read; \
	COLLECTION func5_Logbook_ALARM_SUM; \
	VARIABLE func5_Logbook_ALARM_SUM_Current; \
	VARIABLE func5_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func5_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func5_Logbook_ALARM_SUM_Disabled; \
	MENU func5_Logbook_ALARM_SUM_page; \
	COMMAND func5_Logbook_ALARM_SUM_read; \
	COLLECTION func5_Logbook_BATCH; \
	VARIABLE func5_Logbook_BATCH_Batch_ID; \
	VARIABLE func5_Logbook_BATCH_Rup; \
	VARIABLE func5_Logbook_BATCH_Operation; \
	VARIABLE func5_Logbook_BATCH_Phase; \
	MENU func5_Logbook_BATCH_page; \
	COMMAND func5_Logbook_BATCH_read; \
	COMMAND func5_Logbook_BATCH_write; \
	VARIABLE func5_Logbook_COMMAND; \
	MENU func5_Logbook_COMMAND_page; \
	COMMAND func5_Logbook_COMMAND_read; \
	COMMAND func5_Logbook_COMMAND_write; \
	VARIABLE func5_Logbook_STATUS; \
	MENU func5_Logbook_STATUS_page; \
	COMMAND func5_Logbook_STATUS_read; \
	VARIABLE func5_Logbook_SIZE_OF_ENTRIES; \
	MENU func5_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func5_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func5_Logbook_NUMBER_OF_ENTRIES; \
	MENU func5_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func5_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func5_Logbook_TURN_NUMBER; \
	MENU func5_Logbook_TURN_NUMBER_page; \
	COMMAND func5_Logbook_TURN_NUMBER_read; \
	COLLECTION func5_Logbook_NEWEST_ENTRY; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func5_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func5_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func5_Logbook_NEWEST_ENTRY_page; \
	COMMAND func5_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func5_Logbook_OLDEST_ENTRY; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func5_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func5_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func5_Logbook_OLDEST_ENTRY_page; \
	COMMAND func5_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func5_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func5_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func5_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func5_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func5_Logbook_POST_READ_ENTRY; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func5_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func5_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func5_Logbook_POST_READ_ENTRY_page; \
	COMMAND func5_Logbook_POST_READ_ENTRY_read

#define USE_FUNC5_LOGBOOK_MANDATORY_A \
	USE_FUNC5_LOGBOOK_MANDATORY_BOTH; \
	MENU func5_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC5_LOGBOOK_MANDATORY_B \
	USE_FUNC5_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func5_Logbook_VIEW_1; \
	MENU func5_Logbook_VIEW_1_page; \
	MENU func5_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC5_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func5_Logbook_VIEW_2; \
	MENU func5_Logbook_VIEW_2_page; \
	COLLECTION func5_Logbook_VIEW_3; \
	MENU func5_Logbook_VIEW_3_page

#define USE_FUNC5_LOGBOOK_OPTIONAL_A \
	USE_FUNC5_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func5_Logbook_VIEW_1; \
	MENU func5_Logbook_VIEW_1_page; \
	MENU func5_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC5_LOGBOOK_OPTIONAL_B \
	USE_FUNC5_LOGBOOK_OPTIONAL_BOTH; \
	MENU func5_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC5_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func5_Logbook_)
#define USE_FUNC5_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func5_Logbook_)
#define USE_FUNC5_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func5_Logbook_)
#define USE_FUNC5_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func5_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC6_LOGBOOK_MANDATORY_BOTH \
	BLOCK func6_Logbook_block; \
	COLLECTION func6_Logbook_BLOCK_OBJECT; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func6_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func6_Logbook_BLOCK_OBJECT_page; \
	COMMAND func6_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func6_Logbook_ST_REV; \
	MENU func6_Logbook_ST_REV_page; \
	COMMAND func6_Logbook_ST_REV_read; \
	VARIABLE func6_Logbook_TAG_DESC; \
	MENU func6_Logbook_TAG_DESC_page; \
	COMMAND func6_Logbook_TAG_DESC_read; \
	COMMAND func6_Logbook_TAG_DESC_write; \
	VARIABLE func6_Logbook_STRATEGY; \
	MENU func6_Logbook_STRATEGY_page; \
	COMMAND func6_Logbook_STRATEGY_read; \
	COMMAND func6_Logbook_STRATEGY_write; \
	VARIABLE func6_Logbook_ALERT_KEY; \
	MENU func6_Logbook_ALERT_KEY_page; \
	COMMAND func6_Logbook_ALERT_KEY_read; \
	COMMAND func6_Logbook_ALERT_KEY_write; \
	VARIABLE func6_Logbook_TARGET_MODE; \
	MENU func6_Logbook_TARGET_MODE_page; \
	COMMAND func6_Logbook_TARGET_MODE_read; \
	COMMAND func6_Logbook_TARGET_MODE_write; \
	COLLECTION func6_Logbook_MODE_BLK; \
	VARIABLE func6_Logbook_MODE_BLK_Actual; \
	VARIABLE func6_Logbook_MODE_BLK_Permitted; \
	VARIABLE func6_Logbook_MODE_BLK_Normal; \
	MENU func6_Logbook_MODE_BLK_page; \
	COMMAND func6_Logbook_MODE_BLK_read; \
	COLLECTION func6_Logbook_ALARM_SUM; \
	VARIABLE func6_Logbook_ALARM_SUM_Current; \
	VARIABLE func6_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func6_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func6_Logbook_ALARM_SUM_Disabled; \
	MENU func6_Logbook_ALARM_SUM_page; \
	COMMAND func6_Logbook_ALARM_SUM_read; \
	COLLECTION func6_Logbook_BATCH; \
	VARIABLE func6_Logbook_BATCH_Batch_ID; \
	VARIABLE func6_Logbook_BATCH_Rup; \
	VARIABLE func6_Logbook_BATCH_Operation; \
	VARIABLE func6_Logbook_BATCH_Phase; \
	MENU func6_Logbook_BATCH_page; \
	COMMAND func6_Logbook_BATCH_read; \
	COMMAND func6_Logbook_BATCH_write; \
	VARIABLE func6_Logbook_COMMAND; \
	MENU func6_Logbook_COMMAND_page; \
	COMMAND func6_Logbook_COMMAND_read; \
	COMMAND func6_Logbook_COMMAND_write; \
	VARIABLE func6_Logbook_STATUS; \
	MENU func6_Logbook_STATUS_page; \
	COMMAND func6_Logbook_STATUS_read; \
	VARIABLE func6_Logbook_SIZE_OF_ENTRIES; \
	MENU func6_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func6_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func6_Logbook_NUMBER_OF_ENTRIES; \
	MENU func6_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func6_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func6_Logbook_TURN_NUMBER; \
	MENU func6_Logbook_TURN_NUMBER_page; \
	COMMAND func6_Logbook_TURN_NUMBER_read; \
	COLLECTION func6_Logbook_NEWEST_ENTRY; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func6_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func6_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func6_Logbook_NEWEST_ENTRY_page; \
	COMMAND func6_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func6_Logbook_OLDEST_ENTRY; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func6_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func6_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func6_Logbook_OLDEST_ENTRY_page; \
	COMMAND func6_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func6_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func6_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func6_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func6_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func6_Logbook_POST_READ_ENTRY; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func6_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func6_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func6_Logbook_POST_READ_ENTRY_page; \
	COMMAND func6_Logbook_POST_READ_ENTRY_read

#define USE_FUNC6_LOGBOOK_MANDATORY_A \
	USE_FUNC6_LOGBOOK_MANDATORY_BOTH; \
	MENU func6_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC6_LOGBOOK_MANDATORY_B \
	USE_FUNC6_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func6_Logbook_VIEW_1; \
	MENU func6_Logbook_VIEW_1_page; \
	MENU func6_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC6_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func6_Logbook_VIEW_2; \
	MENU func6_Logbook_VIEW_2_page; \
	COLLECTION func6_Logbook_VIEW_3; \
	MENU func6_Logbook_VIEW_3_page

#define USE_FUNC6_LOGBOOK_OPTIONAL_A \
	USE_FUNC6_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func6_Logbook_VIEW_1; \
	MENU func6_Logbook_VIEW_1_page; \
	MENU func6_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC6_LOGBOOK_OPTIONAL_B \
	USE_FUNC6_LOGBOOK_OPTIONAL_BOTH; \
	MENU func6_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC6_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func6_Logbook_)
#define USE_FUNC6_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func6_Logbook_)
#define USE_FUNC6_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func6_Logbook_)
#define USE_FUNC6_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func6_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC7_LOGBOOK_MANDATORY_BOTH \
	BLOCK func7_Logbook_block; \
	COLLECTION func7_Logbook_BLOCK_OBJECT; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func7_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func7_Logbook_BLOCK_OBJECT_page; \
	COMMAND func7_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func7_Logbook_ST_REV; \
	MENU func7_Logbook_ST_REV_page; \
	COMMAND func7_Logbook_ST_REV_read; \
	VARIABLE func7_Logbook_TAG_DESC; \
	MENU func7_Logbook_TAG_DESC_page; \
	COMMAND func7_Logbook_TAG_DESC_read; \
	COMMAND func7_Logbook_TAG_DESC_write; \
	VARIABLE func7_Logbook_STRATEGY; \
	MENU func7_Logbook_STRATEGY_page; \
	COMMAND func7_Logbook_STRATEGY_read; \
	COMMAND func7_Logbook_STRATEGY_write; \
	VARIABLE func7_Logbook_ALERT_KEY; \
	MENU func7_Logbook_ALERT_KEY_page; \
	COMMAND func7_Logbook_ALERT_KEY_read; \
	COMMAND func7_Logbook_ALERT_KEY_write; \
	VARIABLE func7_Logbook_TARGET_MODE; \
	MENU func7_Logbook_TARGET_MODE_page; \
	COMMAND func7_Logbook_TARGET_MODE_read; \
	COMMAND func7_Logbook_TARGET_MODE_write; \
	COLLECTION func7_Logbook_MODE_BLK; \
	VARIABLE func7_Logbook_MODE_BLK_Actual; \
	VARIABLE func7_Logbook_MODE_BLK_Permitted; \
	VARIABLE func7_Logbook_MODE_BLK_Normal; \
	MENU func7_Logbook_MODE_BLK_page; \
	COMMAND func7_Logbook_MODE_BLK_read; \
	COLLECTION func7_Logbook_ALARM_SUM; \
	VARIABLE func7_Logbook_ALARM_SUM_Current; \
	VARIABLE func7_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func7_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func7_Logbook_ALARM_SUM_Disabled; \
	MENU func7_Logbook_ALARM_SUM_page; \
	COMMAND func7_Logbook_ALARM_SUM_read; \
	COLLECTION func7_Logbook_BATCH; \
	VARIABLE func7_Logbook_BATCH_Batch_ID; \
	VARIABLE func7_Logbook_BATCH_Rup; \
	VARIABLE func7_Logbook_BATCH_Operation; \
	VARIABLE func7_Logbook_BATCH_Phase; \
	MENU func7_Logbook_BATCH_page; \
	COMMAND func7_Logbook_BATCH_read; \
	COMMAND func7_Logbook_BATCH_write; \
	VARIABLE func7_Logbook_COMMAND; \
	MENU func7_Logbook_COMMAND_page; \
	COMMAND func7_Logbook_COMMAND_read; \
	COMMAND func7_Logbook_COMMAND_write; \
	VARIABLE func7_Logbook_STATUS; \
	MENU func7_Logbook_STATUS_page; \
	COMMAND func7_Logbook_STATUS_read; \
	VARIABLE func7_Logbook_SIZE_OF_ENTRIES; \
	MENU func7_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func7_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func7_Logbook_NUMBER_OF_ENTRIES; \
	MENU func7_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func7_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func7_Logbook_TURN_NUMBER; \
	MENU func7_Logbook_TURN_NUMBER_page; \
	COMMAND func7_Logbook_TURN_NUMBER_read; \
	COLLECTION func7_Logbook_NEWEST_ENTRY; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func7_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func7_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func7_Logbook_NEWEST_ENTRY_page; \
	COMMAND func7_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func7_Logbook_OLDEST_ENTRY; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func7_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func7_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func7_Logbook_OLDEST_ENTRY_page; \
	COMMAND func7_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func7_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func7_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func7_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func7_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func7_Logbook_POST_READ_ENTRY; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func7_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func7_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func7_Logbook_POST_READ_ENTRY_page; \
	COMMAND func7_Logbook_POST_READ_ENTRY_read

#define USE_FUNC7_LOGBOOK_MANDATORY_A \
	USE_FUNC7_LOGBOOK_MANDATORY_BOTH; \
	MENU func7_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC7_LOGBOOK_MANDATORY_B \
	USE_FUNC7_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func7_Logbook_VIEW_1; \
	MENU func7_Logbook_VIEW_1_page; \
	MENU func7_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC7_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func7_Logbook_VIEW_2; \
	MENU func7_Logbook_VIEW_2_page; \
	COLLECTION func7_Logbook_VIEW_3; \
	MENU func7_Logbook_VIEW_3_page

#define USE_FUNC7_LOGBOOK_OPTIONAL_A \
	USE_FUNC7_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func7_Logbook_VIEW_1; \
	MENU func7_Logbook_VIEW_1_page; \
	MENU func7_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC7_LOGBOOK_OPTIONAL_B \
	USE_FUNC7_LOGBOOK_OPTIONAL_BOTH; \
	MENU func7_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC7_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func7_Logbook_)
#define USE_FUNC7_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func7_Logbook_)
#define USE_FUNC7_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func7_Logbook_)
#define USE_FUNC7_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func7_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC8_LOGBOOK_MANDATORY_BOTH \
	BLOCK func8_Logbook_block; \
	COLLECTION func8_Logbook_BLOCK_OBJECT; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func8_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func8_Logbook_BLOCK_OBJECT_page; \
	COMMAND func8_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func8_Logbook_ST_REV; \
	MENU func8_Logbook_ST_REV_page; \
	COMMAND func8_Logbook_ST_REV_read; \
	VARIABLE func8_Logbook_TAG_DESC; \
	MENU func8_Logbook_TAG_DESC_page; \
	COMMAND func8_Logbook_TAG_DESC_read; \
	COMMAND func8_Logbook_TAG_DESC_write; \
	VARIABLE func8_Logbook_STRATEGY; \
	MENU func8_Logbook_STRATEGY_page; \
	COMMAND func8_Logbook_STRATEGY_read; \
	COMMAND func8_Logbook_STRATEGY_write; \
	VARIABLE func8_Logbook_ALERT_KEY; \
	MENU func8_Logbook_ALERT_KEY_page; \
	COMMAND func8_Logbook_ALERT_KEY_read; \
	COMMAND func8_Logbook_ALERT_KEY_write; \
	VARIABLE func8_Logbook_TARGET_MODE; \
	MENU func8_Logbook_TARGET_MODE_page; \
	COMMAND func8_Logbook_TARGET_MODE_read; \
	COMMAND func8_Logbook_TARGET_MODE_write; \
	COLLECTION func8_Logbook_MODE_BLK; \
	VARIABLE func8_Logbook_MODE_BLK_Actual; \
	VARIABLE func8_Logbook_MODE_BLK_Permitted; \
	VARIABLE func8_Logbook_MODE_BLK_Normal; \
	MENU func8_Logbook_MODE_BLK_page; \
	COMMAND func8_Logbook_MODE_BLK_read; \
	COLLECTION func8_Logbook_ALARM_SUM; \
	VARIABLE func8_Logbook_ALARM_SUM_Current; \
	VARIABLE func8_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func8_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func8_Logbook_ALARM_SUM_Disabled; \
	MENU func8_Logbook_ALARM_SUM_page; \
	COMMAND func8_Logbook_ALARM_SUM_read; \
	COLLECTION func8_Logbook_BATCH; \
	VARIABLE func8_Logbook_BATCH_Batch_ID; \
	VARIABLE func8_Logbook_BATCH_Rup; \
	VARIABLE func8_Logbook_BATCH_Operation; \
	VARIABLE func8_Logbook_BATCH_Phase; \
	MENU func8_Logbook_BATCH_page; \
	COMMAND func8_Logbook_BATCH_read; \
	COMMAND func8_Logbook_BATCH_write; \
	VARIABLE func8_Logbook_COMMAND; \
	MENU func8_Logbook_COMMAND_page; \
	COMMAND func8_Logbook_COMMAND_read; \
	COMMAND func8_Logbook_COMMAND_write; \
	VARIABLE func8_Logbook_STATUS; \
	MENU func8_Logbook_STATUS_page; \
	COMMAND func8_Logbook_STATUS_read; \
	VARIABLE func8_Logbook_SIZE_OF_ENTRIES; \
	MENU func8_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func8_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func8_Logbook_NUMBER_OF_ENTRIES; \
	MENU func8_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func8_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func8_Logbook_TURN_NUMBER; \
	MENU func8_Logbook_TURN_NUMBER_page; \
	COMMAND func8_Logbook_TURN_NUMBER_read; \
	COLLECTION func8_Logbook_NEWEST_ENTRY; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func8_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func8_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func8_Logbook_NEWEST_ENTRY_page; \
	COMMAND func8_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func8_Logbook_OLDEST_ENTRY; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func8_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func8_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func8_Logbook_OLDEST_ENTRY_page; \
	COMMAND func8_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func8_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func8_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func8_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func8_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func8_Logbook_POST_READ_ENTRY; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func8_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func8_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func8_Logbook_POST_READ_ENTRY_page; \
	COMMAND func8_Logbook_POST_READ_ENTRY_read

#define USE_FUNC8_LOGBOOK_MANDATORY_A \
	USE_FUNC8_LOGBOOK_MANDATORY_BOTH; \
	MENU func8_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC8_LOGBOOK_MANDATORY_B \
	USE_FUNC8_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func8_Logbook_VIEW_1; \
	MENU func8_Logbook_VIEW_1_page; \
	MENU func8_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC8_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func8_Logbook_VIEW_2; \
	MENU func8_Logbook_VIEW_2_page; \
	COLLECTION func8_Logbook_VIEW_3; \
	MENU func8_Logbook_VIEW_3_page

#define USE_FUNC8_LOGBOOK_OPTIONAL_A \
	USE_FUNC8_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func8_Logbook_VIEW_1; \
	MENU func8_Logbook_VIEW_1_page; \
	MENU func8_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC8_LOGBOOK_OPTIONAL_B \
	USE_FUNC8_LOGBOOK_OPTIONAL_BOTH; \
	MENU func8_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC8_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func8_Logbook_)
#define USE_FUNC8_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func8_Logbook_)
#define USE_FUNC8_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func8_Logbook_)
#define USE_FUNC8_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func8_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC9_LOGBOOK_MANDATORY_BOTH \
	BLOCK func9_Logbook_block; \
	COLLECTION func9_Logbook_BLOCK_OBJECT; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func9_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func9_Logbook_BLOCK_OBJECT_page; \
	COMMAND func9_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func9_Logbook_ST_REV; \
	MENU func9_Logbook_ST_REV_page; \
	COMMAND func9_Logbook_ST_REV_read; \
	VARIABLE func9_Logbook_TAG_DESC; \
	MENU func9_Logbook_TAG_DESC_page; \
	COMMAND func9_Logbook_TAG_DESC_read; \
	COMMAND func9_Logbook_TAG_DESC_write; \
	VARIABLE func9_Logbook_STRATEGY; \
	MENU func9_Logbook_STRATEGY_page; \
	COMMAND func9_Logbook_STRATEGY_read; \
	COMMAND func9_Logbook_STRATEGY_write; \
	VARIABLE func9_Logbook_ALERT_KEY; \
	MENU func9_Logbook_ALERT_KEY_page; \
	COMMAND func9_Logbook_ALERT_KEY_read; \
	COMMAND func9_Logbook_ALERT_KEY_write; \
	VARIABLE func9_Logbook_TARGET_MODE; \
	MENU func9_Logbook_TARGET_MODE_page; \
	COMMAND func9_Logbook_TARGET_MODE_read; \
	COMMAND func9_Logbook_TARGET_MODE_write; \
	COLLECTION func9_Logbook_MODE_BLK; \
	VARIABLE func9_Logbook_MODE_BLK_Actual; \
	VARIABLE func9_Logbook_MODE_BLK_Permitted; \
	VARIABLE func9_Logbook_MODE_BLK_Normal; \
	MENU func9_Logbook_MODE_BLK_page; \
	COMMAND func9_Logbook_MODE_BLK_read; \
	COLLECTION func9_Logbook_ALARM_SUM; \
	VARIABLE func9_Logbook_ALARM_SUM_Current; \
	VARIABLE func9_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func9_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func9_Logbook_ALARM_SUM_Disabled; \
	MENU func9_Logbook_ALARM_SUM_page; \
	COMMAND func9_Logbook_ALARM_SUM_read; \
	COLLECTION func9_Logbook_BATCH; \
	VARIABLE func9_Logbook_BATCH_Batch_ID; \
	VARIABLE func9_Logbook_BATCH_Rup; \
	VARIABLE func9_Logbook_BATCH_Operation; \
	VARIABLE func9_Logbook_BATCH_Phase; \
	MENU func9_Logbook_BATCH_page; \
	COMMAND func9_Logbook_BATCH_read; \
	COMMAND func9_Logbook_BATCH_write; \
	VARIABLE func9_Logbook_COMMAND; \
	MENU func9_Logbook_COMMAND_page; \
	COMMAND func9_Logbook_COMMAND_read; \
	COMMAND func9_Logbook_COMMAND_write; \
	VARIABLE func9_Logbook_STATUS; \
	MENU func9_Logbook_STATUS_page; \
	COMMAND func9_Logbook_STATUS_read; \
	VARIABLE func9_Logbook_SIZE_OF_ENTRIES; \
	MENU func9_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func9_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func9_Logbook_NUMBER_OF_ENTRIES; \
	MENU func9_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func9_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func9_Logbook_TURN_NUMBER; \
	MENU func9_Logbook_TURN_NUMBER_page; \
	COMMAND func9_Logbook_TURN_NUMBER_read; \
	COLLECTION func9_Logbook_NEWEST_ENTRY; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func9_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func9_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func9_Logbook_NEWEST_ENTRY_page; \
	COMMAND func9_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func9_Logbook_OLDEST_ENTRY; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func9_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func9_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func9_Logbook_OLDEST_ENTRY_page; \
	COMMAND func9_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func9_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func9_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func9_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func9_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func9_Logbook_POST_READ_ENTRY; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func9_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func9_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func9_Logbook_POST_READ_ENTRY_page; \
	COMMAND func9_Logbook_POST_READ_ENTRY_read

#define USE_FUNC9_LOGBOOK_MANDATORY_A \
	USE_FUNC9_LOGBOOK_MANDATORY_BOTH; \
	MENU func9_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC9_LOGBOOK_MANDATORY_B \
	USE_FUNC9_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func9_Logbook_VIEW_1; \
	MENU func9_Logbook_VIEW_1_page; \
	MENU func9_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC9_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func9_Logbook_VIEW_2; \
	MENU func9_Logbook_VIEW_2_page; \
	COLLECTION func9_Logbook_VIEW_3; \
	MENU func9_Logbook_VIEW_3_page

#define USE_FUNC9_LOGBOOK_OPTIONAL_A \
	USE_FUNC9_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func9_Logbook_VIEW_1; \
	MENU func9_Logbook_VIEW_1_page; \
	MENU func9_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC9_LOGBOOK_OPTIONAL_B \
	USE_FUNC9_LOGBOOK_OPTIONAL_BOTH; \
	MENU func9_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC9_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func9_Logbook_)
#define USE_FUNC9_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func9_Logbook_)
#define USE_FUNC9_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func9_Logbook_)
#define USE_FUNC9_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func9_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC10_LOGBOOK_MANDATORY_BOTH \
	BLOCK func10_Logbook_block; \
	COLLECTION func10_Logbook_BLOCK_OBJECT; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func10_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func10_Logbook_BLOCK_OBJECT_page; \
	COMMAND func10_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func10_Logbook_ST_REV; \
	MENU func10_Logbook_ST_REV_page; \
	COMMAND func10_Logbook_ST_REV_read; \
	VARIABLE func10_Logbook_TAG_DESC; \
	MENU func10_Logbook_TAG_DESC_page; \
	COMMAND func10_Logbook_TAG_DESC_read; \
	COMMAND func10_Logbook_TAG_DESC_write; \
	VARIABLE func10_Logbook_STRATEGY; \
	MENU func10_Logbook_STRATEGY_page; \
	COMMAND func10_Logbook_STRATEGY_read; \
	COMMAND func10_Logbook_STRATEGY_write; \
	VARIABLE func10_Logbook_ALERT_KEY; \
	MENU func10_Logbook_ALERT_KEY_page; \
	COMMAND func10_Logbook_ALERT_KEY_read; \
	COMMAND func10_Logbook_ALERT_KEY_write; \
	VARIABLE func10_Logbook_TARGET_MODE; \
	MENU func10_Logbook_TARGET_MODE_page; \
	COMMAND func10_Logbook_TARGET_MODE_read; \
	COMMAND func10_Logbook_TARGET_MODE_write; \
	COLLECTION func10_Logbook_MODE_BLK; \
	VARIABLE func10_Logbook_MODE_BLK_Actual; \
	VARIABLE func10_Logbook_MODE_BLK_Permitted; \
	VARIABLE func10_Logbook_MODE_BLK_Normal; \
	MENU func10_Logbook_MODE_BLK_page; \
	COMMAND func10_Logbook_MODE_BLK_read; \
	COLLECTION func10_Logbook_ALARM_SUM; \
	VARIABLE func10_Logbook_ALARM_SUM_Current; \
	VARIABLE func10_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func10_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func10_Logbook_ALARM_SUM_Disabled; \
	MENU func10_Logbook_ALARM_SUM_page; \
	COMMAND func10_Logbook_ALARM_SUM_read; \
	COLLECTION func10_Logbook_BATCH; \
	VARIABLE func10_Logbook_BATCH_Batch_ID; \
	VARIABLE func10_Logbook_BATCH_Rup; \
	VARIABLE func10_Logbook_BATCH_Operation; \
	VARIABLE func10_Logbook_BATCH_Phase; \
	MENU func10_Logbook_BATCH_page; \
	COMMAND func10_Logbook_BATCH_read; \
	COMMAND func10_Logbook_BATCH_write; \
	VARIABLE func10_Logbook_COMMAND; \
	MENU func10_Logbook_COMMAND_page; \
	COMMAND func10_Logbook_COMMAND_read; \
	COMMAND func10_Logbook_COMMAND_write; \
	VARIABLE func10_Logbook_STATUS; \
	MENU func10_Logbook_STATUS_page; \
	COMMAND func10_Logbook_STATUS_read; \
	VARIABLE func10_Logbook_SIZE_OF_ENTRIES; \
	MENU func10_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func10_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func10_Logbook_NUMBER_OF_ENTRIES; \
	MENU func10_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func10_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func10_Logbook_TURN_NUMBER; \
	MENU func10_Logbook_TURN_NUMBER_page; \
	COMMAND func10_Logbook_TURN_NUMBER_read; \
	COLLECTION func10_Logbook_NEWEST_ENTRY; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func10_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func10_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func10_Logbook_NEWEST_ENTRY_page; \
	COMMAND func10_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func10_Logbook_OLDEST_ENTRY; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func10_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func10_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func10_Logbook_OLDEST_ENTRY_page; \
	COMMAND func10_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func10_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func10_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func10_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func10_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func10_Logbook_POST_READ_ENTRY; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func10_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func10_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func10_Logbook_POST_READ_ENTRY_page; \
	COMMAND func10_Logbook_POST_READ_ENTRY_read

#define USE_FUNC10_LOGBOOK_MANDATORY_A \
	USE_FUNC10_LOGBOOK_MANDATORY_BOTH; \
	MENU func10_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC10_LOGBOOK_MANDATORY_B \
	USE_FUNC10_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func10_Logbook_VIEW_1; \
	MENU func10_Logbook_VIEW_1_page; \
	MENU func10_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC10_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func10_Logbook_VIEW_2; \
	MENU func10_Logbook_VIEW_2_page; \
	COLLECTION func10_Logbook_VIEW_3; \
	MENU func10_Logbook_VIEW_3_page

#define USE_FUNC10_LOGBOOK_OPTIONAL_A \
	USE_FUNC10_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func10_Logbook_VIEW_1; \
	MENU func10_Logbook_VIEW_1_page; \
	MENU func10_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC10_LOGBOOK_OPTIONAL_B \
	USE_FUNC10_LOGBOOK_OPTIONAL_BOTH; \
	MENU func10_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC10_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func10_Logbook_)
#define USE_FUNC10_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func10_Logbook_)
#define USE_FUNC10_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func10_Logbook_)
#define USE_FUNC10_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func10_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC11_LOGBOOK_MANDATORY_BOTH \
	BLOCK func11_Logbook_block; \
	COLLECTION func11_Logbook_BLOCK_OBJECT; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func11_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func11_Logbook_BLOCK_OBJECT_page; \
	COMMAND func11_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func11_Logbook_ST_REV; \
	MENU func11_Logbook_ST_REV_page; \
	COMMAND func11_Logbook_ST_REV_read; \
	VARIABLE func11_Logbook_TAG_DESC; \
	MENU func11_Logbook_TAG_DESC_page; \
	COMMAND func11_Logbook_TAG_DESC_read; \
	COMMAND func11_Logbook_TAG_DESC_write; \
	VARIABLE func11_Logbook_STRATEGY; \
	MENU func11_Logbook_STRATEGY_page; \
	COMMAND func11_Logbook_STRATEGY_read; \
	COMMAND func11_Logbook_STRATEGY_write; \
	VARIABLE func11_Logbook_ALERT_KEY; \
	MENU func11_Logbook_ALERT_KEY_page; \
	COMMAND func11_Logbook_ALERT_KEY_read; \
	COMMAND func11_Logbook_ALERT_KEY_write; \
	VARIABLE func11_Logbook_TARGET_MODE; \
	MENU func11_Logbook_TARGET_MODE_page; \
	COMMAND func11_Logbook_TARGET_MODE_read; \
	COMMAND func11_Logbook_TARGET_MODE_write; \
	COLLECTION func11_Logbook_MODE_BLK; \
	VARIABLE func11_Logbook_MODE_BLK_Actual; \
	VARIABLE func11_Logbook_MODE_BLK_Permitted; \
	VARIABLE func11_Logbook_MODE_BLK_Normal; \
	MENU func11_Logbook_MODE_BLK_page; \
	COMMAND func11_Logbook_MODE_BLK_read; \
	COLLECTION func11_Logbook_ALARM_SUM; \
	VARIABLE func11_Logbook_ALARM_SUM_Current; \
	VARIABLE func11_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func11_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func11_Logbook_ALARM_SUM_Disabled; \
	MENU func11_Logbook_ALARM_SUM_page; \
	COMMAND func11_Logbook_ALARM_SUM_read; \
	COLLECTION func11_Logbook_BATCH; \
	VARIABLE func11_Logbook_BATCH_Batch_ID; \
	VARIABLE func11_Logbook_BATCH_Rup; \
	VARIABLE func11_Logbook_BATCH_Operation; \
	VARIABLE func11_Logbook_BATCH_Phase; \
	MENU func11_Logbook_BATCH_page; \
	COMMAND func11_Logbook_BATCH_read; \
	COMMAND func11_Logbook_BATCH_write; \
	VARIABLE func11_Logbook_COMMAND; \
	MENU func11_Logbook_COMMAND_page; \
	COMMAND func11_Logbook_COMMAND_read; \
	COMMAND func11_Logbook_COMMAND_write; \
	VARIABLE func11_Logbook_STATUS; \
	MENU func11_Logbook_STATUS_page; \
	COMMAND func11_Logbook_STATUS_read; \
	VARIABLE func11_Logbook_SIZE_OF_ENTRIES; \
	MENU func11_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func11_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func11_Logbook_NUMBER_OF_ENTRIES; \
	MENU func11_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func11_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func11_Logbook_TURN_NUMBER; \
	MENU func11_Logbook_TURN_NUMBER_page; \
	COMMAND func11_Logbook_TURN_NUMBER_read; \
	COLLECTION func11_Logbook_NEWEST_ENTRY; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func11_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func11_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func11_Logbook_NEWEST_ENTRY_page; \
	COMMAND func11_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func11_Logbook_OLDEST_ENTRY; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func11_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func11_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func11_Logbook_OLDEST_ENTRY_page; \
	COMMAND func11_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func11_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func11_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func11_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func11_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func11_Logbook_POST_READ_ENTRY; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func11_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func11_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func11_Logbook_POST_READ_ENTRY_page; \
	COMMAND func11_Logbook_POST_READ_ENTRY_read

#define USE_FUNC11_LOGBOOK_MANDATORY_A \
	USE_FUNC11_LOGBOOK_MANDATORY_BOTH; \
	MENU func11_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC11_LOGBOOK_MANDATORY_B \
	USE_FUNC11_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func11_Logbook_VIEW_1; \
	MENU func11_Logbook_VIEW_1_page; \
	MENU func11_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC11_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func11_Logbook_VIEW_2; \
	MENU func11_Logbook_VIEW_2_page; \
	COLLECTION func11_Logbook_VIEW_3; \
	MENU func11_Logbook_VIEW_3_page

#define USE_FUNC11_LOGBOOK_OPTIONAL_A \
	USE_FUNC11_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func11_Logbook_VIEW_1; \
	MENU func11_Logbook_VIEW_1_page; \
	MENU func11_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC11_LOGBOOK_OPTIONAL_B \
	USE_FUNC11_LOGBOOK_OPTIONAL_BOTH; \
	MENU func11_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC11_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func11_Logbook_)
#define USE_FUNC11_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func11_Logbook_)
#define USE_FUNC11_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func11_Logbook_)
#define USE_FUNC11_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func11_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC12_LOGBOOK_MANDATORY_BOTH \
	BLOCK func12_Logbook_block; \
	COLLECTION func12_Logbook_BLOCK_OBJECT; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func12_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func12_Logbook_BLOCK_OBJECT_page; \
	COMMAND func12_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func12_Logbook_ST_REV; \
	MENU func12_Logbook_ST_REV_page; \
	COMMAND func12_Logbook_ST_REV_read; \
	VARIABLE func12_Logbook_TAG_DESC; \
	MENU func12_Logbook_TAG_DESC_page; \
	COMMAND func12_Logbook_TAG_DESC_read; \
	COMMAND func12_Logbook_TAG_DESC_write; \
	VARIABLE func12_Logbook_STRATEGY; \
	MENU func12_Logbook_STRATEGY_page; \
	COMMAND func12_Logbook_STRATEGY_read; \
	COMMAND func12_Logbook_STRATEGY_write; \
	VARIABLE func12_Logbook_ALERT_KEY; \
	MENU func12_Logbook_ALERT_KEY_page; \
	COMMAND func12_Logbook_ALERT_KEY_read; \
	COMMAND func12_Logbook_ALERT_KEY_write; \
	VARIABLE func12_Logbook_TARGET_MODE; \
	MENU func12_Logbook_TARGET_MODE_page; \
	COMMAND func12_Logbook_TARGET_MODE_read; \
	COMMAND func12_Logbook_TARGET_MODE_write; \
	COLLECTION func12_Logbook_MODE_BLK; \
	VARIABLE func12_Logbook_MODE_BLK_Actual; \
	VARIABLE func12_Logbook_MODE_BLK_Permitted; \
	VARIABLE func12_Logbook_MODE_BLK_Normal; \
	MENU func12_Logbook_MODE_BLK_page; \
	COMMAND func12_Logbook_MODE_BLK_read; \
	COLLECTION func12_Logbook_ALARM_SUM; \
	VARIABLE func12_Logbook_ALARM_SUM_Current; \
	VARIABLE func12_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func12_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func12_Logbook_ALARM_SUM_Disabled; \
	MENU func12_Logbook_ALARM_SUM_page; \
	COMMAND func12_Logbook_ALARM_SUM_read; \
	COLLECTION func12_Logbook_BATCH; \
	VARIABLE func12_Logbook_BATCH_Batch_ID; \
	VARIABLE func12_Logbook_BATCH_Rup; \
	VARIABLE func12_Logbook_BATCH_Operation; \
	VARIABLE func12_Logbook_BATCH_Phase; \
	MENU func12_Logbook_BATCH_page; \
	COMMAND func12_Logbook_BATCH_read; \
	COMMAND func12_Logbook_BATCH_write; \
	VARIABLE func12_Logbook_COMMAND; \
	MENU func12_Logbook_COMMAND_page; \
	COMMAND func12_Logbook_COMMAND_read; \
	COMMAND func12_Logbook_COMMAND_write; \
	VARIABLE func12_Logbook_STATUS; \
	MENU func12_Logbook_STATUS_page; \
	COMMAND func12_Logbook_STATUS_read; \
	VARIABLE func12_Logbook_SIZE_OF_ENTRIES; \
	MENU func12_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func12_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func12_Logbook_NUMBER_OF_ENTRIES; \
	MENU func12_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func12_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func12_Logbook_TURN_NUMBER; \
	MENU func12_Logbook_TURN_NUMBER_page; \
	COMMAND func12_Logbook_TURN_NUMBER_read; \
	COLLECTION func12_Logbook_NEWEST_ENTRY; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func12_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func12_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func12_Logbook_NEWEST_ENTRY_page; \
	COMMAND func12_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func12_Logbook_OLDEST_ENTRY; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func12_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func12_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func12_Logbook_OLDEST_ENTRY_page; \
	COMMAND func12_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func12_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func12_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func12_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func12_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func12_Logbook_POST_READ_ENTRY; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func12_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func12_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func12_Logbook_POST_READ_ENTRY_page; \
	COMMAND func12_Logbook_POST_READ_ENTRY_read

#define USE_FUNC12_LOGBOOK_MANDATORY_A \
	USE_FUNC12_LOGBOOK_MANDATORY_BOTH; \
	MENU func12_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC12_LOGBOOK_MANDATORY_B \
	USE_FUNC12_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func12_Logbook_VIEW_1; \
	MENU func12_Logbook_VIEW_1_page; \
	MENU func12_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC12_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func12_Logbook_VIEW_2; \
	MENU func12_Logbook_VIEW_2_page; \
	COLLECTION func12_Logbook_VIEW_3; \
	MENU func12_Logbook_VIEW_3_page

#define USE_FUNC12_LOGBOOK_OPTIONAL_A \
	USE_FUNC12_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func12_Logbook_VIEW_1; \
	MENU func12_Logbook_VIEW_1_page; \
	MENU func12_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC12_LOGBOOK_OPTIONAL_B \
	USE_FUNC12_LOGBOOK_OPTIONAL_BOTH; \
	MENU func12_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC12_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func12_Logbook_)
#define USE_FUNC12_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func12_Logbook_)
#define USE_FUNC12_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func12_Logbook_)
#define USE_FUNC12_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func12_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC13_LOGBOOK_MANDATORY_BOTH \
	BLOCK func13_Logbook_block; \
	COLLECTION func13_Logbook_BLOCK_OBJECT; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func13_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func13_Logbook_BLOCK_OBJECT_page; \
	COMMAND func13_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func13_Logbook_ST_REV; \
	MENU func13_Logbook_ST_REV_page; \
	COMMAND func13_Logbook_ST_REV_read; \
	VARIABLE func13_Logbook_TAG_DESC; \
	MENU func13_Logbook_TAG_DESC_page; \
	COMMAND func13_Logbook_TAG_DESC_read; \
	COMMAND func13_Logbook_TAG_DESC_write; \
	VARIABLE func13_Logbook_STRATEGY; \
	MENU func13_Logbook_STRATEGY_page; \
	COMMAND func13_Logbook_STRATEGY_read; \
	COMMAND func13_Logbook_STRATEGY_write; \
	VARIABLE func13_Logbook_ALERT_KEY; \
	MENU func13_Logbook_ALERT_KEY_page; \
	COMMAND func13_Logbook_ALERT_KEY_read; \
	COMMAND func13_Logbook_ALERT_KEY_write; \
	VARIABLE func13_Logbook_TARGET_MODE; \
	MENU func13_Logbook_TARGET_MODE_page; \
	COMMAND func13_Logbook_TARGET_MODE_read; \
	COMMAND func13_Logbook_TARGET_MODE_write; \
	COLLECTION func13_Logbook_MODE_BLK; \
	VARIABLE func13_Logbook_MODE_BLK_Actual; \
	VARIABLE func13_Logbook_MODE_BLK_Permitted; \
	VARIABLE func13_Logbook_MODE_BLK_Normal; \
	MENU func13_Logbook_MODE_BLK_page; \
	COMMAND func13_Logbook_MODE_BLK_read; \
	COLLECTION func13_Logbook_ALARM_SUM; \
	VARIABLE func13_Logbook_ALARM_SUM_Current; \
	VARIABLE func13_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func13_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func13_Logbook_ALARM_SUM_Disabled; \
	MENU func13_Logbook_ALARM_SUM_page; \
	COMMAND func13_Logbook_ALARM_SUM_read; \
	COLLECTION func13_Logbook_BATCH; \
	VARIABLE func13_Logbook_BATCH_Batch_ID; \
	VARIABLE func13_Logbook_BATCH_Rup; \
	VARIABLE func13_Logbook_BATCH_Operation; \
	VARIABLE func13_Logbook_BATCH_Phase; \
	MENU func13_Logbook_BATCH_page; \
	COMMAND func13_Logbook_BATCH_read; \
	COMMAND func13_Logbook_BATCH_write; \
	VARIABLE func13_Logbook_COMMAND; \
	MENU func13_Logbook_COMMAND_page; \
	COMMAND func13_Logbook_COMMAND_read; \
	COMMAND func13_Logbook_COMMAND_write; \
	VARIABLE func13_Logbook_STATUS; \
	MENU func13_Logbook_STATUS_page; \
	COMMAND func13_Logbook_STATUS_read; \
	VARIABLE func13_Logbook_SIZE_OF_ENTRIES; \
	MENU func13_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func13_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func13_Logbook_NUMBER_OF_ENTRIES; \
	MENU func13_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func13_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func13_Logbook_TURN_NUMBER; \
	MENU func13_Logbook_TURN_NUMBER_page; \
	COMMAND func13_Logbook_TURN_NUMBER_read; \
	COLLECTION func13_Logbook_NEWEST_ENTRY; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func13_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func13_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func13_Logbook_NEWEST_ENTRY_page; \
	COMMAND func13_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func13_Logbook_OLDEST_ENTRY; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func13_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func13_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func13_Logbook_OLDEST_ENTRY_page; \
	COMMAND func13_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func13_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func13_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func13_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func13_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func13_Logbook_POST_READ_ENTRY; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func13_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func13_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func13_Logbook_POST_READ_ENTRY_page; \
	COMMAND func13_Logbook_POST_READ_ENTRY_read

#define USE_FUNC13_LOGBOOK_MANDATORY_A \
	USE_FUNC13_LOGBOOK_MANDATORY_BOTH; \
	MENU func13_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC13_LOGBOOK_MANDATORY_B \
	USE_FUNC13_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func13_Logbook_VIEW_1; \
	MENU func13_Logbook_VIEW_1_page; \
	MENU func13_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC13_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func13_Logbook_VIEW_2; \
	MENU func13_Logbook_VIEW_2_page; \
	COLLECTION func13_Logbook_VIEW_3; \
	MENU func13_Logbook_VIEW_3_page

#define USE_FUNC13_LOGBOOK_OPTIONAL_A \
	USE_FUNC13_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func13_Logbook_VIEW_1; \
	MENU func13_Logbook_VIEW_1_page; \
	MENU func13_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC13_LOGBOOK_OPTIONAL_B \
	USE_FUNC13_LOGBOOK_OPTIONAL_BOTH; \
	MENU func13_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC13_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func13_Logbook_)
#define USE_FUNC13_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func13_Logbook_)
#define USE_FUNC13_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func13_Logbook_)
#define USE_FUNC13_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func13_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC14_LOGBOOK_MANDATORY_BOTH \
	BLOCK func14_Logbook_block; \
	COLLECTION func14_Logbook_BLOCK_OBJECT; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func14_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func14_Logbook_BLOCK_OBJECT_page; \
	COMMAND func14_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func14_Logbook_ST_REV; \
	MENU func14_Logbook_ST_REV_page; \
	COMMAND func14_Logbook_ST_REV_read; \
	VARIABLE func14_Logbook_TAG_DESC; \
	MENU func14_Logbook_TAG_DESC_page; \
	COMMAND func14_Logbook_TAG_DESC_read; \
	COMMAND func14_Logbook_TAG_DESC_write; \
	VARIABLE func14_Logbook_STRATEGY; \
	MENU func14_Logbook_STRATEGY_page; \
	COMMAND func14_Logbook_STRATEGY_read; \
	COMMAND func14_Logbook_STRATEGY_write; \
	VARIABLE func14_Logbook_ALERT_KEY; \
	MENU func14_Logbook_ALERT_KEY_page; \
	COMMAND func14_Logbook_ALERT_KEY_read; \
	COMMAND func14_Logbook_ALERT_KEY_write; \
	VARIABLE func14_Logbook_TARGET_MODE; \
	MENU func14_Logbook_TARGET_MODE_page; \
	COMMAND func14_Logbook_TARGET_MODE_read; \
	COMMAND func14_Logbook_TARGET_MODE_write; \
	COLLECTION func14_Logbook_MODE_BLK; \
	VARIABLE func14_Logbook_MODE_BLK_Actual; \
	VARIABLE func14_Logbook_MODE_BLK_Permitted; \
	VARIABLE func14_Logbook_MODE_BLK_Normal; \
	MENU func14_Logbook_MODE_BLK_page; \
	COMMAND func14_Logbook_MODE_BLK_read; \
	COLLECTION func14_Logbook_ALARM_SUM; \
	VARIABLE func14_Logbook_ALARM_SUM_Current; \
	VARIABLE func14_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func14_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func14_Logbook_ALARM_SUM_Disabled; \
	MENU func14_Logbook_ALARM_SUM_page; \
	COMMAND func14_Logbook_ALARM_SUM_read; \
	COLLECTION func14_Logbook_BATCH; \
	VARIABLE func14_Logbook_BATCH_Batch_ID; \
	VARIABLE func14_Logbook_BATCH_Rup; \
	VARIABLE func14_Logbook_BATCH_Operation; \
	VARIABLE func14_Logbook_BATCH_Phase; \
	MENU func14_Logbook_BATCH_page; \
	COMMAND func14_Logbook_BATCH_read; \
	COMMAND func14_Logbook_BATCH_write; \
	VARIABLE func14_Logbook_COMMAND; \
	MENU func14_Logbook_COMMAND_page; \
	COMMAND func14_Logbook_COMMAND_read; \
	COMMAND func14_Logbook_COMMAND_write; \
	VARIABLE func14_Logbook_STATUS; \
	MENU func14_Logbook_STATUS_page; \
	COMMAND func14_Logbook_STATUS_read; \
	VARIABLE func14_Logbook_SIZE_OF_ENTRIES; \
	MENU func14_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func14_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func14_Logbook_NUMBER_OF_ENTRIES; \
	MENU func14_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func14_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func14_Logbook_TURN_NUMBER; \
	MENU func14_Logbook_TURN_NUMBER_page; \
	COMMAND func14_Logbook_TURN_NUMBER_read; \
	COLLECTION func14_Logbook_NEWEST_ENTRY; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func14_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func14_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func14_Logbook_NEWEST_ENTRY_page; \
	COMMAND func14_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func14_Logbook_OLDEST_ENTRY; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func14_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func14_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func14_Logbook_OLDEST_ENTRY_page; \
	COMMAND func14_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func14_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func14_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func14_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func14_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func14_Logbook_POST_READ_ENTRY; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func14_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func14_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func14_Logbook_POST_READ_ENTRY_page; \
	COMMAND func14_Logbook_POST_READ_ENTRY_read

#define USE_FUNC14_LOGBOOK_MANDATORY_A \
	USE_FUNC14_LOGBOOK_MANDATORY_BOTH; \
	MENU func14_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC14_LOGBOOK_MANDATORY_B \
	USE_FUNC14_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func14_Logbook_VIEW_1; \
	MENU func14_Logbook_VIEW_1_page; \
	MENU func14_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC14_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func14_Logbook_VIEW_2; \
	MENU func14_Logbook_VIEW_2_page; \
	COLLECTION func14_Logbook_VIEW_3; \
	MENU func14_Logbook_VIEW_3_page

#define USE_FUNC14_LOGBOOK_OPTIONAL_A \
	USE_FUNC14_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func14_Logbook_VIEW_1; \
	MENU func14_Logbook_VIEW_1_page; \
	MENU func14_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC14_LOGBOOK_OPTIONAL_B \
	USE_FUNC14_LOGBOOK_OPTIONAL_BOTH; \
	MENU func14_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC14_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func14_Logbook_)
#define USE_FUNC14_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func14_Logbook_)
#define USE_FUNC14_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func14_Logbook_)
#define USE_FUNC14_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func14_Logbook_)

#endif /* CPP_CANT_CONCAT */

#ifdef CPP_CANT_CONCAT

#define USE_FUNC15_LOGBOOK_MANDATORY_BOTH \
	BLOCK func15_Logbook_block; \
	COLLECTION func15_Logbook_BLOCK_OBJECT; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Reserved; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Block_Object; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Parent_Class; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Class; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Dev_Rev; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Dev_Rev_Comp; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_DD_Revision; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Profile; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Profile_Revision; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Execution_Time; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Number_of_Parameters; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Slot; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Address_of_VIEW_1_Index; \
	VARIABLE func15_Logbook_BLOCK_OBJECT_Number_of_Views; \
	MENU func15_Logbook_BLOCK_OBJECT_page; \
	COMMAND func15_Logbook_BLOCK_OBJECT_read; \
	VARIABLE func15_Logbook_ST_REV; \
	MENU func15_Logbook_ST_REV_page; \
	COMMAND func15_Logbook_ST_REV_read; \
	VARIABLE func15_Logbook_TAG_DESC; \
	MENU func15_Logbook_TAG_DESC_page; \
	COMMAND func15_Logbook_TAG_DESC_read; \
	COMMAND func15_Logbook_TAG_DESC_write; \
	VARIABLE func15_Logbook_STRATEGY; \
	MENU func15_Logbook_STRATEGY_page; \
	COMMAND func15_Logbook_STRATEGY_read; \
	COMMAND func15_Logbook_STRATEGY_write; \
	VARIABLE func15_Logbook_ALERT_KEY; \
	MENU func15_Logbook_ALERT_KEY_page; \
	COMMAND func15_Logbook_ALERT_KEY_read; \
	COMMAND func15_Logbook_ALERT_KEY_write; \
	VARIABLE func15_Logbook_TARGET_MODE; \
	MENU func15_Logbook_TARGET_MODE_page; \
	COMMAND func15_Logbook_TARGET_MODE_read; \
	COMMAND func15_Logbook_TARGET_MODE_write; \
	COLLECTION func15_Logbook_MODE_BLK; \
	VARIABLE func15_Logbook_MODE_BLK_Actual; \
	VARIABLE func15_Logbook_MODE_BLK_Permitted; \
	VARIABLE func15_Logbook_MODE_BLK_Normal; \
	MENU func15_Logbook_MODE_BLK_page; \
	COMMAND func15_Logbook_MODE_BLK_read; \
	COLLECTION func15_Logbook_ALARM_SUM; \
	VARIABLE func15_Logbook_ALARM_SUM_Current; \
	VARIABLE func15_Logbook_ALARM_SUM_Unacknowledged; \
	VARIABLE func15_Logbook_ALARM_SUM_Unreported; \
	VARIABLE func15_Logbook_ALARM_SUM_Disabled; \
	MENU func15_Logbook_ALARM_SUM_page; \
	COMMAND func15_Logbook_ALARM_SUM_read; \
	COLLECTION func15_Logbook_BATCH; \
	VARIABLE func15_Logbook_BATCH_Batch_ID; \
	VARIABLE func15_Logbook_BATCH_Rup; \
	VARIABLE func15_Logbook_BATCH_Operation; \
	VARIABLE func15_Logbook_BATCH_Phase; \
	MENU func15_Logbook_BATCH_page; \
	COMMAND func15_Logbook_BATCH_read; \
	COMMAND func15_Logbook_BATCH_write; \
	VARIABLE func15_Logbook_COMMAND; \
	MENU func15_Logbook_COMMAND_page; \
	COMMAND func15_Logbook_COMMAND_read; \
	COMMAND func15_Logbook_COMMAND_write; \
	VARIABLE func15_Logbook_STATUS; \
	MENU func15_Logbook_STATUS_page; \
	COMMAND func15_Logbook_STATUS_read; \
	VARIABLE func15_Logbook_SIZE_OF_ENTRIES; \
	MENU func15_Logbook_SIZE_OF_ENTRIES_page; \
	COMMAND func15_Logbook_SIZE_OF_ENTRIES_read; \
	VARIABLE func15_Logbook_NUMBER_OF_ENTRIES; \
	MENU func15_Logbook_NUMBER_OF_ENTRIES_page; \
	COMMAND func15_Logbook_NUMBER_OF_ENTRIES_read; \
	VARIABLE func15_Logbook_TURN_NUMBER; \
	MENU func15_Logbook_TURN_NUMBER_page; \
	COMMAND func15_Logbook_TURN_NUMBER_read; \
	COLLECTION func15_Logbook_NEWEST_ENTRY; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Type; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Value; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Active; \
	COLLECTION func15_Logbook_NEWEST_ENTRY_Time; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Time_Milliseconds; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Time_Minutes; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Time_Hours; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Time_Month; \
	VARIABLE func15_Logbook_NEWEST_ENTRY_Time_Years; \
	MENU func15_Logbook_NEWEST_ENTRY_page; \
	COMMAND func15_Logbook_NEWEST_ENTRY_read; \
	COLLECTION func15_Logbook_OLDEST_ENTRY; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Type; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Value; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Active; \
	COLLECTION func15_Logbook_OLDEST_ENTRY_Time; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Time_Milliseconds; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Time_Minutes; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Time_Hours; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Time_Month; \
	VARIABLE func15_Logbook_OLDEST_ENTRY_Time_Years; \
	MENU func15_Logbook_OLDEST_ENTRY_page; \
	COMMAND func15_Logbook_OLDEST_ENTRY_read; \
	VARIABLE func15_Logbook_ACTUAL_POST_READ_NUMBER; \
	MENU func15_Logbook_ACTUAL_POST_READ_NUMBER_page; \
	COMMAND func15_Logbook_ACTUAL_POST_READ_NUMBER_read; \
	COMMAND func15_Logbook_ACTUAL_POST_READ_NUMBER_write; \
	COLLECTION func15_Logbook_POST_READ_ENTRY; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Type; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Value; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Active; \
	COLLECTION func15_Logbook_POST_READ_ENTRY_Time; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Time_Milliseconds; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Time_Minutes; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Time_Hours; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Time_Day_of_Week_and_Month; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Time_Month; \
	VARIABLE func15_Logbook_POST_READ_ENTRY_Time_Years; \
	MENU func15_Logbook_POST_READ_ENTRY_page; \
	COMMAND func15_Logbook_POST_READ_ENTRY_read

#define USE_FUNC15_LOGBOOK_MANDATORY_A \
	USE_FUNC15_LOGBOOK_MANDATORY_BOTH; \
	MENU func15_Logbook_Simple_Dialog_Mandatory_A

#define USE_FUNC15_LOGBOOK_MANDATORY_B \
	USE_FUNC15_LOGBOOK_MANDATORY_BOTH; \
	COLLECTION func15_Logbook_VIEW_1; \
	MENU func15_Logbook_VIEW_1_page; \
	MENU func15_Logbook_Simple_Dialog_Mandatory_B

#define USE_FUNC15_LOGBOOK_OPTIONAL_BOTH \
	COLLECTION func15_Logbook_VIEW_2; \
	MENU func15_Logbook_VIEW_2_page; \
	COLLECTION func15_Logbook_VIEW_3; \
	MENU func15_Logbook_VIEW_3_page

#define USE_FUNC15_LOGBOOK_OPTIONAL_A \
	USE_FUNC15_LOGBOOK_OPTIONAL_BOTH; \
	COLLECTION func15_Logbook_VIEW_1; \
	MENU func15_Logbook_VIEW_1_page; \
	MENU func15_Logbook_Simple_Dialog_Optional_A

#define USE_FUNC15_LOGBOOK_OPTIONAL_B \
	USE_FUNC15_LOGBOOK_OPTIONAL_BOTH; \
	MENU func15_Logbook_Simple_Dialog_Optional_B

#else /* CPP_CANT_CONCAT */

#define USE_FUNC15_LOGBOOK_MANDATORY_A USE_FUNC_LOGBOOK_MANDATORY_A(func15_Logbook_)
#define USE_FUNC15_LOGBOOK_MANDATORY_B USE_FUNC_LOGBOOK_MANDATORY_B(func15_Logbook_)
#define USE_FUNC15_LOGBOOK_OPTIONAL_A  USE_FUNC_LOGBOOK_OPTIONAL_A(func15_Logbook_)
#define USE_FUNC15_LOGBOOK_OPTIONAL_B  USE_FUNC_LOGBOOK_OPTIONAL_B(func15_Logbook_)

#endif /* CPP_CANT_CONCAT */

#endif /* __PA_IMPORT_0302_H */
